@@ -1,5 +1,5 @@
 ;; Liquid War 6 is a unique multiplayer wargame.
-;; Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+;; Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 ;;
 ;; This program is free software; you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published by
@@ -143,6 +143,8 @@
 (define lw6-test-sys-bazooka
   (lambda ()
     (begin
+      (lw6-log-notice (format #f "bazooka-size=~a"
+			      (c-lw6sys-get-memory-bazooka-size)))
       ;; double bazooka size
       (c-lw6sys-set-memory-bazooka-size
        (* 2 (c-lw6sys-get-memory-bazooka-size)))
@@ -182,6 +184,18 @@
 	#t
 	))))
 
+(define lw6-test-sys-log-backtrace-mode
+  (lambda ()
+    (let (
+	  (log-backtrace-mode #f)
+	  )
+      (begin
+	(set! log-backtrace-mode (c-lw6sys-log-get-backtrace-mode))
+	(lw6-log-notice (format #f "log-backtrace-mode=~a" log-backtrace-mode))
+	(c-lw6sys-log-set-backtrace-mode log-backtrace-mode)
+	#t
+	))))
+
 (define lw6-test-sys-dump
   (lambda ()
     (begin
@@ -650,6 +664,7 @@
 		(lw6-test-run lw6-test-sys-bazooka)
 		(lw6-test-run lw6-test-sys-debug)
 		(lw6-test-run lw6-test-sys-log-level)
+		(lw6-test-run lw6-test-sys-log-backtrace-mode)
 		(lw6-test-run lw6-test-sys-dump)
 		(lw6-test-run lw6-test-sys-env)
 		(lw6-test-run lw6-test-sys-hardware)
