@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -37,6 +37,7 @@
 /**
  * lw6bot_get_backends
  *
+ * @sys_context: global system context
  * @argc: argc, as passed to @main
  * @argv: argv, as passed to @main
  *
@@ -50,47 +51,43 @@
  * Return value: hash containing id/name pairs.
  */
 lw6sys_assoc_t *
-lw6bot_get_backends (int argc, const char *argv[])
+lw6bot_get_backends (lw6sys_context_t * sys_context, int argc, const char *argv[])
 {
   lw6sys_assoc_t *ret = NULL;
 
 #ifdef LW6_ALLINONE
   lw6sys_module_pedigree_t *module_pedigree = NULL;
 
-  ret = lw6sys_assoc_new (lw6sys_free_callback);
+  ret = lw6sys_assoc_new (sys_context, lw6sys_free_callback);
   if (ret)
     {
-      module_pedigree = mod_brute_get_pedigree ();
+      module_pedigree = mod_brute_get_pedigree (sys_context);
       if (module_pedigree)
 	{
-	  lw6sys_assoc_set (&ret, module_pedigree->id,
-			    lw6sys_str_copy (module_pedigree->name));
-	  LW6SYS_FREE (module_pedigree);
+	  lw6sys_assoc_set (sys_context, &ret, module_pedigree->id, lw6sys_str_copy (sys_context, module_pedigree->name));
+	  LW6SYS_FREE (sys_context, module_pedigree);
 	}
-      module_pedigree = mod_follow_get_pedigree ();
+      module_pedigree = mod_follow_get_pedigree (sys_context);
       if (module_pedigree)
 	{
-	  lw6sys_assoc_set (&ret, module_pedigree->id,
-			    lw6sys_str_copy (module_pedigree->name));
-	  LW6SYS_FREE (module_pedigree);
+	  lw6sys_assoc_set (sys_context, &ret, module_pedigree->id, lw6sys_str_copy (sys_context, module_pedigree->name));
+	  LW6SYS_FREE (sys_context, module_pedigree);
 	}
-      module_pedigree = mod_idiot_get_pedigree ();
+      module_pedigree = mod_idiot_get_pedigree (sys_context);
       if (module_pedigree)
 	{
-	  lw6sys_assoc_set (&ret, module_pedigree->id,
-			    lw6sys_str_copy (module_pedigree->name));
-	  LW6SYS_FREE (module_pedigree);
+	  lw6sys_assoc_set (sys_context, &ret, module_pedigree->id, lw6sys_str_copy (sys_context, module_pedigree->name));
+	  LW6SYS_FREE (sys_context, module_pedigree);
 	}
-      module_pedigree = mod_random_get_pedigree ();
+      module_pedigree = mod_random_get_pedigree (sys_context);
       if (module_pedigree)
 	{
-	  lw6sys_assoc_set (&ret, module_pedigree->id,
-			    lw6sys_str_copy (module_pedigree->name));
-	  LW6SYS_FREE (module_pedigree);
+	  lw6sys_assoc_set (sys_context, &ret, module_pedigree->id, lw6sys_str_copy (sys_context, module_pedigree->name));
+	  LW6SYS_FREE (sys_context, module_pedigree);
 	}
     }
 #else
-  ret = lw6dyn_list_backends (argc, argv, "bot");
+  ret = lw6dyn_list_backends (sys_context, argc, argv, "bot");
 #endif
 
   return ret;
@@ -99,6 +96,7 @@ lw6bot_get_backends (int argc, const char *argv[])
 /**
  * lw6bot_create_backend
  *
+ * @sys_context: global system context
  * @argc: argc, as passed to @main
  * @argv: argv, as passed to @main
  * @name: string containing bot key, typically got from @lw6bot_get_backends
@@ -110,25 +108,25 @@ lw6bot_get_backends (int argc, const char *argv[])
  * Return value: bot backend.
  */
 lw6bot_backend_t *
-lw6bot_create_backend (int argc, const char *argv[], const char *name)
+lw6bot_create_backend (lw6sys_context_t * sys_context, int argc, const char *argv[], const char *name)
 {
   lw6bot_backend_t *backend = NULL;
 #ifdef LW6_ALLINONE
   if (name && !strcmp (name, "brute"))
     {
-      backend = mod_brute_create_backend ();
+      backend = mod_brute_create_backend (sys_context);
     }
   if (name && !strcmp (name, "follow"))
     {
-      backend = mod_follow_create_backend ();
+      backend = mod_follow_create_backend (sys_context);
     }
   if (name && !strcmp (name, "idiot"))
     {
-      backend = mod_idiot_create_backend ();
+      backend = mod_idiot_create_backend (sys_context);
     }
   if (name && !strcmp (name, "random"))
     {
-      backend = mod_random_create_backend ();
+      backend = mod_random_create_backend (sys_context);
     }
 
   if (backend)
@@ -138,37 +136,32 @@ lw6bot_create_backend (int argc, const char *argv[], const char *name)
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING,
-		  _x_ ("bot backend \"%s\" does not exist"), name);
+      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("bot backend \"%s\" does not exist"), name);
     }
 #else
   lw6dyn_dl_handle_t *backend_handle = NULL;
 
-  backend_handle = lw6dyn_dlopen_backend (argc, argv, "bot", name);
+  backend_handle = lw6dyn_dlopen_backend (sys_context, argc, argv, "bot", name);
 
   if (backend_handle)
     {
       char *init_func_name;
-      lw6bot_backend_t *(*init_func) ();
+      lw6bot_backend_t *(*init_func) (lw6sys_context_t * sys_context);
 
-      init_func_name =
-	lw6sys_new_sprintf (LW6DYN_CREATE_BACKEND_FUNC_FORMAT, name);
+      init_func_name = lw6sys_new_sprintf (sys_context, LW6DYN_CREATE_BACKEND_FUNC_FORMAT, name);
       if (init_func_name)
 	{
-	  init_func = lw6dyn_dlsym (backend_handle, init_func_name);
+	  init_func = lw6dyn_dlsym (sys_context, backend_handle, init_func_name);
 	  if (init_func)
 	    {
-	      backend = init_func ();
+	      backend = init_func (sys_context);
 	    }
 	  else
 	    {
-	      lw6sys_log (LW6SYS_LOG_WARNING,
-			  _x_
-			  ("unable to find function \"%s\" in server backend \"%s\""),
-			  init_func_name, name);
+	      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("unable to find function \"%s\" in server backend \"%s\""), init_func_name, name);
 	    }
 
-	  LW6SYS_FREE (init_func_name);
+	  LW6SYS_FREE (sys_context, init_func_name);
 	}
     }
 
@@ -180,8 +173,7 @@ lw6bot_create_backend (int argc, const char *argv[], const char *name)
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING,
-		  _x_ ("unable to open server backend \"%s\""), name);
+      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("unable to open server backend \"%s\""), name);
     }
 #endif
 
@@ -202,6 +194,7 @@ lw6bot_create_backend (int argc, const char *argv[], const char *name)
 /**
  * lw6bot_destroy_backend
  *
+ * @sys_context: global system context
  * @backend: bot backend to destroy
  *
  * Frees the ressources associated to a bot, which must have been
@@ -210,10 +203,10 @@ lw6bot_create_backend (int argc, const char *argv[], const char *name)
  * Return value: none.
  */
 void
-lw6bot_destroy_backend (lw6bot_backend_t * backend)
+lw6bot_destroy_backend (lw6sys_context_t * sys_context, lw6bot_backend_t * backend)
 {
 #ifndef LW6_ALLINONE
-  lw6dyn_dlclose_backend (backend->dl_handle);
+  lw6dyn_dlclose_backend (sys_context, backend->dl_handle);
 #endif
-  LW6SYS_FREE (backend);
+  LW6SYS_FREE (sys_context, backend);
 }
