@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -28,24 +28,22 @@
 #include "mod-brute-internal.h"
 
 _mod_brute_context_t *
-_mod_brute_init (int argc, const char *argv[], lw6bot_data_t * data)
+_mod_brute_init (lw6sys_context_t * sys_context, int argc, const char *argv[], lw6bot_data_t * data)
 {
   _mod_brute_context_t *brute_context = NULL;
   float iq_divided = 0.0f;
 
-  lw6sys_log (LW6SYS_LOG_INFO, _x_ ("brute init"));
+  lw6sys_log (sys_context, LW6SYS_LOG_INFO, _x_ ("brute init"));
 
-  brute_context =
-    (_mod_brute_context_t *) LW6SYS_CALLOC (sizeof (_mod_brute_context_t));
+  brute_context = (_mod_brute_context_t *) LW6SYS_CALLOC (sys_context, sizeof (_mod_brute_context_t));
   if (brute_context)
     {
       iq_divided = data->param.iq / _MOD_BRUTE_IQ_DIVISOR;
       brute_context->nb_rounds_to_anticipate = 1 + iq_divided * iq_divided;
-      brute_context->game_sandbox =
-	lw6ker_game_state_dup (data->game_state, NULL);
+      brute_context->game_sandbox = lw6ker_game_state_dup (sys_context, data->game_state, NULL);
       if (!brute_context->game_sandbox)
 	{
-	  _mod_brute_quit (brute_context);
+	  _mod_brute_quit (sys_context, brute_context);
 	  brute_context = NULL;
 	}
     }
@@ -54,13 +52,13 @@ _mod_brute_init (int argc, const char *argv[], lw6bot_data_t * data)
 }
 
 void
-_mod_brute_quit (_mod_brute_context_t * brute_context)
+_mod_brute_quit (lw6sys_context_t * sys_context, _mod_brute_context_t * brute_context)
 {
-  lw6sys_log (LW6SYS_LOG_INFO, _x_ ("brute quit"));
+  lw6sys_log (sys_context, LW6SYS_LOG_INFO, _x_ ("brute quit"));
   if (brute_context->game_sandbox)
     {
-      lw6ker_game_state_free (brute_context->game_sandbox);
+      lw6ker_game_state_free (sys_context, brute_context->game_sandbox);
       brute_context->game_sandbox = NULL;
     }
-  LW6SYS_FREE (brute_context);
+  LW6SYS_FREE (sys_context, brute_context);
 }
