@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -28,14 +28,13 @@
 #include "mod-follow-internal.h"
 
 _mod_follow_context_t *
-_mod_follow_init (int argc, const char *argv[], lw6bot_data_t * data)
+_mod_follow_init (lw6sys_context_t * sys_context, int argc, const char *argv[], lw6bot_data_t * data)
 {
   _mod_follow_context_t *follow_context = NULL;
 
-  lw6sys_log (LW6SYS_LOG_INFO, _x_ ("follow init"));
+  lw6sys_log (sys_context, LW6SYS_LOG_INFO, _x_ ("follow init"));
 
-  follow_context =
-    (_mod_follow_context_t *) LW6SYS_CALLOC (sizeof (_mod_follow_context_t));
+  follow_context = (_mod_follow_context_t *) LW6SYS_CALLOC (sys_context, sizeof (_mod_follow_context_t));
   if (follow_context)
     {
       // nothing to do, everything zeroed is fine
@@ -45,8 +44,8 @@ _mod_follow_init (int argc, const char *argv[], lw6bot_data_t * data)
 }
 
 void
-_mod_follow_quit (_mod_follow_context_t * follow_context)
+_mod_follow_quit (lw6sys_context_t * sys_context, _mod_follow_context_t * follow_context)
 {
-  lw6sys_log (LW6SYS_LOG_INFO, _x_ ("follow quit"));
-  LW6SYS_FREE (follow_context);
+  lw6sys_log (sys_context, LW6SYS_LOG_INFO, _x_ ("follow quit"));
+  LW6SYS_FREE (sys_context, follow_context);
 }
