@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -28,14 +28,13 @@
 #include "mod-idiot-internal.h"
 
 _mod_idiot_context_t *
-_mod_idiot_init (int argc, const char *argv[], lw6bot_data_t * data)
+_mod_idiot_init (lw6sys_context_t * sys_context, int argc, const char *argv[], lw6bot_data_t * data)
 {
   _mod_idiot_context_t *idiot_context = NULL;
 
-  lw6sys_log (LW6SYS_LOG_INFO, _x_ ("idiot init"));
+  lw6sys_log (sys_context, LW6SYS_LOG_INFO, _x_ ("idiot init"));
 
-  idiot_context =
-    (_mod_idiot_context_t *) LW6SYS_CALLOC (sizeof (_mod_idiot_context_t));
+  idiot_context = (_mod_idiot_context_t *) LW6SYS_CALLOC (sys_context, sizeof (_mod_idiot_context_t));
   if (idiot_context)
     {
       idiot_context->last_move_round = -1;
@@ -49,8 +48,8 @@ _mod_idiot_init (int argc, const char *argv[], lw6bot_data_t * data)
 }
 
 void
-_mod_idiot_quit (_mod_idiot_context_t * idiot_context)
+_mod_idiot_quit (lw6sys_context_t * sys_context, _mod_idiot_context_t * idiot_context)
 {
-  lw6sys_log (LW6SYS_LOG_INFO, _x_ ("idiot quit"));
-  LW6SYS_FREE (idiot_context);
+  lw6sys_log (sys_context, LW6SYS_LOG_INFO, _x_ ("idiot quit"));
+  LW6SYS_FREE (sys_context, idiot_context);
 }
