@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -30,7 +30,7 @@
 #include "cfg-internal.h"
 
 static int
-must_be_stored (char *key)
+_must_be_stored (lw6sys_context_t * sys_context, char *key)
 {
   int ret = 1;
 
@@ -49,7 +49,7 @@ must_be_stored (char *key)
 }
 
 static void
-merge_func (void *func_data, void *data)
+_merge_func (lw6sys_context_t * sys_context, void *func_data, void *data)
 {
   _lw6cfg_context_t *cfg_context = (_lw6cfg_context_t *) func_data;
   char *keyword = (char *) data;
@@ -57,49 +57,44 @@ merge_func (void *func_data, void *data)
   char *value_converted = NULL;
   char *env = NULL;
 
-  if (must_be_stored (keyword) && strlen (keyword) > 0
-      && lw6sys_env_exists_prefixed (keyword))
+  if (_must_be_stored (sys_context, keyword) && strlen (keyword) > 0 && lw6sys_env_exists_prefixed (sys_context, keyword))
     {
-      value = lw6sys_getenv_prefixed (keyword);
+      value = lw6sys_getenv_prefixed (sys_context, keyword);
       if (value)
 	{
-	  value_converted = lw6cfg_format_guess_type (keyword, value);
+	  value_converted = lw6cfg_format_guess_type (sys_context, keyword, value);
 	  if (value_converted)
 	    {
-	      env = lw6sys_keyword_as_env (keyword);
+	      env = lw6sys_keyword_as_env (sys_context, keyword);
 	      if (env)
 		{
-		  lw6sys_log (LW6SYS_LOG_INFO,
-			      _x_
-			      ("key \"%s\" set to \"%s\" by environment variable \"%s\""),
-			      keyword, value_converted, env);
-		  LW6SYS_FREE (env);
+		  lw6sys_log (sys_context, LW6SYS_LOG_INFO, _x_ ("key \"%s\" set to \"%s\" by environment variable \"%s\""), keyword, value_converted, env);
+		  LW6SYS_FREE (sys_context, env);
 		}
-	      if (lw6sys_spinlock_lock (cfg_context->spinlock))
+	      if (lw6sys_spinlock_lock (sys_context, cfg_context->spinlock))
 		{
-		  lw6sys_hash_set (cfg_context->options, keyword,
-				   value_converted);
+		  lw6sys_hash_set (sys_context, cfg_context->options, keyword, value_converted);
 		  // no need to free value_converted now
-		  lw6sys_spinlock_unlock (cfg_context->spinlock);
+		  lw6sys_spinlock_unlock (sys_context, cfg_context->spinlock);
 		}
 	    }
-	  LW6SYS_FREE (value);
+	  LW6SYS_FREE (sys_context, value);
 	}
     }
 }
 
 int
-_lw6cfg_merge_env (_lw6cfg_context_t * cfg_context)
+_lw6cfg_merge_env (lw6sys_context_t * sys_context, _lw6cfg_context_t * cfg_context)
 {
   int ret = 0;
   lw6sys_list_t *keywords;
 
-  lw6sys_log (LW6SYS_LOG_INFO, _x_ ("merging environment variables"));
-  keywords = lw6hlp_list ();
+  lw6sys_log (sys_context, LW6SYS_LOG_INFO, _x_ ("merging environment variables"));
+  keywords = lw6hlp_list (sys_context);
   if (keywords)
     {
-      lw6sys_list_map (keywords, &merge_func, (void *) cfg_context);
-      lw6sys_list_free (keywords);
+      lw6sys_list_map (sys_context, keywords, _merge_func, (void *) cfg_context);
+      lw6sys_list_free (sys_context, keywords);
     }
 
   return ret;
@@ -108,6 +103,7 @@ _lw6cfg_merge_env (_lw6cfg_context_t * cfg_context)
 /**
  * lw6cfg_merge_env
  *
+ * @sys_context: global system context
  * @cfg_context: a context returned by @lw6cfg_init
  *
  * Overwrites any existing vale in the config with environment
@@ -116,7 +112,7 @@ _lw6cfg_merge_env (_lw6cfg_context_t * cfg_context)
  * Return value: 1 if successfull, 0 if error.
  */
 int
-lw6cfg_merge_env (void *cfg_context)
+lw6cfg_merge_env (lw6sys_context_t * sys_context, void *cfg_context)
 {
-  return _lw6cfg_merge_env ((_lw6cfg_context_t *) cfg_context);
+  return _lw6cfg_merge_env (sys_context, (_lw6cfg_context_t *) cfg_context);
 }
