@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -30,6 +30,7 @@
 /**
  * lw6cfg_format
  *
+ * @sys_context: global system context
  * @key: the key of the value to format
  * @value: the value to format
  * @type: the type of the value to format
@@ -43,7 +44,7 @@
  * input, but reformatted the pedantic way.
  */
 char *
-lw6cfg_format (const char *key, const char *value, lw6hlp_type_t type)
+lw6cfg_format (lw6sys_context_t * sys_context, const char *key, const char *value, lw6hlp_type_t type)
 {
   char *ret = NULL;
 
@@ -52,19 +53,19 @@ lw6cfg_format (const char *key, const char *value, lw6hlp_type_t type)
       switch (type)
 	{
 	case LW6HLP_TYPE_INT:
-	  ret = lw6sys_itoa (lw6sys_atoi (value));
+	  ret = lw6sys_itoa (sys_context, lw6sys_atoi (sys_context, value));
 	  break;
 	case LW6HLP_TYPE_FLOAT:
-	  ret = lw6sys_ftoa (lw6sys_atof (value));
+	  ret = lw6sys_ftoa (sys_context, lw6sys_atof (sys_context, value));
 	  break;
 	case LW6HLP_TYPE_BOOL:
-	  ret = lw6sys_btoa (lw6sys_atob (value));
+	  ret = lw6sys_btoa (sys_context, lw6sys_atob (sys_context, value));
 	  break;
 	case LW6HLP_TYPE_COLOR:
-	  ret = lw6sys_color_8_to_a (lw6sys_color_a_to_8 (value));
+	  ret = lw6sys_color_8_to_a (sys_context, lw6sys_color_a_to_8 (sys_context, value));
 	  break;
 	default:
-	  ret = lw6sys_str_copy (value);
+	  ret = lw6sys_str_copy (sys_context, value);
 	  break;
 	}
     }
@@ -75,6 +76,7 @@ lw6cfg_format (const char *key, const char *value, lw6hlp_type_t type)
 /**
  * lw6cfg_format_guess_type
  *
+ * @sys_context: global system context
  * @key: the key of the value to format
  * @value: the value to format
  *
@@ -88,13 +90,13 @@ lw6cfg_format (const char *key, const char *value, lw6hlp_type_t type)
  * input, but reformatted the pedantic way.
  */
 char *
-lw6cfg_format_guess_type (const char *key, const char *value)
+lw6cfg_format_guess_type (lw6sys_context_t * sys_context, const char *key, const char *value)
 {
   char *ret = NULL;
   lw6hlp_type_t type;
 
-  type = lw6hlp_get_type (key);
-  ret = lw6cfg_format (key, value, type);
+  type = lw6hlp_get_type (sys_context, key);
+  ret = lw6cfg_format (sys_context, key, value, type);
 
   return ret;
 }
