@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -29,6 +29,7 @@
 /**
  * lw6cli_oob_new
  *
+ * @sys_context: global system context
  * @public_url: the address of the distant server to test
  * @verify_callback_func: a function which will be called when a node has been verified
  * @verify_callback_data: additionnal data passed to the callback func
@@ -42,18 +43,16 @@
  * Return value: new object
  */
 lw6cli_oob_t *
-lw6cli_oob_new (const char *public_url,
-		lw6cli_verify_callback_func_t verify_callback_func,
-		void *verify_callback_data)
+lw6cli_oob_new (lw6sys_context_t * sys_context, const char *public_url, lw6cli_verify_callback_func_t verify_callback_func, void *verify_callback_data)
 {
   lw6cli_oob_t *oob = NULL;
 
-  oob = (lw6cli_oob_t *) LW6SYS_CALLOC (sizeof (lw6cli_oob_t));
+  oob = (lw6cli_oob_t *) LW6SYS_CALLOC (sys_context, sizeof (lw6cli_oob_t));
   if (oob)
     {
-      oob->data.creation_timestamp = lw6sys_get_timestamp ();
+      oob->data.creation_timestamp = lw6sys_get_timestamp (sys_context);
       oob->data.do_not_finish = 0;
-      oob->data.public_url = lw6sys_url_canonize (public_url);
+      oob->data.public_url = lw6sys_url_canonize (sys_context, public_url);
       oob->data.verify_callback_func = verify_callback_func;
       oob->data.verify_callback_data = verify_callback_data;
     }
@@ -62,7 +61,7 @@ lw6cli_oob_new (const char *public_url,
     {
       if (!oob->data.public_url)
 	{
-	  lw6cli_oob_free (oob);
+	  lw6cli_oob_free (sys_context, oob);
 	  oob = NULL;
 	}
     }
@@ -73,6 +72,7 @@ lw6cli_oob_new (const char *public_url,
 /**
  * lw6cli_oob_free
  *
+ * @sys_context: global system context
  * @oob: the object to free
  *
  * Frees an OOB structure.
@@ -80,7 +80,7 @@ lw6cli_oob_new (const char *public_url,
  * Return value: none
  */
 void
-lw6cli_oob_free (lw6cli_oob_t * oob)
+lw6cli_oob_free (lw6sys_context_t * sys_context, lw6cli_oob_t * oob)
 {
   if (oob)
     {
@@ -95,40 +95,33 @@ lw6cli_oob_free (lw6cli_oob_t * oob)
 	  oob->data.do_not_finish = 1;
 	  if (oob->data.public_url)
 	    {
-	      lw6sys_log (LW6SYS_LOG_INFO,
-			  _x_
-			  ("joining cli OOB thread connecting on \"%s\" this might take some time..."),
-			  oob->data.public_url);
+	      lw6sys_log (sys_context, LW6SYS_LOG_INFO,
+			  _x_ ("joining cli OOB thread connecting on \"%s\" this might take some time..."), oob->data.public_url);
 	    }
 	  else
 	    {
-	      lw6sys_log (LW6SYS_LOG_INFO,
-			  _x_
-			  ("joining cli OOB thread, this might take some time..."));
+	      lw6sys_log (sys_context, LW6SYS_LOG_INFO, _x_ ("joining cli OOB thread, this might take some time..."));
 	    }
-	  lw6sys_thread_join (oob->thread);
+	  lw6sys_thread_join (sys_context, oob->thread);
 	  if (oob->data.public_url)
 	    {
-	      lw6sys_log (LW6SYS_LOG_INFO,
-			  _x_
-			  ("joined cli OOB thread connecting on \"%s\""),
-			  oob->data.public_url);
+	      lw6sys_log (sys_context, LW6SYS_LOG_INFO, _x_ ("joined cli OOB thread connecting on \"%s\""), oob->data.public_url);
 	    }
 	  else
 	    {
-	      lw6sys_log (LW6SYS_LOG_INFO, _x_ ("joined cli OOB thread"));
+	      lw6sys_log (sys_context, LW6SYS_LOG_INFO, _x_ ("joined cli OOB thread"));
 	    }
 	}
 
       if (oob->data.public_url)
 	{
-	  LW6SYS_FREE (oob->data.public_url);
+	  LW6SYS_FREE (sys_context, oob->data.public_url);
 	}
-      LW6SYS_FREE (oob);
-      lw6sys_log (LW6SYS_LOG_DEBUG, _x_ ("oob freed"));
+      LW6SYS_FREE (sys_context, oob);
+      lw6sys_log (sys_context, LW6SYS_LOG_DEBUG, _x_ ("oob freed"));
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("trying to free NULL oob"));
+      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("trying to free NULL oob"));
     }
 }
