@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -32,27 +32,28 @@ int
 main (int argc, const char *argv[])
 {
   int ret = 0;
+  lw6sys_context_t *sys_context = NULL;
   int mode = 0;
 
-  LW6SYS_MAIN_BEGIN;
-  LW6HLP_MAIN_BEGIN;
+  LW6SYS_MAIN_BEGIN (sys_context);
+  LW6HLP_MAIN_BEGIN (sys_context);
 
-  lw6sys_log_clear (NULL);
-  mode = lw6sys_arg_test_mode (argc, argv);
+  lw6sys_log_clear (sys_context, NULL);
+  mode = lw6sys_arg_test_mode (sys_context, argc, argv);
 
   if (CU_initialize_registry () == CUE_SUCCESS)
     {
-      if (lw6cli_test_register (mode))
+      if (lw6cli_test_register (sys_context, mode))
 	{
-	  ret = lw6cli_test_run (mode);
+	  ret = lw6cli_test_run (sys_context, mode);
 	}
       CU_cleanup_registry ();
     }
 
   LW6SYS_TEST_OUTPUT;
 
-  LW6HLP_MAIN_END;
-  LW6SYS_MAIN_END;
+  LW6HLP_MAIN_END (sys_context);
+  LW6SYS_MAIN_END (sys_context);
 
   return (!ret);
 }
