@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -34,9 +34,7 @@
 
 #define LW6CLI_CONTENT_BUFFER_SIZE LW6NET_PPPOE_MTU
 
-typedef int (*lw6cli_verify_callback_func_t) (void *func_data,
-					      const char *url, const char *ip,
-					      int port, int ping_delay_msec,
+typedef int (*lw6cli_verify_callback_func_t) (lw6sys_context_t * sys_context, void *func_data, const char *url, const char *ip, int port, int ping_delay_msec,
 					      lw6sys_assoc_t * assoc);
 
 /**
@@ -124,91 +122,61 @@ typedef struct lw6cli_backend_s
   lw6cnx_properties_t properties;
 
   /// Pointer on lw6cli_init callback code.
-  void *(*init) (int argc, const char *argv[],
-		 lw6cnx_properties_t * properties);
+  void *(*init) (lw6sys_context_t * sys_context, int argc, const char *argv[], lw6cnx_properties_t * properties);
   /// Pointer on lw6cli_quit callback code.
-  void (*quit) (void *cli_context);
+  void (*quit) (lw6sys_context_t * sys_context, void *cli_context);
   /// Pointer on lw6cli_process_oob callback code.
-  int (*process_oob) (void *cli_context, lw6nod_info_t * node_info,
-		      lw6cli_oob_data_t * oob_data);
+  int (*process_oob) (lw6sys_context_t * sys_context, void *cli_context, lw6nod_info_t * node_info, lw6cli_oob_data_t * oob_data);
   /// Pointer on lw6cli_open callback code.
-  lw6cnx_connection_t *(*open) (void *cli_context, const char *local_url,
+  lw6cnx_connection_t *(*open) (lw6sys_context_t * sys_context, void *cli_context, const char *local_url,
 				const char *remote_url, const char *remote_ip,
-				int remote_port, const char *password,
-				u_int64_t local_id, u_int64_t remote_id,
-				int dns_ok,
-				int network_reliability,
-				lw6cnx_recv_callback_t recv_callback_func,
-				void *recv_callback_data);
+				int remote_port, const char *password, u_int64_t local_id, u_int64_t remote_id, int dns_ok, int network_reliability);
   /// Pointer on lw6cli_close callback code.
-  void (*close) (void *cli_context, lw6cnx_connection_t * connection);
+  void (*close) (lw6sys_context_t * sys_context, void *cli_context, lw6cnx_connection_t * connection);
   /// Pointer on lw6cli_send callback code.
-  int (*send) (void *cli_context, lw6cnx_connection_t * connection,
+  int (*send) (lw6sys_context_t * sys_context, void *cli_context, lw6cnx_connection_t * connection,
 	       int64_t now,
-	       u_int32_t physical_ticket_sig,
-	       u_int32_t logical_ticket_sig,
-	       u_int64_t logical_from_id,
-	       u_int64_t logical_to_id, const char *message);
+	       u_int32_t physical_ticket_sig, u_int32_t logical_ticket_sig, u_int64_t logical_from_id, u_int64_t logical_to_id, const char *message);
   /// Pointer on lw6cli_can_send callback code.
-  int (*can_send) (void *cli_context, lw6cnx_connection_t * connection);
+  int (*can_send) (lw6sys_context_t * sys_context, void *cli_context, lw6cnx_connection_t * connection);
   /// Pointer on lw6cli_poll callback code.
-  void (*poll) (void *cli_context, lw6cnx_connection_t * connection);
+  void (*poll) (lw6sys_context_t * sys_context, void *cli_context, lw6cnx_connection_t * connection);
   /// Pointer on lw6cli_repr callback code.
-  char *(*repr) (void *cli_context, lw6cnx_connection_t * connection);
+  char *(*repr) (lw6sys_context_t * sys_context, void *cli_context, lw6cnx_connection_t * connection);
 }
 lw6cli_backend_t;
 
 /* cli-api.c */
-extern int lw6cli_init (lw6cli_backend_t * backend);
-extern void lw6cli_quit (lw6cli_backend_t * backend);
-extern int lw6cli_process_oob (lw6cli_backend_t * backend,
-			       lw6nod_info_t * node_info,
-			       lw6cli_oob_data_t * oob_data);
-extern lw6cnx_connection_t *lw6cli_open (lw6cli_backend_t * backend,
+extern int lw6cli_init (lw6sys_context_t * sys_context, lw6cli_backend_t * backend);
+extern void lw6cli_quit (lw6sys_context_t * sys_context, lw6cli_backend_t * backend);
+extern int lw6cli_process_oob (lw6sys_context_t * sys_context, lw6cli_backend_t * backend, lw6nod_info_t * node_info, lw6cli_oob_data_t * oob_data);
+extern lw6cnx_connection_t *lw6cli_open (lw6sys_context_t * sys_context, lw6cli_backend_t * backend,
 					 const char *local_url,
 					 const char *remote_url,
 					 const char *remote_ip,
-					 int remote_port,
-					 const char *password,
-					 u_int64_t local_id,
-					 u_int64_t remote_id,
-					 int dns_ok,
-					 int network_reliability,
-					 lw6cnx_recv_callback_t
-					 recv_callback_func,
-					 void *recv_callback_data);
-extern void lw6cli_close (lw6cli_backend_t * backend,
-			  lw6cnx_connection_t * connection);
-extern int lw6cli_send (lw6cli_backend_t * backend,
+					 int remote_port, const char *password, u_int64_t local_id, u_int64_t remote_id, int dns_ok, int network_reliability);
+extern void lw6cli_close (lw6sys_context_t * sys_context, lw6cli_backend_t * backend, lw6cnx_connection_t * connection);
+extern int lw6cli_send (lw6sys_context_t * sys_context, lw6cli_backend_t * backend,
 			lw6cnx_connection_t * connection,
 			int64_t now,
-			u_int32_t physical_ticket_sig,
-			u_int32_t logical_ticket_sig,
-			u_int64_t logical_from_id, u_int64_t logical_to_id,
-			const char *message);
-extern int lw6cli_can_send (lw6cli_backend_t * backend,
-			    lw6cnx_connection_t * connection);
-extern void lw6cli_poll (lw6cli_backend_t * backend,
-			 lw6cnx_connection_t * connection);
-extern char *lw6cli_repr (const lw6cli_backend_t * backend,
-			  lw6cnx_connection_t * connection);
+			u_int32_t physical_ticket_sig, u_int32_t logical_ticket_sig, u_int64_t logical_from_id, u_int64_t logical_to_id, const char *message);
+extern int lw6cli_can_send (lw6sys_context_t * sys_context, lw6cli_backend_t * backend, lw6cnx_connection_t * connection);
+extern void lw6cli_poll (lw6sys_context_t * sys_context, lw6cli_backend_t * backend, lw6cnx_connection_t * connection);
+extern char *lw6cli_repr (lw6sys_context_t * sys_context, const lw6cli_backend_t * backend, lw6cnx_connection_t * connection);
 
 /* cli-oob.c */
-extern lw6cli_oob_t *lw6cli_oob_new (const char *public_url,
-				     lw6cli_verify_callback_func_t
-				     verify_callback_func,
+extern lw6cli_oob_t *lw6cli_oob_new (lw6sys_context_t * sys_context, const char *public_url, lw6cli_verify_callback_func_t verify_callback_func,
 				     void *verify_callback_data);
-extern void lw6cli_oob_free (lw6cli_oob_t * oob);
+extern void lw6cli_oob_free (lw6sys_context_t * sys_context, lw6cli_oob_t * oob);
 
 /* cli-register.c */
-extern char *lw6cli_default_backends ();
-extern lw6sys_assoc_t *lw6cli_get_backends (int argc, const char *argv[]);
-extern lw6cli_backend_t *lw6cli_create_backend (int argc, const char *argv[],
-						const char *name);
-extern void lw6cli_destroy_backend (lw6cli_backend_t * backend);
+extern char *lw6cli_default_backends (lw6sys_context_t * sys_context);
+extern lw6sys_assoc_t *lw6cli_get_backends (lw6sys_context_t * sys_context, int argc, const char *argv[]);
+extern lw6cli_backend_t *lw6cli_create_backend (lw6sys_context_t * sys_context, int argc, const char *argv[], const char *name);
+extern void lw6cli_destroy_backend (lw6sys_context_t * sys_context, lw6cli_backend_t * backend);
 
 /* cli-test.c */
-extern int lw6cli_test_register (int mode);
-extern int lw6cli_test_run (int mode);
+extern int lw6cli_test_register (lw6sys_context_t * sys_context, int mode);
+extern int lw6cli_test_run (lw6sys_context_t * sys_context, int mode);
 
 #endif
