@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -28,47 +28,35 @@
 #include "mod-http-internal.h"
 
 lw6cnx_connection_t *
-_mod_http_open (_mod_http_context_t * http_context, const char *local_url,
+_mod_http_open (lw6sys_context_t * sys_context, _mod_http_context_t * http_context, const char *local_url,
 		const char *remote_url, const char *remote_ip,
-		int remote_port, const char *password, u_int64_t local_id,
-		u_int64_t remote_id, int dns_ok, int network_reliability,
-		lw6cnx_recv_callback_t recv_callback_func,
-		void *recv_callback_data)
+		int remote_port, const char *password, u_int64_t local_id, u_int64_t remote_id, int dns_ok, int network_reliability)
 {
   lw6cnx_connection_t *ret = NULL;
   _mod_http_specific_data_t *specific_data = NULL;
 
-  lw6sys_log (LW6SYS_LOG_DEBUG, _x_ ("_mod_http_open \"%s\""), remote_url);
-  ret =
-    lw6cnx_connection_new (local_url, remote_url, remote_ip, remote_port,
-			   password, local_id, remote_id, dns_ok,
-			   network_reliability, recv_callback_func,
-			   recv_callback_data);
+  lw6sys_log (sys_context, LW6SYS_LOG_DEBUG, _x_ ("_mod_http_open \"%s\""), remote_url);
+  ret = lw6cnx_connection_new (sys_context, local_url, remote_url, remote_ip, remote_port, password, local_id, remote_id, dns_ok, network_reliability);
   if (ret)
     {
-      ret->backend_specific_data =
-	LW6SYS_CALLOC (sizeof (_mod_http_specific_data_t));
-      specific_data =
-	(_mod_http_specific_data_t *) ret->backend_specific_data;
+      ret->backend_specific_data = LW6SYS_CALLOC (sys_context, sizeof (_mod_http_specific_data_t));
+      specific_data = (_mod_http_specific_data_t *) ret->backend_specific_data;
       if (specific_data)
 	{
-	  specific_data->query_threads =
-	    lw6sys_list_new (_mod_http_query_thread_free_list_item);
+	  specific_data->query_threads = lw6sys_list_new (sys_context, _mod_http_query_thread_free_list_item);
 	  if (specific_data->query_threads)
 	    {
-	      lw6sys_log (LW6SYS_LOG_DEBUG,
-			  _x_ ("open http connection with \"%s\""),
-			  remote_url);
+	      lw6sys_log (sys_context, LW6SYS_LOG_DEBUG, _x_ ("open http connection with \"%s\""), remote_url);
 	    }
 	  else
 	    {
-	      _mod_http_close (http_context, ret);
+	      _mod_http_close (sys_context, http_context, ret);
 	      ret = NULL;
 	    }
 	}
       else
 	{
-	  _mod_http_close (http_context, ret);
+	  _mod_http_close (sys_context, http_context, ret);
 	  ret = NULL;
 	}
     }
@@ -77,26 +65,23 @@ _mod_http_open (_mod_http_context_t * http_context, const char *local_url,
 }
 
 void
-_mod_http_close (_mod_http_context_t * http_context,
-		 lw6cnx_connection_t * connection)
+_mod_http_close (lw6sys_context_t * sys_context, _mod_http_context_t * http_context, lw6cnx_connection_t * connection)
 {
-  _mod_http_specific_data_t *specific_data =
-    (_mod_http_specific_data_t *) connection->backend_specific_data;
+  _mod_http_specific_data_t *specific_data = (_mod_http_specific_data_t *) connection->backend_specific_data;
 
   if (specific_data)
     {
       if (specific_data->query_threads)
 	{
-	  lw6sys_list_free (specific_data->query_threads);
+	  lw6sys_list_free (sys_context, specific_data->query_threads);
 	}
-      LW6SYS_FREE (specific_data);
+      LW6SYS_FREE (sys_context, specific_data);
     }
-  lw6cnx_connection_free (connection);
+  lw6cnx_connection_free (sys_context, connection);
 }
 
 int
-_mod_http_timeout_ok (_mod_http_context_t * http_context,
-		      int64_t origin_timestamp)
+_mod_http_timeout_ok (lw6sys_context_t * sys_context, _mod_http_context_t * http_context, int64_t origin_timestamp)
 {
   int ret = 0;
   int d = 0;
@@ -108,7 +93,7 @@ _mod_http_timeout_ok (_mod_http_context_t * http_context,
    * some time assumed to be reasonnable (depends on settings)
    * it will be over.
    */
-  d = abs (lw6sys_get_timestamp () - origin_timestamp);
+  d = abs (lw6sys_get_timestamp (sys_context) - origin_timestamp);
   ret = (d < (http_context->data.consts.global_timeout * 1000));
 
   return ret;
