@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -75,57 +75,38 @@ typedef struct _mod_tcp_connect_data_s
 _mod_tcp_connect_data_t;
 
 /* mod-tcp-data.c */
-extern int _mod_tcp_load_data (_mod_tcp_data_t * tcp_data,
-			       const char *data_dir);
-extern void _mod_tcp_unload_data (_mod_tcp_data_t * tcp_data);
+extern int _mod_tcp_load_data (lw6sys_context_t * sys_context, _mod_tcp_data_t * tcp_data, const char *data_dir);
+extern void _mod_tcp_unload_data (lw6sys_context_t * sys_context, _mod_tcp_data_t * tcp_data);
 
 /* mod-tcp-setup.c */
-extern _mod_tcp_context_t *_mod_tcp_init (int argc, const char *argv[],
-					  lw6cnx_properties_t * properties);
-extern void _mod_tcp_quit (_mod_tcp_context_t * tcp_context);
+extern _mod_tcp_context_t *_mod_tcp_init (lw6sys_context_t * sys_context, int argc, const char *argv[], lw6cnx_properties_t * properties);
+extern void _mod_tcp_quit (lw6sys_context_t * sys_context, _mod_tcp_context_t * tcp_context);
 
 /* mod-tcp-state.c */
-extern lw6cnx_connection_t *_mod_tcp_open (_mod_tcp_context_t * tcp_context,
+extern lw6cnx_connection_t *_mod_tcp_open (lw6sys_context_t * sys_context, _mod_tcp_context_t * tcp_context,
 					   const char *local_url,
 					   const char *remote_url,
 					   const char *remote_ip,
 					   int remote_port,
-					   const char *password,
-					   u_int64_t local_id,
-					   u_int64_t remote_id, int dns_ok,
-					   int network_reliability,
-					   lw6cnx_recv_callback_t
-					   recv_callback_func,
-					   void *recv_callback_data);
-extern void _mod_tcp_close (_mod_tcp_context_t * tcp_context,
-			    lw6cnx_connection_t * connection);
-extern int _mod_tcp_timeout_ok (_mod_tcp_context_t * tcp_context,
-				int64_t origin_timestamp);
-extern void _mod_tcp_connect_func (void *func_data);
+					   const char *password, u_int64_t local_id, u_int64_t remote_id, int dns_ok, int network_reliability);
+extern void _mod_tcp_close (lw6sys_context_t * sys_context, _mod_tcp_context_t * tcp_context, lw6cnx_connection_t * connection);
+extern int _mod_tcp_timeout_ok (lw6sys_context_t * sys_context, _mod_tcp_context_t * tcp_context, int64_t origin_timestamp);
+extern void _mod_tcp_connect_func (lw6sys_context_t * sys_context, void *func_data);
 
 /* mod-tcp-message.c */
-extern int _mod_tcp_send (_mod_tcp_context_t * tcp_context,
+extern int _mod_tcp_send (lw6sys_context_t * sys_context, _mod_tcp_context_t * tcp_context,
 			  lw6cnx_connection_t * connection,
 			  int64_t now,
 			  u_int32_t physical_ticket_sig,
-			  u_int32_t logical_ticket_sig,
-			  u_int64_t logical_from_id, u_int64_t logical_to_id,
-			  const char *message);
-extern int _mod_tcp_can_send (_mod_tcp_context_t * tcp_context,
-			      lw6cnx_connection_t * connection);
-extern void _mod_tcp_poll (_mod_tcp_context_t * tcp_context,
-			   lw6cnx_connection_t * connection);
+			  u_int32_t logical_ticket_sig, u_int64_t logical_from_id, u_int64_t logical_to_id, const char *message);
+extern int _mod_tcp_can_send (lw6sys_context_t * sys_context, _mod_tcp_context_t * tcp_context, lw6cnx_connection_t * connection);
+extern void _mod_tcp_poll (lw6sys_context_t * sys_context, _mod_tcp_context_t * tcp_context, lw6cnx_connection_t * connection);
 
 /* mod-tcp-info.c */
-extern char *_mod_tcp_repr (_mod_tcp_context_t * tcp_context,
-			    lw6cnx_connection_t * connection);
+extern char *_mod_tcp_repr (lw6sys_context_t * sys_context, _mod_tcp_context_t * tcp_context, lw6cnx_connection_t * connection);
 
 /* mod-tcp-oob.c */
-extern int _mod_tcp_process_oob (_mod_tcp_context_t * tcp_context,
-				 lw6nod_info_t * node_info,
-				 lw6cli_oob_data_t * oob_data);
-extern int _mod_tcp_oob_should_continue (_mod_tcp_context_t * tcp_context,
-					 lw6cli_oob_data_t * oob_data,
-					 int *sock);
+extern int _mod_tcp_process_oob (lw6sys_context_t * sys_context, _mod_tcp_context_t * tcp_context, lw6nod_info_t * node_info, lw6cli_oob_data_t * oob_data);
+extern int _mod_tcp_oob_should_continue (lw6sys_context_t * sys_context, _mod_tcp_context_t * tcp_context, lw6cli_oob_data_t * oob_data, int *sock);
 
-#endif
+#endif // LIQUIDWAR6CLI_TCP_INTERNAL_H
