@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -28,14 +28,11 @@
 #include "mod-udp-internal.h"
 
 char *
-_mod_udp_repr (_mod_udp_context_t * udp_context,
-	       lw6cnx_connection_t * connection)
+_mod_udp_repr (lw6sys_context_t * sys_context, _mod_udp_context_t * udp_context, lw6cnx_connection_t * connection)
 {
   char *ret = NULL;
 
-  ret =
-    lw6sys_new_sprintf (_x_ ("udp connexion of \"%s\" on \"%s\""),
-			connection->local_url, connection->remote_url);
+  ret = lw6sys_new_sprintf (sys_context, _x_ ("udp connexion of \"%s\" on \"%s\""), connection->local_url, connection->remote_url);
 
   return ret;
 }
