@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -33,12 +33,14 @@
 /**
  * lw6cns_console_support
  *
+ * @sys_context: global system context
+ *
  * Tells wether console is supported.
  *
  * Return value: 1 if console can be enabled, 0 if not
  */
 int
-lw6cns_console_support ()
+lw6cns_console_support (lw6sys_context_t * sys_context)
 {
   int ret = 0;
 
@@ -52,12 +54,14 @@ lw6cns_console_support ()
 /**
  * lw6cns_term_support
  *
+ * @sys_context: global system context
+ *
  * Tells wether program is likely to have proper term (xterm, Linux console) support.
  *
  * Return value: 1 if has validated TERM support, 0 if not
  */
 int
-lw6cns_term_support ()
+lw6cns_term_support (lw6sys_context_t * sys_context)
 {
   int ret = 0;
   char *env_term = NULL;
@@ -66,36 +70,28 @@ lw6cns_term_support ()
    * We're sort of paranoid, if TERM is not a well-known proven-to-work
    * entry, then simply disable console support.
    */
-  env_term = lw6sys_getenv (_ENV_TERM_KEY);
+  env_term = lw6sys_getenv (sys_context, _ENV_TERM_KEY);
   if (env_term)
     {
-      if (lw6sys_str_is_same (env_term, _ENV_TERM_ALLOWED_XTERM)
-	  || lw6sys_str_is_same (env_term, _ENV_TERM_ALLOWED_LINUX))
+      if (lw6sys_str_is_same (sys_context, env_term, _ENV_TERM_ALLOWED_XTERM) || lw6sys_str_is_same (sys_context, env_term, _ENV_TERM_ALLOWED_LINUX))
 	{
-	  lw6sys_log (LW6SYS_LOG_INFO,
-		      _x_
-		      ("term support should be fine, env variable \"%s\" is \"%s\""),
-		      _ENV_TERM_KEY, env_term);
+	  lw6sys_log (sys_context, LW6SYS_LOG_INFO, _x_ ("term support should be fine, env variable \"%s\" is \"%s\""), _ENV_TERM_KEY, env_term);
 	  ret = 1;
 	}
       else
 	{
-	  lw6sys_log (LW6SYS_LOG_INFO,
+	  lw6sys_log (sys_context, LW6SYS_LOG_INFO,
 		      _x_
 		      ("term support probably broken, env variable \"%s\" is \"%s\" which is neither \"%s\" or \"%s\""),
-		      _ENV_TERM_KEY, env_term, _ENV_TERM_ALLOWED_XTERM,
-		      _ENV_TERM_ALLOWED_LINUX);
+		      _ENV_TERM_KEY, env_term, _ENV_TERM_ALLOWED_XTERM, _ENV_TERM_ALLOWED_LINUX);
 	}
 
-      LW6SYS_FREE (env_term);
+      LW6SYS_FREE (sys_context, env_term);
       env_term = NULL;
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_INFO,
-		  _x_
-		  ("term support probably broken, env variable \"%s\" is not set"),
-		  _ENV_TERM_KEY);
+      lw6sys_log (sys_context, LW6SYS_LOG_INFO, _x_ ("term support probably broken, env variable \"%s\" is not set"), _ENV_TERM_KEY);
     }
 
   return ret;
