@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -33,6 +33,7 @@
 /**
  * lw6cnx_connection_new
  *
+ * @sys_context: global system context
  * @local_url: the local public URL
  * @remote_url: the remote public URL
  * @remote_ip: the remote IP address
@@ -42,8 +43,6 @@
  * @remote_id: the remote ID
  * @dns_ok: 1 if no DNS mismatch, 0 if IP does not match public URL
  * @network_reliability: drop 1 out of X packets
- * @recv_callback_func: a callback to call when data is received
- * @recv_callback_data: additionnal data to pass to the callback
  *
  * Create a connection object. This object in itself does
  * nothing, it's just to share common structures among
@@ -55,56 +54,47 @@
  * Return value: newly allocated object.
  */
 lw6cnx_connection_t *
-lw6cnx_connection_new (const char *local_url, const char *remote_url,
+lw6cnx_connection_new (lw6sys_context_t * sys_context, const char *local_url, const char *remote_url,
 		       const char *remote_ip, int remote_port,
-		       const char *password, u_int64_t local_id,
-		       u_int64_t remote_id,
-		       int dns_ok, int network_reliability,
-		       lw6cnx_recv_callback_t recv_callback_func,
-		       void *recv_callback_data)
+		       const char *password, u_int64_t local_id, u_int64_t remote_id, int dns_ok, int network_reliability)
 {
   lw6cnx_connection_t *ret = NULL;
 
-  ret = (lw6cnx_connection_t *) LW6SYS_CALLOC (sizeof (lw6cnx_connection_t));
+  ret = (lw6cnx_connection_t *) LW6SYS_CALLOC (sys_context, sizeof (lw6cnx_connection_t));
   if (ret)
     {
-      ret->local_url = lw6sys_str_copy (local_url);
-      ret->remote_url = lw6sys_str_copy (remote_url);
-      ret->remote_ip = lw6sys_str_copy (remote_ip);
+      ret->local_url = lw6sys_str_copy (sys_context, local_url);
+      ret->remote_url = lw6sys_str_copy (sys_context, remote_url);
+      ret->remote_ip = lw6sys_str_copy (sys_context, remote_ip);
       ret->remote_port = remote_port;
       if (password && strlen (password) > 0)
 	{
-	  ret->password = lw6sys_str_copy (password);
-	  ret->password_send_checksum =
-	    lw6cnx_password_checksum (remote_url, password);
+	  ret->password = lw6sys_str_copy (sys_context, password);
+	  ret->password_send_checksum = lw6cnx_password_checksum (sys_context, remote_url, password);
 	}
       else
 	{
-	  ret->password = lw6sys_str_copy ("");
-	  ret->password_send_checksum =
-	    lw6sys_str_copy (_DEFAULT_SEND_PASSWORD_CHECKSUM);
+	  ret->password = lw6sys_str_copy (sys_context, "");
+	  ret->password_send_checksum = lw6sys_str_copy (sys_context, _DEFAULT_SEND_PASSWORD_CHECKSUM);
 	}
       ret->local_id_int = local_id;
-      ret->local_id_str = lw6sys_id_ltoa (local_id);
+      ret->local_id_str = lw6sys_id_ltoa (sys_context, local_id);
       ret->remote_id_int = remote_id;
-      ret->remote_id_str = lw6sys_id_ltoa (remote_id);
+      ret->remote_id_str = lw6sys_id_ltoa (sys_context, remote_id);
       ret->dns_ok = dns_ok ? 1 : 0;
       ret->network_reliability = network_reliability;
-      ret->recv_callback_func = recv_callback_func;
-      ret->recv_callback_data = recv_callback_data;
-      ret->send_mutex = lw6sys_mutex_create ();
+      ret->recv_list = lw6sys_list_r_new (sys_context, (lw6sys_free_func_t) lw6cnx_packet_free);
+      ret->send_mutex = LW6SYS_MUTEX_CREATE (sys_context);
       ret->ping_msec = LW6CNX_WORST_PING_MSEC;
 
       if (ret->local_url && ret->remote_url && ret->remote_ip && ret->password
-	  && ret->password_send_checksum && ret->local_id_str
-	  && ret->remote_id_str && ret->send_mutex)
+	  && ret->password_send_checksum && ret->local_id_str && ret->remote_id_str && ret->recv_list && ret->send_mutex)
 	{
-	  lw6sys_log (LW6SYS_LOG_DEBUG,
-		      _x_ ("created connection with \"%s\""), remote_url);
+	  lw6sys_log (sys_context, LW6SYS_LOG_DEBUG, _x_ ("created connection with \"%s\""), remote_url);
 	}
       else
 	{
-	  lw6cnx_connection_free (ret);
+	  lw6cnx_connection_free (sys_context, ret);
 	  ret = NULL;
 	}
     }
@@ -115,6 +105,7 @@ lw6cnx_connection_new (const char *local_url, const char *remote_url,
 /**
  * lw6cnx_connection_free
  *
+ * @sys_context: global system context
  * @connection: object to free
  *
  * Frees a connection object. It's the responsibility of
@@ -123,46 +114,51 @@ lw6cnx_connection_new (const char *local_url, const char *remote_url,
  * Return value: none.
  */
 void
-lw6cnx_connection_free (lw6cnx_connection_t * connection)
+lw6cnx_connection_free (lw6sys_context_t * sys_context, lw6cnx_connection_t * connection)
 {
   if (connection->local_url)
     {
-      LW6SYS_FREE (connection->local_url);
+      LW6SYS_FREE (sys_context, connection->local_url);
     }
   if (connection->remote_url)
     {
-      LW6SYS_FREE (connection->remote_url);
+      LW6SYS_FREE (sys_context, connection->remote_url);
     }
   if (connection->remote_ip)
     {
-      LW6SYS_FREE (connection->remote_ip);
+      LW6SYS_FREE (sys_context, connection->remote_ip);
     }
   if (connection->password)
     {
-      LW6SYS_FREE (connection->password);
+      LW6SYS_FREE (sys_context, connection->password);
     }
   if (connection->password_send_checksum)
     {
-      LW6SYS_FREE (connection->password_send_checksum);
+      LW6SYS_FREE (sys_context, connection->password_send_checksum);
     }
   if (connection->local_id_str)
     {
-      LW6SYS_FREE (connection->local_id_str);
+      LW6SYS_FREE (sys_context, connection->local_id_str);
     }
   if (connection->remote_id_str)
     {
-      LW6SYS_FREE (connection->remote_id_str);
+      LW6SYS_FREE (sys_context, connection->remote_id_str);
+    }
+  if (connection->recv_list)
+    {
+      lw6sys_list_r_free (sys_context, connection->recv_list);
     }
   if (connection->send_mutex)
     {
-      lw6sys_mutex_destroy (connection->send_mutex);
+      LW6SYS_MUTEX_DESTROY (sys_context, connection->send_mutex);
     }
-  LW6SYS_FREE (connection);
+  LW6SYS_FREE (sys_context, connection);
 }
 
 /**
  * lw6cnx_connection_should_send_foo
  *
+ * @sys_context: global system context
  * @connection: the connection concerned
  * @now: the current timestamp
  *
@@ -171,8 +167,7 @@ lw6cnx_connection_free (lw6cnx_connection_t * connection)
  * Return value: 1 if true, 0 if false.
  */
 int
-lw6cnx_connection_should_send_foo (lw6cnx_connection_t * connection,
-				   int64_t now)
+lw6cnx_connection_should_send_foo (lw6sys_context_t * sys_context, lw6cnx_connection_t * connection, int64_t now)
 {
   return (now > connection->next_send_foo_timestamp);
 }
@@ -180,6 +175,7 @@ lw6cnx_connection_should_send_foo (lw6cnx_connection_t * connection,
 /**
  * lw6cnx_connection_init_foo_bar_key
  *
+ * @sys_context: global system context
  * @connection: the connection concerned
  * @now: the current timestamp
  * @next_foo_delay: the delay (msec) before next foo message is sent
@@ -189,8 +185,7 @@ lw6cnx_connection_should_send_foo (lw6cnx_connection_t * connection,
  * Return value: none.
  */
 void
-lw6cnx_connection_init_foo_bar_key (lw6cnx_connection_t * connection,
-				    int64_t now, int next_foo_delay)
+lw6cnx_connection_init_foo_bar_key (lw6sys_context_t * sys_context, lw6cnx_connection_t * connection, int64_t now, int next_foo_delay)
 {
   if (connection->foo_bar_key)
     {
@@ -203,14 +198,14 @@ lw6cnx_connection_init_foo_bar_key (lw6cnx_connection_t * connection,
       connection->ping_msec = LW6CNX_WORST_PING_MSEC;
     }
   connection->last_send_foo_timestamp = now;
-  connection->next_send_foo_timestamp =
-    now + next_foo_delay / 2 + lw6sys_random (next_foo_delay);
-  connection->foo_bar_key = lw6sys_generate_id_32 ();
+  connection->next_send_foo_timestamp = now + next_foo_delay / 2 + lw6sys_random (sys_context, next_foo_delay);
+  connection->foo_bar_key = lw6sys_generate_id_32 (sys_context);
 }
 
 /**
  * lw6cnx_connection_lock_send
  *
+ * @sys_context: global system context
  * @connection: the connexion to lock
  *
  * Acquires a "send" lock on the connexion, the idea is to avoid
@@ -221,14 +216,15 @@ lw6cnx_connection_init_foo_bar_key (lw6cnx_connection_t * connection,
  * Return value: 1 on success, 0 if not.
  */
 int
-lw6cnx_connection_lock_send (lw6cnx_connection_t * connection)
+lw6cnx_connection_lock_send (lw6sys_context_t * sys_context, lw6cnx_connection_t * connection)
 {
-  return lw6sys_mutex_lock (connection->send_mutex);
+  return LW6SYS_MUTEX_LOCK (sys_context, connection->send_mutex);
 }
 
 /**
  * lw6cnx_connection_unlock_send
  *
+ * @sys_context: global system context
  * @connection: the connexion to lock
  *
  * Releases a "send" lock on the connexion, the idea is to avoid
@@ -239,14 +235,15 @@ lw6cnx_connection_lock_send (lw6cnx_connection_t * connection)
  * Return value: none.
  */
 void
-lw6cnx_connection_unlock_send (lw6cnx_connection_t * connection)
+lw6cnx_connection_unlock_send (lw6sys_context_t * sys_context, lw6cnx_connection_t * connection)
 {
-  lw6sys_mutex_unlock (connection->send_mutex);
+  LW6SYS_MUTEX_UNLOCK (sys_context, connection->send_mutex);
 }
 
 /**
  * lw6cnx_connection_reliability_filter
  *
+ * @sys_context: global system context
  * @connection: the connexion concerned
  *
  * Will filter and return true only in "rare" cases when packets
@@ -255,18 +252,14 @@ lw6cnx_connection_unlock_send (lw6cnx_connection_t * connection)
  * Return value: 1 if message must be sent/received, 0 if not
  */
 int
-lw6cnx_connection_reliability_filter (lw6cnx_connection_t * connection)
+lw6cnx_connection_reliability_filter (lw6sys_context_t * sys_context, lw6cnx_connection_t * connection)
 {
   int ret = 0;
 
-  ret =
-    (lw6sys_random (connection->network_reliability) !=
-     (connection->network_reliability >> 1));
+  ret = (lw6sys_random (sys_context, connection->network_reliability) != (connection->network_reliability >> 1));
   if (!ret)
     {
-      lw6sys_log (LW6SYS_LOG_DEBUG,
-		  _x_ ("filtering message due to reliability %d"),
-		  connection->network_reliability);
+      lw6sys_log (sys_context, LW6SYS_LOG_DEBUG, _x_ ("filtering message due to reliability %d"), connection->network_reliability);
     }
 
   return ret;
