@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -29,6 +29,7 @@
 /**
  * lw6cnx_password_checksum
  *
+ * @sys_context: global system context
  * @seed: a seed to blur the password, can be NULL
  * @password: the password, can be NULL
  *
@@ -47,7 +48,7 @@
  * Return value: a dynamically allocated string
  */
 char *
-lw6cnx_password_checksum (const char *seed, const char *password)
+lw6cnx_password_checksum (lw6sys_context_t * sys_context, const char *seed, const char *password)
 {
   char *ret = NULL;
 
@@ -62,11 +63,11 @@ lw6cnx_password_checksum (const char *seed, const char *password)
        * URL whereas the password is supposed to
        * be secret...
        */
-      ret = lw6glb_sha1_hmac_80_str (password, seed);
+      ret = lw6glb_sha1_hmac_80_str (sys_context, password, seed);
     }
   else
     {
-      ret = lw6sys_str_copy ("");
+      ret = lw6sys_str_copy (sys_context, "");
     }
 
   return ret;
@@ -75,6 +76,7 @@ lw6cnx_password_checksum (const char *seed, const char *password)
 /**
  * lw6cnx_password_verify
  *
+ * @sys_context: global system context
  * @seed: a seed to blur the password, can be NULL
  * @password_here: the local password, can be NULL
  * @password_received: the password received from network, can be NULL
@@ -87,8 +89,7 @@ lw6cnx_password_checksum (const char *seed, const char *password)
  * Return value: 1 if OK, passwords are the same, 0 if not.
  */
 int
-lw6cnx_password_verify (const char *seed, const char *password_here,
-			const char *password_received)
+lw6cnx_password_verify (lw6sys_context_t * sys_context, const char *seed, const char *password_here, const char *password_received)
 {
   int ret = 0;
   char *checksum = NULL;
@@ -98,27 +99,24 @@ lw6cnx_password_verify (const char *seed, const char *password_here,
       // no passwd
       ret = 1;
     }
-  if (password_here && strlen (password_here) > 0 && password_received
-      && strlen (password_received) > 0)
+  if (password_here && strlen (password_here) > 0 && password_received && strlen (password_received) > 0)
     {
       if (!(strcmp (password_here, password_received)))
 	{
-	  lw6sys_log (LW6SYS_LOG_DEBUG,
-		      _x_ ("password OK, received as clear text"));
+	  lw6sys_log (sys_context, LW6SYS_LOG_DEBUG, _x_ ("password OK, received as clear text"));
 	  ret = 1;
 	}
       else
 	{
-	  checksum = lw6cnx_password_checksum (seed, password_here);
+	  checksum = lw6cnx_password_checksum (sys_context, seed, password_here);
 	  if (checksum)
 	    {
 	      if (!(strcmp (checksum, password_received)))
 		{
-		  lw6sys_log (LW6SYS_LOG_DEBUG,
-			      _x_ ("password OK, received as checksum"));
+		  lw6sys_log (sys_context, LW6SYS_LOG_DEBUG, _x_ ("password OK, received as checksum"));
 		  ret = 1;
 		}
-	      LW6SYS_FREE (checksum);
+	      LW6SYS_FREE (sys_context, checksum);
 	    }
 	}
     }
