@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -84,14 +84,6 @@ lw6cnx_properties_t;
 
 typedef struct lw6cnx_connection_s *lw6cnx_connection_p;
 
-typedef void (*lw6cnx_recv_callback_t) (void *recv_callback_data,
-					lw6cnx_connection_p connection,
-					u_int32_t physical_ticket_sig,
-					u_int32_t logical_ticket_sig,
-					u_int64_t logical_from_id,
-					u_int64_t logical_to_id,
-					const char *message);
-
 /**
  * This structure holds all data associated to a physical connexion
  * with a remote peer. This includes informations about the local node,
@@ -144,13 +136,11 @@ typedef struct lw6cnx_connection_s
   /// Properties got from the backend.
   lw6cnx_properties_t properties;
   /**
-   * Function which will be called when receiving data. This one
-   * must clearly be reentrant, depending on the backend it could
-   * be called in a separate thread, at any time.
+   * List of messages received. This is a list_r and not a plain
+   * list because it can typically be filled and consumed in
+   * different threads.
    */
-  lw6cnx_recv_callback_t recv_callback_func;
-  /// Data passed to recv_callback_func.
-  void *recv_callback_data;
+  lw6sys_list_r_t *recv_list;
   /**
    * Send mutex, this will be used so that sending operations
    * are properly serialized. Indeed, threads that respond on the
@@ -229,60 +219,60 @@ typedef struct lw6cnx_ticket_table_s
 }
 lw6cnx_ticket_table_t;
 
+/**
+ * Used to hold a network message plus some metadata, such
+ * as who it is for, and who emitted the message.
+ */
+typedef struct lw6cnx_packet_s
+{
+  /// Logical signature for the packet.
+  u_int32_t logical_ticket_sig;
+  /// Physical signature for the packet.
+  u_int32_t physical_ticket_sig;
+  /// Logical sender.
+  u_int64_t logical_from_id;
+  /// Logical receiver.
+  u_int64_t logical_to_id;
+  char *msg;
+} lw6cnx_packet_t;
+
 /* cnx-connection.c */
-extern lw6cnx_connection_t *lw6cnx_connection_new (const char *local_url,
+extern lw6cnx_connection_t *lw6cnx_connection_new (lw6sys_context_t * sys_context, const char *local_url,
 						   const char *remote_url,
 						   const char *remote_ip,
 						   int remote_port,
-						   const char *password,
-						   u_int64_t local_id,
-						   u_int64_t remote_id,
-						   int dns_ok,
-						   int network_reliability,
-						   lw6cnx_recv_callback_t
-						   recv_callback_func,
-						   void *recv_callback_data);
-extern void lw6cnx_connection_free (lw6cnx_connection_t * connection);
-extern int lw6cnx_connection_should_send_foo (lw6cnx_connection_t *
-					      connection, int64_t now);
-extern void lw6cnx_connection_init_foo_bar_key (lw6cnx_connection_t *
-						connection, int64_t now,
-						int next_foo_delay);
-extern int lw6cnx_connection_lock_send (lw6cnx_connection_t * connection);
-extern void lw6cnx_connection_unlock_send (lw6cnx_connection_t * connection);
-extern int lw6cnx_connection_reliability_filter (lw6cnx_connection_t *
-						 connection);
+						   const char *password, u_int64_t local_id, u_int64_t remote_id, int dns_ok, int network_reliability);
+extern void lw6cnx_connection_free (lw6sys_context_t * sys_context, lw6cnx_connection_t * connection);
+extern int lw6cnx_connection_should_send_foo (lw6sys_context_t * sys_context, lw6cnx_connection_t * connection, int64_t now);
+extern void lw6cnx_connection_init_foo_bar_key (lw6sys_context_t * sys_context, lw6cnx_connection_t * connection, int64_t now, int next_foo_delay);
+extern int lw6cnx_connection_lock_send (lw6sys_context_t * sys_context, lw6cnx_connection_t * connection);
+extern void lw6cnx_connection_unlock_send (lw6sys_context_t * sys_context, lw6cnx_connection_t * connection);
+extern int lw6cnx_connection_reliability_filter (lw6sys_context_t * sys_context, lw6cnx_connection_t * connection);
+
+/* cnx-packet.c */
+extern lw6cnx_packet_t *lw6cnx_packet_new (lw6sys_context_t * sys_context, u_int32_t logical_ticket_sig,
+					   u_int32_t physical_ticket_sig, u_int64_t logical_from_id, u_int64_t logical_to_id, const char *msg);
+extern void lw6cnx_packet_free (lw6sys_context_t * sys_context, lw6cnx_packet_t * packet);
+extern u_int32_t lw6cnx_packet_checksum (lw6sys_context_t * sys_context, const lw6cnx_packet_t * packet);
+extern int lw6cnx_packet_compare (lw6sys_context_t * sys_context, const lw6cnx_packet_t * a, const lw6cnx_packet_t * b);
+extern int lw6cnx_packet_sort_callback (lw6sys_context_t * sys_context, void *func_data, const void *ptr_a, const void *ptr_b);
 
 /* cnx-password.c */
-extern char *lw6cnx_password_checksum (const char *seed,
-				       const char *password);
-extern int lw6cnx_password_verify (const char *seed,
-				   const char *password_here,
-				   const char *password_received);
+extern char *lw6cnx_password_checksum (lw6sys_context_t * sys_context, const char *seed, const char *password);
+extern int lw6cnx_password_verify (lw6sys_context_t * sys_context, const char *seed, const char *password_here, const char *password_received);
 
 /* cnx-test.c */
-extern int lw6cnx_test_register (int mode);
-extern int lw6cnx_test_run (int mode);
+extern int lw6cnx_test_register (lw6sys_context_t * sys_context, int mode);
+extern int lw6cnx_test_run (lw6sys_context_t * sys_context, int mode);
 
 /* cnx-tickettable.c */
-extern void lw6cnx_ticket_table_zero (lw6cnx_ticket_table_t * ticket_table);
-extern int lw6cnx_ticket_table_init (lw6cnx_ticket_table_t * ticket_table,
-				     int hash_size);
-extern void lw6cnx_ticket_table_clear (lw6cnx_ticket_table_t * ticket_table);
-extern u_int64_t lw6cnx_ticket_table_get_recv (lw6cnx_ticket_table_t *
-					       ticket_table,
-					       const char *peer_id);
-extern void lw6cnx_ticket_table_ack_recv (lw6cnx_ticket_table_t *
-					  ticket_table, const char *peer_id,
-					  int ack_delay_msec);
-extern int lw6cnx_ticket_table_was_recv_exchanged (lw6cnx_ticket_table_t *
-						   ticket_table,
-						   const char *peer_id);
-extern u_int64_t lw6cnx_ticket_table_get_send (lw6cnx_ticket_table_t *
-					       ticket_table,
-					       const char *peer_id);
-extern void lw6cnx_ticket_table_set_send (lw6cnx_ticket_table_t *
-					  ticket_table, const char *peer_id,
-					  u_int64_t send_ticket);
+extern void lw6cnx_ticket_table_zero (lw6sys_context_t * sys_context, lw6cnx_ticket_table_t * ticket_table);
+extern int lw6cnx_ticket_table_init (lw6sys_context_t * sys_context, lw6cnx_ticket_table_t * ticket_table, int hash_size);
+extern void lw6cnx_ticket_table_clear (lw6sys_context_t * sys_context, lw6cnx_ticket_table_t * ticket_table);
+extern u_int64_t lw6cnx_ticket_table_get_recv (lw6sys_context_t * sys_context, lw6cnx_ticket_table_t * ticket_table, const char *peer_id);
+extern void lw6cnx_ticket_table_ack_recv (lw6sys_context_t * sys_context, lw6cnx_ticket_table_t * ticket_table, const char *peer_id, int ack_delay_msec);
+extern int lw6cnx_ticket_table_was_recv_exchanged (lw6sys_context_t * sys_context, lw6cnx_ticket_table_t * ticket_table, const char *peer_id);
+extern u_int64_t lw6cnx_ticket_table_get_send (lw6sys_context_t * sys_context, lw6cnx_ticket_table_t * ticket_table, const char *peer_id);
+extern void lw6cnx_ticket_table_set_send (lw6sys_context_t * sys_context, lw6cnx_ticket_table_t * ticket_table, const char *peer_id, u_int64_t send_ticket);
 
 #endif
