@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -27,11 +27,11 @@
 #include "dat-internal.h"
 
 _lw6dat_block_t *
-_lw6dat_block_new (int serial_0)
+_lw6dat_block_new (lw6sys_context_t * sys_context, int serial_0)
 {
   _lw6dat_block_t *block = NULL;
 
-  block = (_lw6dat_block_t *) LW6SYS_CALLOC (sizeof (_lw6dat_block_t));
+  block = (_lw6dat_block_t *) LW6SYS_CALLOC (sys_context, sizeof (_lw6dat_block_t));
   if (block)
     {
       block->serial_0 = serial_0;
@@ -42,22 +42,21 @@ _lw6dat_block_new (int serial_0)
 }
 
 void
-_lw6dat_block_free (_lw6dat_block_t * block)
+_lw6dat_block_free (lw6sys_context_t * sys_context, _lw6dat_block_t * block)
 {
   int i;
 
   for (i = 0; i < _LW6DAT_NB_ATOMS_PER_BLOCK; ++i)
     {
-      _lw6dat_atom_clear (&(block->atoms[i]));
+      _lw6dat_atom_clear (sys_context, &(block->atoms[i]));
     }
-  LW6SYS_FREE (block);
+  LW6SYS_FREE (sys_context, block);
 }
 
 int
-_lw6dat_block_put_atom (_lw6dat_block_t * block, int type,
+_lw6dat_block_put_atom (lw6sys_context_t * sys_context, _lw6dat_block_t * block, int type,
 			int serial, int order_i, int order_n, int64_t seq,
-			const char *full_str, int seq_from_cmd_str_offset,
-			int cmd_str_offset, int send_flag)
+			const char *full_str, int seq_from_cmd_str_offset, int cmd_str_offset, int send_flag)
 {
   int ret = 0;
   _lw6dat_atom_t *atom;
@@ -66,30 +65,26 @@ _lw6dat_block_put_atom (_lw6dat_block_t * block, int type,
   if (serial >= block->serial_0 && serial <= block->serial_n_1)
     {
       atom = &(block->atoms[serial - block->serial_0]);
-      old_full_str = _lw6dat_atom_get_full_str (atom);
+      old_full_str = _lw6dat_atom_get_full_str (sys_context, atom);
       if (old_full_str)
 	{
-	  if (strcmp (old_full_str, full_str) || order_i != atom->order_i
-	      || order_n != atom->order_n || serial != atom->serial)
+	  if (strcmp (old_full_str, full_str) || order_i != atom->order_i || order_n != atom->order_n || serial != atom->serial)
 	    {
-	      lw6sys_log (LW6SYS_LOG_WARNING,
+	      lw6sys_log (sys_context, LW6SYS_LOG_WARNING,
 			  _x_
 			  ("inconsistency, atom set twice atom->serial=%d atom->order_i=%d atom->order_n=%d atom->full_str=\"%s\" but serial=%d order_i=%d order_n=%d full_str=\"%s\""),
-			  atom->serial, atom->order_i, atom->order_n,
-			  old_full_str, serial, order_i, order_n, full_str);
+			  atom->serial, atom->order_i, atom->order_n, old_full_str, serial, order_i, order_n, full_str);
 	    }
 	  else
 	    {
-	      lw6sys_log (LW6SYS_LOG_DEBUG,
-			  _x_
-			  ("receiving same atom serial=%d order_i=%d order_n=%d full_str=\"%s\""),
-			  serial, order_i, order_n, full_str);
+	      lw6sys_log (sys_context, LW6SYS_LOG_DEBUG,
+			  _x_ ("receiving same atom serial=%d order_i=%d order_n=%d full_str=\"%s\""), serial, order_i, order_n, full_str);
 	      ret = 1;
 	    }
 	}
       else
 	{
-	  ret = _lw6dat_atom_set_full_str (atom, full_str);
+	  ret = _lw6dat_atom_set_full_str (sys_context, atom, full_str);
 	  if (ret)
 	    {
 	      atom->not_null = 1;
@@ -104,24 +99,21 @@ _lw6dat_block_put_atom (_lw6dat_block_t * block, int type,
 	    }
 	  else
 	    {
-	      lw6sys_log (LW6SYS_LOG_DEBUG,
-			  _x_ ("couldn't set atom full_str"));
+	      lw6sys_log (sys_context, LW6SYS_LOG_DEBUG, _x_ ("couldn't set atom full_str"));
 	    }
 	}
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING,
-		  _x_
-		  ("serial out of range serial=%d block->serial_0=%d block->serial_n_1=%d"),
-		  serial, block->serial_0, block->serial_n_1);
+      lw6sys_log (sys_context, LW6SYS_LOG_WARNING,
+		  _x_ ("serial out of range serial=%d block->serial_0=%d block->serial_n_1=%d"), serial, block->serial_0, block->serial_n_1);
     }
 
   return ret;
 }
 
 _lw6dat_atom_t *
-_lw6dat_block_get_atom (_lw6dat_block_t * block, int serial)
+_lw6dat_block_get_atom (lw6sys_context_t * sys_context, _lw6dat_block_t * block, int serial)
 {
   int atom_index;
   _lw6dat_atom_t *atom = NULL;
@@ -135,15 +127,12 @@ _lw6dat_block_get_atom (_lw6dat_block_t * block, int serial)
 	}
       else
 	{
-	  lw6sys_log (LW6SYS_LOG_DEBUG,
-		      _x_ ("no atom defined at atom_index=%d for serial %d"),
-		      atom_index, serial);
+	  lw6sys_log (sys_context, LW6SYS_LOG_DEBUG, _x_ ("no atom defined at atom_index=%d for serial %d"), atom_index, serial);
 	}
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("bad atom_index=%d for serial %d"),
-		  atom_index, serial);
+      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("bad atom_index=%d for serial %d"), atom_index, serial);
     }
 
   return atom;
