@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -39,11 +39,11 @@
  * Return value: new dynamically allocated object
  */
 lw6dat_miss_t *
-lw6dat_miss_new (u_int64_t from_id, int serial_min, int serial_max)
+lw6dat_miss_new (lw6sys_context_t * sys_context, u_int64_t from_id, int serial_min, int serial_max)
 {
   lw6dat_miss_t *miss = NULL;
 
-  miss = (lw6dat_miss_t *) LW6SYS_MALLOC (sizeof (lw6dat_miss_t));
+  miss = (lw6dat_miss_t *) LW6SYS_MALLOC (sys_context, sizeof (lw6dat_miss_t));
   if (miss)
     {
       miss->from_id = from_id;
@@ -64,15 +64,15 @@ lw6dat_miss_new (u_int64_t from_id, int serial_min, int serial_max)
  * Return value: none.
  */
 void
-lw6dat_miss_free (lw6dat_miss_t * miss)
+lw6dat_miss_free (lw6sys_context_t * sys_context, lw6dat_miss_t * miss)
 {
   if (miss)
     {
-      LW6SYS_FREE (miss);
+      LW6SYS_FREE (sys_context, miss);
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("trying to free NULL miss"));
+      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("trying to free NULL miss"));
     }
 }
 
@@ -87,7 +87,7 @@ lw6dat_miss_free (lw6dat_miss_t * miss)
  * Return value: none.
  */
 void
-lw6dat_miss_sync (lw6dat_miss_t * dst, lw6dat_miss_t * src)
+lw6dat_miss_sync (lw6sys_context_t * sys_context, lw6dat_miss_t * dst, lw6dat_miss_t * src)
 {
   if (dst && src)
     {
@@ -95,8 +95,7 @@ lw6dat_miss_sync (lw6dat_miss_t * dst, lw6dat_miss_t * src)
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING,
-		  _x_ ("trying to sync NULL miss dst=%p src=%p"), dst, src);
+      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("trying to sync NULL miss dst=%p src=%p"), dst, src);
     }
 }
 
@@ -111,7 +110,7 @@ lw6dat_miss_sync (lw6dat_miss_t * dst, lw6dat_miss_t * src)
  * Return value: 1 if same, else 0.
  */
 int
-lw6dat_miss_is_same (lw6dat_miss_t * a, lw6dat_miss_t * b)
+lw6dat_miss_is_same (lw6sys_context_t * sys_context, lw6dat_miss_t * a, lw6dat_miss_t * b)
 {
   int ret = 0;
 
@@ -121,8 +120,7 @@ lw6dat_miss_is_same (lw6dat_miss_t * a, lw6dat_miss_t * b)
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING,
-		  _x_ ("trying to compare NULL miss a=%p b=%p"), a, b);
+      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("trying to compare NULL miss a=%p b=%p"), a, b);
     }
 
   return ret;
@@ -139,20 +137,17 @@ lw6dat_miss_is_same (lw6dat_miss_t * a, lw6dat_miss_t * b)
  * Return value: 1 if included, else 0.
  */
 int
-lw6dat_miss_is_included (lw6dat_miss_t * a, lw6dat_miss_t * b)
+lw6dat_miss_is_included (lw6sys_context_t * sys_context, lw6dat_miss_t * a, lw6dat_miss_t * b)
 {
   int ret = 0;
 
   if (a && b)
     {
-      ret = (a->from_id == b->from_id) && (a->serial_min >= b->serial_min)
-	&& (a->serial_max <= b->serial_max)
-	&& (a->serial_min <= a->serial_max);
+      ret = (a->from_id == b->from_id) && (a->serial_min >= b->serial_min) && (a->serial_max <= b->serial_max) && (a->serial_min <= a->serial_max);
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING,
-		  _x_ ("trying to compare NULL miss a=%p b=%p"), a, b);
+      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("trying to compare NULL miss a=%p b=%p"), a, b);
     }
 
   return ret;
@@ -169,21 +164,18 @@ lw6dat_miss_is_included (lw6dat_miss_t * a, lw6dat_miss_t * b)
  * Return value: 1 if included, else 0.
  */
 int
-lw6dat_miss_overlaps (lw6dat_miss_t * a, lw6dat_miss_t * b)
+lw6dat_miss_overlaps (lw6sys_context_t * sys_context, lw6dat_miss_t * a, lw6dat_miss_t * b)
 {
   int ret = 0;
 
   if (a && b)
     {
       ret = (a->from_id == b->from_id) && (a->serial_min <= a->serial_max)
-	&& (b->serial_min <= b->serial_max)
-	&& ((a->serial_max >= b->serial_min)
-	    || (a->serial_min <= b->serial_max));
+	&& (b->serial_min <= b->serial_max) && ((a->serial_max >= b->serial_min) || (a->serial_min <= b->serial_max));
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING,
-		  _x_ ("trying to compare NULL miss a=%p b=%p"), a, b);
+      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("trying to compare NULL miss a=%p b=%p"), a, b);
     }
 
   return ret;
