@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -27,37 +27,43 @@
 #include "dsp-internal.h"
 
 _lw6dsp_data_t *
-_lw6dsp_data_new ()
+_lw6dsp_data_new (lw6sys_context_t * sys_context)
 {
   _lw6dsp_data_t *ret = NULL;
 
-  ret = (_lw6dsp_data_t *) LW6SYS_CALLOC (sizeof (_lw6dsp_data_t));
+  ret = (_lw6dsp_data_t *) LW6SYS_CALLOC (sys_context, sizeof (_lw6dsp_data_t));
   if (ret)
     {
       ret->instant_fps = 0.0f;
       ret->average_fps = 0.0f;
+      ret->render_mutex = LW6SYS_MUTEX_CREATE (sys_context);
+      if (!ret->render_mutex)
+	{
+	  LW6SYS_FREE (sys_context, ret);
+	  ret = NULL;
+	}
     }
 
   return ret;
 }
 
 void
-_lw6dsp_data_free (_lw6dsp_data_t * data)
+_lw6dsp_data_free (lw6sys_context_t * sys_context, _lw6dsp_data_t * data)
 {
   if (data->gfx_backend_name)
     {
-      LW6SYS_FREE (data->gfx_backend_name);
+      LW6SYS_FREE (sys_context, data->gfx_backend_name);
     }
   if (data->gfx_backend)
     {
-      lw6sys_log (LW6SYS_LOG_WARNING,
+      lw6sys_log (sys_context, LW6SYS_LOG_WARNING,
 		  _x_
 		  ("graphics backend is still defined but we're freeing data, the backend should have be closed before, int the display thread (join function)"));
     }
   if (data->render_mutex)
     {
-      lw6sys_mutex_destroy (data->render_mutex);
+      LW6SYS_MUTEX_DESTROY (sys_context, data->render_mutex);
     }
-  _lw6dsp_param_clear (&(data->param));
-  LW6SYS_FREE (data);
+  _lw6dsp_param_clear (sys_context, &(data->param));
+  LW6SYS_FREE (sys_context, data);
 }
