@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -22,7 +22,7 @@
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
+#endif // HAVE_CONFIG_H
 
 #include "dsp-internal.h"
 
@@ -39,6 +39,7 @@ static volatile u_int32_t seq_id = 0;
 /**
  * lw6dsp_create_backend
  *
+ * @sys_context: global system context
  * @argc: argc as passed to @main
  * @argv: argv as passed to @main
  * @gfx_backend_name: the id/name of the gfx backend to use
@@ -53,14 +54,13 @@ static volatile u_int32_t seq_id = 0;
  * Return value: a newly allocated object.
  */
 lw6dsp_backend_t *
-lw6dsp_create_backend (int argc, const char *argv[],
-		       const char *gfx_backend_name)
+lw6dsp_create_backend (lw6sys_context_t * sys_context, int argc, const char *argv[], const char *gfx_backend_name)
 {
   lw6dsp_backend_t *ret = NULL;
   _lw6dsp_data_t *data = NULL;
   int ok = 0;
 
-  ret = (lw6dsp_backend_t *) LW6SYS_CALLOC (sizeof (lw6dsp_backend_t));
+  ret = (lw6dsp_backend_t *) LW6SYS_CALLOC (sys_context, sizeof (lw6dsp_backend_t));
   if (ret)
     {
       ret->id = 0;
@@ -68,20 +68,19 @@ lw6dsp_create_backend (int argc, const char *argv[],
 	{
 	  ret->id = ++seq_id;
 	}
-      data = _lw6dsp_data_new ();
+      data = _lw6dsp_data_new (sys_context);
       if (data)
 	{
 	  ret->data = (void *) data;
 	  data->argc = argc;
 	  data->argv = argv;
-	  data->gfx_backend_name = lw6sys_str_copy (gfx_backend_name);
+	  data->gfx_backend_name = lw6sys_str_copy (sys_context, gfx_backend_name);
 	  if (data->gfx_backend_name)
 	    {
-	      data->render_mutex = lw6sys_mutex_create ();
 	      if (data->render_mutex)
 		{
-		  lw6dsp_param_zero (&(data->param));
-		  if ((ret->input = lw6gui_input_new ()) != NULL)
+		  lw6dsp_param_zero (sys_context, &(data->param));
+		  if ((ret->input = lw6gui_input_new (sys_context)) != NULL)
 		    {
 		      ok = 1;
 		    }
@@ -93,14 +92,14 @@ lw6dsp_create_backend (int argc, const char *argv[],
 	{
 	  if (data)
 	    {
-	      _lw6dsp_data_free (data);
+	      _lw6dsp_data_free (sys_context, data);
 	    }
 	  data = NULL;
 	  if (ret->input)
 	    {
-	      lw6gui_input_free (ret->input);
+	      lw6gui_input_free (sys_context, ret->input);
 	    }
-	  LW6SYS_FREE (ret);
+	  LW6SYS_FREE (sys_context, ret);
 	  ret = NULL;
 	}
     }
@@ -111,6 +110,7 @@ lw6dsp_create_backend (int argc, const char *argv[],
 /**
  * lw6dsp_destroy_backend
  *
+ * @sys_context: global system context
  * @dsp_backend: the dsp_backend object to free
  *
  * Frees all ressources used by a dsp_backend object. Note that you must
@@ -119,7 +119,7 @@ lw6dsp_create_backend (int argc, const char *argv[],
  * Return value: none.
  */
 void
-lw6dsp_destroy_backend (lw6dsp_backend_t * dsp_backend)
+lw6dsp_destroy_backend (lw6sys_context_t * sys_context, lw6dsp_backend_t * dsp_backend)
 {
   if (dsp_backend)
     {
@@ -127,36 +127,35 @@ lw6dsp_destroy_backend (lw6dsp_backend_t * dsp_backend)
 	{
 	  if (dsp_backend->data)
 	    {
-	      _lw6dsp_data_free (dsp_backend->data);
+	      _lw6dsp_data_free (sys_context, dsp_backend->data);
 	      dsp_backend->data = NULL;
 	    }
 	  else
 	    {
-	      lw6sys_log (LW6SYS_LOG_WARNING,
-			  _x_ ("can't destroy backend with NULL data"));
+	      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("can't destroy backend with NULL data"));
 	    }
 	  if (dsp_backend->input)
 	    {
-	      lw6gui_input_free (dsp_backend->input);
+	      lw6gui_input_free (sys_context, dsp_backend->input);
 	      dsp_backend->input = NULL;
 	    }
 	}
       else
 	{
-	  lw6sys_log (LW6SYS_LOG_WARNING,
-		      _x_ ("trying to free running dsp_backend"));
+	  lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("trying to free running dsp_backend"));
 	}
-      LW6SYS_FREE (dsp_backend);
+      LW6SYS_FREE (sys_context, dsp_backend);
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("trying to free NULL backend"));
+      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("trying to free NULL backend"));
     }
 }
 
 /**
  * lw6dsp_repr
  *
+ * @sys_context: global system context
  * @dsp_backend: the object to represent
  *
  * Gives a short human-readable description of the object.
@@ -164,7 +163,7 @@ lw6dsp_destroy_backend (lw6dsp_backend_t * dsp_backend)
  * Return value: a newly allocated string, must be freed.
  */
 char *
-lw6dsp_repr (const lw6dsp_backend_t * dsp_backend)
+lw6dsp_repr (lw6sys_context_t * sys_context, const lw6dsp_backend_t * dsp_backend)
 {
   char *ret = NULL;
   _lw6dsp_data_t *data = NULL;
@@ -174,18 +173,16 @@ lw6dsp_repr (const lw6dsp_backend_t * dsp_backend)
 
   if (data && data->gfx_backend)
     {
-      gfx_backend_repr = lw6gfx_repr (data->gfx_backend);
+      gfx_backend_repr = lw6gfx_repr (sys_context, data->gfx_backend);
       if (gfx_backend_repr)
 	{
-	  ret =
-	    lw6sys_new_sprintf (_x_ ("%u using %s"), dsp_backend->id,
-				gfx_backend_repr);
-	  LW6SYS_FREE (gfx_backend_repr);
+	  ret = lw6sys_new_sprintf (sys_context, _x_ ("%u using %s"), dsp_backend->id, gfx_backend_repr);
+	  LW6SYS_FREE (sys_context, gfx_backend_repr);
 	}
     }
   else
     {
-      ret = lw6sys_new_sprintf (_x_ ("%u with no gfx"), dsp_backend->id);
+      ret = lw6sys_new_sprintf (sys_context, _x_ ("%u with no gfx"), dsp_backend->id);
     }
 
   return ret;
@@ -194,6 +191,7 @@ lw6dsp_repr (const lw6dsp_backend_t * dsp_backend)
 /**
  * lw6dsp_init
  *
+ * @sys_context: global system context
  * @dsp_backend: the dsp_backend to start
  * @param: parameters to pass to the display funcs
  * @resize_callback: a function which will be called when there's a resize event
@@ -207,45 +205,41 @@ lw6dsp_repr (const lw6dsp_backend_t * dsp_backend)
  * Return value: 1 if success, 0 if error.
  */
 int
-lw6dsp_init (lw6dsp_backend_t * dsp_backend, const lw6dsp_param_t * param,
-	     lw6gui_resize_callback_func_t resize_callback)
+lw6dsp_init (lw6sys_context_t * sys_context, lw6dsp_backend_t * dsp_backend, const lw6dsp_param_t * param, lw6gui_resize_callback_func_t resize_callback)
 {
   int ret = 0;
   int thread_ok = 0;
   _lw6dsp_data_t *data = NULL;
 
   data = (_lw6dsp_data_t *) dsp_backend->data;
-  if (lw6dsp_update (dsp_backend, param))
+  if (lw6dsp_update (sys_context, dsp_backend, param))
     {
       data->run = 1;
-      data->start_ticks = lw6sys_get_timestamp ();
+      data->start_ticks = lw6sys_get_timestamp (sys_context);
       data->resize_callback = resize_callback;
-      lw6gui_input_reset (dsp_backend->input);
-      if (lw6sys_vthread_is_running ())
+      lw6gui_input_reset (sys_context, dsp_backend->input);
+      if (lw6sys_vthread_is_running (sys_context))
 	{
 	  thread_ok =
-	    lw6sys_vthread_create ((lw6sys_thread_callback_func_t)
-				   _lw6dsp_thread_func,
+	    lw6sys_vthread_create (sys_context,
 				   (lw6sys_thread_callback_func_t)
-				   _lw6dsp_thread_join, dsp_backend->data);
+				   _lw6dsp_thread_func, (lw6sys_thread_callback_func_t) _lw6dsp_thread_join, dsp_backend->data);
 	}
       else
 	{
 	  dsp_backend->thread =
-	    lw6sys_thread_create ((lw6sys_thread_callback_func_t)
-				  _lw6dsp_thread_func,
-				  (lw6sys_thread_callback_func_t)
-				  _lw6dsp_thread_join, dsp_backend->data);
+	    lw6sys_thread_create (sys_context, (lw6sys_thread_callback_func_t) _lw6dsp_thread_func, (lw6sys_thread_callback_func_t) _lw6dsp_thread_join,
+				  dsp_backend->data);
 	  thread_ok = (dsp_backend->thread != NULL);
 	}
       if (thread_ok)
 	{
 #ifdef LW6_MAC_OS_X
-	  data->macosx_thread_handler = _lw6dsp_macosx_thread_init ();
-#endif
+	  data->macosx_thread_handler = _lw6dsp_macosx_thread_init (sys_context);
+#endif // LW6_MAC_OS_X
 	  while (!data->started)
 	    {
-	      lw6sys_idle ();
+	      lw6sys_idle (sys_context);
 	    }
 	  if (!data->failed)
 	    {
@@ -253,16 +247,15 @@ lw6dsp_init (lw6dsp_backend_t * dsp_backend, const lw6dsp_param_t * param,
 	    }
 	  else
 	    {
-	      lw6sys_log (LW6SYS_LOG_WARNING,
-			  _x_ ("stopping dsp_backend thread"));
+	      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("stopping dsp_backend thread"));
 	      data->run = 0;
-	      if (lw6sys_vthread_is_running ())
+	      if (lw6sys_vthread_is_running (sys_context))
 		{
-		  lw6sys_vthread_join ();
+		  lw6sys_vthread_join (sys_context);
 		}
 	      else
 		{
-		  lw6sys_thread_join (dsp_backend->thread);
+		  lw6sys_thread_join (sys_context, dsp_backend->thread);
 		  dsp_backend->thread = NULL;
 		}
 	    }
@@ -274,7 +267,7 @@ lw6dsp_init (lw6dsp_backend_t * dsp_backend, const lw6dsp_param_t * param,
       data->run = 0;
       data->started = 0;
       data->failed = 0;
-      _lw6dsp_param_clear (&(data->param));
+      _lw6dsp_param_clear (sys_context, &(data->param));
     }
 
   return ret;
@@ -283,6 +276,7 @@ lw6dsp_init (lw6dsp_backend_t * dsp_backend, const lw6dsp_param_t * param,
 /**
  * lw6dsp_quit
  *
+ * @sys_context: global system context
  * @dsp_backend: the dsp_backend to stop
  *
  * Stops a dsp_backend, that is, cancel rendering and unset the
@@ -292,7 +286,7 @@ lw6dsp_init (lw6dsp_backend_t * dsp_backend, const lw6dsp_param_t * param,
  * Return value: none.
  */
 void
-lw6dsp_quit (lw6dsp_backend_t * dsp_backend)
+lw6dsp_quit (lw6sys_context_t * sys_context, lw6dsp_backend_t * dsp_backend)
 {
   _lw6dsp_data_t *data = NULL;
 
@@ -309,19 +303,19 @@ lw6dsp_quit (lw6dsp_backend_t * dsp_backend)
 #ifdef LW6_MAC_OS_X
       if (data->macosx_thread_handler)
 	{
-	  _lw6dsp_macosx_thread_quit (data->macosx_thread_handler);
+	  _lw6dsp_macosx_thread_quit (sys_context, data->macosx_thread_handler);
 	}
-#endif
-      if (lw6sys_vthread_is_running ())
+#endif // LW6_MAC_OS_X
+      if (lw6sys_vthread_is_running (sys_context))
 	{
-	  lw6sys_vthread_join ();
+	  lw6sys_vthread_join (sys_context);
 	}
       else
 	{
-	  lw6sys_thread_join (dsp_backend->thread);
+	  lw6sys_thread_join (sys_context, dsp_backend->thread);
 	}
-      lw6gui_input_quit (dsp_backend->input);
-      _lw6dsp_param_clear (&(data->param));
+      lw6gui_input_quit (sys_context, dsp_backend->input);
+      _lw6dsp_param_clear (sys_context, &(data->param));
       dsp_backend->thread = NULL;
     }
 }
@@ -329,6 +323,7 @@ lw6dsp_quit (lw6dsp_backend_t * dsp_backend)
 /**
  * lw6dsp_update
  *
+ * @sys_context: global system context
  * @dsp_backend: the dsp_backend to update
  * @param: parameters to pass to the dsp_backend funcs
  *
@@ -347,7 +342,7 @@ lw6dsp_quit (lw6dsp_backend_t * dsp_backend)
  * Return value: 1 if success, 0 if error.
  */
 int
-lw6dsp_update (lw6dsp_backend_t * dsp_backend, const lw6dsp_param_t * param)
+lw6dsp_update (lw6sys_context_t * sys_context, lw6dsp_backend_t * dsp_backend, const lw6dsp_param_t * param)
 {
   int ret = 1;
   _lw6dsp_data_t *data = NULL;
@@ -355,6 +350,8 @@ lw6dsp_update (lw6dsp_backend_t * dsp_backend, const lw6dsp_param_t * param)
   int need_sync = 0;
   int i = 0;
 
+  lw6sys_log (sys_context, LW6SYS_LOG_DEBUG, _x_ ("dsp update begin"));
+
   data = (_lw6dsp_data_t *) dsp_backend->data;
 
   if (data)
@@ -368,17 +365,14 @@ lw6dsp_update (lw6dsp_backend_t * dsp_backend, const lw6dsp_param_t * param)
 	  /*
 	   * No need to do anything until next frame is drawn
 	   */
-	  while (data->nb_frames <= data->nb_frames_at_last_update
-		 && i < _LW6DSP_IDLE_LIMIT)
+	  while (data->nb_frames <= data->nb_frames_at_last_update && i < _LW6DSP_IDLE_LIMIT)
 	    {
-	      lw6sys_log (LW6SYS_LOG_DEBUG,
-			  _x_
-			  ("calling display_update too often, no frame drawn between two calls"));
+	      lw6sys_log (sys_context, LW6SYS_LOG_DEBUG, _x_ ("calling display_update too often, no frame drawn between two calls"));
 	      /*
 	       * We go idle for a very short time, this will just avoid the
 	       * caller to get stuck in 100% CPU greedy loops.
 	       */
-	      lw6sys_idle ();
+	      lw6sys_idle (sys_context);
 	      ++i;
 	    }
 	}
@@ -390,18 +384,16 @@ lw6dsp_update (lw6dsp_backend_t * dsp_backend, const lw6dsp_param_t * param)
        * of pilot, then the parent object can be freed.
        */
       data->nb_frames_at_last_update = data->nb_frames;
-      diff = _lw6dsp_param_diff (data, param);
+      diff = _lw6dsp_param_diff (sys_context, data, param);
       if (data->input)
 	{
-	  need_sync = lw6gui_input_need_sync (data->input);
+	  need_sync = lw6gui_input_need_sync (sys_context, data->input);
 	}
       if (diff || need_sync)
 	{
-	  lw6sys_log (LW6SYS_LOG_DEBUG,
-		      _x_ ("dsp param update diff=%d sync=%d"), diff,
-		      need_sync);
+	  lw6sys_log (sys_context, LW6SYS_LOG_DEBUG, _x_ ("dsp param update diff=%d sync=%d"), diff, need_sync);
 
-	  lw6sys_mutex_lock (data->render_mutex);
+	  LW6SYS_MUTEX_LOCK (sys_context, data->render_mutex);
 
 	  if (diff & _LW6DSP_PARAM_DIFF_MISC)
 	    {
@@ -417,9 +409,9 @@ lw6dsp_update (lw6dsp_backend_t * dsp_backend, const lw6dsp_param_t * param)
 	    {
 	      if (data->param.look)
 		{
-		  lw6gui_look_free (data->param.look);
+		  lw6gui_look_free (sys_context, data->param.look);
 		}
-	      data->param.look = lw6gui_look_dup (param->look);
+	      data->param.look = lw6gui_look_dup (sys_context, param->look);
 	    }
 
 	  if (diff & _LW6DSP_PARAM_DIFF_MENU)
@@ -430,24 +422,21 @@ lw6dsp_update (lw6dsp_backend_t * dsp_backend, const lw6dsp_param_t * param)
 		    {
 		      if (data->last_menu_id == param->menu->id)
 			{
-			  lw6sys_log (LW6SYS_LOG_DEBUG,
-				      _x_ ("synchronising menu"));
-			  lw6gui_menu_sync (data->param.menu, param->menu);
+			  lw6sys_log (sys_context, LW6SYS_LOG_DEBUG, _x_ ("synchronising menu"));
+			  lw6gui_menu_sync (sys_context, data->param.menu, param->menu);
 			}
 		      else
 			{
-			  lw6sys_log (LW6SYS_LOG_DEBUG,
-				      _x_
-				      ("new menu is totally different, duping it"));
-			  lw6gui_menu_free (data->param.menu);
-			  data->param.menu = lw6gui_menu_dup (param->menu);
+			  lw6sys_log (sys_context, LW6SYS_LOG_DEBUG, _x_ ("new menu is totally different, duping it"));
+			  lw6gui_menu_free (sys_context, data->param.menu);
+			  data->param.menu = lw6gui_menu_dup (sys_context, param->menu);
 			  data->last_menu_id = param->menu->id;
 			}
 		    }
 		  else
 		    {
-		      lw6sys_log (LW6SYS_LOG_DEBUG, _x_ ("new menu is NULL"));
-		      lw6gui_menu_free (data->param.menu);
+		      lw6sys_log (sys_context, LW6SYS_LOG_DEBUG, _x_ ("new menu is NULL"));
+		      lw6gui_menu_free (sys_context, data->param.menu);
 		      data->param.menu = NULL;
 		      data->last_menu_id = 0;
 		    }
@@ -456,10 +445,8 @@ lw6dsp_update (lw6dsp_backend_t * dsp_backend, const lw6dsp_param_t * param)
 		{
 		  if (param->menu)
 		    {
-		      lw6sys_log (LW6SYS_LOG_DEBUG,
-				  _x_
-				  ("new menu and no previous one, duping it"));
-		      data->param.menu = lw6gui_menu_dup (param->menu);
+		      lw6sys_log (sys_context, LW6SYS_LOG_DEBUG, _x_ ("new menu and no previous one, duping it"));
+		      data->param.menu = lw6gui_menu_dup (sys_context, param->menu);
 		      data->last_menu_id = param->menu->id;
 		    }
 		}
@@ -487,19 +474,22 @@ lw6dsp_update (lw6dsp_backend_t * dsp_backend, const lw6dsp_param_t * param)
 	    }
 	  if (dsp_backend->input != NULL && data->input != NULL)
 	    {
-	      lw6gui_input_sync (dsp_backend->input, data->input);
+	      lw6gui_input_sync (sys_context, dsp_backend->input, data->input);
 	    }
 
-	  lw6sys_mutex_unlock (data->render_mutex);
+	  LW6SYS_MUTEX_UNLOCK (sys_context, data->render_mutex);
 	}
     }
 
+  lw6sys_log (sys_context, LW6SYS_LOG_DEBUG, _x_ ("dsp update end"));
+
   return ret;
 }
 
 /**
  * lw6dsp_get_nb_frames
  *
+ * @sys_context: global system context
  * @dsp_backend: the dsp_backend to query
  *
  * Returns the number of frames displayed since the display was started.
@@ -507,7 +497,7 @@ lw6dsp_update (lw6dsp_backend_t * dsp_backend, const lw6dsp_param_t * param)
  * Return value: the number of frames displayed.
  */
 int
-lw6dsp_get_nb_frames (lw6dsp_backend_t * dsp_backend)
+lw6dsp_get_nb_frames (lw6sys_context_t * sys_context, lw6dsp_backend_t * dsp_backend)
 {
   int ret = 0;
   _lw6dsp_data_t *data = NULL;
@@ -536,7 +526,7 @@ lw6dsp_get_nb_frames (lw6dsp_backend_t * dsp_backend)
  * Return value: the number of milliseconds it took to draw screen
  */
 int
-lw6dsp_get_last_frame_rendering_time (lw6dsp_backend_t * dsp_backend)
+lw6dsp_get_last_frame_rendering_time (lw6sys_context_t * sys_context, lw6dsp_backend_t * dsp_backend)
 {
   int ret = 0;
   _lw6dsp_data_t *data = NULL;
@@ -558,6 +548,7 @@ lw6dsp_get_last_frame_rendering_time (lw6dsp_backend_t * dsp_backend)
 /**
  * lw6dsp_get_instant_fps
  *
+ * @sys_context: global system context
  * @dsp_backend: the dsp_backend to query
  *
  * Returns the current frames per sec display rate. This is the instant value,
@@ -566,7 +557,7 @@ lw6dsp_get_last_frame_rendering_time (lw6dsp_backend_t * dsp_backend)
  * Return value: the current instant display rate.
  */
 int
-lw6dsp_get_instant_fps (lw6dsp_backend_t * dsp_backend)
+lw6dsp_get_instant_fps (lw6sys_context_t * sys_context, lw6dsp_backend_t * dsp_backend)
 {
   int ret = 0;
   _lw6dsp_data_t *data = NULL;
@@ -588,6 +579,7 @@ lw6dsp_get_instant_fps (lw6dsp_backend_t * dsp_backend)
 /**
  * lw6dsp_get_average_fps
  *
+ * @sys_context: global system context
  * @dsp_backend: the dsp_backend to query
  *
  * Returns the current frames per sec display rate. This is not absolutely
@@ -596,7 +588,7 @@ lw6dsp_get_instant_fps (lw6dsp_backend_t * dsp_backend)
  * Return value: the current averaged display rate.
  */
 int
-lw6dsp_get_average_fps (lw6dsp_backend_t * dsp_backend)
+lw6dsp_get_average_fps (lw6sys_context_t * sys_context, lw6dsp_backend_t * dsp_backend)
 {
   int ret = 0;
   _lw6dsp_data_t *data = NULL;
@@ -618,6 +610,7 @@ lw6dsp_get_average_fps (lw6dsp_backend_t * dsp_backend)
 /**
  * lw6dsp_get_video_mode
  *
+ * @sys_context: global system context
  * @dsp_backend: the dsp_backend to query
  * @video_mode: a structure which will contain the results
  *
@@ -628,8 +621,7 @@ lw6dsp_get_average_fps (lw6dsp_backend_t * dsp_backend)
  * Return value: 1 if ok, 0 if failure (mode not set)
  */
 int
-lw6dsp_get_video_mode (lw6dsp_backend_t * dsp_backend,
-		       lw6gui_video_mode_t * video_mode)
+lw6dsp_get_video_mode (lw6sys_context_t * sys_context, lw6dsp_backend_t * dsp_backend, lw6gui_video_mode_t * video_mode)
 {
   int ret = 0;
   _lw6dsp_data_t *data = NULL;
@@ -642,13 +634,13 @@ lw6dsp_get_video_mode (lw6dsp_backend_t * dsp_backend,
        * Here we can't do a dirty read as with atomic values such as fps,
        * so we reserve the mutex
        */
-      lw6sys_mutex_lock (data->render_mutex);
+      LW6SYS_MUTEX_LOCK (sys_context, data->render_mutex);
       if (data->run && data->started)
 	{
 	  (*video_mode) = data->video_mode_obtained;
 	  ret = 1;
 	}
-      lw6sys_mutex_unlock (data->render_mutex);
+      LW6SYS_MUTEX_UNLOCK (sys_context, data->render_mutex);
     }
 
   return ret;
@@ -657,6 +649,7 @@ lw6dsp_get_video_mode (lw6dsp_backend_t * dsp_backend,
 /**
  * lw6dsp_get_fullscreen_modes
  *
+ * @sys_context: global system context
  * @dsp_backend: the dsp_backend to query
  * @fullscreen_modes: a structure which will contain the results
  *
@@ -668,8 +661,7 @@ lw6dsp_get_video_mode (lw6dsp_backend_t * dsp_backend,
  * Return value: 1 if ok, 0 if failure (mode not set)
  */
 int
-lw6dsp_get_fullscreen_modes (lw6dsp_backend_t * dsp_backend,
-			     lw6gui_fullscreen_modes_t * fullscreen_modes)
+lw6dsp_get_fullscreen_modes (lw6sys_context_t * sys_context, lw6dsp_backend_t * dsp_backend, lw6gui_fullscreen_modes_t * fullscreen_modes)
 {
   int ret = 0;
   _lw6dsp_data_t *data = NULL;
@@ -682,13 +674,13 @@ lw6dsp_get_fullscreen_modes (lw6dsp_backend_t * dsp_backend,
        * Here we can't do a dirty read as with atomic values such as fps,
        * so we reserve the mutex
        */
-      lw6sys_mutex_lock (data->render_mutex);
+      LW6SYS_MUTEX_LOCK (sys_context, data->render_mutex);
       if (data->run && data->started)
 	{
 	  (*fullscreen_modes) = data->fullscreen_modes;
 	  ret = 1;
 	}
-      lw6sys_mutex_unlock (data->render_mutex);
+      LW6SYS_MUTEX_UNLOCK (sys_context, data->render_mutex);
     }
 
   return ret;
