@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -30,6 +30,7 @@
 /**
  * lw6dsp_param_zero
  *
+ * @sys_context: global system context
  * @param: the structure to initialize
  *
  * Fills a display param struct with zeros, this is mandatory
@@ -38,28 +39,28 @@
  * Return value: none.
  */
 void
-lw6dsp_param_zero (lw6dsp_param_t * param)
+lw6dsp_param_zero (lw6sys_context_t * sys_context, lw6dsp_param_t * param)
 {
   memset (param, 0, sizeof (lw6dsp_param_t));
 }
 
 void
-_lw6dsp_param_clear (lw6dsp_param_t * param)
+_lw6dsp_param_clear (lw6sys_context_t * sys_context, lw6dsp_param_t * param)
 {
   if (param->menu)
     {
-      lw6gui_menu_free (param->menu);
+      lw6gui_menu_free (sys_context, param->menu);
     }
   if (param->look)
     {
-      lw6gui_look_free (param->look);
+      lw6gui_look_free (sys_context, param->look);
     }
 
-  lw6dsp_param_zero (param);
+  lw6dsp_param_zero (sys_context, param);
 }
 
 int
-_lw6dsp_param_diff (const _lw6dsp_data_t * data, const lw6dsp_param_t * param)
+_lw6dsp_param_diff (lw6sys_context_t * sys_context, const _lw6dsp_data_t * data, const lw6dsp_param_t * param)
 {
   int ret = 0;
 
@@ -68,18 +69,17 @@ _lw6dsp_param_diff (const _lw6dsp_data_t * data, const lw6dsp_param_t * param)
       ret = ret | _LW6DSP_PARAM_DIFF_MISC;
     }
 
-  if (!lw6gui_video_mode_is_same
-      (&(data->param.video_mode), &(param->video_mode)))
+  if (!lw6gui_video_mode_is_same (sys_context, &(data->param.video_mode), &(param->video_mode)))
     {
       ret = ret | _LW6DSP_PARAM_DIFF_VIDEO_MODE;
     }
 
-  if (!lw6gui_look_is_same (data->param.look, param->look))
+  if (!lw6gui_look_is_same (sys_context, data->param.look, param->look))
     {
       ret = ret | _LW6DSP_PARAM_DIFF_LOOK;
     }
 
-  if (!lw6gui_menu_is_same (data->param.menu, param->menu))
+  if (!lw6gui_menu_is_same (sys_context, data->param.menu, param->menu))
     {
       ret = ret | _LW6DSP_PARAM_DIFF_MENU;
     }
