@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -32,22 +32,24 @@
 /**
  * lw6gen_seed_new
  *
+ * @sys_context: global system context
+ *
  * Generate a new random seed. The seed is composed of letters and numbers.
  *
  * Return value: newly allocated string.
  */
 char *
-lw6gen_seed_new ()
+lw6gen_seed_new (lw6sys_context_t * sys_context)
 {
   char *ret = NULL;
   int i = 0;
 
-  ret = LW6SYS_CALLOC (LW6GEN_SEED_LENGTH + 1);
+  ret = LW6SYS_CALLOC (sys_context, LW6GEN_SEED_LENGTH + 1);
   if (ret)
     {
       for (i = 0; i < LW6GEN_SEED_LENGTH; ++i)
 	{
-	  ret[i] = lw6gen_seed_char ();
+	  ret[i] = lw6gen_seed_char (sys_context);
 	}
     }
 
@@ -57,6 +59,7 @@ lw6gen_seed_new ()
 /**
  * lw6gen_seed_normalize
  *
+ * @sys_context: global system context
  * @seed: the seed to normalize
  *
  * Builds a normalized seed from an arbitrary string. The idea is to
@@ -66,7 +69,7 @@ lw6gen_seed_new ()
  * Return value: newly allocated string.
  */
 char *
-lw6gen_seed_normalize (const char *seed)
+lw6gen_seed_normalize (lw6sys_context_t * sys_context, const char *seed)
 {
   char *ret = NULL;
   int i = 0;
@@ -74,7 +77,7 @@ lw6gen_seed_normalize (const char *seed)
   int len_chars = 0;
   int len_seed = 0;
 
-  ret = LW6SYS_CALLOC (LW6GEN_SEED_LENGTH + 1);
+  ret = LW6SYS_CALLOC (sys_context, LW6GEN_SEED_LENGTH + 1);
   if (ret)
     {
       len_chars = strlen (LW6GEN_SEED_CHARS);
@@ -99,12 +102,14 @@ lw6gen_seed_normalize (const char *seed)
 /**
  * lw6gen_seed_char
  *
+ * @sys_context: global system context
+ *
  * Returns a random char suitable for seed (letter or digit).
  *
  * Return value: a single char
  */
 char
-lw6gen_seed_char ()
+lw6gen_seed_char (lw6sys_context_t * sys_context)
 {
   char ret = ' ';
   int len = 0;
@@ -116,7 +121,7 @@ lw6gen_seed_char ()
    * array size and simplifies code in lw6gen_seed_new.
    */
   len = strlen (LW6GEN_SEED_CHARS);
-  ret = LW6GEN_SEED_CHARS[lw6sys_random (len)];
+  ret = LW6GEN_SEED_CHARS[lw6sys_random (sys_context, len)];
 
   return ret;
 }
