@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -40,9 +40,10 @@
 typedef struct _lw6gen_test_data_s
 {
   int ret;
+  lw6sys_context_t *sys_context;
 } _lw6gen_test_data_t;
 
-static _lw6gen_test_data_t _test_data = { 0 };
+static _lw6gen_test_data_t _test_data = { 0, NULL };
 
 /*
  * test create
@@ -51,48 +52,40 @@ static void
 _test_create ()
 {
   int ret = 0;
+  lw6sys_context_t *sys_context = NULL;
 
   LW6SYS_TEST_FUNCTION_BEGIN;
 
   {
     lw6map_level_t *level = NULL;
     char *repr = NULL;
-    lw6sys_log (LW6SYS_LOG_NOTICE,
-		_x_ ("creating map from seed \"%s\" with size %dx%d"),
-		_TEST_SEED, _TEST_WIDTH, _TEST_HEIGHT);
-    level = lw6gen_create_from_seed (_TEST_SEED, _TEST_WIDTH, _TEST_HEIGHT);
+    lw6sys_log (sys_context, LW6SYS_LOG_NOTICE, _x_ ("creating map from seed \"%s\" with size %dx%d"), _TEST_SEED, _TEST_WIDTH, _TEST_HEIGHT);
+    level = lw6gen_create_from_seed (sys_context, _TEST_SEED, _TEST_WIDTH, _TEST_HEIGHT);
     if (level)
       {
-	repr = lw6map_repr (level);
+	repr = lw6map_repr (sys_context, level);
 	if (repr)
 	  {
-	    if (level->body.shape.w == _TEST_WIDTH
-		&& level->body.shape.h == _TEST_HEIGHT)
+	    if (level->body.shape.w == _TEST_WIDTH && level->body.shape.h == _TEST_HEIGHT)
 	      {
-		lw6sys_log (LW6SYS_LOG_NOTICE,
-			    _x_ ("built map \"%s\" from seed \"%s\""), repr,
-			    _TEST_SEED);
-		LW6SYS_FREE (repr);
+		lw6sys_log (sys_context, LW6SYS_LOG_NOTICE, _x_ ("built map \"%s\" from seed \"%s\""), repr, _TEST_SEED);
+		LW6SYS_FREE (sys_context, repr);
 
 		ret = 1;
 	      }
 	    else
 	      {
-		lw6sys_log (LW6SYS_LOG_WARNING,
+		lw6sys_log (sys_context, LW6SYS_LOG_WARNING,
 			    _x_
 			    ("map created from seed \"%s\" with bad size %dx%d, should have been %dx%d"),
-			    _TEST_SEED, level->body.shape.w,
-			    level->body.shape.h, _TEST_WIDTH, _TEST_HEIGHT);
+			    _TEST_SEED, level->body.shape.w, level->body.shape.h, _TEST_WIDTH, _TEST_HEIGHT);
 	      }
 	  }
-	lw6map_free (level);
+	lw6map_free (sys_context, level);
       }
     else
       {
-	lw6sys_log (LW6SYS_LOG_WARNING,
-		    _x_
-		    ("unable to create map from seed \"%s\" with size %dx%d"),
-		    _TEST_SEED, _TEST_WIDTH, _TEST_HEIGHT);
+	lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("unable to create map from seed \"%s\" with size %dx%d"), _TEST_SEED, _TEST_WIDTH, _TEST_HEIGHT);
       }
   }
 
@@ -106,68 +99,58 @@ static void
 _test_seed ()
 {
   int ret = 1;
+  lw6sys_context_t *sys_context = NULL;
 
   LW6SYS_TEST_FUNCTION_BEGIN;
 
   {
     char *seed = NULL;
 
-    seed = lw6gen_seed_new ();
+    seed = lw6gen_seed_new (sys_context);
     if (seed)
       {
-	lw6sys_log (LW6SYS_LOG_NOTICE,
-		    _x_ ("generated new random seed \"%s\""), seed);
-	LW6SYS_FREE (seed);
+	lw6sys_log (sys_context, LW6SYS_LOG_NOTICE, _x_ ("generated new random seed \"%s\""), seed);
+	LW6SYS_FREE (sys_context, seed);
       }
     else
       {
 	ret = 0;
       }
 
-    seed = lw6gen_seed_normalize (_TEST_SEED_SHORT_SRC);
+    seed = lw6gen_seed_normalize (sys_context, _TEST_SEED_SHORT_SRC);
     if (seed)
       {
-	lw6sys_log (LW6SYS_LOG_NOTICE,
-		    _x_ ("normalizing short seed \"%s\" -> \"%s\""),
-		    _TEST_SEED_SHORT_SRC, seed);
-	if (lw6sys_str_is_same (seed, _TEST_SEED_SHORT_DST))
+	lw6sys_log (sys_context, LW6SYS_LOG_NOTICE, _x_ ("normalizing short seed \"%s\" -> \"%s\""), _TEST_SEED_SHORT_SRC, seed);
+	if (lw6sys_str_is_same (sys_context, seed, _TEST_SEED_SHORT_DST))
 	  {
-	    lw6sys_log (LW6SYS_LOG_NOTICE, _x_ ("ouput is correct"));
+	    lw6sys_log (sys_context, LW6SYS_LOG_NOTICE, _x_ ("ouput is correct"));
 	  }
 	else
 	  {
-	    lw6sys_log (LW6SYS_LOG_WARNING,
-			_x_
-			("bad ouput, should have been \"%s\" but is \"%s\""),
-			_TEST_SEED_SHORT_DST, seed);
+	    lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("bad ouput, should have been \"%s\" but is \"%s\""), _TEST_SEED_SHORT_DST, seed);
 	    ret = 0;
 	  }
-	LW6SYS_FREE (seed);
+	LW6SYS_FREE (sys_context, seed);
       }
     else
       {
 	ret = 0;
       }
 
-    seed = lw6gen_seed_normalize (_TEST_SEED_LONG_SRC);
+    seed = lw6gen_seed_normalize (sys_context, _TEST_SEED_LONG_SRC);
     if (seed)
       {
-	lw6sys_log (LW6SYS_LOG_NOTICE,
-		    _x_ ("normalizing long seed \"%s\" -> \"%s\""),
-		    _TEST_SEED_LONG_SRC, seed);
-	if (lw6sys_str_is_same (seed, _TEST_SEED_LONG_DST))
+	lw6sys_log (sys_context, LW6SYS_LOG_NOTICE, _x_ ("normalizing long seed \"%s\" -> \"%s\""), _TEST_SEED_LONG_SRC, seed);
+	if (lw6sys_str_is_same (sys_context, seed, _TEST_SEED_LONG_DST))
 	  {
-	    lw6sys_log (LW6SYS_LOG_NOTICE, _x_ ("ouput is correct"));
+	    lw6sys_log (sys_context, LW6SYS_LOG_NOTICE, _x_ ("ouput is correct"));
 	  }
 	else
 	  {
-	    lw6sys_log (LW6SYS_LOG_WARNING,
-			_x_
-			("bad ouput, should have been \"%s\" but is \"%s\""),
-			_TEST_SEED_LONG_DST, seed);
+	    lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("bad ouput, should have been \"%s\" but is \"%s\""), _TEST_SEED_LONG_DST, seed);
 	    ret = 0;
 	  }
-	LW6SYS_FREE (seed);
+	LW6SYS_FREE (sys_context, seed);
       }
     else
       {
@@ -181,20 +164,27 @@ _test_seed ()
 static int
 _setup_init ()
 {
-  lw6sys_log (LW6SYS_LOG_NOTICE, _x_ ("init libgen CUnit test suite"));
+  lw6sys_context_t *sys_context = _test_data.sys_context;
+
+  lw6sys_log (sys_context, LW6SYS_LOG_NOTICE, _x_ ("init libgen CUnit test suite"));
+
   return CUE_SUCCESS;
 }
 
 static int
 _setup_quit ()
 {
-  lw6sys_log (LW6SYS_LOG_NOTICE, _x_ ("quit libgen CUnit test suite"));
+  lw6sys_context_t *sys_context = _test_data.sys_context;
+
+  lw6sys_log (sys_context, LW6SYS_LOG_NOTICE, _x_ ("quit libgen CUnit test suite"));
+
   return CUE_SUCCESS;
 }
 
 /**
  * lw6gen_test_register
  *
+ * @sys_context: global system context
  * @mode: test mode (bitmask)
  *
  * Registers all tests for the libgen module.
@@ -202,18 +192,20 @@ _setup_quit ()
  * Return value: 1 if test is successfull, 0 on error.
  */
 int
-lw6gen_test_register (int mode)
+lw6gen_test_register (lw6sys_context_t * sys_context, int mode)
 {
   int ret = 1;
-  CU_Suite *suite;
+  CU_Suite *suite = NULL;
+
+  _test_data.sys_context = sys_context;
 
   if (lw6sys_false ())
     {
       /*
        * Just to make sure most functions are stuffed in the binary
        */
-      lw6sys_test_register (mode);
-      lw6map_test_register (mode);
+      lw6sys_test_register (sys_context, mode);
+      lw6map_test_register (sys_context, mode);
     }
 
   suite = CU_add_suite ("lw6gen", _setup_init, _setup_quit);
@@ -224,9 +216,7 @@ lw6gen_test_register (int mode)
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING,
-		  _x_ ("unable to add CUnit test suite, error msg is \"%s\""),
-		  CU_get_error_msg ());
+      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("unable to add CUnit test suite, error msg is \"%s\""), CU_get_error_msg ());
       ret = 0;
     }
 
@@ -236,6 +226,7 @@ lw6gen_test_register (int mode)
 /**
  * lw6gen_test_run
  *
+ * @sys_context: global system context
  * @mode: test mode (bitmask)
  *
  * Runs the @gen module test suite, testing most (if not all...)
@@ -244,12 +235,14 @@ lw6gen_test_register (int mode)
  * Return value: 1 if test is successfull, 0 on error.
  */
 int
-lw6gen_test_run (int mode)
+lw6gen_test_run (lw6sys_context_t * sys_context, int mode)
 {
   int ret = 0;
 
   _test_data.ret = 1;
-  if (lw6sys_cunit_run_tests (mode))
+  _test_data.sys_context = sys_context;
+
+  if (lw6sys_cunit_run_tests (sys_context, mode))
     {
       ret = _test_data.ret;
     }
