@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -30,16 +30,15 @@
 #define LW6GEN_SEED_LENGTH 16
 
 /* gen-create.c */
-extern lw6map_level_t *lw6gen_create_from_seed (const char *seed, int map_w,
-						int map_h);
+extern lw6map_level_t *lw6gen_create_from_seed (lw6sys_context_t * sys_context, const char *seed, int map_w, int map_h);
 
 /* gen-seed.c */
-extern char *lw6gen_seed_new ();
-extern char *lw6gen_seed_normalize (const char *seed);
-extern char lw6gen_seed_char ();
+extern char *lw6gen_seed_new (lw6sys_context_t * sys_context);
+extern char *lw6gen_seed_normalize (lw6sys_context_t * sys_context, const char *seed);
+extern char lw6gen_seed_char (lw6sys_context_t * sys_context);
 
 /* gen-test.c */
-extern int lw6gen_test_register (int mode);
-extern int lw6gen_test_run (int mode);
+extern int lw6gen_test_register (lw6sys_context_t * sys_context, int mode);
+extern int lw6gen_test_run (lw6sys_context_t * sys_context, int mode);
 
 #endif
