@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -27,15 +27,15 @@
 #include "gfx.h"
 
 static void
-_warning (const char *func_name)
+_warning (lw6sys_context_t * sys_context, const char *func_name)
 {
-  lw6sys_log (LW6SYS_LOG_WARNING,
-	      _x_ ("gfx backend function \"%s\" is not defined"), func_name);
+  lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("gfx backend function \"%s\" is not defined"), func_name);
 }
 
 /**
  * lw6gfx_init
  *
+ * @sys_context: global system context
  * @backend: the graphical backend to use
  * @video_mode: the video mode to use at start up
  * @resize_callback: a callback function which will be called at each resize event
@@ -47,20 +47,21 @@ _warning (const char *func_name)
  * Return value: 1 on success, 0 if not
  */
 int
-lw6gfx_init (lw6gfx_backend_t * backend, lw6gui_video_mode_t * video_mode,
-	     lw6gui_resize_callback_func_t resize_callback)
+lw6gfx_init (lw6sys_context_t * sys_context, lw6gfx_backend_t * backend, lw6gui_video_mode_t * video_mode, lw6gui_resize_callback_func_t resize_callback)
 {
   LW6SYS_BACKEND_FUNCTION_BEGIN;
 
   if (backend->init)
     {
-      backend->gfx_context =
-	backend->init (backend->argc, backend->argv, video_mode,
-		       resize_callback);
+      if (LW6SYS_MUTEX_LOCK (sys_context, backend->call_lock))
+	{
+	  backend->gfx_context = backend->init (sys_context, backend->argc, backend->argv, video_mode, resize_callback);
+	  LW6SYS_MUTEX_UNLOCK (sys_context, backend->call_lock);
+	}
     }
   else
     {
-      _warning (__FUNCTION__);
+      _warning (sys_context, __FUNCTION__);
     }
 
   LW6SYS_BACKEND_FUNCTION_END;
@@ -71,6 +72,7 @@ lw6gfx_init (lw6gfx_backend_t * backend, lw6gui_video_mode_t * video_mode,
 /**
  * lw6gfx_quit
  *
+ * @sys_context: global system context
  * @backend: the backend to quit
  *
  * Uninitializes the backend, that is, exits the graphical mode. All threads that
@@ -79,25 +81,29 @@ lw6gfx_init (lw6gfx_backend_t * backend, lw6gui_video_mode_t * video_mode,
  * Return value: none.
  */
 void
-lw6gfx_quit (lw6gfx_backend_t * backend)
+lw6gfx_quit (lw6sys_context_t * sys_context, lw6gfx_backend_t * backend)
 {
   LW6SYS_BACKEND_FUNCTION_BEGIN;
 
   if (backend->quit)
     {
-      /*
-       * It's important to check that backend is not NULL for
-       * quit can *really* be called several times on the same backend
-       */
-      if (backend->gfx_context)
+      if (LW6SYS_MUTEX_LOCK (sys_context, backend->call_lock))
 	{
-	  backend->quit (backend->gfx_context);
-	  backend->gfx_context = NULL;
+	  /*
+	   * It's important to check that backend is not NULL for
+	   * quit can *really* be called several times on the same backend
+	   */
+	  if (backend->gfx_context)
+	    {
+	      backend->quit (sys_context, backend->gfx_context);
+	      backend->gfx_context = NULL;
+	    }
+	  LW6SYS_MUTEX_UNLOCK (sys_context, backend->call_lock);
 	}
     }
   else
     {
-      _warning (__FUNCTION__);
+      _warning (sys_context, __FUNCTION__);
     }
 
   LW6SYS_BACKEND_FUNCTION_END;
@@ -106,6 +112,7 @@ lw6gfx_quit (lw6gfx_backend_t * backend)
 /**
  * lw6gfx_repr
  *
+ * @sys_context: global system context
  * @backend: the backend to represent
  *
  * Returns a readable version of the backend object.
@@ -113,7 +120,7 @@ lw6gfx_quit (lw6gfx_backend_t * backend)
  * Return value: a newly allocated pointer.
  */
 char *
-lw6gfx_repr (const lw6gfx_backend_t * backend)
+lw6gfx_repr (lw6sys_context_t * sys_context, const lw6gfx_backend_t * backend)
 {
   char *ret = NULL;
 
@@ -121,11 +128,15 @@ lw6gfx_repr (const lw6gfx_backend_t * backend)
 
   if (backend->repr)
     {
-      ret = backend->repr (backend->gfx_context, backend->id);
+      if (LW6SYS_MUTEX_LOCK (sys_context, backend->call_lock))
+	{
+	  ret = backend->repr (sys_context, backend->gfx_context, backend->id);
+	  LW6SYS_MUTEX_UNLOCK (sys_context, backend->call_lock);
+	}
     }
   else
     {
-      _warning (__FUNCTION__);
+      _warning (sys_context, __FUNCTION__);
     }
 
   LW6SYS_BACKEND_FUNCTION_END;
@@ -136,6 +147,7 @@ lw6gfx_repr (const lw6gfx_backend_t * backend)
 /**
  * lw6gfx_set_video_mode
  *
+ * @sys_context: global system context
  * @backend: the backend to use
  * @video_mode: the new video mode
  *
@@ -149,8 +161,7 @@ lw6gfx_repr (const lw6gfx_backend_t * backend)
  * Return value: 1 on success, 0 on failure;
  */
 int
-lw6gfx_set_video_mode (lw6gfx_backend_t * backend,
-		       lw6gui_video_mode_t * video_mode)
+lw6gfx_set_video_mode (lw6sys_context_t * sys_context, lw6gfx_backend_t * backend, lw6gui_video_mode_t * video_mode)
 {
   int ret = 0;
 
@@ -158,11 +169,15 @@ lw6gfx_set_video_mode (lw6gfx_backend_t * backend,
 
   if (backend->set_video_mode)
     {
-      ret = backend->set_video_mode (backend->gfx_context, video_mode);
+      if (LW6SYS_MUTEX_LOCK (sys_context, backend->call_lock))
+	{
+	  ret = backend->set_video_mode (sys_context, backend->gfx_context, video_mode);
+	  LW6SYS_MUTEX_UNLOCK (sys_context, backend->call_lock);
+	}
     }
   else
     {
-      _warning (__FUNCTION__);
+      _warning (sys_context, __FUNCTION__);
     }
 
   LW6SYS_BACKEND_FUNCTION_END;
@@ -173,6 +188,7 @@ lw6gfx_set_video_mode (lw6gfx_backend_t * backend,
 /**
  * lw6gfx_get_video_mode
  *
+ * @sys_context: global system context
  * @backend: the backend to use
  * @video_mode: the current video mode (will be overwritten, out parameter)
  *
@@ -181,8 +197,7 @@ lw6gfx_set_video_mode (lw6gfx_backend_t * backend,
  * Return value: 1 on success, 0 on failure;
  */
 int
-lw6gfx_get_video_mode (lw6gfx_backend_t * backend,
-		       lw6gui_video_mode_t * video_mode)
+lw6gfx_get_video_mode (lw6sys_context_t * sys_context, lw6gfx_backend_t * backend, lw6gui_video_mode_t * video_mode)
 {
   int ret = 0;
 
@@ -190,11 +205,15 @@ lw6gfx_get_video_mode (lw6gfx_backend_t * backend,
 
   if (backend->get_video_mode)
     {
-      ret = backend->get_video_mode (backend->gfx_context, video_mode);
+      if (LW6SYS_MUTEX_LOCK (sys_context, backend->call_lock))
+	{
+	  ret = backend->get_video_mode (sys_context, backend->gfx_context, video_mode);
+	  LW6SYS_MUTEX_UNLOCK (sys_context, backend->call_lock);
+	}
     }
   else
     {
-      _warning (__FUNCTION__);
+      _warning (sys_context, __FUNCTION__);
     }
 
   LW6SYS_BACKEND_FUNCTION_END;
@@ -205,6 +224,7 @@ lw6gfx_get_video_mode (lw6gfx_backend_t * backend,
 /**
  * lw6gfx_get_fullscreen_modes
  *
+ * @sys_context: global system context
  * @backend: the backend to use
  * @fullscreen_modes: the available fullscreen modes (will be overwritten, out parameter)
  *
@@ -213,8 +233,7 @@ lw6gfx_get_video_mode (lw6gfx_backend_t * backend,
  * Return value: 1 on success, 0 on failure;
  */
 int
-lw6gfx_get_fullscreen_modes (lw6gfx_backend_t * backend,
-			     lw6gui_fullscreen_modes_t * fullscreen_modes)
+lw6gfx_get_fullscreen_modes (lw6sys_context_t * sys_context, lw6gfx_backend_t * backend, lw6gui_fullscreen_modes_t * fullscreen_modes)
 {
   int ret = 0;
 
@@ -222,13 +241,15 @@ lw6gfx_get_fullscreen_modes (lw6gfx_backend_t * backend,
 
   if (backend->get_fullscreen_modes)
     {
-      ret =
-	backend->get_fullscreen_modes (backend->gfx_context,
-				       fullscreen_modes);
+      if (LW6SYS_MUTEX_LOCK (sys_context, backend->call_lock))
+	{
+	  ret = backend->get_fullscreen_modes (sys_context, backend->gfx_context, fullscreen_modes);
+	  LW6SYS_MUTEX_UNLOCK (sys_context, backend->call_lock);
+	}
     }
   else
     {
-      _warning (__FUNCTION__);
+      _warning (sys_context, __FUNCTION__);
     }
 
   LW6SYS_BACKEND_FUNCTION_END;
@@ -239,6 +260,7 @@ lw6gfx_get_fullscreen_modes (lw6gfx_backend_t * backend,
 /**
  * lw6gfx_pump_events
  *
+ * @sys_context: global system context
  * @backend: the backend to use
  *
  * This function "pumps" events, that is gets pending events, puts them in queues,
@@ -248,7 +270,7 @@ lw6gfx_get_fullscreen_modes (lw6gfx_backend_t * backend,
  * Return value: a pointer on the internal input state, musn't be freed.
  */
 lw6gui_input_t *
-lw6gfx_pump_events (lw6gfx_backend_t * backend)
+lw6gfx_pump_events (lw6sys_context_t * sys_context, lw6gfx_backend_t * backend)
 {
   lw6gui_input_t *ret = NULL;
 
@@ -256,11 +278,15 @@ lw6gfx_pump_events (lw6gfx_backend_t * backend)
 
   if (backend->pump_events)
     {
-      ret = backend->pump_events (backend->gfx_context);
+      if (LW6SYS_MUTEX_LOCK (sys_context, backend->call_lock))
+	{
+	  ret = backend->pump_events (sys_context, backend->gfx_context);
+	  LW6SYS_MUTEX_UNLOCK (sys_context, backend->call_lock);
+	}
     }
   else
     {
-      _warning (__FUNCTION__);
+      _warning (sys_context, __FUNCTION__);
     }
 
   return ret;
@@ -271,6 +297,7 @@ lw6gfx_pump_events (lw6gfx_backend_t * backend)
 /**
  * lw6gfx_display
  *
+ * @sys_context: global system context
  * @backend: the graphical backend to use
  * @look: the look, the skin, contains display options
  * @mask: display flag, tells what to display
@@ -297,14 +324,12 @@ lw6gfx_pump_events (lw6gfx_backend_t * backend)
  * Return value: 1 on success, 0 on failure.
  */
 int
-lw6gfx_display (lw6gfx_backend_t * backend, int mask,
+lw6gfx_display (lw6sys_context_t * sys_context, lw6gfx_backend_t * backend, int mask,
 		const lw6gui_look_t * look, const lw6map_level_t * level,
 		const lw6ker_game_struct_t * game_struct,
 		const lw6ker_game_state_t * game_state,
 		lw6pil_local_cursors_t * local_cursors, lw6gui_menu_t * menu,
-		float progress, float fps, float mps, const char **log_list,
-		int capture, int gfx_debug, int debug_team_id,
-		int debug_layer_id)
+		float progress, float fps, float mps, const char **log_list, int capture, int gfx_debug, int debug_team_id, int debug_layer_id)
 {
   int ret = 0;
 
@@ -312,15 +337,17 @@ lw6gfx_display (lw6gfx_backend_t * backend, int mask,
 
   if (backend->display)
     {
-      ret =
-	backend->display (backend->gfx_context, mask, look, level,
-			  game_struct, game_state, local_cursors, menu,
-			  progress, fps, mps, log_list, capture, gfx_debug,
-			  debug_team_id, debug_layer_id);
+      if (LW6SYS_MUTEX_LOCK (sys_context, backend->call_lock))
+	{
+	  ret =
+	    backend->display (sys_context, backend->gfx_context, mask, look, level,
+			      game_struct, game_state, local_cursors, menu, progress, fps, mps, log_list, capture, gfx_debug, debug_team_id, debug_layer_id);
+	  LW6SYS_MUTEX_UNLOCK (sys_context, backend->call_lock);
+	}
     }
   else
     {
-      _warning (__FUNCTION__);
+      _warning (sys_context, __FUNCTION__);
     }
 
   LW6SYS_BACKEND_FUNCTION_END;
