@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -55,6 +55,8 @@ typedef struct lw6gfx_backend_s
   int argc;
   /// The argv value passed to main.
   const char **argv;
+  /// Lock used to avoid concurrent access to underlying libs.
+  lw6sys_mutex_t *call_lock;
   /**
    * The id of the object, this is non-zero and unique within one run session,
    * incremented at each object creation.
@@ -62,68 +64,56 @@ typedef struct lw6gfx_backend_s
   u_int32_t id;
 
   /// Pointer on lw6gfx_init callback code.
-  void *(*init) (int argc, const char *argv[],
-		 lw6gui_video_mode_t * video_mode,
+  void *(*init) (lw6sys_context_t * sys_context, int argc, const char *argv[], lw6gui_video_mode_t * video_mode,
 		 lw6gui_resize_callback_func_t resize_callback);
   /// Pointer on lw6gfx_quit callback code.
-  void (*quit) (void *gfx_context);
+  void (*quit) (lw6sys_context_t * sys_context, void *gfx_context);
   /// Pointer on lw6gfx_repr callback code.
-  char *(*repr) (void *gfx_context, u_int32_t id);
+  char *(*repr) (lw6sys_context_t * sys_context, void *gfx_context, u_int32_t id);
   /// Pointer on lw6gfx_set_video_mode callback code.
-  int (*set_video_mode) (void *gfx_context, lw6gui_video_mode_t * video_mode);
+  int (*set_video_mode) (lw6sys_context_t * sys_context, void *gfx_context, lw6gui_video_mode_t * video_mode);
   /// Pointer on lw6gfx_get_video_mode callback code.
-  int (*get_video_mode) (void *gfx_context, lw6gui_video_mode_t * video_mode);
+  int (*get_video_mode) (lw6sys_context_t * sys_context, void *gfx_context, lw6gui_video_mode_t * video_mode);
   /// Pointer on lw6gfx_get_fullscreen_modes callback code.
-  int (*get_fullscreen_modes) (void *gfx_context,
-			       lw6gui_fullscreen_modes_t * modes);
+  int (*get_fullscreen_modes) (lw6sys_context_t * sys_context, void *gfx_context, lw6gui_fullscreen_modes_t * modes);
   /// Pointer on lw6gfx_pump_events code.
-  lw6gui_input_t *(*pump_events) (void *gfx_context);
+  lw6gui_input_t *(*pump_events) (lw6sys_context_t * sys_context, void *gfx_context);
   /// Pointer on lw6gfx_display code.
-  int (*display) (void *gfx_context, int mask, const lw6gui_look_t * look,
+  int (*display) (lw6sys_context_t * sys_context, void *gfx_context, int mask, const lw6gui_look_t * look,
 		  const lw6map_level_t * level,
 		  const lw6ker_game_struct_t * game_struct,
 		  const lw6ker_game_state_t * game_state,
 		  lw6pil_local_cursors_t * local_cursors,
 		  lw6gui_menu_t * menu,
-		  float progress,
-		  float fps, float mps,
-		  const char **log_list, int capture, int gfx_debug,
-		  int debug_team_id, int debug_layer_id);
+		  float progress, float fps, float mps, const char **log_list, int capture, int gfx_debug, int debug_team_id, int debug_layer_id);
 }
 lw6gfx_backend_t;
 
 /* gfx-api.c */
-extern int lw6gfx_init (lw6gfx_backend_t * backend,
-			lw6gui_video_mode_t * video_mode,
+extern int lw6gfx_init (lw6sys_context_t * sys_context, lw6gfx_backend_t * backend, lw6gui_video_mode_t * video_mode,
 			lw6gui_resize_callback_func_t resize_callback);
-extern void lw6gfx_quit (lw6gfx_backend_t * backend);
-extern char *lw6gfx_repr (const lw6gfx_backend_t * backend);
-extern int lw6gfx_set_video_mode (lw6gfx_backend_t * backend,
-				  lw6gui_video_mode_t * video_mode);
-extern int lw6gfx_get_video_mode (lw6gfx_backend_t * backend,
-				  lw6gui_video_mode_t * video_mode);
-extern int lw6gfx_get_fullscreen_modes (lw6gfx_backend_t * backend,
-					lw6gui_fullscreen_modes_t * modes);
-extern lw6gui_input_t *lw6gfx_pump_events (lw6gfx_backend_t * backend);
-extern int lw6gfx_display (lw6gfx_backend_t * backend, int mask,
+extern void lw6gfx_quit (lw6sys_context_t * sys_context, lw6gfx_backend_t * backend);
+extern char *lw6gfx_repr (lw6sys_context_t * sys_context, const lw6gfx_backend_t * backend);
+extern int lw6gfx_set_video_mode (lw6sys_context_t * sys_context, lw6gfx_backend_t * backend, lw6gui_video_mode_t * video_mode);
+extern int lw6gfx_get_video_mode (lw6sys_context_t * sys_context, lw6gfx_backend_t * backend, lw6gui_video_mode_t * video_mode);
+extern int lw6gfx_get_fullscreen_modes (lw6sys_context_t * sys_context, lw6gfx_backend_t * backend, lw6gui_fullscreen_modes_t * modes);
+extern lw6gui_input_t *lw6gfx_pump_events (lw6sys_context_t * sys_context, lw6gfx_backend_t * backend);
+extern int lw6gfx_display (lw6sys_context_t * sys_context, lw6gfx_backend_t * backend, int mask,
 			   const lw6gui_look_t * look,
 			   const lw6map_level_t * level,
 			   const lw6ker_game_struct_t * game_struct,
 			   const lw6ker_game_state_t * game_state,
 			   lw6pil_local_cursors_t * local_cursors,
 			   lw6gui_menu_t * menu, float progress, float fps,
-			   float mps, const char **log_list, int capture,
-			   int gfx_debug, int debug_team_id,
-			   int debug_layer_id);
+			   float mps, const char **log_list, int capture, int gfx_debug, int debug_team_id, int debug_layer_id);
 
 /* gfx-register.c */
-extern lw6sys_assoc_t *lw6gfx_get_backends (int argc, const char *argv[]);
-extern lw6gfx_backend_t *lw6gfx_create_backend (int argc, const char *argv[],
-						const char *name);
-extern void lw6gfx_destroy_backend (lw6gfx_backend_t * backend);
+extern lw6sys_assoc_t *lw6gfx_get_backends (lw6sys_context_t * sys_context, int argc, const char *argv[]);
+extern lw6gfx_backend_t *lw6gfx_create_backend (lw6sys_context_t * sys_context, int argc, const char *argv[], const char *name);
+extern void lw6gfx_destroy_backend (lw6sys_context_t * sys_context, lw6gfx_backend_t * backend);
 
 /* gfx-test.c */
-extern int lw6gfx_test_register (int mode);
-extern int lw6gfx_test_run (int mode);
+extern int lw6gfx_test_register (lw6sys_context_t * sys_context, int mode);
+extern int lw6gfx_test_run (lw6sys_context_t * sys_context, int mode);
 
 #endif
