@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -46,106 +46,101 @@ mod_caca_is_GPL_compatible ()
 }
 
 static void *
-_init (int argc, const char *argv[], lw6gui_video_mode_t * video_mode,
-       lw6gui_resize_callback_func_t resize_callback)
+_init (lw6sys_context_t * sys_context, int argc, const char *argv[], lw6gui_video_mode_t * video_mode, lw6gui_resize_callback_func_t resize_callback)
 {
-  _mod_caca_context_t *mod_caca_context =
-    _mod_caca_init (argc, argv, video_mode, resize_callback);
+  _mod_caca_context_t *mod_caca_context = _mod_caca_init (sys_context, argc, argv, video_mode, resize_callback);
 
   return (void *) mod_caca_context;
 }
 
 static void
-_quit (void *gfx_context)
+_quit (lw6sys_context_t * sys_context, void *gfx_context)
 {
   _mod_caca_context_t *mod_caca_context = (_mod_caca_context_t *) gfx_context;
 
   if (mod_caca_context)
     {
-      _mod_caca_quit (mod_caca_context);
+      _mod_caca_quit (sys_context, mod_caca_context);
     }
 }
 
 static char *
-_repr (void *gfx_context, u_int32_t id)
+_repr (lw6sys_context_t * sys_context, void *gfx_context, u_int32_t id)
 {
   char *ret = NULL;
   _mod_caca_context_t *mod_caca_context = (_mod_caca_context_t *) gfx_context;
 
   if (mod_caca_context)
     {
-      ret = _mod_caca_repr (mod_caca_context, id);
+      ret = _mod_caca_repr (sys_context, mod_caca_context, id);
     }
 
   return ret;
 }
 
 static int
-_set_video_mode (void *gfx_context, lw6gui_video_mode_t * video_mode)
+_set_video_mode (lw6sys_context_t * sys_context, void *gfx_context, lw6gui_video_mode_t * video_mode)
 {
   int ret = 0;
   _mod_caca_context_t *mod_caca_context = (_mod_caca_context_t *) gfx_context;
 
   if (mod_caca_context)
     {
-      ret = _mod_caca_set_video_mode (mod_caca_context, video_mode);
+      ret = _mod_caca_set_video_mode (sys_context, mod_caca_context, video_mode);
     }
 
   return ret;
 }
 
 static int
-_get_video_mode (void *gfx_context, lw6gui_video_mode_t * video_mode)
+_get_video_mode (lw6sys_context_t * sys_context, void *gfx_context, lw6gui_video_mode_t * video_mode)
 {
   int ret = 0;
   _mod_caca_context_t *mod_caca_context = (_mod_caca_context_t *) gfx_context;
 
   if (mod_caca_context)
     {
-      ret = _mod_caca_get_video_mode (mod_caca_context, video_mode);
+      ret = _mod_caca_get_video_mode (sys_context, mod_caca_context, video_mode);
     }
 
   return ret;
 }
 
 static int
-_get_fullscreen_modes (void *gfx_context, lw6gui_fullscreen_modes_t * modes)
+_get_fullscreen_modes (lw6sys_context_t * sys_context, void *gfx_context, lw6gui_fullscreen_modes_t * modes)
 {
   int ret = 0;
   _mod_caca_context_t *mod_caca_context = (_mod_caca_context_t *) gfx_context;
 
   if (mod_caca_context)
     {
-      ret = _mod_caca_get_fullscreen_modes (mod_caca_context, modes);
+      ret = _mod_caca_get_fullscreen_modes (sys_context, mod_caca_context, modes);
     }
 
   return ret;
 }
 
 static lw6gui_input_t *
-_pump_events (void *gfx_context)
+_pump_events (lw6sys_context_t * sys_context, void *gfx_context)
 {
   lw6gui_input_t *ret = NULL;
   _mod_caca_context_t *mod_caca_context = (_mod_caca_context_t *) gfx_context;
 
   if (mod_caca_context)
     {
-      ret = _mod_caca_pump_events (mod_caca_context);
+      ret = _mod_caca_pump_events (sys_context, mod_caca_context);
     }
 
   return ret;
 }
 
 static int
-_display (void *gfx_context, int mask, const lw6gui_look_t * look,
+_display (lw6sys_context_t * sys_context, void *gfx_context, int mask, const lw6gui_look_t * look,
 	  const lw6map_level_t * level,
 	  const lw6ker_game_struct_t * game_struct,
 	  const lw6ker_game_state_t * game_state,
 	  lw6pil_local_cursors_t * local_cursors,
-	  lw6gui_menu_t * menu,
-	  float progress,
-	  float fps, float mps, const char **log_list, int capture,
-	  int gfx_debug, int debug_team_id, int debug_layer_id)
+	  lw6gui_menu_t * menu, float progress, float fps, float mps, const char **log_list, int capture, int gfx_debug, int debug_team_id, int debug_layer_id)
 {
   int ret = 0;
   _mod_caca_context_t *mod_caca_context = (_mod_caca_context_t *) gfx_context;
@@ -153,33 +148,37 @@ _display (void *gfx_context, int mask, const lw6gui_look_t * look,
   if (mod_caca_context)
     {
       ret =
-	_mod_caca_display (mod_caca_context, mask, look, level, game_struct,
-			   game_state, local_cursors, menu, progress, fps,
-			   mps, log_list, capture, gfx_debug, debug_team_id,
-			   debug_layer_id);
+	_mod_caca_display (sys_context, mod_caca_context, mask, look, level, game_struct,
+			   game_state, local_cursors, menu, progress, fps, mps, log_list, capture, gfx_debug, debug_team_id, debug_layer_id);
     }
 
   return ret;
 }
 
+/**
+ * mod_caca_get_pedigree
+ *
+ * @sys_context: global system context
+ *
+ * Returns the pedigree for mod-caca, giving details about the module,
+ * including name, description, licence, date/time of compilation.
+ *
+ * Return value: dynamically allocated object.
+ */
 lw6sys_module_pedigree_t *
-mod_caca_get_pedigree ()
+mod_caca_get_pedigree (lw6sys_context_t * sys_context)
 {
   lw6sys_module_pedigree_t *module_pedigree = NULL;
 
-  module_pedigree =
-    (lw6sys_module_pedigree_t *)
-    LW6SYS_CALLOC (sizeof (lw6sys_module_pedigree_t));
+  module_pedigree = (lw6sys_module_pedigree_t *) LW6SYS_CALLOC (sys_context, sizeof (lw6sys_module_pedigree_t));
   if (module_pedigree)
     {
       module_pedigree->id = "caca";
       module_pedigree->category = "gfx";
       module_pedigree->name = _("libcaca");
-      module_pedigree->readme =
-	_x_ ("ASCII-art based backend, using libcaca from Caca Labs.");
+      module_pedigree->readme = _x_ ("ASCII-art based backend, using libcaca from Caca Labs.");
       module_pedigree->version = VERSION;
-      module_pedigree->copyright =
-	"Copyright (C)  2014  Christian Mauduit <ufoot@ufoot.org>";
+      module_pedigree->copyright = "Copyright (C)  2015  Christian Mauduit <ufoot@ufoot.org>";
       module_pedigree->license = "GPLv3+ (GNU GPL version 3 or later)";
       module_pedigree->date = __DATE__;
       module_pedigree->time = __TIME__;
@@ -188,12 +187,21 @@ mod_caca_get_pedigree ()
   return module_pedigree;
 }
 
+/**
+ * mod_caca_create_backend
+ *
+ * @sys_context: global system context
+ *
+ * Creates a mod-caca backend.
+ *
+ * Return value: backend pointer.
+ */
 lw6gfx_backend_t *
-mod_caca_create_backend ()
+mod_caca_create_backend (lw6sys_context_t * sys_context)
 {
   lw6gfx_backend_t *backend;
 
-  backend = LW6SYS_CALLOC (sizeof (lw6gfx_backend_t));
+  backend = LW6SYS_CALLOC (sys_context, sizeof (lw6gfx_backend_t));
   if (backend)
     {
       backend->init = _init;
