@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -28,16 +28,15 @@
 
 #include "mod-caca-internal.h"
 
-extern int
-_mod_caca_display_menu (_mod_caca_context_t * caca_context,
-			const lw6gui_look_t * look, lw6gui_menu_t * menu)
+int
+_mod_caca_display_menu (lw6sys_context_t * sys_context, _mod_caca_context_t * caca_context, const lw6gui_look_t * look, lw6gui_menu_t * menu)
 {
   int ret = 1;
   int i, j, wc;
   lw6gui_menuitem_t *menuitem;
 
   wc = caca_get_canvas_width (caca_context->canvas);
-  lw6sys_log (LW6SYS_LOG_INFO, _x_ ("menu:nb_item %d"), menu->nb_items);
+  lw6sys_log (sys_context, LW6SYS_LOG_INFO, _x_ ("menu:nb_item %d"), menu->nb_items);
   for (i = 0; i < menu->nb_items; ++i)
     {
       j = i + menu->first_item_displayed;
@@ -47,9 +46,8 @@ _mod_caca_display_menu (_mod_caca_context_t * caca_context,
 	{
 	  caca_set_color_ansi (caca_context->canvas, CACA_BLACK, CACA_WHITE);
 	}
-      lw6sys_log (LW6SYS_LOG_INFO, _x_ ("menu:nb_item %s"), menuitem->label);
-      caca_put_str (caca_context->canvas, (wc - strlen (menuitem->label)) / 2,
-		    4 + i, menuitem->label);
+      lw6sys_log (sys_context, LW6SYS_LOG_INFO, _x_ ("menu:nb_item %s"), menuitem->label);
+      caca_put_str (caca_context->canvas, (wc - strlen (menuitem->label)) / 2, 4 + i, menuitem->label);
     }
 
   return ret;
