@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -32,55 +32,40 @@
 #define _DRIVER_SLANG "slang"
 
 static caca_display_t *
-_set_with_driver (caca_canvas_t * canvas, const char *driver)
+_set_with_driver (lw6sys_context_t * sys_context, caca_canvas_t * canvas, const char *driver)
 {
   caca_display_t *ret = NULL;
   int try_it = 1;
 
-  if (!lw6cns_term_support ())
+  if (!lw6cns_term_support (sys_context))
     {
-      if (lw6sys_str_is_same (driver, _DRIVER_NCURSES)
-	  || lw6sys_str_is_same (driver, _DRIVER_SLANG))
+      if (lw6sys_str_is_same (sys_context, driver, _DRIVER_NCURSES) || lw6sys_str_is_same (sys_context, driver, _DRIVER_SLANG))
 	{
-	  lw6sys_log (LW6SYS_LOG_WARNING,
-		      _x_
-		      ("not even trying driver \"%s\" since no proper TERM support was detected"),
-		      driver);
+	  lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("not even trying driver \"%s\" since no proper TERM support was detected"), driver);
 	  try_it = 0;
 	}
     }
   if (try_it)
     {
-      lw6sys_log (LW6SYS_LOG_INFO, _x_ ("trying libcaca driver \"%s\""),
-		  driver);
+      lw6sys_log (sys_context, LW6SYS_LOG_INFO, _x_ ("trying libcaca driver \"%s\""), driver);
       ret = caca_create_display_with_driver (canvas, driver);
       if (ret == NULL)
 	{
 	  switch (errno)
 	    {
 	    case ENOMEM:
-	      lw6sys_log (LW6SYS_LOG_WARNING,
-			  _x_
-			  ("libcaca driver \"%s\" failed to create display (memory problem)"),
-			  driver);
+	      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("libcaca driver \"%s\" failed to create display (memory problem)"), driver);
 	      break;
 	    case ENODEV:
-	      lw6sys_log (LW6SYS_LOG_WARNING,
-			  _x_
-			  ("libcaca driver \"%s\" failed to create display (device problem)"),
-			  driver);
+	      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("libcaca driver \"%s\" failed to create display (device problem)"), driver);
 	      break;
 	    default:
-	      lw6sys_log (LW6SYS_LOG_WARNING,
-			  _x_
-			  ("libcaca driver \"%s\" failed to create display (unknown problem)"),
-			  driver);
+	      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("libcaca driver \"%s\" failed to create display (unknown problem)"), driver);
 	    }
 	}
       else
 	{
-	  lw6sys_log (LW6SYS_LOG_INFO, _x_ ("set libcaca driver \"%s\""),
-		      driver);
+	  lw6sys_log (sys_context, LW6SYS_LOG_INFO, _x_ ("set libcaca driver \"%s\""), driver);
 	}
     }
 
@@ -91,13 +76,12 @@ _set_with_driver (caca_canvas_t * canvas, const char *driver)
  * Initialize display.
  */
 int
-_mod_caca_set_video_mode (_mod_caca_context_t * caca_context,
-			  lw6gui_video_mode_t * video_mode)
+_mod_caca_set_video_mode (lw6sys_context_t * sys_context, _mod_caca_context_t * caca_context, lw6gui_video_mode_t * video_mode)
 {
   int ret = 0;
   int i = 0;
 
-  lw6sys_log (LW6SYS_LOG_INFO, _x_ ("setVideo Mode"));
+  lw6sys_log (sys_context, LW6SYS_LOG_INFO, _x_ ("setVideo Mode"));
   if (caca_context->display && caca_context->canvas)
     {
       caca_free_display (caca_context->display);
@@ -105,13 +89,10 @@ _mod_caca_set_video_mode (_mod_caca_context_t * caca_context,
     }
   if (caca_context->canvas)
     {
-      for (i = 0; i < _MOD_CACA_NB_VIDEO_DRIVERS && !caca_context->display;
-	   ++i)
+      for (i = 0; i < _MOD_CACA_NB_VIDEO_DRIVERS && !caca_context->display; ++i)
 	{
-	  lw6sys_log (LW6SYS_LOG_INFO, _x_ ("trying video driver i=%d"), i);
-	  caca_context->display =
-	    _set_with_driver (caca_context->canvas,
-			      caca_context->const_data.video_driver[i]);
+	  lw6sys_log (sys_context, LW6SYS_LOG_INFO, _x_ ("trying video driver i=%d"), i);
+	  caca_context->display = _set_with_driver (sys_context, caca_context->canvas, caca_context->const_data.video_driver[i]);
 	}
 
       if (caca_context->display)
@@ -121,17 +102,12 @@ _mod_caca_set_video_mode (_mod_caca_context_t * caca_context,
 
       if (caca_context->display && caca_context->canvas)
 	{
-	  caca_set_display_title (caca_context->display,
-				  lw6sys_build_get_package_string ());
-	  caca_context->video_mode.width =
-	    caca_get_canvas_width (caca_context->canvas);
-	  caca_context->video_mode.height =
-	    caca_get_canvas_height (caca_context->canvas);
+	  caca_set_display_title (caca_context->display, lw6sys_build_get_package_string ());
+	  caca_context->video_mode.width = caca_get_canvas_width (caca_context->canvas);
+	  caca_context->video_mode.height = caca_get_canvas_height (caca_context->canvas);
 	  caca_context->video_mode.fullscreen = 1;
-	  lw6sys_log (LW6SYS_LOG_INFO,
-		      _x_ ("libcaca mode with canvas=%dx%d OK"),
-		      caca_context->video_mode.width,
-		      caca_context->video_mode.height);
+	  lw6sys_log (sys_context, LW6SYS_LOG_INFO,
+		      _x_ ("libcaca mode with canvas=%dx%d OK"), caca_context->video_mode.width, caca_context->video_mode.height);
 	  ret = 1;
 	}
     }
@@ -144,8 +120,7 @@ _mod_caca_set_video_mode (_mod_caca_context_t * caca_context,
  * Called whenever window resize is asked for.
  */
 int
-_mod_caca_resize_video_mode (_mod_caca_context_t * caca_context,
-			     lw6gui_video_mode_t * video_mode)
+_mod_caca_resize_video_mode (lw6sys_context_t * sys_context, _mod_caca_context_t * caca_context, lw6gui_video_mode_t * video_mode)
 {
   int ret = 0;
   int canvas_width = 0;
@@ -154,13 +129,10 @@ _mod_caca_resize_video_mode (_mod_caca_context_t * caca_context,
   canvas_width = caca_get_canvas_width (caca_context->canvas);
   canvas_height = caca_get_canvas_height (caca_context->canvas);
 
-  if (video_mode->width != canvas_width
-      || video_mode->height != canvas_height)
+  if (video_mode->width != canvas_width || video_mode->height != canvas_height)
     {
-      lw6sys_log (LW6SYS_LOG_DEBUG,
-		  _x_ ("canvas should be resized %dx%d -> %dx%d"),
-		  canvas_width, canvas_height, video_mode->width,
-		  video_mode->height);
+      lw6sys_log (sys_context, LW6SYS_LOG_DEBUG,
+		  _x_ ("canvas should be resized %dx%d -> %dx%d"), canvas_width, canvas_height, video_mode->width, video_mode->height);
       /*
        * No clue how to do that, but what should be done here
        * is to adjust the canvas size to the video_mode size.
@@ -181,8 +153,7 @@ _mod_caca_resize_video_mode (_mod_caca_context_t * caca_context,
 }
 
 int
-_mod_caca_get_video_mode (_mod_caca_context_t * caca_context,
-			  lw6gui_video_mode_t * video_mode)
+_mod_caca_get_video_mode (lw6sys_context_t * sys_context, _mod_caca_context_t * caca_context, lw6gui_video_mode_t * video_mode)
 {
   int ret = 0;
 
@@ -196,8 +167,7 @@ _mod_caca_get_video_mode (_mod_caca_context_t * caca_context,
 }
 
 int
-_mod_caca_set_resize_callback (_mod_caca_context_t * caca_context,
-			       lw6gui_resize_callback_func_t resize_callback)
+_mod_caca_set_resize_callback (lw6sys_context_t * sys_context, _mod_caca_context_t * caca_context, lw6gui_resize_callback_func_t resize_callback)
 {
   int ret = 0;
 
@@ -208,11 +178,11 @@ _mod_caca_set_resize_callback (_mod_caca_context_t * caca_context,
 }
 
 void
-_mod_caca_call_resize_callback (_mod_caca_context_t * caca_context)
+_mod_caca_call_resize_callback (lw6sys_context_t * sys_context, _mod_caca_context_t * caca_context)
 {
   if (caca_context->resize_callback)
     {
-      lw6sys_log (LW6SYS_LOG_INFO, _x_ ("calling resize callback"));
-      caca_context->resize_callback (&(caca_context->video_mode));
+      lw6sys_log (sys_context, LW6SYS_LOG_INFO, _x_ ("calling resize callback"));
+      caca_context->resize_callback (sys_context, &(caca_context->video_mode));
     }
 }
