@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -28,18 +28,15 @@
 #include "mod-caca-internal.h"
 
 char *
-_mod_caca_repr (_mod_caca_context_t * caca_context, u_int32_t id)
+_mod_caca_repr (lw6sys_context_t * sys_context, _mod_caca_context_t * caca_context, u_int32_t id)
 {
   char *ret = NULL;
   const char *caca_version = NULL;
 
-  caca_version = lw6sys_str_empty_if_null (caca_get_version ());
+  caca_version = lw6sys_str_empty_if_null (sys_context, caca_get_version ());
   ret =
-    lw6sys_new_sprintf (_x_
-			("%u caca libcaca version %s resolution %dx%d"),
-			id, caca_version,
-			caca_context->video_mode.width,
-			caca_context->video_mode.height);
+    lw6sys_new_sprintf (sys_context, _x_
+			("%u caca libcaca version %s resolution %dx%d"), id, caca_version, caca_context->video_mode.width, caca_context->video_mode.height);
 
   return ret;
 }
