@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -27,9 +27,7 @@
 #include "mod-caca-internal.h"
 
 int
-_mod_caca_get_fullscreen_modes (_mod_caca_context_t *
-				caca_context,
-				lw6gui_fullscreen_modes_t * modes)
+_mod_caca_get_fullscreen_modes (lw6sys_context_t * sys_context, _mod_caca_context_t * caca_context, lw6gui_fullscreen_modes_t * modes)
 {
   int ret = 0;
 
@@ -51,12 +49,9 @@ _mod_caca_get_fullscreen_modes (_mod_caca_context_t *
   modes->standard.width = (modes->low.width + modes->high.width) / 2;
   modes->standard.height = (modes->low.height + modes->high.height) / 2;
 
-  lw6gui_video_mode_sync_ratio (&(modes->standard), &(modes->high));
+  lw6gui_video_mode_sync_ratio (sys_context, &(modes->standard), &(modes->high));
 
-  _mod_caca_find_closest_resolution (caca_context,
-				     &(modes->standard.width),
-				     &(modes->standard.height),
-				     modes->standard.width,
+  _mod_caca_find_closest_resolution (sys_context, caca_context, &(modes->standard.width), &(modes->standard.height), modes->standard.width,
 				     modes->standard.height);
 
   /*
@@ -72,10 +67,8 @@ _mod_caca_get_fullscreen_modes (_mod_caca_context_t *
 }
 
 void
-_mod_caca_find_closest_resolution (_mod_caca_context_t *
-				   caca_context, int *closest_width,
-				   int *closest_height, int wished_width,
-				   int wished_height)
+_mod_caca_find_closest_resolution (lw6sys_context_t * sys_context, _mod_caca_context_t * caca_context, int *closest_width, int *closest_height,
+				   int wished_width, int wished_height)
 {
   (*closest_width) = wished_width;
   (*closest_height) = wished_height;
