@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -27,56 +27,49 @@
 #include "gl1-background.h"
 
 static void
-_warning (const char *func_name)
+_warning (lw6sys_context_t * sys_context, const char *func_name)
 {
-  lw6sys_log (LW6SYS_LOG_WARNING,
-	      _x_ ("background backend function \"%s\" is not defined"),
-	      func_name);
+  lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("background backend function \"%s\" is not defined"), func_name);
 }
 
 int
-mod_gl1_background_init (mod_gl1_utils_context_t * utils_context,
-			 mod_gl1_background_backend_t * backend)
+mod_gl1_background_init (lw6sys_context_t * sys_context, mod_gl1_utils_context_t * utils_context, mod_gl1_background_backend_t * backend)
 {
   if (backend->init)
     {
-      backend->background_context = backend->init (utils_context);
+      backend->background_context = backend->init (sys_context, utils_context);
     }
   else
     {
-      _warning (__FUNCTION__);
+      _warning (sys_context, __FUNCTION__);
     }
 
   return backend->background_context ? 1 : 0;
 }
 
 void
-mod_gl1_background_quit (mod_gl1_utils_context_t * utils_context,
-			 mod_gl1_background_backend_t * backend)
+mod_gl1_background_quit (lw6sys_context_t * sys_context, mod_gl1_utils_context_t * utils_context, mod_gl1_background_backend_t * backend)
 {
   if (backend->quit)
     {
-      backend->quit (utils_context, backend->background_context);
+      backend->quit (sys_context, utils_context, backend->background_context);
     }
   else
     {
-      _warning (__FUNCTION__);
+      _warning (sys_context, __FUNCTION__);
     }
 }
 
 void
-mod_gl1_background_display_background (mod_gl1_utils_context_t *
-				       utils_context,
-				       mod_gl1_background_backend_t * backend,
+mod_gl1_background_display_background (lw6sys_context_t * sys_context, mod_gl1_utils_context_t * utils_context, mod_gl1_background_backend_t * backend,
 				       const lw6gui_look_t * look)
 {
   if (backend->display_background)
     {
-      backend->display_background (utils_context, backend->background_context,
-				   look);
+      backend->display_background (sys_context, utils_context, backend->background_context, look);
     }
   else
     {
-      _warning (__FUNCTION__);
+      _warning (sys_context, __FUNCTION__);
     }
 }
