@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -38,8 +38,7 @@ _mod_gl1_background_bubbles_bubble_t;
 
 typedef struct _mod_gl1_background_bubbles_state_s
 {
-  _mod_gl1_background_bubbles_bubble_t
-    bubbles[_MOD_GL1_BACKGROUND_BUBBLES_MAX_NB_BUBBLES];
+  _mod_gl1_background_bubbles_bubble_t bubbles[_MOD_GL1_BACKGROUND_BUBBLES_MAX_NB_BUBBLES];
 }
 _mod_gl1_background_bubbles_state_t;
 
@@ -77,37 +76,20 @@ typedef struct _mod_gl1_background_bubbles_context_s
 }
 _mod_gl1_background_bubbles_context_t;
 
-/*
- * In display.c
- */
+/* gl1-bubbles-display.c */
 extern void
-_mod_gl1_background_bubbles_display_background (mod_gl1_utils_context_t *
-						utils_context,
-						_mod_gl1_background_bubbles_context_t
-						* bubbles_context,
-						const lw6gui_look_t * look);
+_mod_gl1_background_bubbles_display_background (lw6sys_context_t * sys_context, mod_gl1_utils_context_t *
+						utils_context, _mod_gl1_background_bubbles_context_t * bubbles_context, const lw6gui_look_t * look);
 
-/*
- * In data.c
- */
-extern int _mod_gl1_background_bubbles_load_data (mod_gl1_utils_context_t *
-						  utils_context,
-						  _mod_gl1_background_bubbles_context_t
-						  * bubbles_context);
-extern void _mod_gl1_background_bubbles_unload_data (mod_gl1_utils_context_t *
-						     utils_context,
-						     _mod_gl1_background_bubbles_context_t
-						     * bubbles_context);
+/* gl1-bubbles-data.c */
+extern int _mod_gl1_background_bubbles_load_data (lw6sys_context_t * sys_context, mod_gl1_utils_context_t * utils_context,
+						  _mod_gl1_background_bubbles_context_t * bubbles_context);
+extern void _mod_gl1_background_bubbles_unload_data (lw6sys_context_t * sys_context, mod_gl1_utils_context_t * utils_context,
+						     _mod_gl1_background_bubbles_context_t * bubbles_context);
 
-/*
- * In setup.c
- */
-extern _mod_gl1_background_bubbles_context_t
-  * _mod_gl1_background_bubbles_init (mod_gl1_utils_context_t *
-				      utils_context);
-extern void _mod_gl1_background_bubbles_quit (mod_gl1_utils_context_t *
-					      utils_context,
-					      _mod_gl1_background_bubbles_context_t
-					      * bubbles_context);
+/* gl1-bubbles-setup.c */
+extern _mod_gl1_background_bubbles_context_t *_mod_gl1_background_bubbles_init (lw6sys_context_t * sys_context, mod_gl1_utils_context_t * utils_context);
+extern void _mod_gl1_background_bubbles_quit (lw6sys_context_t * sys_context, mod_gl1_utils_context_t * utils_context,
+					      _mod_gl1_background_bubbles_context_t * bubbles_context);
 
 #endif
