@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -29,20 +29,15 @@
 
 
 void
-_mod_gl1_background_void_display_background (mod_gl1_utils_context_t *
-					     utils_context,
-					     _mod_gl1_background_void_context_t
-					     * void_context,
-					     const lw6gui_look_t * look)
+_mod_gl1_background_void_display_background (lw6sys_context_t * sys_context, mod_gl1_utils_context_t *
+					     utils_context, _mod_gl1_background_void_context_t * void_context, const lw6gui_look_t * look)
 {
   // nothing to do, just plain black... (void!)
 }
 
 void
-mod_gl1_background_void_display_background (mod_gl1_utils_context_t *
-					    utils_context, void *void_context,
+mod_gl1_background_void_display_background (lw6sys_context_t * sys_context, mod_gl1_utils_context_t * utils_context, void *void_context,
 					    const lw6gui_look_t * look)
 {
-  _mod_gl1_background_void_display_background (utils_context, void_context,
-					       look);
+  _mod_gl1_background_void_display_background (sys_context, utils_context, void_context, look);
 }
