@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -31,24 +31,14 @@ typedef struct _mod_gl1_background_void_context_s
 }
 _mod_gl1_background_void_context_t;
 
-/*
- * In display.c
- */
+/* gl1-void-display.c */
 extern void
-_mod_gl1_background_void_display_background (mod_gl1_utils_context_t *
-					     utils_context,
-					     _mod_gl1_background_void_context_t
-					     * void_context,
-					     const lw6gui_look_t * look);
+_mod_gl1_background_void_display_background (lw6sys_context_t * sys_context, mod_gl1_utils_context_t *
+					     utils_context, _mod_gl1_background_void_context_t * void_context, const lw6gui_look_t * look);
 
-/*
- * In setup.c
- */
-extern _mod_gl1_background_void_context_t
-  * _mod_gl1_background_void_init (mod_gl1_utils_context_t * utils_context);
-extern void _mod_gl1_background_void_quit (mod_gl1_utils_context_t *
-					   utils_context,
-					   _mod_gl1_background_void_context_t
-					   * void_context);
+/* gl1-void-setup.c */
+extern _mod_gl1_background_void_context_t *_mod_gl1_background_void_init (lw6sys_context_t * sys_context, mod_gl1_utils_context_t * utils_context);
+extern void _mod_gl1_background_void_quit (lw6sys_context_t * sys_context, mod_gl1_utils_context_t * utils_context,
+					   _mod_gl1_background_void_context_t * void_context);
 
 #endif
