@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -27,36 +27,21 @@
 #include "../../gl1-utils/gl1-utils.h"
 #include "../gl1-hud.h"
 
-extern mod_gl1_hud_backend_t
-  * mod_gl1_hud_floating_create_backend (mod_gl1_utils_context_t *
-					 utils_context);
+/* gl1-floating-backend.c */
+extern mod_gl1_hud_backend_t *mod_gl1_hud_floating_create_backend (lw6sys_context_t * sys_context, mod_gl1_utils_context_t * utils_context);
 
-/*
- * In display.c
- */
-extern void mod_gl1_hud_floating_display_hud (mod_gl1_utils_context_t *
+/* gl1-floating-display.c */
+extern void mod_gl1_hud_floating_display_hud (lw6sys_context_t * sys_context, mod_gl1_utils_context_t *
 					      utils_context,
 					      void *hud_context,
-					      const lw6gui_look_t * look,
-					      const lw6ker_game_state_t *
-					      game_state,
-					      lw6pil_local_cursors_t *
-					      local_cursors);
-extern void mod_gl1_hud_floating_display_score (mod_gl1_utils_context_t *
+					      const lw6gui_look_t * look, const lw6ker_game_state_t * game_state, lw6pil_local_cursors_t * local_cursors);
+extern void mod_gl1_hud_floating_display_score (lw6sys_context_t * sys_context, mod_gl1_utils_context_t *
 						utils_context,
 						void *hud_context,
-						const lw6gui_look_t * look,
-						const lw6ker_game_state_t *
-						game_state,
-						lw6pil_local_cursors_t *
-						local_cursors);
+						const lw6gui_look_t * look, const lw6ker_game_state_t * game_state, lw6pil_local_cursors_t * local_cursors);
 
-/*
- * In setup.c
- */
-extern void *mod_gl1_hud_floating_init (mod_gl1_utils_context_t *
-					utils_context);
-extern void mod_gl1_hud_floating_quit (mod_gl1_utils_context_t *
-				       utils_context, void *hud_context);
+/* gl1-floating-setup.c */
+extern void *mod_gl1_hud_floating_init (lw6sys_context_t * sys_context, mod_gl1_utils_context_t * utils_context);
+extern void mod_gl1_hud_floating_quit (lw6sys_context_t * sys_context, mod_gl1_utils_context_t * utils_context, void *hud_context);
 
-#endif
+#endif // LIQUIDWAR6GFX_MOD_GL1_HUD_FLOATING_H
