@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -47,48 +47,27 @@ typedef struct _mod_gl1_hud_tactical_context_s
 }
 _mod_gl1_hud_tactical_context_t;
 
-/*
- * In display.c
- */
-extern void _mod_gl1_hud_tactical_display_hud (mod_gl1_utils_context_t *
+/* gl1-tactical-display.c */
+extern void _mod_gl1_hud_tactical_display_hud (lw6sys_context_t * sys_context, mod_gl1_utils_context_t *
 					       utils_context,
 					       _mod_gl1_hud_tactical_context_t
 					       * tactical_context,
-					       const lw6gui_look_t * look,
-					       const lw6ker_game_state_t *
-					       game_state,
-					       lw6pil_local_cursors_t *
-					       local_cursors);
-extern void _mod_gl1_hud_tactical_display_score (mod_gl1_utils_context_t *
+					       const lw6gui_look_t * look, const lw6ker_game_state_t * game_state, lw6pil_local_cursors_t * local_cursors);
+extern void _mod_gl1_hud_tactical_display_score (lw6sys_context_t * sys_context, mod_gl1_utils_context_t *
 						 utils_context,
 						 _mod_gl1_hud_tactical_context_t
 						 * tactical_context,
-						 const lw6gui_look_t * look,
-						 const lw6ker_game_state_t *
-						 game_state,
-						 lw6pil_local_cursors_t *
-						 local_cursors);
+						 const lw6gui_look_t * look, const lw6ker_game_state_t * game_state, lw6pil_local_cursors_t * local_cursors);
 
-/*
- * In data.c
- */
-extern int _mod_gl1_hud_tactical_load_data (mod_gl1_utils_context_t *
-					    utils_context,
-					    _mod_gl1_hud_tactical_context_t
-					    * tactical_context);
-extern void _mod_gl1_hud_tactical_unload_data (mod_gl1_utils_context_t *
-					       utils_context,
-					       _mod_gl1_hud_tactical_context_t
-					       * tactical_context);
+/* gl1-tactical-data.c */
+extern int _mod_gl1_hud_tactical_load_data (lw6sys_context_t * sys_context, mod_gl1_utils_context_t * utils_context,
+					    _mod_gl1_hud_tactical_context_t * tactical_context);
+extern void _mod_gl1_hud_tactical_unload_data (lw6sys_context_t * sys_context, mod_gl1_utils_context_t * utils_context,
+					       _mod_gl1_hud_tactical_context_t * tactical_context);
 
-/*
- * In setup.c
- */
-extern _mod_gl1_hud_tactical_context_t
-  * _mod_gl1_hud_tactical_init (mod_gl1_utils_context_t * utils_context);
-extern void _mod_gl1_hud_tactical_quit (mod_gl1_utils_context_t *
-					utils_context,
-					_mod_gl1_hud_tactical_context_t *
-					tactical_context);
+/* gl1-tactical-setup.c */
+extern _mod_gl1_hud_tactical_context_t *_mod_gl1_hud_tactical_init (lw6sys_context_t * sys_context, mod_gl1_utils_context_t * utils_context);
+extern void _mod_gl1_hud_tactical_quit (lw6sys_context_t * sys_context, mod_gl1_utils_context_t * utils_context,
+					_mod_gl1_hud_tactical_context_t * tactical_context);
 
 #endif
