@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -28,26 +28,16 @@
 #include "gl1-cylinder-internal.h"
 
 void
-_mod_gl1_menu_cylinder_center_on_menuitem (mod_gl1_utils_context_t *
+_mod_gl1_menu_cylinder_center_on_menuitem (lw6sys_context_t * sys_context, mod_gl1_utils_context_t *
 					   utils_context,
-					   _mod_gl1_menu_cylinder_context_t
-					   * cylinder_context,
-					   const lw6gui_look_t * look,
-					   lw6gui_menu_t * menu, int position)
+					   _mod_gl1_menu_cylinder_context_t * cylinder_context, const lw6gui_look_t * look, lw6gui_menu_t * menu, int position)
 {
-  lw6gui_menu_center (menu, position,
-		      cylinder_context->const_data.max_displayed_items);
+  lw6gui_menu_center (sys_context, menu, position, cylinder_context->const_data.max_displayed_items);
 }
 
 void
-mod_gl1_menu_cylinder_center (mod_gl1_utils_context_t *
-			      utils_context,
-			      void *cylinder_context,
-			      const lw6gui_look_t * look,
+mod_gl1_menu_cylinder_center (lw6sys_context_t * sys_context, mod_gl1_utils_context_t * utils_context, void *cylinder_context, const lw6gui_look_t * look,
 			      lw6gui_menu_t * menu, int position)
 {
-  _mod_gl1_menu_cylinder_center_on_menuitem (utils_context,
-					     (_mod_gl1_menu_cylinder_context_t
-					      *) cylinder_context, look, menu,
-					     position);
+  _mod_gl1_menu_cylinder_center_on_menuitem (sys_context, utils_context, (_mod_gl1_menu_cylinder_context_t *) cylinder_context, look, menu, position);
 }
