@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -31,11 +31,9 @@
 #include "gl1-cylinder/gl1-cylinder.h"
 
 mod_gl1_menu_backend_t *
-mod_gl1_menu_create_backend (mod_gl1_utils_context_t * utils_context,
-			     const char *name)
+mod_gl1_menu_create_backend (lw6sys_context_t * sys_context, mod_gl1_utils_context_t * utils_context, const char *name)
 {
-  mod_gl1_menu_backend_t *(*init_func) (mod_gl1_utils_context_t *
-					utils_context) = NULL;
+  mod_gl1_menu_backend_t *(*init_func) (lw6sys_context_t * sys_context, mod_gl1_utils_context_t * utils_context) = NULL;
   mod_gl1_menu_backend_t *backend = NULL;
 
   if (strcmp (name, "cylinder") == 0)
@@ -44,16 +42,15 @@ mod_gl1_menu_create_backend (mod_gl1_utils_context_t * utils_context,
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING,
-		  _x_ ("menu backend \"%s\" does not exists"), name);
+      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("menu backend \"%s\" does not exists"), name);
     }
 
   if (init_func)
     {
-      backend = init_func (utils_context);
+      backend = init_func (sys_context, utils_context);
       if (backend)
 	{
-	  backend->backend_name = lw6sys_str_copy (name);
+	  backend->backend_name = lw6sys_str_copy (sys_context, name);
 	}
     }
 
@@ -61,15 +58,14 @@ mod_gl1_menu_create_backend (mod_gl1_utils_context_t * utils_context,
 }
 
 void
-mod_gl1_menu_destroy_backend (mod_gl1_utils_context_t * utils_context,
-			      mod_gl1_menu_backend_t * backend)
+mod_gl1_menu_destroy_backend (lw6sys_context_t * sys_context, mod_gl1_utils_context_t * utils_context, mod_gl1_menu_backend_t * backend)
 {
   if (backend)
     {
       if (backend->backend_name)
 	{
-	  LW6SYS_FREE (backend->backend_name);
+	  LW6SYS_FREE (sys_context, backend->backend_name);
 	}
-      LW6SYS_FREE (backend);
+      LW6SYS_FREE (sys_context, backend);
     }
 }
