@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -28,22 +28,20 @@
 #include "gl1-splash-internal.h"
 
 _mod_gl1_splash_context_t *
-_mod_gl1_splash_init (mod_gl1_utils_context_t * utils_context)
+_mod_gl1_splash_init (lw6sys_context_t * sys_context, mod_gl1_utils_context_t * utils_context)
 {
   _mod_gl1_splash_context_t *splash_context = NULL;
 
-  splash_context =
-    (_mod_gl1_splash_context_t *)
-    LW6SYS_CALLOC (sizeof (_mod_gl1_splash_context_t));
+  splash_context = (_mod_gl1_splash_context_t *) LW6SYS_CALLOC (sys_context, sizeof (_mod_gl1_splash_context_t));
   if (splash_context)
     {
-      if (_mod_gl1_splash_load_data (utils_context, splash_context))
+      if (_mod_gl1_splash_load_data (sys_context, utils_context, splash_context))
 	{
 	  // ok
 	}
       else
 	{
-	  LW6SYS_FREE (splash_context);
+	  LW6SYS_FREE (sys_context, splash_context);
 	  splash_context = NULL;
 	}
     }
@@ -52,37 +50,33 @@ _mod_gl1_splash_init (mod_gl1_utils_context_t * utils_context)
 }
 
 void *
-mod_gl1_splash_init (mod_gl1_utils_context_t * utils_context)
+mod_gl1_splash_init (lw6sys_context_t * sys_context, mod_gl1_utils_context_t * utils_context)
 {
   void *ret = NULL;
   if (utils_context)
     {
-      ret = (void *) _mod_gl1_splash_init (utils_context);
+      ret = (void *) _mod_gl1_splash_init (sys_context, utils_context);
     }
 
   return ret;
 }
 
 void
-_mod_gl1_splash_quit (mod_gl1_utils_context_t * utils_context,
-		      _mod_gl1_splash_context_t * splash_context)
+_mod_gl1_splash_quit (lw6sys_context_t * sys_context, mod_gl1_utils_context_t * utils_context, _mod_gl1_splash_context_t * splash_context)
 {
   if (utils_context && splash_context)
     {
       if (splash_context->text.shaded_text)
 	{
-	  mod_gl1_utils_shaded_text_free (utils_context,
-					  splash_context->text.shaded_text);
+	  mod_gl1_utils_shaded_text_free (sys_context, utils_context, splash_context->text.shaded_text);
 	}
-      _mod_gl1_splash_unload_data (utils_context, splash_context);
-      LW6SYS_FREE (splash_context);
+      _mod_gl1_splash_unload_data (sys_context, utils_context, splash_context);
+      LW6SYS_FREE (sys_context, splash_context);
     }
 }
 
 void
-mod_gl1_splash_quit (mod_gl1_utils_context_t * utils_context,
-		     void *splash_context)
+mod_gl1_splash_quit (lw6sys_context_t * sys_context, mod_gl1_utils_context_t * utils_context, void *splash_context)
 {
-  _mod_gl1_splash_quit (utils_context,
-			(_mod_gl1_splash_context_t *) splash_context);
+  _mod_gl1_splash_quit (sys_context, utils_context, (_mod_gl1_splash_context_t *) splash_context);
 }
