@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -30,25 +30,17 @@
 #define _BITMAP_ARRAY_DESC "bitmap_array"
 
 int
-mod_gl1_utils_bitmap_array_init (mod_gl1_utils_context_t *
-				 utils_context,
-				 mod_gl1_utils_bitmap_array_t * bitmap_array,
-				 int w, int h, int tile_size, int border_size)
+mod_gl1_utils_bitmap_array_init (lw6sys_context_t * sys_context, mod_gl1_utils_context_t *
+				 utils_context, mod_gl1_utils_bitmap_array_t * bitmap_array, int w, int h, int tile_size, int border_size)
 {
   int ret = 0;
   int i;
   mod_gl1_utils_bitmap_t *bitmap;
 
   tile_size = lw6sys_imin (tile_size, utils_context->caps.max_texture_size);
-  if (lw6gui_rect_array_init
-      (&(bitmap_array->layout), w, h, tile_size, border_size))
+  if (lw6gui_rect_array_init (sys_context, &(bitmap_array->layout), w, h, tile_size, border_size))
     {
-      bitmap_array->bitmaps =
-	(mod_gl1_utils_bitmap_t **) LW6SYS_CALLOC (bitmap_array->
-						   layout.nb_tiles *
-						   sizeof
-						   (mod_gl1_utils_bitmap_t
-						    *));
+      bitmap_array->bitmaps = (mod_gl1_utils_bitmap_t **) LW6SYS_CALLOC (sys_context, bitmap_array->layout.nb_tiles * sizeof (mod_gl1_utils_bitmap_t *));
 
       if (bitmap_array->bitmaps)
 	{
@@ -56,10 +48,7 @@ mod_gl1_utils_bitmap_array_init (mod_gl1_utils_context_t *
 	  for (i = 0; i < bitmap_array->layout.nb_tiles; ++i)
 	    {
 	      bitmap =
-		mod_gl1_utils_bitmap_new (utils_context,
-					  bitmap_array->layout.tile_size,
-					  bitmap_array->layout.tile_size,
-					  _BITMAP_ARRAY_DESC);
+		mod_gl1_utils_bitmap_new (sys_context, utils_context, bitmap_array->layout.tile_size, bitmap_array->layout.tile_size, _BITMAP_ARRAY_DESC);
 	      if (bitmap)
 		{
 		  /*
@@ -68,26 +57,23 @@ mod_gl1_utils_bitmap_array_init (mod_gl1_utils_context_t *
 		   * happens when bitmap has never been displayed
 		   * so it might still be 0.
 		   */
-		  mod_gl1_utils_bitmap_refresh (utils_context, bitmap);
-		  mod_gl1_utils_bitmap_array_set (bitmap_array, i, bitmap);
+		  mod_gl1_utils_bitmap_refresh (sys_context, utils_context, bitmap);
+		  mod_gl1_utils_bitmap_array_set (sys_context, bitmap_array, i, bitmap);
 		}
 	      else
 		{
 		  ret = 0;
-		  lw6sys_log (LW6SYS_LOG_WARNING,
-			      _x_
-			      ("bitmap %d of bitmap array couldn't be created, array is broken"),
-			      i);
+		  lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("bitmap %d of bitmap array couldn't be created, array is broken"), i);
 		}
 	    }
 	}
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("unable to init rect_array"));
+      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("unable to init rect_array"));
       if (bitmap_array->bitmaps)
 	{
-	  LW6SYS_FREE (bitmap_array->bitmaps);
+	  LW6SYS_FREE (sys_context, bitmap_array->bitmaps);
 	  bitmap_array->bitmaps = NULL;
 	}
     }
@@ -96,13 +82,10 @@ mod_gl1_utils_bitmap_array_init (mod_gl1_utils_context_t *
 }
 
 int
-mod_gl1_utils_bitmap_array_init_from_surface (mod_gl1_utils_context_t *
+mod_gl1_utils_bitmap_array_init_from_surface (lw6sys_context_t * sys_context, mod_gl1_utils_context_t *
 					      utils_context,
 					      mod_gl1_utils_bitmap_array_t *
-					      bitmap_array,
-					      SDL_Surface * surface,
-					      int tile_size, int border_size,
-					      int x_polarity, int y_polarity)
+					      bitmap_array, SDL_Surface * surface, int tile_size, int border_size, int x_polarity, int y_polarity)
 {
   int ret = 0;
   int i;
@@ -114,19 +97,17 @@ mod_gl1_utils_bitmap_array_init_from_surface (mod_gl1_utils_context_t *
   lw6sys_whd_t shape;
   int x_get, y_get, x_put, y_put;
 
-  if (mod_gl1_utils_bitmap_array_init
-      (utils_context, bitmap_array, surface->w, surface->h, tile_size,
-       border_size))
+  if (mod_gl1_utils_bitmap_array_init (sys_context, utils_context, bitmap_array, surface->w, surface->h, tile_size, border_size))
     {
       ret = 1;
-      lw6map_rules_defaults (&rules);
+      lw6map_rules_defaults (sys_context, &rules);
       rules.x_polarity = x_polarity;
       rules.y_polarity = y_polarity;
       shape.w = surface->w;
       shape.h = surface->h;
       for (i = 0; i < bitmap_array->layout.nb_tiles; ++i)
 	{
-	  bitmap = mod_gl1_utils_bitmap_array_get (bitmap_array, i);
+	  bitmap = mod_gl1_utils_bitmap_array_get (sys_context, bitmap_array, i);
 	  if (bitmap)
 	    {
 	      sub_surface = bitmap->surface;
@@ -134,9 +115,8 @@ mod_gl1_utils_bitmap_array_init_from_surface (mod_gl1_utils_context_t *
 		{
 		  SDL_SetAlpha (surface, 0, SDL_ALPHA_OPAQUE);
 		  SDL_SetAlpha (sub_surface, 0, SDL_ALPHA_OPAQUE);
-		  mod_gl1_utils_clear_surface (sub_surface);
-		  if (lw6gui_rect_array_get_tile_by_i
-		      (&(bitmap_array->layout), &rect, i))
+		  mod_gl1_utils_clear_surface (sys_context, sub_surface);
+		  if (lw6gui_rect_array_get_tile_by_i (sys_context, &(bitmap_array->layout), &rect, i))
 		    {
 		      /*
 		       * Previous version of the code used blits but it's really
@@ -150,35 +130,28 @@ mod_gl1_utils_bitmap_array_init_from_surface (mod_gl1_utils_context_t *
 			    {
 			      x_get = x;
 			      y_get = y;
-			      lw6map_coords_fix_xy (&rules, &shape, &x_get,
-						    &y_get);
+			      lw6map_coords_fix_xy (&rules, &shape, &x_get, &y_get);
 			      x_put = x - rect.x1;
 			      y_put = y - rect.y1;
-			      mod_gl1_utils_putpixel (sub_surface, x_put,
-						      y_put,
-						      mod_gl1_utils_getpixel
-						      (surface, x_get,
-						       y_get));
+			      mod_gl1_utils_putpixel (sys_context, sub_surface, x_put, y_put, mod_gl1_utils_getpixel (sys_context, surface, x_get, y_get));
 			    }
 			}
 		    }
 		  else
 		    {
-		      lw6sys_log (LW6SYS_LOG_WARNING,
-				  _x_ ("inconsistent layout"));
+		      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("inconsistent layout"));
 		      ret = 0;
 		    }
 		}
 	      else
 		{
-		  lw6sys_log (LW6SYS_LOG_WARNING,
-			      _x_ ("sub_surface is NULL"));
+		  lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("sub_surface is NULL"));
 		  ret = 0;
 		}
 	    }
 	  else
 	    {
-	      lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("bitmap is NULL"));
+	      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("bitmap is NULL"));
 	      ret = 0;
 	    }
 	}
@@ -188,37 +161,27 @@ mod_gl1_utils_bitmap_array_init_from_surface (mod_gl1_utils_context_t *
 }
 
 int
-mod_gl1_utils_bitmap_array_init_from_map (mod_gl1_utils_context_t *
+mod_gl1_utils_bitmap_array_init_from_map (lw6sys_context_t * sys_context, mod_gl1_utils_context_t *
 					  utils_context,
 					  mod_gl1_utils_bitmap_array_t *
-					  bitmap_array,
-					  const lw6map_level_t * level,
-					  int tile_size, int border_size,
-					  int x_polarity, int y_polarity)
+					  bitmap_array, const lw6map_level_t * level, int tile_size, int border_size, int x_polarity, int y_polarity)
 {
   int ret = 0;
   SDL_Surface *surface;
 
-  surface = mod_gl1_utils_map2surface (utils_context, level);
+  surface = mod_gl1_utils_map2surface (sys_context, utils_context, level);
   if (surface)
     {
-      ret = mod_gl1_utils_bitmap_array_init_from_surface (utils_context,
-							  bitmap_array,
-							  surface, tile_size,
-							  border_size,
-							  x_polarity,
-							  y_polarity);
-      mod_gl1_utils_delete_surface (utils_context, surface);
+      ret = mod_gl1_utils_bitmap_array_init_from_surface (sys_context, utils_context, bitmap_array, surface, tile_size, border_size, x_polarity, y_polarity);
+      mod_gl1_utils_delete_surface (sys_context, utils_context, surface);
     }
 
   return ret;
 }
 
 int
-mod_gl1_utils_bitmap_array_update (mod_gl1_utils_context_t *
-				   utils_context,
-				   mod_gl1_utils_bitmap_array_t *
-				   bitmap_array, GLint wrap, GLint filter)
+mod_gl1_utils_bitmap_array_update (lw6sys_context_t * sys_context, mod_gl1_utils_context_t * utils_context, mod_gl1_utils_bitmap_array_t * bitmap_array,
+				   GLint wrap, GLint filter)
 {
   int ret = 1;
   int i;
@@ -226,21 +189,16 @@ mod_gl1_utils_bitmap_array_update (mod_gl1_utils_context_t *
 
   for (i = 0; i < bitmap_array->layout.nb_tiles; ++i)
     {
-      bitmap = mod_gl1_utils_bitmap_array_get (bitmap_array, i);
+      bitmap = mod_gl1_utils_bitmap_array_get (sys_context, bitmap_array, i);
       if (bitmap)
 	{
-	  ret = mod_gl1_utils_bitmap_set_wrap (utils_context, bitmap, wrap)
-	    && ret;
-	  ret =
-	    mod_gl1_utils_bitmap_set_filter (utils_context, bitmap, filter)
-	    && ret;
-	  mod_gl1_utils_texture_update (utils_context, bitmap->texture,
-					bitmap->surface);
+	  ret = mod_gl1_utils_bitmap_set_wrap (sys_context, utils_context, bitmap, wrap) && ret;
+	  ret = mod_gl1_utils_bitmap_set_filter (sys_context, utils_context, bitmap, filter) && ret;
+	  mod_gl1_utils_texture_update (sys_context, utils_context, bitmap->texture, bitmap->surface);
 	}
       else
 	{
-	  lw6sys_log (LW6SYS_LOG_WARNING,
-		      _x_ ("NULL bitmap in bitmap_array at index %d"), i);
+	  lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("NULL bitmap in bitmap_array at index %d"), i);
 	  ret = 0;
 	}
     }
@@ -249,8 +207,7 @@ mod_gl1_utils_bitmap_array_update (mod_gl1_utils_context_t *
 }
 
 void
-mod_gl1_utils_bitmap_array_clear (mod_gl1_utils_context_t * utils_context,
-				  mod_gl1_utils_bitmap_array_t * bitmap_array)
+mod_gl1_utils_bitmap_array_clear (lw6sys_context_t * sys_context, mod_gl1_utils_context_t * utils_context, mod_gl1_utils_bitmap_array_t * bitmap_array)
 {
   int i;
 
@@ -258,9 +215,9 @@ mod_gl1_utils_bitmap_array_clear (mod_gl1_utils_context_t * utils_context,
     {
       for (i = 0; i < bitmap_array->layout.nb_tiles; ++i)
 	{
-	  mod_gl1_utils_bitmap_free (utils_context, bitmap_array->bitmaps[i]);
+	  mod_gl1_utils_bitmap_free (sys_context, utils_context, bitmap_array->bitmaps[i]);
 	}
-      LW6SYS_FREE (bitmap_array->bitmaps);
+      LW6SYS_FREE (sys_context, bitmap_array->bitmaps);
       bitmap_array->bitmaps = NULL;
     }
 }
@@ -272,10 +229,8 @@ mod_gl1_utils_bitmap_array_clear (mod_gl1_utils_context_t * utils_context,
  * usable 'till next redraw.
  */
 void
-sdl_utils_schedule_delete_bitmap_array (mod_gl1_utils_context_t *
-					utils_context,
-					mod_gl1_utils_bitmap_array_t *
-					bitmap_array)
+mod_gl1_utils_schedule_delete_bitmap_array (lw6sys_context_t * sys_context, mod_gl1_utils_context_t * utils_context,
+					    mod_gl1_utils_bitmap_array_t * bitmap_array)
 {
   int i;
 
@@ -283,17 +238,15 @@ sdl_utils_schedule_delete_bitmap_array (mod_gl1_utils_context_t *
     {
       for (i = 0; i < bitmap_array->layout.nb_tiles; ++i)
 	{
-	  mod_gl1_utils_bitmap_free (utils_context, bitmap_array->bitmaps[i]);
+	  mod_gl1_utils_bitmap_free (sys_context, utils_context, bitmap_array->bitmaps[i]);
 	}
-      LW6SYS_FREE (bitmap_array->bitmaps);
+      LW6SYS_FREE (sys_context, bitmap_array->bitmaps);
       bitmap_array->bitmaps = NULL;
     }
 }
 
 int
-mod_gl1_utils_bitmap_array_set (mod_gl1_utils_bitmap_array_t *
-				bitmap_array, int i,
-				mod_gl1_utils_bitmap_t * bitmap)
+mod_gl1_utils_bitmap_array_set (lw6sys_context_t * sys_context, mod_gl1_utils_bitmap_array_t * bitmap_array, int i, mod_gl1_utils_bitmap_t * bitmap)
 {
   int ret = 0;
 
@@ -303,18 +256,14 @@ mod_gl1_utils_bitmap_array_set (mod_gl1_utils_bitmap_array_t *
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING,
-		  _x_
-		  ("bitmap_array_set parameters out of range i=%d nb_tiles=%d"),
-		  i, bitmap_array->layout.nb_tiles);
+      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("bitmap_array_set parameters out of range i=%d nb_tiles=%d"), i, bitmap_array->layout.nb_tiles);
     }
 
   return ret;
 }
 
 mod_gl1_utils_bitmap_t *
-mod_gl1_utils_bitmap_array_get (mod_gl1_utils_bitmap_array_t *
-				bitmap_array, int i)
+mod_gl1_utils_bitmap_array_get (lw6sys_context_t * sys_context, mod_gl1_utils_bitmap_array_t * bitmap_array, int i)
 {
   mod_gl1_utils_bitmap_t *ret = NULL;
 
@@ -324,10 +273,7 @@ mod_gl1_utils_bitmap_array_get (mod_gl1_utils_bitmap_array_t *
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_INFO,
-		  _x_
-		  ("bitmap_array_get parameters out of range i=%d nb_tiles=%d"),
-		  i, bitmap_array->layout.nb_tiles);
+      lw6sys_log (sys_context, LW6SYS_LOG_INFO, _x_ ("bitmap_array_get parameters out of range i=%d nb_tiles=%d"), i, bitmap_array->layout.nb_tiles);
       /*
        * By default we still return something, display might be a little
        * inconsistent but this is not as bad as a segfault. BTW, most of the
