@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -28,7 +28,7 @@
 #include "gl1-utils.h"
 
 SDL_Color
-mod_gl1_utils_color_8_to_sdl (lw6sys_color_8_t color_8)
+mod_gl1_utils_color_8_to_sdl (lw6sys_context_t * sys_context, lw6sys_color_8_t color_8)
 {
   SDL_Color ret;
 
@@ -41,28 +41,24 @@ mod_gl1_utils_color_8_to_sdl (lw6sys_color_8_t color_8)
 }
 
 SDL_Color
-mod_gl1_utils_color_f_to_sdl (const lw6sys_color_f_t * color_f)
+mod_gl1_utils_color_f_to_sdl (lw6sys_context_t * sys_context, const lw6sys_color_f_t * color_f)
 {
   lw6sys_color_8_t color_8;
   SDL_Color ret;
 
   color_8 = lw6sys_color_f_to_8 (color_f);
-  ret = mod_gl1_utils_color_8_to_sdl (color_8);
+  ret = mod_gl1_utils_color_8_to_sdl (sys_context, color_8);
 
   return ret;
 }
 
 static Uint32
-_prepare_shaded_color_for_fighter (lw6sys_color_8_t dead_color,
-				   lw6sys_color_8_t team_color, int j)
+_prepare_shaded_color_for_fighter (lw6sys_context_t * sys_context, lw6sys_color_8_t dead_color, lw6sys_color_8_t team_color, int j)
 {
   Uint32 ret = 0;
   lw6sys_color_8_t color;
 
-  color =
-    lw6sys_color_ponderate (dead_color, team_color,
-			    ((float) j) /
-			    ((float) MOD_GL1_SHADES_FOR_FIGHTERS_SCALE));
+  color = lw6sys_color_ponderate (sys_context, dead_color, team_color, ((float) j) / ((float) MOD_GL1_SHADES_FOR_FIGHTERS_SCALE));
   color.a = 0xFF;
   ret = lw6sys_color_8_to_irgba (color);
 
@@ -70,9 +66,7 @@ _prepare_shaded_color_for_fighter (lw6sys_color_8_t dead_color,
 }
 
 void
-mod_gl1_utils_update_team_color_map (mod_gl1_utils_team_color_map_t *
-				     team_color_map,
-				     const lw6map_style_t * map_style)
+mod_gl1_utils_update_team_color_map (lw6sys_context_t * sys_context, mod_gl1_utils_team_color_map_t * team_color_map, const lw6map_style_t * map_style)
 {
   int i, j;
   Uint32 test;
@@ -83,40 +77,31 @@ mod_gl1_utils_update_team_color_map (mod_gl1_utils_team_color_map_t *
   for (i = 0; i < LW6MAP_MAX_NB_TEAMS; ++i)
     {
       team_color = map_style->color_set.team_colors[i];
-      test =
-	_prepare_shaded_color_for_fighter (dead_color, team_color,
-					   MOD_GL1_SHADES_FOR_FIGHTERS_SCALE);
-      if (test !=
-	  team_color_map->team_colors[i][MOD_GL1_SHADES_FOR_FIGHTERS_SCALE])
+      test = _prepare_shaded_color_for_fighter (sys_context, dead_color, team_color, MOD_GL1_SHADES_FOR_FIGHTERS_SCALE);
+      if (test != team_color_map->team_colors[i][MOD_GL1_SHADES_FOR_FIGHTERS_SCALE])
 	{
-	  lw6sys_color_8_to_f (&(team_color_map->team_colors_f[i]),
-			       team_color);
+	  lw6sys_color_8_to_f (&(team_color_map->team_colors_f[i]), team_color);
 	  for (j = 0; j < MOD_GL1_SHADES_FOR_FIGHTERS_SCALE + 1; ++j)
 	    {
-	      team_color_map->team_colors[i][j] =
-		_prepare_shaded_color_for_fighter (dead_color, team_color, j);
+	      team_color_map->team_colors[i][j] = _prepare_shaded_color_for_fighter (sys_context, dead_color, team_color, j);
 	    }
 	}
     }
 }
 
 int
-mod_gl1_utils_team_color_map_is_same (const mod_gl1_utils_team_color_map_t
-				      * team_color_map_a,
-				      const mod_gl1_utils_team_color_map_t *
-				      team_color_map_b)
+mod_gl1_utils_team_color_map_is_same (lw6sys_context_t * sys_context, const mod_gl1_utils_team_color_map_t * team_color_map_a,
+				      const mod_gl1_utils_team_color_map_t * team_color_map_b)
 {
   int ret = 0;
 
-  ret =
-    !memcmp (team_color_map_a, team_color_map_b,
-	     sizeof (mod_gl1_utils_team_color_map_t));
+  ret = !memcmp (team_color_map_a, team_color_map_b, sizeof (mod_gl1_utils_team_color_map_t));
 
   return ret;
 }
 
 void
-mod_gl1_utils_force_color32_alpha (Uint32 * color, float alpha)
+mod_gl1_utils_force_color32_alpha (lw6sys_context_t * sys_context, Uint32 * color, float alpha)
 {
   unsigned char *ptr = (unsigned char *) color;
 
@@ -124,9 +109,7 @@ mod_gl1_utils_force_color32_alpha (Uint32 * color, float alpha)
 }
 
 Uint32
-mod_gl1_utils_get_shaded_color_for_fighter_f (mod_gl1_utils_context_t *
-					      utils_context, int team_id,
-					      float health)
+mod_gl1_utils_get_shaded_color_for_fighter_f (lw6sys_context_t * sys_context, mod_gl1_utils_context_t * utils_context, int team_id, float health)
 {
   Uint32 ret;
   float f;
