@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -28,10 +28,8 @@
 #include "gl1-utils.h"
 
 SDL_Surface *
-mod_gl1_utils_colorize_surface (mod_gl1_utils_context_t *
-				utils_context, SDL_Surface * surface,
-				const lw6map_color_couple_t * color,
-				int has_alpha)
+mod_gl1_utils_colorize_surface (lw6sys_context_t * sys_context, mod_gl1_utils_context_t * utils_context, SDL_Surface * surface,
+				const lw6map_color_couple_t * color, int has_alpha)
 {
   SDL_Surface *colorized_surface = NULL;
   int x, y;
@@ -39,15 +37,13 @@ mod_gl1_utils_colorize_surface (mod_gl1_utils_context_t *
   lw6sys_color_hsv_t color_hsv;
   int a;
 
-  colorized_surface =
-    mod_gl1_utils_create_surface (utils_context, surface->w, surface->h);
+  colorized_surface = mod_gl1_utils_create_surface (sys_context, utils_context, surface->w, surface->h);
 
   for (y = 0; y < surface->h; ++y)
     {
       for (x = 0; x < surface->w; ++x)
 	{
-	  color_8 =
-	    lw6sys_color_irgba_to_8 (mod_gl1_utils_getpixel (surface, x, y));
+	  color_8 = lw6sys_color_irgba_to_8 (mod_gl1_utils_getpixel (sys_context, surface, x, y));
 	  if (has_alpha)
 	    {
 	      a = color_8.a;
@@ -56,12 +52,10 @@ mod_gl1_utils_colorize_surface (mod_gl1_utils_context_t *
 	    {
 	      a = 255;
 	    }
-	  lw6sys_color_rgb_to_hsv (&color_hsv, color_8);
-	  color_8 = lw6sys_color_ponderate (color->bg,
-					    color->fg, color_hsv.v);
+	  lw6sys_color_rgb_to_hsv (sys_context, &color_hsv, color_8);
+	  color_8 = lw6sys_color_ponderate (sys_context, color->bg, color->fg, color_hsv.v);
 	  color_8.a = a;
-	  mod_gl1_utils_putpixel (colorized_surface, x, y,
-				  lw6sys_color_8_to_irgba (color_8));
+	  mod_gl1_utils_putpixel (sys_context, colorized_surface, x, y, lw6sys_color_8_to_irgba (color_8));
 	}
     }
 
