@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -32,11 +32,9 @@
  * fighters here" is done.
  */
 static void
-_update_game_surface_raw (mod_gl1_utils_context_t * utils_context,
+_update_game_surface_raw (lw6sys_context_t * sys_context, mod_gl1_utils_context_t * utils_context,
 			  SDL_Surface * surface,
-			  const lw6ker_game_state_t * game_state,
-			  const lw6map_color_couple_t * map_color,
-			  int invert_y, int x0, int y0, int w, int h)
+			  const lw6ker_game_state_t * game_state, const lw6map_color_couple_t * map_color, int invert_y, int x0, int y0, int w, int h)
 {
   int x, y, x1, y1, ry;
   int fighter_id;
@@ -49,7 +47,7 @@ _update_game_surface_raw (mod_gl1_utils_context_t * utils_context,
   lw6sys_whd_t shape = { 0, 0, 0 };
   int bytes_per_pixel;
 
-  lw6ker_game_state_get_shape (game_state, &shape);
+  lw6ker_game_state_get_shape (sys_context, game_state, &shape);
   rules = &(game_state->game_struct->rules);
 
   x1 = x0 + w - 1;
@@ -69,13 +67,10 @@ _update_game_surface_raw (mod_gl1_utils_context_t * utils_context,
 	  for (x = x0; x < x1; ++x)
 	    {
 	      fighter_id = -1;
-	      fighter_id =
-		lw6ker_game_state_get_fighter_id (game_state, x, ry, 0);
+	      fighter_id = lw6ker_game_state_get_fighter_id (sys_context, game_state, x, ry, 0);
 	      if (fighter_id >= 0)
 		{
-		  fighter =
-		    lw6ker_game_state_get_fighter_ro_by_id (game_state,
-							    fighter_id);
+		  fighter = lw6ker_game_state_get_fighter_ro_by_id (sys_context, game_state, fighter_id);
 		  team_color = fighter->team_color;
 		  if (team_color >= 0)
 		    {
@@ -84,14 +79,12 @@ _update_game_surface_raw (mod_gl1_utils_context_t * utils_context,
 		       * mode, team_color could be negative even if fighter was
 		       * reported active just before.
 		       */
-		      color = mod_gl1_utils_get_shaded_color_for_fighter
-			(utils_context, team_color, fighter->health);
+		      color = mod_gl1_utils_get_shaded_color_for_fighter (utils_context, team_color, fighter->health);
 		    }
 		}
 	      else
 		{
-		  if (lw6ker_game_struct_is_bg
-		      (game_state->game_struct, x, ry, 0))
+		  if (lw6ker_game_struct_is_bg (sys_context, game_state->game_struct, x, ry, 0))
 		    {
 		      color = bg;
 		    }
@@ -102,49 +95,39 @@ _update_game_surface_raw (mod_gl1_utils_context_t * utils_context,
 		}
 	      if (bytes_per_pixel == 4)
 		{
-		  mod_gl1_utils_putpixel_4_bytes_per_pixel (surface, x - x0,
-							    y - y0, color);
+		  mod_gl1_utils_putpixel_4_bytes_per_pixel (surface, x - x0, y - y0, color);
 		}
 	      else
 		{
-		  mod_gl1_utils_putpixel (surface, x - x0, y - y0, color);
+		  mod_gl1_utils_putpixel (sys_context, surface, x - x0, y - y0, color);
 		}
 	    }
 	}
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING,
-		  _x_
-		  ("wrong surface dimension x0=%d x1=%d surface->w=%d y0=%d y1=%d surface->h=%d"),
-		  x0, x1, surface->w, y0, y1, surface->h);
+      lw6sys_log (sys_context, LW6SYS_LOG_WARNING,
+		  _x_ ("wrong surface dimension x0=%d x1=%d surface->w=%d y0=%d y1=%d surface->h=%d"), x0, x1, surface->w, y0, y1, surface->h);
     }
 }
 
 static void
-_update_game_bitmap_raw (mod_gl1_utils_context_t * utils_context,
+_update_game_bitmap_raw (lw6sys_context_t * sys_context, mod_gl1_utils_context_t * utils_context,
 			 mod_gl1_utils_bitmap_t * bitmap,
-			 const lw6ker_game_state_t * game_state,
-			 const lw6map_color_couple_t * map_color,
-			 int invert_y, int x0, int y0, int w, int h)
+			 const lw6ker_game_state_t * game_state, const lw6map_color_couple_t * map_color, int invert_y, int x0, int y0, int w, int h)
 {
-  _update_game_surface_raw (utils_context, bitmap->surface, game_state,
-			    map_color, invert_y, x0, y0, w, h);
+  _update_game_surface_raw (sys_context, utils_context, bitmap->surface, game_state, map_color, invert_y, x0, y0, w, h);
 }
 
 void
-mod_gl1_utils_update_game_bitmap_raw (mod_gl1_utils_context_t * utils_context,
+mod_gl1_utils_update_game_bitmap_raw (lw6sys_context_t * sys_context, mod_gl1_utils_context_t * utils_context,
 				      mod_gl1_utils_bitmap_t * bitmap,
-				      const lw6ker_game_state_t * game_state,
-				      const lw6map_color_couple_t * map_color,
-				      int invert_y)
+				      const lw6ker_game_state_t * game_state, const lw6map_color_couple_t * map_color, int invert_y)
 {
   if (bitmap->surface)
     {
-      _update_game_bitmap_raw (utils_context, bitmap, game_state, map_color,
-			       invert_y, 0, 0,
-			       lw6ker_game_state_get_w (game_state),
-			       lw6ker_game_state_get_h (game_state));
+      _update_game_bitmap_raw (sys_context, utils_context, bitmap, game_state, map_color,
+			       invert_y, 0, 0, lw6ker_game_state_get_w (sys_context, game_state), lw6ker_game_state_get_h (sys_context, game_state));
       if (bitmap->texture)
 	{
 	  /*
@@ -154,8 +137,7 @@ mod_gl1_utils_update_game_bitmap_raw (mod_gl1_utils_context_t * utils_context,
 	   * be created each time: it's always the same size and represents
 	   * pretty much the same thing/layer -> where fighters are!
 	   */
-	  mod_gl1_utils_texture_update (utils_context, bitmap->texture,
-					bitmap->surface);
+	  mod_gl1_utils_texture_update (sys_context, utils_context, bitmap->texture, bitmap->surface);
 	}
     }
 }
@@ -165,11 +147,8 @@ mod_gl1_utils_update_game_bitmap_raw (mod_gl1_utils_context_t * utils_context,
  * fighters here" is done.
  */
 static void
-_update_game_surface (mod_gl1_utils_context_t * utils_context,
-		      SDL_Surface * surface,
-		      const lw6ker_game_state_t * game_state,
-		      const lw6gui_look_t * look, int x0, int y0, int w,
-		      int h)
+_update_game_surface (lw6sys_context_t * sys_context, mod_gl1_utils_context_t * utils_context,
+		      SDL_Surface * surface, const lw6ker_game_state_t * game_state, const lw6gui_look_t * look, int x0, int y0, int w, int h)
 {
   int x, y, z, x1, y1, d;
   int safe_x = 0, safe_y = 0;
@@ -182,7 +161,7 @@ _update_game_surface (mod_gl1_utils_context_t * utils_context,
   lw6sys_whd_t shape = { 0, 0, 0 };
   int bytes_per_pixel;
 
-  lw6ker_game_state_get_shape (game_state, &shape);
+  lw6ker_game_state_get_shape (sys_context, game_state, &shape);
   rules = &(game_state->game_struct->rules);
 
   hidden_layer_alpha = look->style.hidden_layer_alpha;
@@ -203,9 +182,7 @@ _update_game_surface (mod_gl1_utils_context_t * utils_context,
 	      hidden = 0;
 	      for (z = 0; z < d && fighter_id < 0; ++z)
 		{
-		  fighter_id =
-		    lw6ker_game_state_get_fighter_id (game_state,
-						      safe_x, safe_y, z);
+		  fighter_id = lw6ker_game_state_get_fighter_id (sys_context, game_state, safe_x, safe_y, z);
 		  /*
 		   * It's important to test d>1 else a call
 		   * to get_zone_id is done when it's not needed,
@@ -214,16 +191,12 @@ _update_game_surface (mod_gl1_utils_context_t * utils_context,
 		   */
 		  if (d > 1 && fighter_id < 0)
 		    {
-		      hidden =
-			lw6ker_game_struct_is_fg
-			(game_state->game_struct, safe_x, safe_y, z);
+		      hidden = lw6ker_game_struct_is_fg (sys_context, game_state->game_struct, safe_x, safe_y, z);
 		    }
 		}
 	      if (fighter_id >= 0)
 		{
-		  fighter =
-		    lw6ker_game_state_get_fighter_ro_by_id (game_state,
-							    fighter_id);
+		  fighter = lw6ker_game_state_get_fighter_ro_by_id (sys_context, game_state, fighter_id);
 		  team_color = fighter->team_color;
 		  if (team_color >= 0)
 		    {
@@ -232,37 +205,30 @@ _update_game_surface (mod_gl1_utils_context_t * utils_context,
 		       * mode, team_color could be negative even if fighter was
 		       * reported active just before.
 		       */
-		      color = mod_gl1_utils_get_shaded_color_for_fighter
-			(utils_context, team_color, fighter->health);
+		      color = mod_gl1_utils_get_shaded_color_for_fighter (utils_context, team_color, fighter->health);
 		      if (hidden)
 			{
-			  mod_gl1_utils_force_color32_alpha (&color,
-							     hidden_layer_alpha);
+			  mod_gl1_utils_force_color32_alpha (sys_context, &color, hidden_layer_alpha);
 			}
 		    }
 		  if (bytes_per_pixel == 4)
 		    {
-		      mod_gl1_utils_putpixel_4_bytes_per_pixel (surface,
-								x - x0,
-								y - y0,
-								color);
+		      mod_gl1_utils_putpixel_4_bytes_per_pixel (surface, x - x0, y - y0, color);
 		    }
 		  else
 		    {
-		      mod_gl1_utils_putpixel (surface, x - x0, y - y0, color);
+		      mod_gl1_utils_putpixel (sys_context, surface, x - x0, y - y0, color);
 		    }
 		}
 	      else
 		{
 		  if (bytes_per_pixel == 4)
 		    {
-		      mod_gl1_utils_putpixel_4_bytes_per_pixel (surface,
-								x - x0,
-								y - y0, 0);
+		      mod_gl1_utils_putpixel_4_bytes_per_pixel (surface, x - x0, y - y0, 0);
 		    }
 		  else
 		    {
-		      mod_gl1_utils_putpixel (surface, x - x0, y - y0, 0);
+		      mod_gl1_utils_putpixel (sys_context, surface, x - x0, y - y0, 0);
 		    }
 		}
 	    }
@@ -270,34 +236,26 @@ _update_game_surface (mod_gl1_utils_context_t * utils_context,
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING,
-		  _x_
-		  ("wrong surface dimension x0=%d x1=%d surface->w=%d y0=%d y1=%d surface->h=%d"),
-		  x0, x1, surface->w, y0, y1, surface->h);
+      lw6sys_log (sys_context, LW6SYS_LOG_WARNING,
+		  _x_ ("wrong surface dimension x0=%d x1=%d surface->w=%d y0=%d y1=%d surface->h=%d"), x0, x1, surface->w, y0, y1, surface->h);
     }
 }
 
 static void
-_update_game_bitmap (mod_gl1_utils_context_t * utils_context,
-		     mod_gl1_utils_bitmap_t * bitmap,
-		     const lw6ker_game_state_t * game_state,
-		     const lw6gui_look_t * look, int x0, int y0, int w, int h)
+_update_game_bitmap (lw6sys_context_t * sys_context, mod_gl1_utils_context_t * utils_context,
+		     mod_gl1_utils_bitmap_t * bitmap, const lw6ker_game_state_t * game_state, const lw6gui_look_t * look, int x0, int y0, int w, int h)
 {
-  _update_game_surface (utils_context, bitmap->surface, game_state, look, x0,
-			y0, w, h);
+  _update_game_surface (sys_context, utils_context, bitmap->surface, game_state, look, x0, y0, w, h);
 }
 
 void
-mod_gl1_utils_update_game_bitmap (mod_gl1_utils_context_t * utils_context,
-				  mod_gl1_utils_bitmap_t * bitmap,
-				  const lw6ker_game_state_t * game_state,
-				  const lw6gui_look_t * look)
+mod_gl1_utils_update_game_bitmap (lw6sys_context_t * sys_context, mod_gl1_utils_context_t * utils_context,
+				  mod_gl1_utils_bitmap_t * bitmap, const lw6ker_game_state_t * game_state, const lw6gui_look_t * look)
 {
   if (bitmap->surface)
     {
-      _update_game_bitmap (utils_context, bitmap, game_state, look,
-			   0, 0, lw6ker_game_state_get_w (game_state),
-			   lw6ker_game_state_get_h (game_state));
+      _update_game_bitmap (sys_context, utils_context, bitmap, game_state, look,
+			   0, 0, lw6ker_game_state_get_w (sys_context, game_state), lw6ker_game_state_get_h (sys_context, game_state));
       if (bitmap->texture)
 	{
 	  /*
@@ -307,20 +265,15 @@ mod_gl1_utils_update_game_bitmap (mod_gl1_utils_context_t * utils_context,
 	   * be created each time: it's always the same size and represents
 	   * pretty much the same thing/layer -> where fighters are!
 	   */
-	  mod_gl1_utils_texture_update (utils_context, bitmap->texture,
-					bitmap->surface);
+	  mod_gl1_utils_texture_update (sys_context, utils_context, bitmap->texture, bitmap->surface);
 	}
     }
 }
 
 void
-mod_gl1_utils_update_game_bitmap_array (mod_gl1_utils_context_t *
+mod_gl1_utils_update_game_bitmap_array (lw6sys_context_t * sys_context, mod_gl1_utils_context_t *
 					utils_context,
-					mod_gl1_utils_bitmap_array_t *
-					bitmap_array,
-					const lw6ker_game_state_t *
-					game_state,
-					const lw6gui_look_t * look)
+					mod_gl1_utils_bitmap_array_t * bitmap_array, const lw6ker_game_state_t * game_state, const lw6gui_look_t * look)
 {
   int i;
   GLint wrap = 0;
@@ -328,9 +281,7 @@ mod_gl1_utils_update_game_bitmap_array (mod_gl1_utils_context_t *
   mod_gl1_utils_bitmap_t *bitmap = NULL;
 
   if (utils_context->last_action.game_bitmap_array_update_id !=
-      game_state->id
-      || utils_context->last_action.game_bitmap_array_update_rounds !=
-      lw6ker_game_state_get_rounds (game_state))
+      game_state->id || utils_context->last_action.game_bitmap_array_update_rounds != lw6ker_game_state_get_rounds (sys_context, game_state))
     {
       wrap = GL_CLAMP_TO_EDGE;
       if (look->style.pixelize)
@@ -343,11 +294,9 @@ mod_gl1_utils_update_game_bitmap_array (mod_gl1_utils_context_t *
 	}
 
       utils_context->last_action.game_bitmap_array_update_id = game_state->id;
-      utils_context->last_action.game_bitmap_array_update_rounds =
-	lw6ker_game_state_get_rounds (game_state);
+      utils_context->last_action.game_bitmap_array_update_rounds = lw6ker_game_state_get_rounds (sys_context, game_state);
 
-      lw6sys_log (LW6SYS_LOG_DEBUG, _x_ ("updating %d game tiles"),
-		  bitmap_array->layout.nb_tiles);
+      lw6sys_log (sys_context, LW6SYS_LOG_DEBUG, _x_ ("updating %d game tiles"), bitmap_array->layout.nb_tiles);
       /*
        * Typically parallelizable function. Doesn't matter how tiles are updated,
        * and in which order.
@@ -363,15 +312,12 @@ mod_gl1_utils_update_game_bitmap_array (mod_gl1_utils_context_t *
 	   */
 	  lw6gui_rect_t rect;
 
-	  if (lw6gui_rect_array_get_tile_by_i
-	      (&(bitmap_array->layout), &rect, i))
+	  if (lw6gui_rect_array_get_tile_by_i (sys_context, &(bitmap_array->layout), &rect, i))
 	    {
-	      bitmap = mod_gl1_utils_bitmap_array_get (bitmap_array, i);
+	      bitmap = mod_gl1_utils_bitmap_array_get (sys_context, bitmap_array, i);
 	      if (bitmap)
 		{
-		  _update_game_bitmap (utils_context, bitmap, game_state,
-				       look, rect.x1, rect.y1, rect.w,
-				       rect.h);
+		  _update_game_bitmap (sys_context, utils_context, bitmap, game_state, look, rect.x1, rect.y1, rect.w, rect.h);
 		}
 	    }
 	}
@@ -379,8 +325,7 @@ mod_gl1_utils_update_game_bitmap_array (mod_gl1_utils_context_t *
       /*
        * Now render from surfaces to textures.
        */
-      mod_gl1_utils_bitmap_array_update (utils_context, bitmap_array,
-					 wrap, filter);
+      mod_gl1_utils_bitmap_array_update (sys_context, utils_context, bitmap_array, wrap, filter);
     }
   else
     {
