@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -38,12 +38,11 @@
 #endif
 
 int
-mod_gl1_utils_icon_set (mod_gl1_utils_context_t * utils_context)
+mod_gl1_utils_icon_set (lw6sys_context_t * sys_context, mod_gl1_utils_context_t * utils_context)
 {
   int ret = 0;
 
-  utils_context->icon.bitmap =
-    mod_gl1_utils_bitmap_load (utils_context, ICON_DIR ICON_PNG);
+  utils_context->icon.bitmap = mod_gl1_utils_bitmap_load (sys_context, utils_context, ICON_DIR ICON_PNG);
   if (utils_context->icon.bitmap)
     {
       SDL_WM_SetIcon (utils_context->icon.bitmap->surface, NULL);
@@ -54,10 +53,10 @@ mod_gl1_utils_icon_set (mod_gl1_utils_context_t * utils_context)
 }
 
 void
-mod_gl1_utils_icon_unset (mod_gl1_utils_context_t * utils_context)
+mod_gl1_utils_icon_unset (lw6sys_context_t * sys_context, mod_gl1_utils_context_t * utils_context)
 {
   if (utils_context->icon.bitmap)
     {
-      mod_gl1_utils_bitmap_free (utils_context, utils_context->icon.bitmap);
+      mod_gl1_utils_bitmap_free (sys_context, utils_context, utils_context->icon.bitmap);
     }
 }
