@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -30,55 +30,50 @@
 #include "gl1-utils.h"
 
 void
-mod_gl1_utils_display_log (mod_gl1_utils_context_t * context,
-			   const lw6gui_look_t * look, const char **log_list)
+mod_gl1_utils_display_log (lw6sys_context_t * sys_context, mod_gl1_utils_context_t * context, const lw6gui_look_t * look, const char **log_list)
 {
-  mod_gl1_utils_draw_system_text_bottom_left (context, look, log_list);
+  mod_gl1_utils_draw_system_text_bottom_left (sys_context, context, look, log_list);
 }
 
 void
-mod_gl1_utils_display_fps (mod_gl1_utils_context_t * context,
-			   const lw6gui_look_t * look, float fps)
+mod_gl1_utils_display_fps (lw6sys_context_t * sys_context, mod_gl1_utils_context_t * context, const lw6gui_look_t * look, float fps)
 {
   const char *list_fps[2];
 
   if (fps >= 0)
     {
-      list_fps[0] = lw6sys_itoa (fps);
+      list_fps[0] = lw6sys_itoa (sys_context, fps);
       list_fps[1] = NULL;
 
       if (list_fps[0])
 	{
-	  mod_gl1_utils_draw_system_text_top_left (context, look, list_fps);
-	  LW6SYS_FREE (list_fps[0]);
+	  mod_gl1_utils_draw_system_text_top_left (sys_context, context, look, list_fps);
+	  LW6SYS_FREE (sys_context, list_fps[0]);
 	}
     }
 }
 
 void
-mod_gl1_utils_display_mps (mod_gl1_utils_context_t * context,
-			   const lw6gui_look_t * look, float mps,
-			   int target_mps)
+mod_gl1_utils_display_mps (lw6sys_context_t * sys_context, mod_gl1_utils_context_t * context, const lw6gui_look_t * look, float mps, int target_mps)
 {
   const char *list_mps[3];
 
   if (mps >= 0.0f)
     {
       list_mps[0] = " ";
-      list_mps[1] = lw6sys_new_sprintf ("%d/%d", (int) mps, target_mps);
+      list_mps[1] = lw6sys_new_sprintf (sys_context, "%d/%d", (int) mps, target_mps);
       list_mps[2] = NULL;
 
       if (list_mps[0])
 	{
-	  mod_gl1_utils_draw_system_text_top_left (context, look, list_mps);
-	  LW6SYS_FREE (list_mps[1]);
+	  mod_gl1_utils_draw_system_text_top_left (sys_context, context, look, list_mps);
+	  LW6SYS_FREE (sys_context, list_mps[1]);
 	}
     }
 }
 
 void
-mod_gl1_utils_display_url (mod_gl1_utils_context_t * context,
-			   const lw6gui_look_t * look, const char *url)
+mod_gl1_utils_display_url (lw6sys_context_t * sys_context, mod_gl1_utils_context_t * context, const lw6gui_look_t * look, const char *url)
 {
   const char *list_url[2];
 
@@ -89,6 +84,6 @@ mod_gl1_utils_display_url (mod_gl1_utils_context_t * context,
        */
       list_url[0] = (char *) url;
       list_url[1] = NULL;
-      mod_gl1_utils_draw_system_text_bottom_right (context, look, list_url);
+      mod_gl1_utils_draw_system_text_bottom_right (sys_context, context, look, list_url);
     }
 }
