@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -30,14 +30,13 @@
 #include "gl1-utils.h"
 
 int
-mod_gl1_utils_joystick_init (mod_gl1_utils_joysticks_info_t * joysticks_info)
+mod_gl1_utils_joystick_init (lw6sys_context_t * sys_context, mod_gl1_utils_joysticks_info_t * joysticks_info)
 {
   int ret = 0;
   int i;
 
   joysticks_info->driver_nb_joysticks = SDL_NumJoysticks ();
-  lw6sys_log (LW6SYS_LOG_INFO, _x_ ("%d joystick(s) initialized"),
-	      joysticks_info->driver_nb_joysticks);
+  lw6sys_log (sys_context, LW6SYS_LOG_INFO, _x_ ("%d joystick(s) initialized"), joysticks_info->driver_nb_joysticks);
   for (i = 0; i < joysticks_info->driver_nb_joysticks; ++i)
     {
       if (i < LW6GUI_NB_JOYSTICKS)
@@ -45,23 +44,17 @@ mod_gl1_utils_joystick_init (mod_gl1_utils_joysticks_info_t * joysticks_info)
 	  joysticks_info->sdl_joysticks[i] = SDL_JoystickOpen (i);
 	  if (joysticks_info->sdl_joysticks[i])
 	    {
-	      lw6sys_log (LW6SYS_LOG_INFO, _x_ ("joystick %d \"%s\" enabled"),
-			  i, SDL_JoystickName (i));
+	      lw6sys_log (sys_context, LW6SYS_LOG_INFO, _x_ ("joystick %d \"%s\" enabled"), i, SDL_JoystickName (i));
 	    }
 	  else
 	    {
-	      lw6sys_log (LW6SYS_LOG_WARNING,
-			  _x_
-			  ("unable to initialize joystick %d \"%s\" enabled"),
-			  i, SDL_JoystickName (i));
+	      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("unable to initialize joystick %d \"%s\" enabled"), i, SDL_JoystickName (i));
 	    }
 	}
       else
 	{
-	  lw6sys_log (LW6SYS_LOG_NOTICE,
-		      _x_
-		      ("joystick %d \"%s\" ignored, only %d joysticks supported"),
-		      i, SDL_JoystickName (i), LW6GUI_NB_JOYSTICKS);
+	  lw6sys_log (sys_context, LW6SYS_LOG_NOTICE,
+		      _x_ ("joystick %d \"%s\" ignored, only %d joysticks supported"), i, SDL_JoystickName (i), LW6GUI_NB_JOYSTICKS);
 	}
     }
 
@@ -74,18 +67,15 @@ mod_gl1_utils_joystick_init (mod_gl1_utils_joysticks_info_t * joysticks_info)
 }
 
 void
-mod_gl1_utils_joystick_quit (mod_gl1_utils_joysticks_info_t * joysticks_info)
+mod_gl1_utils_joystick_quit (lw6sys_context_t * sys_context, mod_gl1_utils_joysticks_info_t * joysticks_info)
 {
   int i;
 
-  for (i = 0;
-       i < joysticks_info->driver_nb_joysticks && i < LW6GUI_NB_JOYSTICKS;
-       ++i)
+  for (i = 0; i < joysticks_info->driver_nb_joysticks && i < LW6GUI_NB_JOYSTICKS; ++i)
     {
       if (joysticks_info->sdl_joysticks[i])
 	{
-	  lw6sys_log (LW6SYS_LOG_INFO, _x_ ("joystick %d \"%s\" disabled"), i,
-		      SDL_JoystickName (i));
+	  lw6sys_log (sys_context, LW6SYS_LOG_INFO, _x_ ("joystick %d \"%s\" disabled"), i, SDL_JoystickName (i));
 	  SDL_JoystickClose (joysticks_info->sdl_joysticks[i]);
 	}
     }
