@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -34,16 +34,21 @@
  * Pointer must be freed.
  */
 static char *
-create_button_key (const lw6gui_look_t * look,
-		   const lw6gui_menuitem_t * menuitem)
+_create_button_key (lw6sys_context_t * sys_context, const lw6gui_look_t * look, const lw6gui_menuitem_t * menuitem)
 {
   char *key;
-  int c1, c2;
+  int c1 = 0;
+  int c2 = 0;
 
-  c1 = lw6sys_checksum ((unsigned char *) look, sizeof (lw6gui_look_t));
-  c2 =
-    lw6sys_checksum ((unsigned char *) menuitem, sizeof (lw6gui_menuitem_t));
-  key = lw6sys_new_sprintf ("%d %d", c1, c2);
+  if (look)
+    {
+      c1 = lw6sys_checksum (sys_context, (unsigned char *) look, sizeof (lw6gui_look_t));
+    }
+  if (menuitem)
+    {
+      c2 = lw6sys_checksum (sys_context, (unsigned char *) menuitem, sizeof (lw6gui_menuitem_t));
+    }
+  key = lw6sys_new_sprintf (sys_context, "%d %d", c1, c2);
 
   return key;
 }
@@ -52,10 +57,8 @@ create_button_key (const lw6gui_look_t * look,
  * Store a button bitmap in the menucache. Returns != 0 if successfull.
  */
 int
-mod_gl1_utils_store_button_in_menucache (mod_gl1_utils_context_t * context,
-					 const lw6gui_look_t * look,
-					 const lw6gui_menuitem_t * menuitem,
-					 mod_gl1_utils_bitmap_t * bitmap)
+mod_gl1_utils_store_button_in_menucache (lw6sys_context_t * sys_context, mod_gl1_utils_context_t * context,
+					 const lw6gui_look_t * look, const lw6gui_menuitem_t * menuitem, mod_gl1_utils_bitmap_t * bitmap)
 {
   mod_gl1_utils_menucache_array_t *menucache_array;
   int ret = 0;
@@ -66,22 +69,20 @@ mod_gl1_utils_store_button_in_menucache (mod_gl1_utils_context_t * context,
 
   menucache_array = &(context->menucache_array);
 
-  i = menucache_array->last_stored_item =
-    (menucache_array->last_stored_item +
-     1) % MOD_GL1_UTILS_MENUCACHE_ARRAY_SIZE;
+  i = menucache_array->last_stored_item = (menucache_array->last_stored_item + 1) % MOD_GL1_UTILS_MENUCACHE_ARRAY_SIZE;
 
   if ((old_key = menucache_array->item_array[i].key) != NULL)
     {
-      LW6SYS_FREE (old_key);
+      LW6SYS_FREE (sys_context, old_key);
       menucache_array->item_array[i].key = NULL;
     }
   if ((old_bitmap = menucache_array->item_array[i].bitmap) != NULL)
     {
-      mod_gl1_utils_bitmap_free (context, old_bitmap);
+      mod_gl1_utils_bitmap_free (sys_context, context, old_bitmap);
       menucache_array->item_array[i].bitmap = NULL;
     }
 
-  key = create_button_key (look, menuitem);
+  key = _create_button_key (sys_context, look, menuitem);
   if (key != NULL)
     {
       ret = 1;
@@ -96,8 +97,7 @@ mod_gl1_utils_store_button_in_menucache (mod_gl1_utils_context_t * context,
  * Gets a button bitmap from the menucache. Returns non NULL if successfull.
  */
 mod_gl1_utils_bitmap_t *
-mod_gl1_utils_get_button_from_menucache (mod_gl1_utils_context_t * context,
-					 const lw6gui_look_t * look,
+mod_gl1_utils_get_button_from_menucache (lw6sys_context_t * sys_context, mod_gl1_utils_context_t * context, const lw6gui_look_t * look,
 					 const lw6gui_menuitem_t * menuitem)
 {
   mod_gl1_utils_menucache_array_t *menucache_array;
@@ -107,14 +107,13 @@ mod_gl1_utils_get_button_from_menucache (mod_gl1_utils_context_t * context,
 
   menucache_array = &(context->menucache_array);
 
-  key = create_button_key (look, menuitem);
+  key = _create_button_key (sys_context, look, menuitem);
 
   if (key != NULL)
     {
       for (i = 0; i < MOD_GL1_UTILS_MENUCACHE_ARRAY_SIZE; ++i)
 	{
-	  if (menucache_array->item_array[i].key != NULL &&
-	      menucache_array->item_array[i].bitmap != NULL)
+	  if (menucache_array->item_array[i].key != NULL && menucache_array->item_array[i].bitmap != NULL)
 	    {
 	      if (strcmp (key, menucache_array->item_array[i].key) == 0)
 		{
@@ -123,7 +122,7 @@ mod_gl1_utils_get_button_from_menucache (mod_gl1_utils_context_t * context,
 		}
 	    }
 	}
-      LW6SYS_FREE (key);
+      LW6SYS_FREE (sys_context, key);
     }
 
   return bitmap;
@@ -133,7 +132,7 @@ mod_gl1_utils_get_button_from_menucache (mod_gl1_utils_context_t * context,
  * Clear the cache (usefull when quiting the program).
  */
 void
-mod_gl1_utils_clear_menucache (mod_gl1_utils_context_t * context)
+mod_gl1_utils_clear_menucache (lw6sys_context_t * sys_context, mod_gl1_utils_context_t * context)
 {
   mod_gl1_utils_menucache_array_t *menucache_array;
   int i;
@@ -146,45 +145,44 @@ mod_gl1_utils_clear_menucache (mod_gl1_utils_context_t * context)
     {
       if ((key = menucache_array->item_array[i].key) != NULL)
 	{
-	  LW6SYS_FREE (key);
+	  LW6SYS_FREE (sys_context, key);
 	}
       if ((bitmap = menucache_array->item_array[i].bitmap) != NULL)
 	{
-	  mod_gl1_utils_bitmap_free (context, bitmap);
+	  mod_gl1_utils_bitmap_free (sys_context, context, bitmap);
 	}
     }
   if (menucache_array->tooltip_str)
     {
-      LW6SYS_FREE (menucache_array->tooltip_str);
+      LW6SYS_FREE (sys_context, menucache_array->tooltip_str);
     }
   if (menucache_array->tooltip_bitmap)
     {
-      mod_gl1_utils_bitmap_free (context, menucache_array->tooltip_bitmap);
+      mod_gl1_utils_bitmap_free (sys_context, context, menucache_array->tooltip_bitmap);
     }
   if (menucache_array->help_str)
     {
-      LW6SYS_FREE (menucache_array->help_str);
+      LW6SYS_FREE (sys_context, menucache_array->help_str);
     }
   if (menucache_array->help_bitmap)
     {
-      mod_gl1_utils_bitmap_free (context, menucache_array->help_bitmap);
+      mod_gl1_utils_bitmap_free (sys_context, context, menucache_array->help_bitmap);
     }
   if (menucache_array->breadcrumbs_str)
     {
-      LW6SYS_FREE (menucache_array->breadcrumbs_str);
+      LW6SYS_FREE (sys_context, menucache_array->breadcrumbs_str);
     }
   if (menucache_array->breadcrumbs_bitmap)
     {
-      mod_gl1_utils_bitmap_free (context,
-				 menucache_array->breadcrumbs_bitmap);
+      mod_gl1_utils_bitmap_free (sys_context, context, menucache_array->breadcrumbs_bitmap);
     }
   if (menucache_array->popup_str)
     {
-      LW6SYS_FREE (menucache_array->popup_str);
+      LW6SYS_FREE (sys_context, menucache_array->popup_str);
     }
   if (menucache_array->popup_bitmap)
     {
-      mod_gl1_utils_bitmap_free (context, menucache_array->popup_bitmap);
+      mod_gl1_utils_bitmap_free (sys_context, context, menucache_array->popup_bitmap);
     }
 
   memset (menucache_array, 0, sizeof (mod_gl1_utils_menucache_array_t));
