@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -28,8 +28,7 @@
 #include "gl1-utils.h"
 
 void
-mod_gl1_utils_show_mouse (mod_gl1_utils_context_t * utils_context, int state,
-			  int force)
+mod_gl1_utils_show_mouse (lw6sys_context_t * sys_context, mod_gl1_utils_context_t * utils_context, int state, int force)
 {
   if (force || (state != utils_context->mouse_state.shown))
     {
