@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -31,7 +31,7 @@
 #define SELECT_HEIGHT 3.0f
 
 static void
-basic_cleanup ()
+_basic_cleanup (lw6sys_context_t * sys_context)
 {
   glEnable (GL_TEXTURE_2D);
   glColor3f (1.0f, 1.0f, 1.0f);
@@ -41,39 +41,34 @@ basic_cleanup ()
  * Prepares OpenGL buffer for a new draw.
  */
 void
-mod_gl1_utils_prepare_buffer (mod_gl1_utils_context_t * utils_context,
-			      const lw6gui_look_t * look)
+mod_gl1_utils_prepare_buffer (lw6sys_context_t * sys_context, mod_gl1_utils_context_t * utils_context, const lw6gui_look_t * look)
 {
   lw6sys_color_f_t bg_color;
 
-  mod_gl1_utils_sync_viewport (utils_context);
-  lw6sys_color_8_to_f (&bg_color,
-		       look->style.color_set.background_color_root.bg);
+  mod_gl1_utils_sync_viewport (sys_context, utils_context);
+  lw6sys_color_8_to_f (&bg_color, look->style.color_set.background_color_root.bg);
   glClearColor (bg_color.r, bg_color.g, bg_color.b, bg_color.a);
   glClear (GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT);
-  mod_gl1_utils_update_team_color_map (&(utils_context->team_color_map),
-				       &(look->style));
+  mod_gl1_utils_update_team_color_map (sys_context, &(utils_context->team_color_map), &(look->style));
   if (utils_context->render_param.gfx_quality != look->gfx_quality)
     {
-      lw6sys_log (LW6SYS_LOG_INFO, _x_ ("set rendering gfx_quality to %d"),
-		  look->gfx_quality);
+      lw6sys_log (sys_context, LW6SYS_LOG_INFO, _x_ ("set rendering gfx_quality to %d"), look->gfx_quality);
       utils_context->render_param.gfx_quality = look->gfx_quality;
-      mod_gl1_utils_timer_set_bitmap_refresh (utils_context);
+      mod_gl1_utils_timer_set_bitmap_refresh (sys_context, utils_context);
     }
 }
 
 void
-mod_gl1_prepare_buffer (void *utils_context, lw6gui_look_t * look)
+mod_gl1_prepare_buffer (lw6sys_context_t * sys_context, void *utils_context, lw6gui_look_t * look)
 {
-  mod_gl1_utils_prepare_buffer ((mod_gl1_utils_context_t *) utils_context,
-				look);
+  mod_gl1_utils_prepare_buffer (sys_context, (mod_gl1_utils_context_t *) utils_context, look);
 }
 
 /*
  * Liquid War 6 uses a double buffer, this function swaps them.
  */
 void
-mod_gl1_utils_swap_buffers (mod_gl1_utils_context_t * utils_context)
+mod_gl1_utils_swap_buffers (lw6sys_context_t * sys_context, mod_gl1_utils_context_t * utils_context)
 {
   /*
    * glFinish suspected to be a performance killer, and anyways
@@ -81,19 +76,13 @@ mod_gl1_utils_swap_buffers (mod_gl1_utils_context_t * utils_context)
    */
   //glFinish ();
   SDL_GL_SwapBuffers ();
-  mod_gl1_utils_delete_scheduled_textures (utils_context);
+  mod_gl1_utils_delete_scheduled_textures (sys_context, utils_context);
 }
 
 void
-mod_gl1_swap_buffers (void *utils_context)
+mod_gl1_utils_set_render_mode_2d (lw6sys_context_t * sys_context, mod_gl1_utils_context_t * utils_context)
 {
-  mod_gl1_utils_swap_buffers ((mod_gl1_utils_context_t *) utils_context);
-}
-
-void
-mod_gl1_utils_set_render_mode_2d (mod_gl1_utils_context_t * utils_context)
-{
-  basic_cleanup ();
+  _basic_cleanup (sys_context);
   if (utils_context->render_param.mode != MOD_GL1_UTILS_RENDER_2D)
     {
       glMatrixMode (GL_PROJECTION);
@@ -114,10 +103,9 @@ mod_gl1_utils_set_render_mode_2d (mod_gl1_utils_context_t * utils_context)
 }
 
 void
-mod_gl1_utils_set_render_mode_2d_blend (mod_gl1_utils_context_t *
-					utils_context)
+mod_gl1_utils_set_render_mode_2d_blend (lw6sys_context_t * sys_context, mod_gl1_utils_context_t * utils_context)
 {
-  basic_cleanup ();
+  _basic_cleanup (sys_context);
   if (utils_context->render_param.mode != MOD_GL1_UTILS_RENDER_2D_BLEND)
     {
       glMatrixMode (GL_PROJECTION);
@@ -139,73 +127,64 @@ mod_gl1_utils_set_render_mode_2d_blend (mod_gl1_utils_context_t *
 }
 
 void
-mod_gl1_utils_set_render_mode_3d_map (mod_gl1_utils_context_t * utils_context)
+mod_gl1_utils_set_render_mode_3d_map (lw6sys_context_t * sys_context, mod_gl1_utils_context_t * utils_context)
 {
-  basic_cleanup ();
+  _basic_cleanup (sys_context);
   if (utils_context->render_param.mode != MOD_GL1_UTILS_RENDER_3D_MAP)
     {
       glMatrixMode (GL_PROJECTION);
       glLoadIdentity ();
       gluPerspective (utils_context->const_data.persp_fovy,
 		      ((float) utils_context->sdl_context.video_mode.width) /
-		      ((float) utils_context->sdl_context.video_mode.height),
-		      utils_context->const_data.persp_znear,
-		      utils_context->const_data.persp_zfar);
+		      ((float) utils_context->sdl_context.video_mode.height), utils_context->const_data.persp_znear, utils_context->const_data.persp_zfar);
       glEnable (GL_DEPTH_TEST);
       glEnable (GL_DEPTH);
       glBlendFunc (GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
       glEnable (GL_BLEND);
-      mod_gl1_utils_main_light (utils_context);
+      mod_gl1_utils_main_light (sys_context, utils_context);
 
       utils_context->render_param.mode = MOD_GL1_UTILS_RENDER_3D_MAP;
     }
 }
 
 void
-mod_gl1_utils_set_render_mode_3d_menu (mod_gl1_utils_context_t *
-				       utils_context)
+mod_gl1_utils_set_render_mode_3d_menu (lw6sys_context_t * sys_context, mod_gl1_utils_context_t * utils_context)
 {
-  basic_cleanup ();
+  _basic_cleanup (sys_context);
   if (utils_context->render_param.mode != MOD_GL1_UTILS_RENDER_3D_MENU)
     {
       glMatrixMode (GL_PROJECTION);
       glLoadIdentity ();
       gluPerspective (utils_context->const_data.persp_fovy,
 		      ((float) utils_context->sdl_context.video_mode.width) /
-		      ((float) utils_context->sdl_context.video_mode.height),
-		      utils_context->const_data.persp_znear,
-		      utils_context->const_data.persp_zfar);
+		      ((float) utils_context->sdl_context.video_mode.height), utils_context->const_data.persp_znear, utils_context->const_data.persp_zfar);
       glEnable (GL_DEPTH_TEST);
       glEnable (GL_DEPTH);
       //glBlendFunc (GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
       glDisable (GL_BLEND);
-      mod_gl1_utils_main_light (utils_context);
+      mod_gl1_utils_main_light (sys_context, utils_context);
 
       utils_context->render_param.mode = MOD_GL1_UTILS_RENDER_3D_MENU;
     }
 }
 
 void
-mod_gl1_utils_set_render_mode_3d_select (mod_gl1_utils_context_t *
-					 utils_context, int x, int y)
+mod_gl1_utils_set_render_mode_3d_select (lw6sys_context_t * sys_context, mod_gl1_utils_context_t * utils_context, int x, int y)
 {
   GLint viewport[4];
 
-  basic_cleanup ();
+  _basic_cleanup (sys_context);
   if (utils_context->render_param.mode != MOD_GL1_UTILS_RENDER_3D_SELECT)
     {
       glMatrixMode (GL_PROJECTION);
       glLoadIdentity ();
 
       glGetIntegerv (GL_VIEWPORT, viewport);
-      gluPickMatrix (x, viewport[3] - y, SELECT_WIDTH, SELECT_HEIGHT,
-		     viewport);
+      gluPickMatrix (x, viewport[3] - y, SELECT_WIDTH, SELECT_HEIGHT, viewport);
 
       gluPerspective (utils_context->const_data.persp_fovy,
 		      ((float) utils_context->sdl_context.video_mode.width) /
-		      ((float) utils_context->sdl_context.video_mode.height),
-		      utils_context->const_data.persp_znear,
-		      utils_context->const_data.persp_zfar);
+		      ((float) utils_context->sdl_context.video_mode.height), utils_context->const_data.persp_znear, utils_context->const_data.persp_zfar);
       glDisable (GL_DEPTH_TEST);
       glDisable (GL_DEPTH);
       glDisable (GL_BLEND);
@@ -216,12 +195,11 @@ mod_gl1_utils_set_render_mode_3d_select (mod_gl1_utils_context_t *
 }
 
 void
-mod_gl1_utils_set_render_mode_3d_feedback (mod_gl1_utils_context_t *
-					   utils_context)
+mod_gl1_utils_set_render_mode_3d_feedback (lw6sys_context_t * sys_context, mod_gl1_utils_context_t * utils_context)
 {
   GLint viewport[4];
 
-  basic_cleanup ();
+  _basic_cleanup (sys_context);
   if (utils_context->render_param.mode != MOD_GL1_UTILS_RENDER_3D_FEEDBACK)
     {
       glMatrixMode (GL_PROJECTION);
@@ -231,9 +209,7 @@ mod_gl1_utils_set_render_mode_3d_feedback (mod_gl1_utils_context_t *
 
       gluPerspective (utils_context->const_data.persp_fovy,
 		      ((float) utils_context->sdl_context.video_mode.width) /
-		      ((float) utils_context->sdl_context.video_mode.height),
-		      utils_context->const_data.persp_znear,
-		      utils_context->const_data.persp_zfar);
+		      ((float) utils_context->sdl_context.video_mode.height), utils_context->const_data.persp_znear, utils_context->const_data.persp_zfar);
       glDisable (GL_DEPTH_TEST);
       glDisable (GL_DEPTH);
       glDisable (GL_BLEND);
