@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -28,9 +28,7 @@
 #include "gl1-utils.h"
 
 int
-mod_gl1_utils_get_fullscreen_modes (mod_gl1_utils_context_t *
-				    utils_context,
-				    lw6gui_fullscreen_modes_t * modes)
+mod_gl1_utils_get_fullscreen_modes (lw6sys_context_t * sys_context, mod_gl1_utils_context_t * utils_context, lw6gui_fullscreen_modes_t * modes)
 {
   SDL_Rect **sdl_modes = NULL;
   int i = 0;
@@ -70,22 +68,17 @@ mod_gl1_utils_get_fullscreen_modes (mod_gl1_utils_context_t *
   modes->standard.width = (modes->low.width + modes->high.width) / 2;
   modes->standard.height = (modes->low.height + modes->high.height) / 2;
 
-  lw6gui_video_mode_sync_ratio (&(modes->standard), &(modes->high));
+  lw6gui_video_mode_sync_ratio (sys_context, &(modes->standard), &(modes->high));
 
-  mod_gl1_utils_find_closest_resolution (utils_context,
-					 &(modes->standard.width),
-					 &(modes->standard.height),
-					 modes->standard.width,
+  mod_gl1_utils_find_closest_resolution (sys_context, utils_context, &(modes->standard.width), &(modes->standard.height), modes->standard.width,
 					 modes->standard.height);
 
   return ret;
 }
 
 void
-mod_gl1_utils_find_closest_resolution (mod_gl1_utils_context_t *
-				       utils_context, int *closest_width,
-				       int *closest_height, int wished_width,
-				       int wished_height)
+mod_gl1_utils_find_closest_resolution (lw6sys_context_t * sys_context, mod_gl1_utils_context_t * utils_context, int *closest_width, int *closest_height,
+				       int wished_width, int wished_height)
 {
   SDL_Rect **sdl_modes = NULL;
   int i = 0;
@@ -100,32 +93,30 @@ mod_gl1_utils_find_closest_resolution (mod_gl1_utils_context_t *
   sdl_modes = SDL_ListModes (NULL, SDL_OPENGL | SDL_FULLSCREEN);
   if (sdl_modes)
     {
-      mode_list = lw6sys_list_new (lw6sys_free_callback);
+      mode_list = lw6sys_list_new (sys_context, lw6sys_free_callback);
       if (mode_list)
 	{
 	  for (i = 0; sdl_modes[i]; ++i)
 	    {
-	      video_mode =
-		(lw6gui_video_mode_t *)
-		LW6SYS_MALLOC (sizeof (lw6gui_video_mode_t));
+	      video_mode = (lw6gui_video_mode_t *) LW6SYS_MALLOC (sys_context, sizeof (lw6gui_video_mode_t));
 	      if (video_mode)
 		{
 		  video_mode->width = sdl_modes[i]->w;
 		  video_mode->height = sdl_modes[i]->h;
 		  video_mode->fullscreen = LW6GUI_DEFAULT_FULLSCREEN;
-		  lw6sys_lifo_push (&mode_list, video_mode);
+		  lw6sys_lifo_push (sys_context, &mode_list, video_mode);
 		}
 	    }
 	  wished.width = wished_width;
 	  wished.height = wished_height;
 	  wished.fullscreen = LW6GUI_DEFAULT_FULLSCREEN;
 
-	  lw6gui_video_mode_find_closest (&closest, &wished, mode_list);
+	  lw6gui_video_mode_find_closest (sys_context, &closest, &wished, mode_list);
 
 	  (*closest_width) = closest.width;
 	  (*closest_height) = closest.height;
 
-	  lw6sys_list_free (mode_list);
+	  lw6sys_list_free (sys_context, mode_list);
 	}
     }
 }
