@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -29,8 +29,7 @@
 #define CONST_FILE "gles2-const.xml"
 
 static void
-read_callback (void *callback_data, const char *element, const char *key,
-	       const char *value)
+_read_callback (lw6sys_context_t * sys_context, void *callback_data, const char *element, const char *key, const char *value)
 {
   _mod_gles2_const_data_t *const_data;
 
@@ -38,7 +37,7 @@ read_callback (void *callback_data, const char *element, const char *key,
 
   if (!strcmp (element, "int"))
     {
-      lw6cfg_read_xml_int (key, value, "dummy", &const_data->dummy);
+      lw6cfg_read_xml_int (sys_context, key, value, "dummy", &const_data->dummy);
     }
 }
 
@@ -46,22 +45,20 @@ read_callback (void *callback_data, const char *element, const char *key,
  * Loads constants.
  */
 int
-_mod_gles2_load_consts (_mod_gles2_context_t * context)
+_mod_gles2_load_consts (lw6sys_context_t * sys_context, _mod_gles2_context_t * context)
 {
   int ret = 0;
   char *const_file = NULL;
 
-  const_file = lw6sys_path_concat (context->path.data_dir, CONST_FILE);
+  const_file = lw6sys_path_concat (sys_context, context->path.data_dir, CONST_FILE);
 
   if (const_file)
     {
-      lw6sys_log (LW6SYS_LOG_INFO, _x_ ("reading \"%s\""), const_file);
+      lw6sys_log (sys_context, LW6SYS_LOG_INFO, _x_ ("reading \"%s\""), const_file);
 
-      ret =
-	lw6cfg_read_key_value_xml_file (const_file, read_callback,
-					(void *) &(context->const_data));
+      ret = lw6cfg_read_key_value_xml_file (sys_context, const_file, _read_callback, (void *) &(context->const_data));
 
-      LW6SYS_FREE (const_file);
+      LW6SYS_FREE (sys_context, const_file);
     }
 
   return ret;
@@ -71,7 +68,7 @@ _mod_gles2_load_consts (_mod_gles2_context_t * context)
  * Unload constants, free memory
  */
 void
-_mod_gles2_unload_consts (_mod_gles2_context_t * context)
+_mod_gles2_unload_consts (lw6sys_context_t * sys_context, _mod_gles2_context_t * context)
 {
   memset (&context->const_data, 0, sizeof (_mod_gles2_const_data_t));
 }
