@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -30,7 +30,7 @@
 #include "mod-gles2-internal.h"
 
 char *
-_mod_gles2_repr (_mod_gles2_context_t * gles2_context, u_int32_t id)
+_mod_gles2_repr (lw6sys_context_t * sys_context, _mod_gles2_context_t * gles2_context, u_int32_t id)
 {
   char *ret = NULL;
   SDL_version version;
@@ -38,11 +38,10 @@ _mod_gles2_repr (_mod_gles2_context_t * gles2_context, u_int32_t id)
   memset (&version, 0, sizeof (SDL_version));
   version = *SDL_Linked_Version ();
   ret =
-    lw6sys_new_sprintf (_x_
+    lw6sys_new_sprintf (sys_context, _x_
 			("%u gles2 SDL version %u.%u.%u resolution %dx%d"),
 			id, version.major, version.minor, version.patch,
-			gles2_context->sdl_context.video_mode.width,
-			gles2_context->sdl_context.video_mode.height);
+			gles2_context->sdl_context.video_mode.width, gles2_context->sdl_context.video_mode.height);
 
   return ret;
 }
