@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -27,10 +27,8 @@
 #include "mod-soft-internal.h"
 
 void
-_mod_soft_viewport_drawable_max (_mod_soft_context_t * soft_context)
+_mod_soft_viewport_drawable_max (lw6sys_context_t * sys_context, _mod_soft_context_t * soft_context)
 {
-  lw6gui_zone_init_xywh (&(soft_context->sdl_context.viewport), 0.0f,
-			 0.0f,
-			 soft_context->sdl_context.video_mode.width,
-			 soft_context->sdl_context.video_mode.height);
+  lw6gui_zone_init_xywh (sys_context, &(soft_context->sdl_context.viewport), 0.0f,
+			 0.0f, soft_context->sdl_context.video_mode.width, soft_context->sdl_context.video_mode.height);
 }
