@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -30,45 +30,45 @@
 #define DEBUG "sdl-debug"
 
 int
-shared_sdl_path_init (_lw6gfx_sdl_path_t * path, int argc, const char *argv[])
+shared_sdl_path_init (lw6sys_context_t * sys_context, _lw6gfx_sdl_path_t * path, int argc, const char *argv[])
 {
   char *data_root_dir = NULL;
   char *user_dir = NULL;
   int ret = 0;
 
-  data_root_dir = lw6sys_get_data_dir (argc, argv);
+  data_root_dir = lw6sys_get_data_dir (sys_context, argc, argv);
   if (data_root_dir)
     {
-      path->data_dir = lw6sys_path_concat (data_root_dir, SUB);
-      LW6SYS_FREE (data_root_dir);
+      path->data_dir = lw6sys_path_concat (sys_context, data_root_dir, SUB);
+      LW6SYS_FREE (sys_context, data_root_dir);
     }
 
-  user_dir = lw6sys_get_user_dir (argc, argv);
+  user_dir = lw6sys_get_user_dir (sys_context, argc, argv);
   if (user_dir)
     {
-      path->debug_dir = lw6sys_path_concat (user_dir, DEBUG);
-      LW6SYS_FREE (user_dir);
+      path->debug_dir = lw6sys_path_concat (sys_context, user_dir, DEBUG);
+      LW6SYS_FREE (sys_context, user_dir);
     }
 
   ret = (path->data_dir && path->debug_dir);
 
   if (!ret)
     {
-      shared_sdl_path_quit (path);
+      shared_sdl_path_quit (sys_context, path);
     }
 
   return ret;
 }
 
 void
-shared_sdl_path_quit (_lw6gfx_sdl_path_t * path)
+shared_sdl_path_quit (lw6sys_context_t * sys_context, _lw6gfx_sdl_path_t * path)
 {
   if (path->debug_dir)
     {
-      LW6SYS_FREE (path->debug_dir);
+      LW6SYS_FREE (sys_context, path->debug_dir);
     }
   if (path->data_dir)
     {
-      LW6SYS_FREE (path->data_dir);
+      LW6SYS_FREE (sys_context, path->data_dir);
     }
 }
