@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -27,26 +27,25 @@
 #include "shared-sdl-internal.h"
 
 void
-shared_sdl_timer_update (_lw6gfx_sdl_timer_t * timer)
+shared_sdl_timer_update (lw6sys_context_t * sys_context, _lw6gfx_sdl_timer_t * timer)
 {
-  lw6sys_timer_update (&(timer->timestamp),
-		       &(timer->uptime), &(timer->cycle));
+  lw6sys_timer_update (sys_context, &(timer->timestamp), &(timer->uptime), &(timer->cycle));
 }
 
 int64_t
-shared_sdl_timer_get_timestamp (const _lw6gfx_sdl_timer_t * timer)
+shared_sdl_timer_get_timestamp (lw6sys_context_t * sys_context, const _lw6gfx_sdl_timer_t * timer)
 {
   return timer->timestamp;
 }
 
 int64_t
-shared_sdl_timer_get_uptime (const _lw6gfx_sdl_timer_t * timer)
+shared_sdl_timer_get_uptime (lw6sys_context_t * sys_context, const _lw6gfx_sdl_timer_t * timer)
 {
   return timer->uptime;
 }
 
 int32_t
-shared_sdl_timer_get_cycle (const _lw6gfx_sdl_timer_t * timer)
+shared_sdl_timer_get_cycle (lw6sys_context_t * sys_context, const _lw6gfx_sdl_timer_t * timer)
 {
   return timer->cycle;
 }
