@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -32,6 +32,7 @@
 /**
  * lw6glb_base64_encode_bin
  *
+ * @sys_context: global system context
  * @buf: the data to encode
  * @size: the size of data to encode
  *
@@ -41,11 +42,11 @@
  * Return value: newly allocated string.
  */
 char *
-lw6glb_base64_encode_bin (const char *buf, int size)
+lw6glb_base64_encode_bin (lw6sys_context_t * sys_context, const char *buf, int size)
 {
   char *ret = NULL;
 
-  ret = lw6glb_base64_encode_bin_prefix (buf, size, NULL);
+  ret = lw6glb_base64_encode_bin_prefix (sys_context, buf, size, NULL);
 
   return ret;
 }
@@ -53,6 +54,7 @@ lw6glb_base64_encode_bin (const char *buf, int size)
 /**
  * lw6glb_base64_decode_bin
  *
+ * @sys_context: global system context
  * @size: the size of the decoded data
  * @base64_str: the string to decode
  *
@@ -63,11 +65,11 @@ lw6glb_base64_encode_bin (const char *buf, int size)
  * Return value: newly allocated pointer, NULL on error.
  */
 char *
-lw6glb_base64_decode_bin (int *size, const char *base64_str)
+lw6glb_base64_decode_bin (lw6sys_context_t * sys_context, int *size, const char *base64_str)
 {
   char *ret = NULL;
 
-  ret = lw6glb_base64_decode_bin_prefix (size, base64_str, NULL);
+  ret = lw6glb_base64_decode_bin_prefix (sys_context, size, base64_str, NULL);
 
   return ret;
 }
@@ -75,6 +77,7 @@ lw6glb_base64_decode_bin (int *size, const char *base64_str)
 /**
  * lw6glb_base64_encode_str
  *
+ * @sys_context: global system context
  * @str: the string to encode
  *
  * Encodes a string into base64.
@@ -82,11 +85,11 @@ lw6glb_base64_decode_bin (int *size, const char *base64_str)
  * Return value: newly allocated string.
  */
 char *
-lw6glb_base64_encode_str (const char *str)
+lw6glb_base64_encode_str (lw6sys_context_t * sys_context, const char *str)
 {
   char *ret = NULL;
 
-  ret = lw6glb_base64_encode_str_prefix (str, NULL);
+  ret = lw6glb_base64_encode_str_prefix (sys_context, str, NULL);
 
   return ret;
 }
@@ -94,6 +97,7 @@ lw6glb_base64_encode_str (const char *str)
 /**
  * lw6glb_base64_decode_str
  *
+ * @sys_context: global system context
  * @str: the string to decode
  *
  * Decodes a string from base64.
@@ -101,11 +105,11 @@ lw6glb_base64_encode_str (const char *str)
  * Return value: newly allocated string, NULL on error.
  */
 char *
-lw6glb_base64_decode_str (const char *str)
+lw6glb_base64_decode_str (lw6sys_context_t * sys_context, const char *str)
 {
   char *ret = NULL;
 
-  ret = lw6glb_base64_decode_str_prefix (str, NULL);
+  ret = lw6glb_base64_decode_str_prefix (sys_context, str, NULL);
 
   return ret;
 }
@@ -113,6 +117,7 @@ lw6glb_base64_decode_str (const char *str)
 /**
  * lw6glb_base64_encode_bin_prefix
  *
+ * @sys_context: global system context
  * @buf: the data to encode
  * @size: the size of data to encode
  * @prefix: a prefix string
@@ -124,8 +129,7 @@ lw6glb_base64_decode_str (const char *str)
  * Return value: newly allocated string.
  */
 char *
-lw6glb_base64_encode_bin_prefix (const char *buf, int size,
-				 const char *prefix)
+lw6glb_base64_encode_bin_prefix (lw6sys_context_t * sys_context, const char *buf, int size, const char *prefix)
 {
   char *ret = NULL;
   int out_len = 0;
@@ -137,7 +141,7 @@ lw6glb_base64_encode_bin_prefix (const char *buf, int size,
     }
 
   out_len = BASE64_LENGTH (size);
-  ret = (char *) LW6SYS_MALLOC (prefix_len + out_len + 1);
+  ret = (char *) LW6SYS_MALLOC (sys_context, prefix_len + out_len + 1);
   if (ret)
     {
       if (prefix && prefix_len > 0)
@@ -154,6 +158,7 @@ lw6glb_base64_encode_bin_prefix (const char *buf, int size,
 /**
  * lw6glb_base64_decode_bin_prefix
  *
+ * @sys_context: global system context
  * @size: the size of the decoded data
  * @base64_str: the string to decode
  * @prefix: a prefix string
@@ -167,8 +172,7 @@ lw6glb_base64_encode_bin_prefix (const char *buf, int size,
  * Return value: newly allocated pointer, NULL on error.
  */
 char *
-lw6glb_base64_decode_bin_prefix (int *size, const char *base64_str,
-				 const char *prefix)
+lw6glb_base64_decode_bin_prefix (lw6sys_context_t * sys_context, int *size, const char *base64_str, const char *prefix)
 {
   char *ret = NULL;
   int in_len = 0;
@@ -184,7 +188,7 @@ lw6glb_base64_decode_bin_prefix (int *size, const char *base64_str,
     }
   if (prefix && prefix_len > 0)
     {
-      if (lw6sys_str_starts_with (base64_str, prefix))
+      if (lw6sys_str_starts_with (sys_context, base64_str, prefix))
 	{
 	  base64_str += prefix_len;
 	}
@@ -201,13 +205,12 @@ lw6glb_base64_decode_bin_prefix (int *size, const char *base64_str,
        * fail on stupid trailing "\n" or such.
        */
       in_len = 0;
-      while (((c = base64_str[in_len]) != '\0') && !lw6sys_chr_is_space (c)
-	     && !lw6sys_chr_is_eol (c))
+      while (((c = base64_str[in_len]) != '\0') && !lw6sys_chr_is_space (c) && !lw6sys_chr_is_eol (c))
 	{
 	  in_len++;
 	}
       out_len = in_len;
-      ret = (char *) LW6SYS_CALLOC (out_len + 1);
+      ret = (char *) LW6SYS_CALLOC (sys_context, out_len + 1);
       if (ret)
 	{
 	  if (in_len > 0)
@@ -222,13 +225,9 @@ lw6glb_base64_decode_bin_prefix (int *size, const char *base64_str,
 		{
 		  if (cut > 0)
 		    {
-		      lw6sys_log (LW6SYS_LOG_INFO,
-				  _x_
-				  ("base64 decoding with cut=%d, in_len=%d"),
-				  cut, in_len);
+		      lw6sys_log (sys_context, LW6SYS_LOG_INFO, _x_ ("base64 decoding with cut=%d, in_len=%d"), cut, in_len);
 		    }
-		  decode_ret =
-		    base64_decode (base64_str, in_len - cut, ret, &out_len);
+		  decode_ret = base64_decode (base64_str, in_len - cut, ret, &out_len);
 		  cut++;
 		}
 	      if (decode_ret == 1)
@@ -237,10 +236,8 @@ lw6glb_base64_decode_bin_prefix (int *size, const char *base64_str,
 		}
 	      else
 		{
-		  lw6sys_log (LW6SYS_LOG_DEBUG,
-			      _x_ ("base64 decode failed, decode_ret=%d"),
-			      decode_ret);
-		  LW6SYS_FREE (ret);
+		  lw6sys_log (sys_context, LW6SYS_LOG_DEBUG, _x_ ("base64 decode failed, decode_ret=%d"), decode_ret);
+		  LW6SYS_FREE (sys_context, ret);
 		  ret = NULL;
 		}
 	    }
@@ -253,6 +250,7 @@ lw6glb_base64_decode_bin_prefix (int *size, const char *base64_str,
 /**
  * lw6glb_base64_encode_str_prefix
  *
+ * @sys_context: global system context
  * @str: the string to encode
  * @prefix: a prefix string
  *
@@ -262,11 +260,11 @@ lw6glb_base64_decode_bin_prefix (int *size, const char *base64_str,
  * Return value: newly allocated string.
  */
 char *
-lw6glb_base64_encode_str_prefix (const char *str, const char *prefix)
+lw6glb_base64_encode_str_prefix (lw6sys_context_t * sys_context, const char *str, const char *prefix)
 {
   char *ret = NULL;
 
-  ret = lw6glb_base64_encode_bin_prefix (str, strlen (str), prefix);
+  ret = lw6glb_base64_encode_bin_prefix (sys_context, str, strlen (str), prefix);
 
   return ret;
 }
@@ -274,6 +272,7 @@ lw6glb_base64_encode_str_prefix (const char *str, const char *prefix)
 /**
  * lw6glb_base64_decode_str_prefix
  *
+ * @sys_context: global system context
  * @str: the string to decode
  * @prefix: a prefix string
  *
@@ -283,12 +282,12 @@ lw6glb_base64_encode_str_prefix (const char *str, const char *prefix)
  * Return value: newly allocated string, NULL on error.
  */
 char *
-lw6glb_base64_decode_str_prefix (const char *str, const char *prefix)
+lw6glb_base64_decode_str_prefix (lw6sys_context_t * sys_context, const char *str, const char *prefix)
 {
   char *ret = NULL;
   int size = 0;
 
-  ret = lw6glb_base64_decode_bin_prefix (&size, str, prefix);
+  ret = lw6glb_base64_decode_bin_prefix (sys_context, &size, str, prefix);
 
   return ret;
 }
