@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -36,6 +36,7 @@
 /**
  * lw6glb_sha1_hmac_80_bin
  *
+ * @sys_context: global system context
  * @key: the key buffer
  * @key_size
  * @buf: the data to analyse
@@ -46,8 +47,7 @@
  * Return value: newly allocated string, containing 20 chars checksum.
  */
 char *
-lw6glb_sha1_hmac_80_bin (const char *key, int key_size, const char *buf,
-			 int buf_size)
+lw6glb_sha1_hmac_80_bin (lw6sys_context_t * sys_context, const char *key, int key_size, const char *buf, int buf_size)
 {
   char *ret = NULL;
   char sha1_bin[_SHA1_SIZE];
@@ -59,12 +59,11 @@ lw6glb_sha1_hmac_80_bin (const char *key, int key_size, const char *buf,
        * We only convert the 10 first bytes, this way we reveal
        * less information when sending password hashes on the net.
        */
-      ret = lw6sys_hexa_buf_to_str (sha1_bin, _SHA1_80_SIZE);
+      ret = lw6sys_hexa_buf_to_str (sys_context, sha1_bin, _SHA1_80_SIZE);
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING,
-		  _x_ ("error calculating SHA-1 sum for %d bytes"), buf_size);
+      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("error calculating SHA-1 sum for %d bytes"), buf_size);
     }
 
   return ret;
@@ -73,6 +72,7 @@ lw6glb_sha1_hmac_80_bin (const char *key, int key_size, const char *buf,
 /**
  * lw6glb_sha1_hmac_80_str
  *
+ * @sys_context: global system context
  * @key: a key (string)
  * @str: the string to calculate the checksum for
  *
@@ -81,7 +81,7 @@ lw6glb_sha1_hmac_80_bin (const char *key, int key_size, const char *buf,
  * Return value: newly allocated string, containing 20 chars checksum.
  */
 char *
-lw6glb_sha1_hmac_80_str (const char *key, const char *str)
+lw6glb_sha1_hmac_80_str (lw6sys_context_t * sys_context, const char *key, const char *str)
 {
   char *ret = NULL;
 
@@ -93,7 +93,7 @@ lw6glb_sha1_hmac_80_str (const char *key, const char *str)
     {
       str = _SHA1_EMPTY;
     }
-  ret = lw6glb_sha1_hmac_80_bin (key, strlen (key), str, strlen (str));
+  ret = lw6glb_sha1_hmac_80_bin (sys_context, key, strlen (key), str, strlen (str));
 
   return ret;
 }
@@ -101,8 +101,9 @@ lw6glb_sha1_hmac_80_str (const char *key, const char *str)
 /**
  * lw6glb_sha1_hmac_32_bin
  *
+ * @sys_context: global system context
  * @key: the key buffer
- * @key_size
+ * @key_size: the key buffer size
  * @buf: the data to analyse
  * @buf_size: the size of data to analyse
  *
@@ -111,8 +112,7 @@ lw6glb_sha1_hmac_80_str (const char *key, const char *str)
  * Return value: a 32-bit unsigned integer
  */
 u_int32_t
-lw6glb_sha1_hmac_32_bin (const char *key, int key_size, const char *buf,
-			 int buf_size)
+lw6glb_sha1_hmac_32_bin (lw6sys_context_t * sys_context, const char *key, int key_size, const char *buf, int buf_size)
 {
   u_int32_t ret = 0;
   char sha1_bin[_SHA1_SIZE];
@@ -124,12 +124,11 @@ lw6glb_sha1_hmac_32_bin (const char *key, int key_size, const char *buf,
        * We only convert the 10 first bytes, this way we reveal
        * less information when sending password hashes on the net.
        */
-      ret = (u_int32_t) lw6sys_unserialize_int32 ((unsigned char *) sha1_bin);
+      ret = (u_int32_t) lw6sys_unserialize_int32 (sys_context, (unsigned char *) sha1_bin);
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING,
-		  _x_ ("error calculating SHA-1 sum for %d bytes"), buf_size);
+      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("error calculating SHA-1 sum for %d bytes"), buf_size);
     }
 
   return ret;
@@ -138,6 +137,7 @@ lw6glb_sha1_hmac_32_bin (const char *key, int key_size, const char *buf,
 /**
  * lw6glb_sha1_hmac_32_str
  *
+ * @sys_context: global system context
  * @key: a key (string)
  * @str: the string to calculate the checksum for
  *
@@ -146,7 +146,7 @@ lw6glb_sha1_hmac_32_bin (const char *key, int key_size, const char *buf,
  * Return value: a 32-bit unsigned integer
  */
 u_int32_t
-lw6glb_sha1_hmac_32_str (const char *key, const char *str)
+lw6glb_sha1_hmac_32_str (lw6sys_context_t * sys_context, const char *key, const char *str)
 {
   u_int32_t ret = 0;
 
@@ -158,7 +158,7 @@ lw6glb_sha1_hmac_32_str (const char *key, const char *str)
     {
       str = _SHA1_EMPTY;
     }
-  ret = lw6glb_sha1_hmac_32_bin (key, strlen (key), str, strlen (str));
+  ret = lw6glb_sha1_hmac_32_bin (sys_context, key, strlen (key), str, strlen (str));
 
   return ret;
 }
