@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -29,6 +29,7 @@
 /**
  * lw6gui_button_register_down
  *
+ * @sys_context: global system context
  * @button: the button to update
  * @timestamp: the current ticks (milliseconds)
  *
@@ -37,13 +38,11 @@
  * Return value: none.
  */
 void
-lw6gui_button_register_down (lw6gui_button_t * button, int64_t timestamp)
+lw6gui_button_register_down (lw6sys_context_t * sys_context, lw6gui_button_t * button, int64_t timestamp)
 {
   if (timestamp <= 0LL)
     {
-      lw6sys_log (LW6SYS_LOG_WARNING,
-		  _x_ ("using negative or zero timestamp (%" LW6SYS_PRINTF_LL
-		       "d)"), (long long) timestamp);
+      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("using negative or zero timestamp (%" LW6SYS_PRINTF_LL "d)"), (long long) timestamp);
     }
 
   button->is_pressed = 1;
@@ -51,8 +50,7 @@ lw6gui_button_register_down (lw6gui_button_t * button, int64_t timestamp)
   button->last_press = timestamp;
   button->last_repeat = 0;
 
-  if (button->double_click_t1 <= 0 || button->double_click_t2 <= 0
-      || button->double_click_t3 <= 0)
+  if (button->double_click_t1 <= 0 || button->double_click_t2 <= 0 || button->double_click_t3 <= 0)
     {
       button->double_click_t1 = button->double_click_t2;
       button->double_click_t2 = button->double_click_t3;
@@ -63,6 +61,7 @@ lw6gui_button_register_down (lw6gui_button_t * button, int64_t timestamp)
 /**
  * lw6gui_button_register_up
  *
+ * @sys_context: global system context
  * @button: the button to update
  *
  * Registers a "up" (release) event on a button.
@@ -70,7 +69,7 @@ lw6gui_button_register_down (lw6gui_button_t * button, int64_t timestamp)
  * Return value: none.
  */
 void
-lw6gui_button_register_up (lw6gui_button_t * button)
+lw6gui_button_register_up (lw6sys_context_t * sys_context, lw6gui_button_t * button)
 {
   button->is_pressed = 0;
   button->last_press = 0;
@@ -80,6 +79,7 @@ lw6gui_button_register_up (lw6gui_button_t * button)
 /**
  * lw6gui_button_is_pressed
  *
+ * @sys_context: global system context
  * @button: the button to query
  *
  * Tells wether a button is pressed or not.
@@ -87,7 +87,7 @@ lw6gui_button_register_up (lw6gui_button_t * button)
  * Return value: 1 if pressed, 0 if not.
  */
 int
-lw6gui_button_is_pressed (const lw6gui_button_t * button)
+lw6gui_button_is_pressed (lw6sys_context_t * sys_context, const lw6gui_button_t * button)
 {
   int ret = 0;
 
@@ -99,6 +99,7 @@ lw6gui_button_is_pressed (const lw6gui_button_t * button)
 /**
  * lw6gui_button_pop_press
  *
+ * @sys_context: global system context
  * @button: the button to query
  *
  * Tells how many times the button has been pressed. Typical usage: the
@@ -110,7 +111,7 @@ lw6gui_button_is_pressed (const lw6gui_button_t * button)
  * Return value: 1 if there's a press event in the queue, 0 if empty.
  */
 int
-lw6gui_button_pop_press (lw6gui_button_t * button)
+lw6gui_button_pop_press (lw6sys_context_t * sys_context, lw6gui_button_t * button)
 {
   int ret = 0;
 
@@ -126,6 +127,7 @@ lw6gui_button_pop_press (lw6gui_button_t * button)
 /**
  * lw6gui_button_pop_simple_click
  *
+ * @sys_context: global system context
  * @button: the button to query
  *
  * Tells how many times the button has been simpleclicked. This is different
@@ -136,7 +138,7 @@ lw6gui_button_pop_press (lw6gui_button_t * button)
  * Return value: 1 if there's a simpleclick event in the queue, 0 if empty.
  */
 int
-lw6gui_button_pop_simple_click (lw6gui_button_t * button)
+lw6gui_button_pop_simple_click (lw6sys_context_t * sys_context, lw6gui_button_t * button)
 {
   int ret = 0;
 
@@ -152,6 +154,7 @@ lw6gui_button_pop_simple_click (lw6gui_button_t * button)
 /**
  * lw6gui_button_pop_double_click
  *
+ * @sys_context: global system context
  * @button: the button to query
  *
  * Tells how many times the button has been doubleclicked. Typical usage: the
@@ -161,7 +164,7 @@ lw6gui_button_pop_simple_click (lw6gui_button_t * button)
  * Return value: 1 if there's a doubleclick event in the queue, 0 if empty.
  */
 int
-lw6gui_button_pop_double_click (lw6gui_button_t * button)
+lw6gui_button_pop_double_click (lw6sys_context_t * sys_context, lw6gui_button_t * button)
 {
   int ret = 0;
 
@@ -177,6 +180,7 @@ lw6gui_button_pop_double_click (lw6gui_button_t * button)
 /**
  * lw6gui_button_pop_triple_click
  *
+ * @sys_context: global system context
  * @button: the button to query
  *
  * Tells how many times the button has been tripleclicked. Typical usage: the
@@ -186,7 +190,7 @@ lw6gui_button_pop_double_click (lw6gui_button_t * button)
  * Return value: 1 if there's a tripleclick event in the queue, 0 if empty.
  */
 int
-lw6gui_button_pop_triple_click (lw6gui_button_t * button)
+lw6gui_button_pop_triple_click (lw6sys_context_t * sys_context, lw6gui_button_t * button)
 {
   int ret = 0;
 
@@ -202,6 +206,7 @@ lw6gui_button_pop_triple_click (lw6gui_button_t * button)
 /**
  * lw6gui_button_update_repeat
  *
+ * @sys_context: global system context
  * @button: the button to update
  * @repeat_settings: the repeat settings
  * @timestamp: the current ticks (milliseconds)
@@ -213,32 +218,26 @@ lw6gui_button_pop_triple_click (lw6gui_button_t * button)
  * Return value: none.
  */
 void
-lw6gui_button_update_repeat (lw6gui_button_t * button,
-			     lw6gui_repeat_settings_t * repeat_settings,
-			     int64_t timestamp, int auto_release_enabled)
+lw6gui_button_update_repeat (lw6sys_context_t * sys_context, lw6gui_button_t * button, lw6gui_repeat_settings_t * repeat_settings, int64_t timestamp,
+			     int auto_release_enabled)
 {
-  if (auto_release_enabled && button->is_pressed
-      && button->last_press <=
-      timestamp - repeat_settings->auto_release_delay)
+  if (auto_release_enabled && button->is_pressed && button->last_press <= timestamp - repeat_settings->auto_release_delay)
     {
       /*
        * Before anything else, register a fake button_up if we're
        * in auto_release mode and it's relevant.
        */
-      lw6sys_log (LW6SYS_LOG_DEBUG,
+      lw6sys_log (sys_context, LW6SYS_LOG_DEBUG,
 		  _x_ ("button auto release button->last_press=%"
-		       LW6SYS_PRINTF_LL "d timestamp=%" LW6SYS_PRINTF_LL "d"),
-		  (long long) button->last_press, (long long) timestamp);
-      lw6gui_button_register_up (button);
+		       LW6SYS_PRINTF_LL "d timestamp=%" LW6SYS_PRINTF_LL "d"), (long long) button->last_press, (long long) timestamp);
+      lw6gui_button_register_up (sys_context, button);
     }
 
   if (button->is_pressed)
     {
       if ((repeat_settings->delay > 0 && button->last_repeat == 0
 	   && button->last_press <= timestamp - repeat_settings->delay)
-	  || (repeat_settings->interval > 0 && button->last_repeat != 0
-	      && button->last_repeat <=
-	      timestamp - repeat_settings->interval))
+	  || (repeat_settings->interval > 0 && button->last_repeat != 0 && button->last_repeat <= timestamp - repeat_settings->interval))
 	{
 	  (button->press_queue)++;
 	  button->last_repeat = timestamp;
@@ -248,9 +247,7 @@ lw6gui_button_update_repeat (lw6gui_button_t * button,
   if (button->double_click_t1 > 0 && button->double_click_t2 > 0
       && button->double_click_t3 > 0
       && (button->double_click_t3 - button->double_click_t2) <
-      repeat_settings->double_click_delay
-      && (button->double_click_t2 - button->double_click_t1) <
-      repeat_settings->double_click_delay)
+      repeat_settings->double_click_delay && (button->double_click_t2 - button->double_click_t1) < repeat_settings->double_click_delay)
     {
       /*
        * We don't "++" here, no buffering of triple clicks
@@ -262,9 +259,7 @@ lw6gui_button_update_repeat (lw6gui_button_t * button,
     }
   if (button->double_click_t2 > 0 && button->double_click_t3 > 0
       && (button->double_click_t3 - button->double_click_t2) <
-      repeat_settings->double_click_delay
-      && timestamp - button->double_click_t3 >=
-      repeat_settings->double_click_delay)
+      repeat_settings->double_click_delay && timestamp - button->double_click_t3 >= repeat_settings->double_click_delay)
     {
       /*
        * We don't "++" here, no buffering of double clicks
@@ -274,9 +269,7 @@ lw6gui_button_update_repeat (lw6gui_button_t * button,
       button->double_click_t2 = 0;
       button->double_click_t3 = 0;
     }
-  if (button->double_click_t3 > 0
-      && timestamp - button->double_click_t3 >=
-      repeat_settings->double_click_delay)
+  if (button->double_click_t3 > 0 && timestamp - button->double_click_t3 >= repeat_settings->double_click_delay)
     {
       /*
        * We don't "++" here, no buffering of simple clicks
@@ -291,6 +284,7 @@ lw6gui_button_update_repeat (lw6gui_button_t * button,
 /**
  * lw6gui_button_sync
  *
+ * @sys_context: global system context
  * @dst: the target button object
  * @src: the source button object
  *
@@ -302,7 +296,7 @@ lw6gui_button_update_repeat (lw6gui_button_t * button,
  * Return value: 1 if success, O if failure.
  */
 int
-lw6gui_button_sync (lw6gui_button_t * dst, lw6gui_button_t * src)
+lw6gui_button_sync (lw6sys_context_t * sys_context, lw6gui_button_t * dst, lw6gui_button_t * src)
 {
   int ret = 1;
 
