@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -29,6 +29,7 @@
 /**
  * lw6gui_coord_calc_xy
  *
+ * @sys_context: global system context
  * @dst_x: the x coord to return
  * @dst_y: the y coord to return
  * @dst_x0: the x coord of point 0 in destination coord system
@@ -47,9 +48,8 @@
  * Return value: 1 if OK, 0 if error (unable to calculate).
  */
 int
-lw6gui_coord_calc_xy (float *dst_x, float *dst_y, float dst_x0, float dst_y0,
-		      float dst_w, float dst_h, float src_x, float src_y,
-		      float src_x0, float src_y0, float src_w, float src_h)
+lw6gui_coord_calc_xy (lw6sys_context_t * sys_context, float *dst_x, float *dst_y, float dst_x0, float dst_y0,
+		      float dst_w, float dst_h, float src_x, float src_y, float src_x0, float src_y0, float src_w, float src_h)
 {
   int ret = 0;
 
@@ -67,10 +67,7 @@ lw6gui_coord_calc_xy (float *dst_x, float *dst_y, float dst_x0, float dst_y0,
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING,
-		  _x_
-		  ("inconsistent coord data dst_w=%f dst_h=%f src_w=%f src_h=%f"),
-		  dst_w, dst_h, src_w, src_h);
+      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("inconsistent coord data dst_w=%f dst_h=%f src_w=%f src_h=%f"), dst_w, dst_h, src_w, src_h);
     }
 
   return ret;
@@ -79,6 +76,7 @@ lw6gui_coord_calc_xy (float *dst_x, float *dst_y, float dst_x0, float dst_y0,
 /**
  * lw6gui_coords_fix_xy_float
  *
+ * @sys_context: global system context
  * @x: x coord (in/out param)
  * @y: y coord (in/out param)
  * @x_flip: flip on x (out param, -1 or +1)
@@ -99,8 +97,7 @@ lw6gui_coord_calc_xy (float *dst_x, float *dst_y, float dst_x0, float dst_y0,
  * Return value: none
  */
 void
-lw6gui_coords_fix_xy_float (float *x, float *y, int *x_flip, int *y_flip,
-			    float w, float h, int x_polarity, int y_polarity)
+lw6gui_coords_fix_xy_float (lw6sys_context_t * sys_context, float *x, float *y, int *x_flip, int *y_flip, float w, float h, int x_polarity, int y_polarity)
 {
   /*
    * The algorithm is copied/pasted from map code, only here it
