@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -29,6 +29,7 @@
 /**
  * lw6gui_keypress_new
  *
+ * @sys_context: global system context
  * @keysym: the keysym to use
  * @unicode: the unicode value for this keysym
  * @label: the label (optional, might be NULL)
@@ -39,18 +40,18 @@
  * Return value: a pointer to the newly allocated object.
  */
 lw6gui_keypress_t *
-lw6gui_keypress_new (int keysym, int unicode, const char *label)
+lw6gui_keypress_new (lw6sys_context_t * sys_context, int keysym, int unicode, const char *label)
 {
   lw6gui_keypress_t *ret = NULL;
 
-  ret = (lw6gui_keypress_t *) LW6SYS_CALLOC (sizeof (lw6gui_keypress_t));
+  ret = (lw6gui_keypress_t *) LW6SYS_CALLOC (sys_context, sizeof (lw6gui_keypress_t));
   if (ret)
     {
       ret->keysym = keysym;
       ret->unicode = unicode;
       if (label)
 	{
-	  ret->label = lw6sys_str_copy (label);
+	  ret->label = lw6sys_str_copy (sys_context, label);
 	  /*
 	   * we don't care if the copied label is NULL, a keypress
 	   * struct with a NULL label is valid anyway
@@ -64,6 +65,7 @@ lw6gui_keypress_new (int keysym, int unicode, const char *label)
 /**
  * lw6gui_keypress_free
  *
+ * @sys_context: global system context
  * @keypress: the keypress object to free.
  *
  * Deletes a keypress structure.
@@ -71,25 +73,26 @@ lw6gui_keypress_new (int keysym, int unicode, const char *label)
  * Return value: none.
  */
 void
-lw6gui_keypress_free (lw6gui_keypress_t * keypress)
+lw6gui_keypress_free (lw6sys_context_t * sys_context, lw6gui_keypress_t * keypress)
 {
   if (keypress)
     {
       if (keypress->label)
 	{
-	  LW6SYS_FREE (keypress->label);
+	  LW6SYS_FREE (sys_context, keypress->label);
 	}
-      LW6SYS_FREE (keypress);
+      LW6SYS_FREE (sys_context, keypress);
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("trying to free NULL keypress"));
+      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("trying to free NULL keypress"));
     }
 }
 
 /**
  * lw6gui_keypress_repr
  *
+ * @sys_context: global system context
  * @keypress: the keypress to work on
  *
  * Returns a human-readable representation of the keypress.
@@ -97,7 +100,7 @@ lw6gui_keypress_free (lw6gui_keypress_t * keypress)
  * Return value: a newly allocated string
  */
 char *
-lw6gui_keypress_repr (const lw6gui_keypress_t * keypress)
+lw6gui_keypress_repr (lw6sys_context_t * sys_context, const lw6gui_keypress_t * keypress)
 {
   char *ret = NULL;
 
@@ -106,25 +109,17 @@ lw6gui_keypress_repr (const lw6gui_keypress_t * keypress)
       if (keypress->unicode >= 32 && keypress->unicode <= 127)
 	{
 	  ret =
-	    lw6sys_new_sprintf (_x_
-				("keypress keysym=%d ascii=%d ('%c') label=\"%s\""),
-				keypress->keysym, keypress->unicode,
-				keypress->unicode, keypress->label);
+	    lw6sys_new_sprintf (sys_context, _x_
+				("keypress keysym=%d ascii=%d ('%c') label=\"%s\""), keypress->keysym, keypress->unicode, keypress->unicode, keypress->label);
 	}
       else
 	{
-	  ret =
-	    lw6sys_new_sprintf (_x_
-				("keypress keysym=%d unicode=%d label=\"%s\""),
-				keypress->keysym, keypress->unicode,
-				keypress->label);
+	  ret = lw6sys_new_sprintf (sys_context, _x_ ("keypress keysym=%d unicode=%d label=\"%s\""), keypress->keysym, keypress->unicode, keypress->label);
 	}
     }
   else
     {
-      ret =
-	lw6sys_new_sprintf (_x_ ("keypress keysym=%d unicode=%d label=NULL"),
-			    keypress->keysym, keypress->unicode);
+      ret = lw6sys_new_sprintf (sys_context, _x_ ("keypress keysym=%d unicode=%d label=NULL"), keypress->keysym, keypress->unicode);
     }
 
   return ret;
