@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -29,7 +29,7 @@
 #define DEFAULT_DYNAMIC_ZOOM 1.0f
 
 static void
-_fix_zoom (lw6gui_look_t * look)
+_fix_zoom (lw6sys_context_t * sys_context, lw6gui_look_t * look)
 {
   if (look->style.zoom <= 0.0f)
     {
@@ -46,7 +46,7 @@ _fix_zoom (lw6gui_look_t * look)
 }
 
 static void
-_fix_gfx_quality (lw6gui_look_t * look)
+_fix_gfx_quality (lw6sys_context_t * sys_context, lw6gui_look_t * look)
 {
   if (look->gfx_quality < LW6GUI_GFX_QUALITY_LOW)
     {
@@ -71,6 +71,7 @@ static volatile u_int32_t seq_id = 0;
 /**
  * lw6gui_look_new
  *
+ * @sys_context: global system context
  * @map_style: map_style to use as a base
  *
  * Create a new look object, a look is basically a style plus
@@ -79,11 +80,11 @@ static volatile u_int32_t seq_id = 0;
  * Return value: newly created object.
  */
 lw6gui_look_t *
-lw6gui_look_new (const lw6map_style_t * map_style)
+lw6gui_look_new (lw6sys_context_t * sys_context, const lw6map_style_t * map_style)
 {
   lw6gui_look_t *look = NULL;
 
-  look = (lw6gui_look_t *) LW6SYS_CALLOC (sizeof (lw6gui_look_t));
+  look = (lw6gui_look_t *) LW6SYS_CALLOC (sys_context, sizeof (lw6gui_look_t));
 
   if (look)
     {
@@ -97,11 +98,11 @@ lw6gui_look_new (const lw6map_style_t * map_style)
       look->gfx_quality = LW6GUI_GFX_QUALITY_STANDARD;
       if (map_style)
 	{
-	  lw6map_style_copy (&look->style, map_style);
+	  lw6map_style_copy (sys_context, &look->style, map_style);
 	}
       else
 	{
-	  lw6map_style_defaults (&look->style);
+	  lw6map_style_defaults (sys_context, &look->style);
 	}
     }
 
@@ -111,6 +112,7 @@ lw6gui_look_new (const lw6map_style_t * map_style)
 /**
  * lw6gui_look_free
  *
+ * @sys_context: global system context
  * @look: look object to free
  *
  * Frees a look and all its members.
@@ -118,16 +120,16 @@ lw6gui_look_new (const lw6map_style_t * map_style)
  * Return value: none.
  */
 void
-lw6gui_look_free (lw6gui_look_t * look)
+lw6gui_look_free (lw6sys_context_t * sys_context, lw6gui_look_t * look)
 {
   if (look)
     {
-      lw6map_style_clear (&look->style);
-      LW6SYS_FREE (look);
+      lw6map_style_clear (sys_context, &look->style);
+      LW6SYS_FREE (sys_context, look);
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("trying to free NULL look"));
+      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("trying to free NULL look"));
     }
 }
 
@@ -135,6 +137,7 @@ lw6gui_look_free (lw6gui_look_t * look)
 /**
  * lw6gui_look_memory_footprint
  *
+ * @sys_context: global system context
  * @look: look object to query
  *
  * Gives the memory taken by this object in memory.
@@ -142,7 +145,7 @@ lw6gui_look_free (lw6gui_look_t * look)
  * Return value: number of bytes.
  */
 int
-lw6gui_look_memory_footprint (const lw6gui_look_t * look)
+lw6gui_look_memory_footprint (lw6sys_context_t * sys_context, const lw6gui_look_t * look)
 {
   //todo
   return sizeof (lw6gui_look_t);
@@ -151,6 +154,7 @@ lw6gui_look_memory_footprint (const lw6gui_look_t * look)
 /**
  * lw6gui_look_repr
  *
+ * @sys_context: global system context
  * @look: look object to describe
  *
  * Returns a readable description of the object.
@@ -158,18 +162,17 @@ lw6gui_look_memory_footprint (const lw6gui_look_t * look)
  * Return value: newly allocated string.
  */
 char *
-lw6gui_look_repr (const lw6gui_look_t * look)
+lw6gui_look_repr (lw6sys_context_t * sys_context, const lw6gui_look_t * look)
 {
   char *ret = NULL;
 
   if (look)
     {
-      ret = lw6sys_new_sprintf ("id=%u", look->id);
+      ret = lw6sys_new_sprintf (sys_context, "id=%u", look->id);
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING,
-		  _x_ ("can't generate string id for NULL look"));
+      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("can't generate string id for NULL look"));
     }
 
   return ret;
@@ -178,6 +181,7 @@ lw6gui_look_repr (const lw6gui_look_t * look)
 /**
  * lw6gui_look_set
  *
+ * @sys_context: global system context
  * @look: look object to modify
  * @key: the key to change
  * @value: the new value for the key
@@ -189,24 +193,24 @@ lw6gui_look_repr (const lw6gui_look_t * look)
  * Return value: 1 on success, 0 on failure.
  */
 int
-lw6gui_look_set (lw6gui_look_t * look, char *key, char *value)
+lw6gui_look_set (lw6sys_context_t * sys_context, lw6gui_look_t * look, char *key, char *value)
 {
   int ret = 0;
 
   if (!strcmp (key, "dynamic-zoom"))
     {
-      look->dynamic_zoom = lw6sys_atof (value);
-      _fix_zoom (look);
+      look->dynamic_zoom = lw6sys_atof (sys_context, value);
+      _fix_zoom (sys_context, look);
       ret = 1;
     }
   else if (!strcmp (key, LW6DEF_GFX_QUALITY))
     {
-      look->gfx_quality = lw6sys_atoi (value);
-      _fix_gfx_quality (look);
+      look->gfx_quality = lw6sys_atoi (sys_context, value);
+      _fix_gfx_quality (sys_context, look);
     }
   else
     {
-      ret = lw6map_style_set (&(look->style), key, value);
+      ret = lw6map_style_set (sys_context, &(look->style), key, value);
     }
 
   return ret;
@@ -215,6 +219,7 @@ lw6gui_look_set (lw6gui_look_t * look, char *key, char *value)
 /**
  * lw6gui_look_get
  *
+ * @sys_context: global system context
  * @look: look object to query
  * @key: the key to get
  *
@@ -225,21 +230,21 @@ lw6gui_look_set (lw6gui_look_t * look, char *key, char *value)
  * Return value: dynamically allocated string.
  */
 char *
-lw6gui_look_get (const lw6gui_look_t * look, char *key)
+lw6gui_look_get (lw6sys_context_t * sys_context, const lw6gui_look_t * look, char *key)
 {
   char *ret = NULL;
 
   if (!strcmp (key, "dynamic-zoom"))
     {
-      ret = lw6sys_ftoa (look->dynamic_zoom);
+      ret = lw6sys_ftoa (sys_context, look->dynamic_zoom);
     }
   else if (!strcmp (key, LW6DEF_GFX_QUALITY))
     {
-      ret = lw6sys_itoa (look->gfx_quality);
+      ret = lw6sys_itoa (sys_context, look->gfx_quality);
     }
   else
     {
-      ret = lw6map_style_get (&look->style, key);
+      ret = lw6map_style_get (sys_context, &look->style, key);
     }
 
   return ret;
@@ -248,6 +253,7 @@ lw6gui_look_get (const lw6gui_look_t * look, char *key)
 /**
  * lw6gui_look_is_same
  *
+ * @sys_context: global system context
  * @look_a: first object to compare
  * @look_b: second object to compare
  *
@@ -260,8 +266,7 @@ lw6gui_look_get (const lw6gui_look_t * look, char *key)
  * Return value: 1 if they are the same, 0 if not.
  */
 int
-lw6gui_look_is_same (const lw6gui_look_t * look_a,
-		     const lw6gui_look_t * look_b)
+lw6gui_look_is_same (lw6sys_context_t * sys_context, const lw6gui_look_t * look_a, const lw6gui_look_t * look_b)
 {
   int ret = 1;
 
@@ -273,7 +278,7 @@ lw6gui_look_is_same (const lw6gui_look_t * look_a,
     {
       ret = ret && look_a->dynamic_zoom == look_b->dynamic_zoom;
       ret = ret && look_a->gfx_quality == look_b->gfx_quality;
-      ret = ret && lw6map_style_is_same (&look_a->style, &look_b->style);
+      ret = ret && lw6map_style_is_same (sys_context, &look_a->style, &look_b->style);
     }
 
   return ret;
@@ -282,6 +287,7 @@ lw6gui_look_is_same (const lw6gui_look_t * look_a,
 /**
  * lw6gui_look_dup
  *
+ * @sys_context: global system context
  * @look: object to duplicate
  *
  * Duplicates a look object, performing recursive copies.
@@ -289,17 +295,17 @@ lw6gui_look_is_same (const lw6gui_look_t * look_a,
  * Return value: newly allocated object.
  */
 lw6gui_look_t *
-lw6gui_look_dup (const lw6gui_look_t * look)
+lw6gui_look_dup (lw6sys_context_t * sys_context, const lw6gui_look_t * look)
 {
   lw6gui_look_t *ret = NULL;
 
   if (look)
     {
-      ret = lw6gui_look_new (&(look->style));
+      ret = lw6gui_look_new (sys_context, &(look->style));
     }
   else
     {
-      ret = lw6gui_look_new (NULL);
+      ret = lw6gui_look_new (sys_context, NULL);
     }
   if (ret)
     {
@@ -313,6 +319,7 @@ lw6gui_look_dup (const lw6gui_look_t * look)
 /**
  * lw6gui_look_fix
  *
+ * @sys_context: global system context
  * @look: look object to modify
  *
  * Peforms sanity checks and modifies the look if needed,
@@ -322,14 +329,15 @@ lw6gui_look_dup (const lw6gui_look_t * look)
  * Return value: none.
  */
 void
-lw6gui_look_fix (lw6gui_look_t * look)
+lw6gui_look_fix (lw6sys_context_t * sys_context, lw6gui_look_t * look)
 {
-  _fix_zoom (look);
+  _fix_zoom (sys_context, look);
 }
 
 /**
  * lw6gui_look_zoom_in
  *
+ * @sys_context: global system context
  * @look: look object to act upon
  * @zoom_step: how much we should zoom, 2.0 means 2 times bigger
  *
@@ -339,7 +347,7 @@ lw6gui_look_fix (lw6gui_look_t * look)
  * Return value: 1 if zoom was changed, 0 if not.
  */
 int
-lw6gui_look_zoom_in (lw6gui_look_t * look, float zoom_step)
+lw6gui_look_zoom_in (lw6sys_context_t * sys_context, lw6gui_look_t * look, float zoom_step)
 {
   int ret = 0;
   float old_zoom = look->dynamic_zoom;
@@ -357,10 +365,9 @@ lw6gui_look_zoom_in (lw6gui_look_t * look, float zoom_step)
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("zoom_step=%f, should be >1.0"),
-		  zoom_step);
+      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("zoom_step=%f, should be >1.0"), zoom_step);
     }
-  _fix_zoom (look);
+  _fix_zoom (sys_context, look);
 
   ret = (old_zoom != look->dynamic_zoom);
 
@@ -370,6 +377,7 @@ lw6gui_look_zoom_in (lw6gui_look_t * look, float zoom_step)
 /**
  * lw6gui_look_zoom_out
  *
+ * @sys_context: global system context
  * @look: look object to act upon
  * @zoom_step: how much we should zoom, 2.0 means 2 times smaller
  *
@@ -379,7 +387,7 @@ lw6gui_look_zoom_in (lw6gui_look_t * look, float zoom_step)
  * Return value: 1 if zoom was changed, 0 if not.
  */
 int
-lw6gui_look_zoom_out (lw6gui_look_t * look, float zoom_step)
+lw6gui_look_zoom_out (lw6sys_context_t * sys_context, lw6gui_look_t * look, float zoom_step)
 {
   int ret = 0;
   float old_zoom = look->dynamic_zoom;
@@ -397,10 +405,9 @@ lw6gui_look_zoom_out (lw6gui_look_t * look, float zoom_step)
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("zoom_step=%f, should be >1.0"),
-		  zoom_step);
+      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("zoom_step=%f, should be >1.0"), zoom_step);
     }
-  _fix_zoom (look);
+  _fix_zoom (sys_context, look);
 
   ret = (old_zoom != look->dynamic_zoom);
 
