@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -38,6 +38,7 @@ static volatile u_int32_t seq_id = 0;
 /**
  * lw6gui_menuitem_new
  *
+ * @sys_context: global system context
  * @label: the string to be displayed, what the user sees. Can be freed after
  *   the call is done, function will make a copy internally.
  * @tooltip: the string to be displayed as a tooltip, describing the menu
@@ -57,12 +58,11 @@ static volatile u_int32_t seq_id = 0;
  * Return value: a pointer to the newly allocated object.
  */
 lw6gui_menuitem_t *
-lw6gui_menuitem_new (const char *label, const char *tooltip, int value,
-		     int enabled, int selected, int colored)
+lw6gui_menuitem_new (lw6sys_context_t * sys_context, const char *label, const char *tooltip, int value, int enabled, int selected, int colored)
 {
   lw6gui_menuitem_t *menuitem = NULL;
 
-  menuitem = (lw6gui_menuitem_t *) LW6SYS_CALLOC (sizeof (lw6gui_menuitem_t));
+  menuitem = (lw6gui_menuitem_t *) LW6SYS_CALLOC (sys_context, sizeof (lw6gui_menuitem_t));
   if (menuitem)
     {
       menuitem->id = 0;
@@ -71,11 +71,10 @@ lw6gui_menuitem_new (const char *label, const char *tooltip, int value,
 	  menuitem->id = ++seq_id;
 	}
 
-      menuitem->label = lw6sys_str_copy (label);
+      menuitem->label = lw6sys_str_copy (sys_context, label);
       if (menuitem->label)
 	{
-	  menuitem->tooltip =
-	    lw6sys_str_copy (lw6sys_str_empty_if_null (tooltip));
+	  menuitem->tooltip = lw6sys_str_copy (sys_context, lw6sys_str_empty_if_null (sys_context, tooltip));
 	  if (menuitem->tooltip)
 	    {
 	      menuitem->value = value;
@@ -86,7 +85,7 @@ lw6gui_menuitem_new (const char *label, const char *tooltip, int value,
 	}
       if ((!menuitem->label) || (!menuitem->tooltip))
 	{
-	  lw6gui_menuitem_free (menuitem);
+	  lw6gui_menuitem_free (sys_context, menuitem);
 	  menuitem = NULL;
 	}
     }
@@ -97,6 +96,7 @@ lw6gui_menuitem_new (const char *label, const char *tooltip, int value,
 /**
  * lw6gui_menuitem_free
  *
+ * @sys_context: global system context
  * @menuitem: a pointer to the menuitem.
  *
  * Frees the menuitem, checking if things are OK before doing so.
@@ -104,39 +104,40 @@ lw6gui_menuitem_new (const char *label, const char *tooltip, int value,
  * Return value: none.
  */
 void
-lw6gui_menuitem_free (lw6gui_menuitem_t * menuitem)
+lw6gui_menuitem_free (lw6sys_context_t * sys_context, lw6gui_menuitem_t * menuitem)
 {
   if (menuitem)
     {
       if (menuitem->label)
 	{
-	  LW6SYS_FREE (menuitem->label);
+	  LW6SYS_FREE (sys_context, menuitem->label);
 	  menuitem->label = NULL;
 	}
       else
 	{
-	  lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("menuitem with NULL label"));
+	  lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("menuitem with NULL label"));
 	}
       if (menuitem->tooltip)
 	{
-	  LW6SYS_FREE (menuitem->tooltip);
+	  LW6SYS_FREE (sys_context, menuitem->tooltip);
 	  menuitem->tooltip = NULL;
 	}
       else
 	{
-	  lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("menuitem with NULL tooltip"));
+	  lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("menuitem with NULL tooltip"));
 	}
-      LW6SYS_FREE (menuitem);
+      LW6SYS_FREE (sys_context, menuitem);
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("trying to free NULL menuitem"));
+      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("trying to free NULL menuitem"));
     }
 }
 
 /**
  * lw6gui_menuitem_memory_footprint
  *
+ * @sys_context: global system context
  * @menuitem: a pointer to the menuitem.
  *
  * Gets the memory occupied by the menuitem. Could be usefull to help
@@ -145,7 +146,7 @@ lw6gui_menuitem_free (lw6gui_menuitem_t * menuitem)
  * Return value: the number of bytes used.
  */
 int
-lw6gui_menuitem_memory_footprint (lw6gui_menuitem_t * menuitem)
+lw6gui_menuitem_memory_footprint (lw6sys_context_t * sys_context, lw6gui_menuitem_t * menuitem)
 {
   int memory_footprint = 0;
 
@@ -156,8 +157,7 @@ lw6gui_menuitem_memory_footprint (lw6gui_menuitem_t * menuitem)
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING,
-		  _x_ ("calling memory_footprint on NULL menuitem"));
+      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("calling memory_footprint on NULL menuitem"));
     }
 
   return memory_footprint;
@@ -166,6 +166,7 @@ lw6gui_menuitem_memory_footprint (lw6gui_menuitem_t * menuitem)
 /**
  * lw6gui_menuitem_repr
  *
+ * @sys_context: global system context
  * @menuitem: a pointer to the menuitem.
  *
  * Constructs a readable description of the object. Usefull for
@@ -176,13 +177,11 @@ lw6gui_menuitem_memory_footprint (lw6gui_menuitem_t * menuitem)
  * Return value: a string describing the object, must be freed.
  */
 char *
-lw6gui_menuitem_repr (const lw6gui_menuitem_t * menuitem)
+lw6gui_menuitem_repr (lw6sys_context_t * sys_context, const lw6gui_menuitem_t * menuitem)
 {
   char *repr;
 
-  repr =
-    lw6sys_new_sprintf (_x_ ("%u \"%s\" (value=%d)"), menuitem->id,
-			menuitem->label, menuitem->value);
+  repr = lw6sys_new_sprintf (sys_context, _x_ ("%u \"%s\" (value=%d)"), menuitem->id, menuitem->label, menuitem->value);
 
   return repr;
 }
@@ -190,6 +189,7 @@ lw6gui_menuitem_repr (const lw6gui_menuitem_t * menuitem)
 /**
  * lw6gui_menuitem_set_label
  *
+ * @sys_context: global system context
  * @menuitem: a pointer to the menuitem.
  * @label: the new label, you can free it after calling the function,
  *   an internal copy will be made.
@@ -204,25 +204,24 @@ lw6gui_menuitem_repr (const lw6gui_menuitem_t * menuitem)
  * Return value: none
  */
 void
-lw6gui_menuitem_set_label (lw6gui_menuitem_t * menuitem, const char *label,
-			   int64_t now)
+lw6gui_menuitem_set_label (lw6sys_context_t * sys_context, lw6gui_menuitem_t * menuitem, const char *label, int64_t now)
 {
   if (strcmp (label, menuitem->label))
     {
       menuitem->last_change = now;
     }
-  LW6SYS_FREE (menuitem->label);
-  menuitem->label = lw6sys_str_copy (lw6sys_str_empty_if_null (label));
+  LW6SYS_FREE (sys_context, menuitem->label);
+  menuitem->label = lw6sys_str_copy (sys_context, lw6sys_str_empty_if_null (sys_context, label));
   if (!(menuitem->label))
     {
-      lw6sys_log (LW6SYS_LOG_WARNING,
-		  _x_ ("couldn't set menu item label \"%s\""), label);
+      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("couldn't set menu item label \"%s\""), label);
     }
 }
 
 /**
  * lw6gui_menuitem_set_tooltip
  *
+ * @sys_context: global system context
  * @menuitem: a pointer to the menuitem.
  * @tooltip: the new tooltip, you can free it after calling the function,
  *   an internal copy will be made.
@@ -237,25 +236,24 @@ lw6gui_menuitem_set_label (lw6gui_menuitem_t * menuitem, const char *label,
  * Return value: none
  */
 void
-lw6gui_menuitem_set_tooltip (lw6gui_menuitem_t * menuitem,
-			     const char *tooltip, int64_t now)
+lw6gui_menuitem_set_tooltip (lw6sys_context_t * sys_context, lw6gui_menuitem_t * menuitem, const char *tooltip, int64_t now)
 {
   if (strcmp (tooltip, menuitem->tooltip))
     {
       menuitem->last_change = now;
     }
-  LW6SYS_FREE (menuitem->tooltip);
-  menuitem->tooltip = lw6sys_str_copy (lw6sys_str_empty_if_null (tooltip));
+  LW6SYS_FREE (sys_context, menuitem->tooltip);
+  menuitem->tooltip = lw6sys_str_copy (sys_context, lw6sys_str_empty_if_null (sys_context, tooltip));
   if (!(menuitem->tooltip))
     {
-      lw6sys_log (LW6SYS_LOG_WARNING,
-		  _x_ ("couldn't set menu item tooltip \"%s\""), tooltip);
+      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("couldn't set menu item tooltip \"%s\""), tooltip);
     }
 }
 
 /**
  * lw6gui_menuitem_set_value
  *
+ * @sys_context: global system context
  * @menuitem: a pointer to the menuitem.
  * @value: the new value.
  * @now: the current time, as a timestamp.
@@ -269,8 +267,7 @@ lw6gui_menuitem_set_tooltip (lw6gui_menuitem_t * menuitem,
  * Return value: none
  */
 void
-lw6gui_menuitem_set_value (lw6gui_menuitem_t * menuitem, int value,
-			   int64_t now)
+lw6gui_menuitem_set_value (lw6sys_context_t * sys_context, lw6gui_menuitem_t * menuitem, int value, int64_t now)
 {
   if (value != menuitem->value)
     {
@@ -282,6 +279,7 @@ lw6gui_menuitem_set_value (lw6gui_menuitem_t * menuitem, int value,
 /**
  * lw6gui_menuitem_select
  *
+ * @sys_context: global system context
  * @menuitem: a pointer to the menuitem.
  * @state: 1 to select, 0 to unselect
  * @now: the current time, as a timestamp.
@@ -294,7 +292,7 @@ lw6gui_menuitem_set_value (lw6gui_menuitem_t * menuitem, int value,
  * Return value: none
  */
 void
-lw6gui_menuitem_select (lw6gui_menuitem_t * menuitem, int state, int64_t now)
+lw6gui_menuitem_select (lw6sys_context_t * sys_context, lw6gui_menuitem_t * menuitem, int state, int64_t now)
 {
   if (state && !(menuitem->selected))
     {
@@ -311,6 +309,7 @@ lw6gui_menuitem_select (lw6gui_menuitem_t * menuitem, int state, int64_t now)
 /**
  * lw6gui_menuitem_enable
  *
+ * @sys_context: global system context
  * @menuitem: a pointer to the menuitem.
  * @state: 1 to enable, 0 to disable
  * @now: the current time, as a timestamp.
@@ -323,7 +322,7 @@ lw6gui_menuitem_select (lw6gui_menuitem_t * menuitem, int state, int64_t now)
  * Return value: none
  */
 void
-lw6gui_menuitem_enable (lw6gui_menuitem_t * menuitem, int state, int64_t now)
+lw6gui_menuitem_enable (lw6sys_context_t * sys_context, lw6gui_menuitem_t * menuitem, int state, int64_t now)
 {
   if (state && (!menuitem->enabled))
     {
@@ -354,6 +353,7 @@ lw6gui_menuitem_enable (lw6gui_menuitem_t * menuitem, int state, int64_t now)
 /**
  * lw6gui_menuitem_checksum
  *
+ * @sys_context: global system context
  * @menuitem: the menuitem we want to identify
  *
  * Returns a checksum which can be used to know, for
@@ -363,15 +363,13 @@ lw6gui_menuitem_enable (lw6gui_menuitem_t * menuitem, int state, int64_t now)
  * Return value: a checksum.
  */
 u_int32_t
-lw6gui_menuitem_checksum (lw6gui_menuitem_t * menuitem, lw6gui_look_t * look)
+lw6gui_menuitem_checksum (lw6sys_context_t * sys_context, lw6gui_menuitem_t * menuitem, lw6gui_look_t * look)
 {
   u_int32_t ret = 0;
 
 
-  lw6sys_checksum_update (&ret, (unsigned char *) menuitem,
-			  sizeof (lw6gui_menuitem_t));
-  lw6sys_checksum_update (&ret, (unsigned char *) look,
-			  sizeof (lw6gui_look_t));
+  lw6sys_checksum_update (sys_context, &ret, (unsigned char *) menuitem, sizeof (lw6gui_menuitem_t));
+  lw6sys_checksum_update (sys_context, &ret, (unsigned char *) look, sizeof (lw6gui_look_t));
 
   return ret;
 }
@@ -379,6 +377,7 @@ lw6gui_menuitem_checksum (lw6gui_menuitem_t * menuitem, lw6gui_look_t * look)
 /**
  * lw6gui_menuitem_is_same
  *
+ * @sys_context: global system context
  * @menuitem_a: first item to compare
  * @menuitem_b: second item to compare
  *
@@ -387,8 +386,7 @@ lw6gui_menuitem_checksum (lw6gui_menuitem_t * menuitem, lw6gui_look_t * look)
  * Return value: 1 if they are the same, 0 if not
  */
 int
-lw6gui_menuitem_is_same (const lw6gui_menuitem_t * menuitem_a,
-			 const lw6gui_menuitem_t * menuitem_b)
+lw6gui_menuitem_is_same (lw6sys_context_t * sys_context, const lw6gui_menuitem_t * menuitem_a, const lw6gui_menuitem_t * menuitem_b)
 {
   int ret = 1;
 
@@ -414,6 +412,7 @@ lw6gui_menuitem_is_same (const lw6gui_menuitem_t * menuitem_a,
 /**
  * lw6gui_menuitem_dup
  *
+ * @sys_context: global system context
  * @menuitem: the menuitem to duplicate
  *
  * The menuitem to duplicate.
@@ -421,16 +420,13 @@ lw6gui_menuitem_is_same (const lw6gui_menuitem_t * menuitem_a,
  * Return value: a pointer to the duplicted menuitem.
  */
 lw6gui_menuitem_t *
-lw6gui_menuitem_dup (const lw6gui_menuitem_t * menuitem)
+lw6gui_menuitem_dup (lw6sys_context_t * sys_context, const lw6gui_menuitem_t * menuitem)
 {
   lw6gui_menuitem_t *ret = NULL;
 
   if (menuitem)
     {
-      ret =
-	lw6gui_menuitem_new (menuitem->label, menuitem->tooltip,
-			     menuitem->value, menuitem->enabled,
-			     menuitem->selected, menuitem->colored);
+      ret = lw6gui_menuitem_new (sys_context, menuitem->label, menuitem->tooltip, menuitem->value, menuitem->enabled, menuitem->selected, menuitem->colored);
       if (ret)
 	{
 	  ret->last_change = menuitem->last_change;
@@ -445,6 +441,7 @@ lw6gui_menuitem_dup (const lw6gui_menuitem_t * menuitem)
 /**
  * lw6gui_menuitem_sync
  *
+ * @sys_context: global system context
  * @dst: the target menuitem
  * @src: the source menuitem
  *
@@ -454,19 +451,19 @@ lw6gui_menuitem_dup (const lw6gui_menuitem_t * menuitem)
  * Return value: 1 if success, 0 if failure
  */
 int
-lw6gui_menuitem_sync (lw6gui_menuitem_t * dst, lw6gui_menuitem_t * src)
+lw6gui_menuitem_sync (lw6sys_context_t * sys_context, lw6gui_menuitem_t * dst, lw6gui_menuitem_t * src)
 {
   int ret = 0;
 
   if (dst && src)
     {
-      if (!lw6sys_str_is_same (dst->label, src->label))
+      if (!lw6sys_str_is_same (sys_context, dst->label, src->label))
 	{
-	  lw6gui_menuitem_set_label (dst, src->label, src->last_change);
+	  lw6gui_menuitem_set_label (sys_context, dst, src->label, src->last_change);
 	}
-      if (!lw6sys_str_is_same (dst->tooltip, src->tooltip))
+      if (!lw6sys_str_is_same (sys_context, dst->tooltip, src->tooltip))
 	{
-	  lw6gui_menuitem_set_tooltip (dst, src->tooltip, src->last_change);
+	  lw6gui_menuitem_set_tooltip (sys_context, dst, src->tooltip, src->last_change);
 	}
       dst->value = src->value;
       dst->enabled = src->enabled;
@@ -479,7 +476,7 @@ lw6gui_menuitem_sync (lw6gui_menuitem_t * dst, lw6gui_menuitem_t * src)
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("menuitems are not syncable"));
+      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("menuitems are not syncable"));
     }
 
   return ret;
