@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -29,6 +29,7 @@
 /**
  * lw6gui_point_is_inside_rect
  *
+ * @sys_context: global system context
  * @point: point to test
  * @rect: rectangle in which point is supposed to be
  *
@@ -38,8 +39,7 @@
  * Return value: 1 if OK, 0 if outside
  */
 int
-lw6gui_point_is_inside_rect (lw6gui_point_t point, const lw6gui_rect_t * rect)
+lw6gui_point_is_inside_rect (lw6sys_context_t * sys_context, lw6gui_point_t point, const lw6gui_rect_t * rect)
 {
-  return (point.x >= rect->x1 && point.x < rect->x2 && point.y >= rect->y1
-	  && point.y < rect->y2);
+  return (point.x >= rect->x1 && point.x < rect->x2 && point.y >= rect->y1 && point.y < rect->y2);
 }
