@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -29,6 +29,7 @@
 /**
  * lw6gui_power_of_two_ge
  *
+ * @sys_context: global system context
  * @input: the value to approach
  *
  * Finds the closest power of two, which is at least greater
@@ -37,7 +38,7 @@
  * Return value: a power of two.
  */
 int
-lw6gui_power_of_two_ge (int input)
+lw6gui_power_of_two_ge (lw6sys_context_t * sys_context, int input)
 {
   int value = 1;
 
@@ -51,6 +52,7 @@ lw6gui_power_of_two_ge (int input)
 /**
  * lw6gui_power_of_two_le
  *
+ * @sys_context: global system context
  * @input: the value to approach
  *
  * Finds the closest power of two, which is equal of inferior
@@ -59,7 +61,7 @@ lw6gui_power_of_two_ge (int input)
  * Return value: a power of two.
  */
 int
-lw6gui_power_of_two_le (int input)
+lw6gui_power_of_two_le (lw6sys_context_t * sys_context, int input)
 {
   int value = 1;
 
