@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -31,6 +31,7 @@
 /**
  * lw6gui_smoother_init
  *
+ * @sys_context: global system context
  * @smoother: the structure to initialize
  * @value: the value to use for now
  * @duration: the duration of a standard move, in ticks (msec)
@@ -41,17 +42,18 @@
  * Return value: none.
  */
 void
-lw6gui_smoother_init (lw6gui_smoother_t * smoother, float value, int duration)
+lw6gui_smoother_init (lw6sys_context_t * sys_context, lw6gui_smoother_t * smoother, float value, int duration)
 {
   memset (smoother, 0, sizeof (lw6gui_smoother_t));
 
-  lw6gui_smoother_immediate_force (smoother, value);
+  lw6gui_smoother_immediate_force (sys_context, smoother, value);
   smoother->duration = lw6sys_imax (1, duration);
 }
 
 /**
  * lw6gui_smoother_immediate_force
  *
+ * @sys_context: global system context
  * @smoother: the structure to use
  * @value: the target value
  *
@@ -60,7 +62,7 @@ lw6gui_smoother_init (lw6gui_smoother_t * smoother, float value, int duration)
  * Return value: none.
  */
 void
-lw6gui_smoother_immediate_force (lw6gui_smoother_t * smoother, float value)
+lw6gui_smoother_immediate_force (lw6sys_context_t * sys_context, lw6gui_smoother_t * smoother, float value)
 {
   smoother->s1 = 0.0f;
   smoother->y1 = value;
@@ -71,6 +73,7 @@ lw6gui_smoother_immediate_force (lw6gui_smoother_t * smoother, float value)
 /**
  * lw6gui_smoother_set_target
  *
+ * @sys_context: global system context
  * @smoother: the structure to use
  * @value: the target value
  * @now: the current timestamp
@@ -81,8 +84,7 @@ lw6gui_smoother_immediate_force (lw6gui_smoother_t * smoother, float value)
  * Return value: none.
  */
 void
-lw6gui_smoother_set_target (lw6gui_smoother_t * smoother, float value,
-			    int64_t now)
+lw6gui_smoother_set_target (lw6sys_context_t * sys_context, lw6gui_smoother_t * smoother, float value, int64_t now)
 {
   float y = 0.0f;
   float s = 0.0f;
@@ -91,9 +93,7 @@ lw6gui_smoother_set_target (lw6gui_smoother_t * smoother, float value,
     {
       if (smoother->t1 > 0)
 	{
-	  lw6sys_math_poly_wy1y2s1 (&y, &s, now - smoother->t1,
-				    smoother->duration, smoother->y1,
-				    smoother->y2, smoother->s1);
+	  lw6sys_math_poly_wy1y2s1 (sys_context, &y, &s, now - smoother->t1, smoother->duration, smoother->y1, smoother->y2, smoother->s1);
 	  smoother->y1 = y;
 	  smoother->s1 = s;
 	}
@@ -110,6 +110,7 @@ lw6gui_smoother_set_target (lw6gui_smoother_t * smoother, float value,
 /**
  * lw6gui_smoother_get_value
  *
+ * @sys_context: global system context
  * @smoother: the structure to use
  * @now: the current timestamp
  *
@@ -118,15 +119,13 @@ lw6gui_smoother_set_target (lw6gui_smoother_t * smoother, float value,
  * Return value: a float.
  */
 float
-lw6gui_smoother_get_value (const lw6gui_smoother_t * smoother, int64_t now)
+lw6gui_smoother_get_value (lw6sys_context_t * sys_context, const lw6gui_smoother_t * smoother, int64_t now)
 {
   float ret = 0.0f;
 
   if (smoother->t1 > 0)
     {
-      lw6sys_math_poly_wy1y2s1 (&ret, NULL, now - smoother->t1,
-				smoother->duration, smoother->y1,
-				smoother->y2, smoother->s1);
+      lw6sys_math_poly_wy1y2s1 (sys_context, &ret, NULL, now - smoother->t1, smoother->duration, smoother->y1, smoother->y2, smoother->s1);
     }
   else
     {
@@ -139,6 +138,7 @@ lw6gui_smoother_get_value (const lw6gui_smoother_t * smoother, int64_t now)
 /**
  * lw6gui_smoother_fix_overflow
  *
+ * @sys_context: global system context
  * @smoother: object to modify
  * @step: step size, typically twice the map size
  *
@@ -149,7 +149,7 @@ lw6gui_smoother_get_value (const lw6gui_smoother_t * smoother, int64_t now)
  * Return value: none.
  */
 void
-lw6gui_smoother_fix_overflow (lw6gui_smoother_t * smoother, int step)
+lw6gui_smoother_fix_overflow (lw6sys_context_t * sys_context, lw6gui_smoother_t * smoother, int step)
 {
   float delta = 0.0f;
   int changed = 0;
@@ -182,6 +182,6 @@ lw6gui_smoother_fix_overflow (lw6gui_smoother_t * smoother, int step)
   if (changed)
     {
       smoother->y1 = value;
-      lw6gui_smoother_set_target (smoother, closest, smoother->t1);
+      lw6gui_smoother_set_target (sys_context, smoother, closest, smoother->t1);
     }
 }
