@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -36,15 +36,14 @@ typedef struct video_mode_sort_s
 } video_mode_sort_t;
 
 static int
-video_mode_sort_callback (const lw6sys_list_t ** list_a,
-			  const lw6sys_list_t ** list_b)
+_video_mode_sort_callback (lw6sys_context_t * sys_context, void *func_data, const void *ptr_a, const void *ptr_b)
 {
   int ret = 0;
   const video_mode_sort_t *a;
   const video_mode_sort_t *b;
 
-  a = (video_mode_sort_t *) ((*list_a)->data);
-  b = (video_mode_sort_t *) ((*list_b)->data);
+  a = (video_mode_sort_t *) ptr_a;
+  b = (video_mode_sort_t *) ptr_b;
 
   if (a->distance < b->distance)
     {
@@ -59,41 +58,37 @@ video_mode_sort_callback (const lw6sys_list_t ** list_a,
 }
 
 static void
-video_mode_copy_callback (void *func_data, void *data)
+_video_mode_copy_callback (lw6sys_context_t * sys_context, void *func_data, void *data)
 {
   lw6sys_list_t **target = (lw6sys_list_t **) func_data;
   lw6gui_video_mode_t *video_mode = (lw6gui_video_mode_t *) data;
   video_mode_sort_t *video_mode_sort = NULL;
 
-  video_mode_sort =
-    (video_mode_sort_t *) LW6SYS_MALLOC (sizeof (video_mode_sort_t));
+  video_mode_sort = (video_mode_sort_t *) LW6SYS_MALLOC (sys_context, sizeof (video_mode_sort_t));
   if (video_mode_sort)
     {
       video_mode_sort->video_mode = (*video_mode);
       video_mode_sort->distance = 0;
-      lw6sys_lifo_push (target, video_mode_sort);
+      lw6sys_lifo_push (sys_context, target, video_mode_sort);
     }
 }
 
 static void
-video_mode_distance_callback (void *func_data, void *data)
+_video_mode_distance_callback (lw6sys_context_t * sys_context, void *func_data, void *data)
 {
   const lw6gui_video_mode_t *wished = (const lw6gui_video_mode_t *) func_data;
   video_mode_sort_t *video_mode_sort = (video_mode_sort_t *) data;
 
   video_mode_sort->distance =
     (wished->width - video_mode_sort->video_mode.width) * (wished->width -
-							   video_mode_sort->
-							   video_mode.width) +
-    (wished->height - video_mode_sort->video_mode.height) * (wished->height -
-							     video_mode_sort->
-							     video_mode.
-							     height);
+							   video_mode_sort->video_mode.width) +
+    (wished->height - video_mode_sort->video_mode.height) * (wished->height - video_mode_sort->video_mode.height);
 }
 
 /**
  * lw6gui_video_mode_find_closest
  *
+ * @sys_context: global system context
  * @closest: the closest video_mode found
  * @wished: the wished video_mode
  * @available: a list of available video_modes (list of lw6gui_video_mode_t *)
@@ -107,31 +102,28 @@ video_mode_distance_callback (void *func_data, void *data)
  *   an approximative match was picked.
  */
 int
-lw6gui_video_mode_find_closest (lw6gui_video_mode_t * closest,
-				const lw6gui_video_mode_t * wished,
-				lw6sys_list_t * available)
+lw6gui_video_mode_find_closest (lw6sys_context_t * sys_context, lw6gui_video_mode_t * closest, const lw6gui_video_mode_t * wished, lw6sys_list_t * available)
 {
   int ret = 0;
   lw6sys_list_t *sorted = NULL;
 
   *closest = *wished;
 
-  sorted = lw6sys_list_new (lw6sys_free_callback);
+  sorted = lw6sys_list_new (sys_context, lw6sys_free_callback);
   if (sorted)
     {
       if (available)
 	{
-	  lw6sys_list_map (available, &video_mode_copy_callback, &sorted);
-	  lw6sys_list_map (sorted, &video_mode_distance_callback,
-			   (void *) wished);
-	  lw6sys_sort (&sorted, video_mode_sort_callback);
+	  lw6sys_list_map (sys_context, available, &_video_mode_copy_callback, &sorted);
+	  lw6sys_list_map (sys_context, sorted, &_video_mode_distance_callback, (void *) wished);
+	  lw6sys_sort (sys_context, &sorted, _video_mode_sort_callback, NULL);
 
 	  if (sorted->data)
 	    {
 	      (*closest) = ((video_mode_sort_t *) (sorted->data))->video_mode;
 	    }
 	}
-      lw6sys_list_free (sorted);
+      lw6sys_list_free (sys_context, sorted);
     }
 
   if (closest->width == wished->width && closest->height == wished->height)
@@ -145,6 +137,7 @@ lw6gui_video_mode_find_closest (lw6gui_video_mode_t * closest,
 /**
  * lw6gui_video_mode_is_same
  *
+ * @sys_context: global system context
  * @mode_a: first mode to compare
  * @mode_b: second mode to compare
  *
@@ -153,13 +146,11 @@ lw6gui_video_mode_find_closest (lw6gui_video_mode_t * closest,
  * Return value: 1 if equal, 0 if not.
  */
 int
-lw6gui_video_mode_is_same (const lw6gui_video_mode_t * mode_a,
-			   const lw6gui_video_mode_t * mode_b)
+lw6gui_video_mode_is_same (lw6sys_context_t * sys_context, const lw6gui_video_mode_t * mode_a, const lw6gui_video_mode_t * mode_b)
 {
   int ret = 0;
 
-  ret = (mode_a->width == mode_b->width) && (mode_a->height == mode_b->height)
-    && (mode_a->fullscreen == mode_b->fullscreen) ? 1 : 0;
+  ret = (mode_a->width == mode_b->width) && (mode_a->height == mode_b->height) && (mode_a->fullscreen == mode_b->fullscreen) ? 1 : 0;
 
   return ret;
 }
@@ -167,6 +158,7 @@ lw6gui_video_mode_is_same (const lw6gui_video_mode_t * mode_a,
 /**
  * lw6gui_video_sync_ratio
  *
+ * @sys_context: global system context
  * @dst: the target video mode
  * @src: the source video mode
  *
@@ -176,8 +168,7 @@ lw6gui_video_mode_is_same (const lw6gui_video_mode_t * mode_a,
  * Return value: 1 on success, 0 on failure
  */
 int
-lw6gui_video_mode_sync_ratio (lw6gui_video_mode_t * dst,
-			      const lw6gui_video_mode_t * src)
+lw6gui_video_mode_sync_ratio (lw6sys_context_t * sys_context, lw6gui_video_mode_t * dst, const lw6gui_video_mode_t * src)
 {
   int ret = 0;
   float coeff = 0.0f;
@@ -186,25 +177,19 @@ lw6gui_video_mode_sync_ratio (lw6gui_video_mode_t * dst,
     {
       if (dst->width > 0 && dst->height > 0)
 	{
-	  coeff =
-	    sqrt (((float) dst->width * dst->height) /
-		  ((float) src->width * src->height));
+	  coeff = sqrt (((float) dst->width * dst->height) / ((float) src->width * src->height));
 	  dst->width = src->width * coeff;
 	  dst->height = src->height * coeff;
 	  ret = 1;
 	}
       else
 	{
-	  lw6sys_log (LW6SYS_LOG_WARNING,
-		      _x_ ("can't handle dst resolution %dx%d"),
-		      dst->width, dst->height);
+	  lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("can't handle dst resolution %dx%d"), dst->width, dst->height);
 	}
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING,
-		  _x_ ("can't handle src resolution %dx%d"), src->width,
-		  src->height);
+      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("can't handle src resolution %dx%d"), src->width, src->height);
     }
 
   return ret;
