@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -31,6 +31,7 @@
 /**
  * lw6hlp_match
  *
+ * @sys_context: global system context
  * @keyword1: the 1st keyword
  * @keyword2: the 2nd keyword
  *
@@ -41,22 +42,22 @@
  * Return value: 1 if matches, 0 if different.
  */
 int
-lw6hlp_match (const char *keyword1, const char *keyword2)
+lw6hlp_match (lw6sys_context_t * sys_context, const char *keyword1, const char *keyword2)
 {
   int ret = 0;
   char *key1 = NULL;
   char *key2 = NULL;
 
-  key1 = lw6sys_keyword_as_key (keyword1);
+  key1 = lw6sys_keyword_as_key (sys_context, keyword1);
   if (key1)
     {
-      key2 = lw6sys_keyword_as_key (keyword2);
+      key2 = lw6sys_keyword_as_key (sys_context, keyword2);
       if (key2)
 	{
 	  ret = !strcasecmp (key1, key2);
-	  LW6SYS_FREE (key2);
+	  LW6SYS_FREE (sys_context, key2);
 	}
-      LW6SYS_FREE (key1);
+      LW6SYS_FREE (sys_context, key1);
     }
 
   return ret;
