@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -29,6 +29,7 @@
 /**
  * lw6img_repr
  *
+ * @sys_context: global system context
  * @jpeg: the jpeg to describe
  *
  * Returns a string describing the jepg. This is a very short description,
@@ -38,20 +39,17 @@
  * Return value: a dynamically allocated string.
  */
 char *
-lw6img_repr (const lw6img_jpeg_t * jpeg)
+lw6img_repr (lw6sys_context_t * sys_context, const lw6img_jpeg_t * jpeg)
 {
   char *ret = NULL;
 
   if (jpeg)
     {
-      ret =
-	lw6sys_new_sprintf ("%u jpeg %dx%d, %d bytes", jpeg->id,
-			    jpeg->shape.w, jpeg->shape.h, jpeg->jpeg_size);
+      ret = lw6sys_new_sprintf (sys_context, "%u jpeg %dx%d, %d bytes", jpeg->id, jpeg->shape.w, jpeg->shape.h, jpeg->jpeg_size);
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING,
-		  _x_ ("can't generate string id for NULL jpeg"));
+      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("can't generate string id for NULL jpeg"));
     }
 
   return ret;
