@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -52,15 +52,14 @@ typedef struct lw6img_jpeg_s
 lw6img_jpeg_t;
 
 /* img-repr.c */
-extern char *lw6img_repr (const lw6img_jpeg_t * jpeg);
+extern char *lw6img_repr (lw6sys_context_t * sys_context, const lw6img_jpeg_t * jpeg);
 
 /* img-screenshot.c */
-extern lw6img_jpeg_t *lw6img_screenshot_new (lw6ker_game_state_t * game_state,
-					     char *user_dir, int quality);
-extern void lw6img_screenshot_free (lw6img_jpeg_t * screenshot);
+extern lw6img_jpeg_t *lw6img_screenshot_new (lw6sys_context_t * sys_context, lw6ker_game_state_t * game_state, char *user_dir, int quality);
+extern void lw6img_screenshot_free (lw6sys_context_t * sys_context, lw6img_jpeg_t * screenshot);
 
 /* img-test.c */
-extern int lw6img_test_register (int mode);
-extern int lw6img_test_run (int mode);
+extern int lw6img_test_register (lw6sys_context_t * sys_context, int mode);
+extern int lw6img_test_run (lw6sys_context_t * sys_context, int mode);
 
 #endif
