@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -33,50 +33,41 @@
  * FIGHTER_MOVE_? offset or used when moving fighters,
  * and calculating "what's in that direction?".
  */
-int32_t _lw6ker_fighter_t_MOVE_X_OFFSET[LW6KER_NB_DIRS] =
-  { 0, 1, 1, 1, 1, 0, 0, -1, -1, -1, -1, 0 };
-int32_t _lw6ker_fighter_t_MOVE_Y_OFFSET[LW6KER_NB_DIRS] =
-  { -1, -1, 0, 0, 1, 1, 1, 1, 0, 0, -1, -1 };
+int32_t _lw6ker_fighter_t_MOVE_X_OFFSET[LW6KER_NB_DIRS] = { 0, 1, 1, 1, 1, 0, 0, -1, -1, -1, -1, 0 };
+int32_t _lw6ker_fighter_t_MOVE_Y_OFFSET[LW6KER_NB_DIRS] = { -1, -1, 0, 0, 1, 1, 1, 1, 0, 0, -1, -1 };
 
 void
-_lw6ker_fighter_clear (lw6ker_fighter_t * fighter)
+_lw6ker_fighter_clear (lw6sys_context_t * sys_context, lw6ker_fighter_t * fighter)
 {
   memset (fighter, 0, sizeof (lw6ker_fighter_t));
 }
 
 void
-_lw6ker_fighter_update_checksum (const lw6ker_fighter_t * fighter,
-				 u_int32_t * checksum)
+_lw6ker_fighter_update_checksum (lw6sys_context_t * sys_context, const lw6ker_fighter_t * fighter, u_int32_t * checksum)
 {
-  lw6sys_checksum_update_int32 (checksum, fighter->team_color);
-  lw6sys_checksum_update_int32 (checksum, fighter->last_direction);
-  lw6sys_checksum_update_int32 (checksum, fighter->health);
-  lw6sys_checksum_update_int32 (checksum, fighter->act_counter);
-  lw6sys_checksum_update_int32 (checksum, fighter->pos.x);
-  lw6sys_checksum_update_int32 (checksum, fighter->pos.y);
-  lw6sys_checksum_update_int32 (checksum, fighter->pos.z);
+  lw6sys_checksum_update_int32 (sys_context, checksum, fighter->team_color);
+  lw6sys_checksum_update_int32 (sys_context, checksum, fighter->last_direction);
+  lw6sys_checksum_update_int32 (sys_context, checksum, fighter->health);
+  lw6sys_checksum_update_int32 (sys_context, checksum, fighter->act_counter);
+  lw6sys_checksum_update_int32 (sys_context, checksum, fighter->pos.x);
+  lw6sys_checksum_update_int32 (sys_context, checksum, fighter->pos.y);
+  lw6sys_checksum_update_int32 (sys_context, checksum, fighter->pos.z);
 }
 
 void
-_lw6ker_fighter_print_debug (lw6ker_fighter_t * fighter)
+_lw6ker_fighter_print_debug (lw6sys_context_t * sys_context, lw6ker_fighter_t * fighter)
 {
-  lw6sys_log (LW6SYS_LOG_DEBUG,
+  lw6sys_log (sys_context, LW6SYS_LOG_DEBUG,
 	      _x_
 	      ("fighter team_color=%d, last_direction=%d, health=%d, x=%d, y=%d, z=%d"),
-	      fighter->team_color, fighter->last_direction,
-	      fighter->health, (int) fighter->pos.x, (int) fighter->pos.y,
-	      (int) fighter->pos.z);
+	      fighter->team_color, fighter->last_direction, fighter->health, (int) fighter->pos.x, (int) fighter->pos.y, (int) fighter->pos.z);
 }
 
 void
-_lw6ker_fighter_move (lw6ker_fighter_t * fighter,
-		      int32_t fighter_id,
-		      int32_t x,
-		      int32_t y, int32_t z, _lw6ker_map_state_t * map_state)
+_lw6ker_fighter_move (lw6sys_context_t * sys_context,
+		      lw6ker_fighter_t * fighter, int32_t fighter_id, int32_t x, int32_t y, int32_t z, _lw6ker_map_state_t * map_state)
 {
-  _lw6ker_map_state_set_fighter_id (map_state,
-				    fighter->pos.x, fighter->pos.y,
-				    fighter->pos.z, -1);
+  _lw6ker_map_state_set_fighter_id (map_state, fighter->pos.x, fighter->pos.y, fighter->pos.z, -1);
   fighter->pos.x = x;
   fighter->pos.y = y;
   fighter->pos.z = z;
@@ -84,10 +75,9 @@ _lw6ker_fighter_move (lw6ker_fighter_t * fighter,
 }
 
 void
-_lw6ker_fighter_attack (lw6ker_fighter_t * fighter,
-			int32_t x,
-			int32_t y, int32_t z, _lw6ker_map_state_t * map_state,
-			int32_t fighter_attack, int32_t fighter_new_health)
+_lw6ker_fighter_attack (lw6sys_context_t * sys_context,
+			lw6ker_fighter_t * fighter, int32_t x, int32_t y,
+			int32_t z, _lw6ker_map_state_t * map_state, int32_t fighter_attack, int32_t fighter_new_health)
 {
   lw6ker_fighter_t *enemy;
 
@@ -112,12 +102,8 @@ _lw6ker_fighter_attack (lw6ker_fighter_t * fighter,
 }
 
 void
-_lw6ker_fighter_defend (lw6ker_fighter_t * fighter,
-			int32_t x,
-			int32_t y,
-			int32_t z,
-			_lw6ker_map_state_t * map_state,
-			int32_t fighter_defense)
+_lw6ker_fighter_defend (lw6sys_context_t * sys_context,
+			lw6ker_fighter_t * fighter, int32_t x, int32_t y, int32_t z, _lw6ker_map_state_t * map_state, int32_t fighter_defense)
 {
   lw6ker_fighter_t *ally;
 
@@ -130,8 +116,7 @@ _lw6ker_fighter_defend (lw6ker_fighter_t * fighter,
 }
 
 void
-_lw6ker_fighter_regenerate (lw6ker_fighter_t * fighter,
-			    int32_t fighter_regenerate)
+_lw6ker_fighter_regenerate (lw6sys_context_t * sys_context, lw6ker_fighter_t * fighter, int32_t fighter_regenerate)
 {
   fighter->health += fighter_regenerate;
   if (fighter->health > LW6MAP_MAX_FIGHTER_HEALTH)
