@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -44,7 +44,7 @@ static volatile u_int32_t seq_id = 0;
  * instance).
  */
 void
-_lw6ker_game_struct_set_id (_lw6ker_game_struct_t * game_struct)
+_lw6ker_game_struct_set_id (lw6sys_context_t * sys_context, _lw6ker_game_struct_t * game_struct)
 {
   game_struct->id = 0;
   while (!game_struct->id)
@@ -54,19 +54,17 @@ _lw6ker_game_struct_set_id (_lw6ker_game_struct_t * game_struct)
 }
 
 _lw6ker_game_struct_t *
-_lw6ker_game_struct_new (const lw6map_level_t * level,
-			 lw6sys_progress_t * progress)
+_lw6ker_game_struct_new (lw6sys_context_t * sys_context, const lw6map_level_t * level, lw6sys_progress_t * progress)
 {
   _lw6ker_game_struct_t *ret = NULL;
 
-  ret =
-    (_lw6ker_game_struct_t *) LW6SYS_CALLOC (sizeof (_lw6ker_game_struct_t));
+  ret = (_lw6ker_game_struct_t *) LW6SYS_CALLOC (sys_context, sizeof (_lw6ker_game_struct_t));
   if (ret)
     {
-      _lw6ker_game_struct_set_id (ret);
+      _lw6ker_game_struct_set_id (sys_context, ret);
       ret->level = level;
-      lw6map_rules_copy (&(ret->rules), &(level->param.rules));
-      _lw6ker_map_struct_init (&(ret->map_struct), level, progress);
+      lw6map_rules_copy (sys_context, &(ret->rules), &(level->param.rules));
+      _lw6ker_map_struct_init (sys_context, &(ret->map_struct), level, progress);
     }
 
   return ret;
@@ -75,6 +73,7 @@ _lw6ker_game_struct_new (const lw6map_level_t * level,
 /**
  * lw6ker_game_struct_new
  *
+ * @sys_context: global system context
  * @level: the level on which the game_struct is based
  * @progress: progress indicator
  *
@@ -86,22 +85,22 @@ _lw6ker_game_struct_new (const lw6map_level_t * level,
  * Return value: newly allocated object
  */
 lw6ker_game_struct_t *
-lw6ker_game_struct_new (const lw6map_level_t * level,
-			lw6sys_progress_t * progress)
+lw6ker_game_struct_new (lw6sys_context_t * sys_context, const lw6map_level_t * level, lw6sys_progress_t * progress)
 {
-  return (lw6ker_game_struct_t *) _lw6ker_game_struct_new (level, progress);
+  return (lw6ker_game_struct_t *) _lw6ker_game_struct_new (sys_context, level, progress);
 }
 
 void
-_lw6ker_game_struct_free (_lw6ker_game_struct_t * game_struct)
+_lw6ker_game_struct_free (lw6sys_context_t * sys_context, _lw6ker_game_struct_t * game_struct)
 {
-  _lw6ker_map_struct_clear (&(game_struct->map_struct));
-  LW6SYS_FREE (game_struct);
+  _lw6ker_map_struct_clear (sys_context, &(game_struct->map_struct));
+  LW6SYS_FREE (sys_context, game_struct);
 }
 
 /**
  * lw6ker_game_struct_free
  *
+ * @sys_context: global system context
  * @game_struct: the game_struct to free
  *
  * Frees a game_struct object, releasing all required stuff. The source
@@ -110,14 +109,13 @@ _lw6ker_game_struct_free (_lw6ker_game_struct_t * game_struct)
  * Return value: none
  */
 void
-lw6ker_game_struct_free (lw6ker_game_struct_t * game_struct)
+lw6ker_game_struct_free (lw6sys_context_t * sys_context, lw6ker_game_struct_t * game_struct)
 {
-  _lw6ker_game_struct_free ((_lw6ker_game_struct_t *) game_struct);
+  _lw6ker_game_struct_free (sys_context, (_lw6ker_game_struct_t *) game_struct);
 }
 
 void
-_lw6ker_game_struct_point_to (_lw6ker_game_struct_t * game_struct,
-			      const lw6map_level_t * level)
+_lw6ker_game_struct_point_to (lw6sys_context_t * sys_context, _lw6ker_game_struct_t * game_struct, const lw6map_level_t * level)
 {
   game_struct->level = level;
 }
@@ -125,6 +123,7 @@ _lw6ker_game_struct_point_to (_lw6ker_game_struct_t * game_struct,
 /**
  * lw6ker_game_struct_point_to
  *
+ * @sys_context: global system context
  * @game_struct: the game_struct to modify
  * @level: the level to point to
  *
@@ -137,15 +136,13 @@ _lw6ker_game_struct_point_to (_lw6ker_game_struct_t * game_struct,
  * Return value: none
  */
 void
-lw6ker_game_struct_point_to (lw6ker_game_struct_t * game_struct,
-			     const lw6map_level_t * level)
+lw6ker_game_struct_point_to (lw6sys_context_t * sys_context, lw6ker_game_struct_t * game_struct, const lw6map_level_t * level)
 {
-  _lw6ker_game_struct_point_to ((_lw6ker_game_struct_t *) game_struct, level);
+  _lw6ker_game_struct_point_to (sys_context, (_lw6ker_game_struct_t *) game_struct, level);
 }
 
 int
-_lw6ker_game_struct_memory_footprint (const _lw6ker_game_struct_t *
-				      game_struct)
+_lw6ker_game_struct_memory_footprint (lw6sys_context_t * sys_context, const _lw6ker_game_struct_t * game_struct)
 {
   int ret = 0;
 
@@ -157,6 +154,7 @@ _lw6ker_game_struct_memory_footprint (const _lw6ker_game_struct_t *
 /**
  * lw6ker_game_struct_memory_footprint
  *
+ * @sys_context: global system context
  * @game_struct: the game_struct to query
  *
  * Returns the approximative amount of memory taken by the object.
@@ -164,14 +162,13 @@ _lw6ker_game_struct_memory_footprint (const _lw6ker_game_struct_t *
  * Return value: number of bytes (approximation)
  */
 int
-lw6ker_game_struct_memory_footprint (const lw6ker_game_struct_t * game_struct)
+lw6ker_game_struct_memory_footprint (lw6sys_context_t * sys_context, const lw6ker_game_struct_t * game_struct)
 {
-  return _lw6ker_game_struct_memory_footprint ((const _lw6ker_game_struct_t *)
-					       game_struct);
+  return _lw6ker_game_struct_memory_footprint (sys_context, (const _lw6ker_game_struct_t *) game_struct);
 }
 
 char *
-_lw6ker_game_struct_repr (const _lw6ker_game_struct_t * game_struct)
+_lw6ker_game_struct_repr (lw6sys_context_t * sys_context, const _lw6ker_game_struct_t * game_struct)
 {
   char *ret = NULL;
   float compression = 0.0f;
@@ -182,20 +179,15 @@ _lw6ker_game_struct_repr (const _lw6ker_game_struct_t * game_struct)
        * do not use references to level here,
        * function is called when freeing the object
        */
-      compression =
-	_lw6ker_map_struct_get_compression (&(game_struct->map_struct)) *
-	100.0f;
+      compression = _lw6ker_map_struct_get_compression (sys_context, &(game_struct->map_struct)) * 100.0f;
 
       ret =
-	lw6sys_new_sprintf ("%u (%dx%dx%d, compression=%0.1f%%)",
-			    game_struct->id, game_struct->map_struct.shape.w,
-			    game_struct->map_struct.shape.h,
-			    game_struct->map_struct.shape.d, compression);
+	lw6sys_new_sprintf (sys_context, "%u (%dx%dx%d, compression=%0.1f%%)",
+			    game_struct->id, game_struct->map_struct.shape.w, game_struct->map_struct.shape.h, game_struct->map_struct.shape.d, compression);
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING,
-		  _x_ ("can't generate string id for NULL game_struct"));
+      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("can't generate string id for NULL game_struct"));
     }
 
   return ret;
@@ -204,6 +196,7 @@ _lw6ker_game_struct_repr (const _lw6ker_game_struct_t * game_struct)
 /**
  * lw6ker_game_struct_repr
  *
+ * @sys_context: global system context
  * @game_struct: the game_struct to query
  *
  * Gives a readable representation of the object.
@@ -211,95 +204,76 @@ _lw6ker_game_struct_repr (const _lw6ker_game_struct_t * game_struct)
  * Return value: newly allocated string, must be freed
  */
 char *
-lw6ker_game_struct_repr (const lw6ker_game_struct_t * game_struct)
+lw6ker_game_struct_repr (lw6sys_context_t * sys_context, const lw6ker_game_struct_t * game_struct)
 {
-  return _lw6ker_game_struct_repr ((const _lw6ker_game_struct_t *)
-				   game_struct);
+  return _lw6ker_game_struct_repr (sys_context, (const _lw6ker_game_struct_t *) game_struct);
 }
 
 _lw6ker_game_struct_t *
-_lw6ker_game_struct_dup (const _lw6ker_game_struct_t * game_struct,
-			 lw6sys_progress_t * progress)
+_lw6ker_game_struct_dup (lw6sys_context_t * sys_context, const _lw6ker_game_struct_t * game_struct, lw6sys_progress_t * progress)
 {
   _lw6ker_game_struct_t *ret = NULL;
 
-  lw6sys_progress_begin (progress);
+  lw6sys_progress_begin (sys_context, progress);
 
-  ret =
-    (_lw6ker_game_struct_t *) LW6SYS_MALLOC (sizeof (_lw6ker_game_struct_t));
+  ret = (_lw6ker_game_struct_t *) LW6SYS_MALLOC (sys_context, sizeof (_lw6ker_game_struct_t));
   if (ret)
     {
       memcpy (ret, game_struct, sizeof (_lw6ker_game_struct_t));
-      lw6sys_progress_update (progress, 0, 8, 1);
+      lw6sys_progress_update (sys_context, progress, 0, 8, 1);
       /*
        * Set id after the memcpy, else will be overwritten
        */
-      _lw6ker_game_struct_set_id (ret);
-      ret->map_struct.places =
-	(_lw6ker_place_struct_t *)
-	LW6SYS_MALLOC (sizeof (_lw6ker_place_struct_t) *
-		       ret->map_struct.nb_places);
-      lw6sys_progress_update (progress, 0, 8, 2);
+      _lw6ker_game_struct_set_id (sys_context, ret);
+      ret->map_struct.places = (_lw6ker_place_struct_t *) LW6SYS_MALLOC (sys_context, sizeof (_lw6ker_place_struct_t) * ret->map_struct.nb_places);
+      lw6sys_progress_update (sys_context, progress, 0, 8, 2);
       if (ret->map_struct.places)
 	{
-	  memcpy (ret->map_struct.places, game_struct->map_struct.places,
-		  sizeof (_lw6ker_place_struct_t) *
-		  ret->map_struct.nb_places);
+	  memcpy (ret->map_struct.places, game_struct->map_struct.places, sizeof (_lw6ker_place_struct_t) * ret->map_struct.nb_places);
 	}
-      lw6sys_progress_update (progress, 0, 8, 3);
-      ret->map_struct.zones =
-	(_lw6ker_zone_struct_t *)
-	LW6SYS_MALLOC (sizeof (_lw6ker_zone_struct_t) *
-		       ret->map_struct.nb_zones);
-      lw6sys_progress_update (progress, 0, 8, 4);
+      lw6sys_progress_update (sys_context, progress, 0, 8, 3);
+      ret->map_struct.zones = (_lw6ker_zone_struct_t *) LW6SYS_MALLOC (sys_context, sizeof (_lw6ker_zone_struct_t) * ret->map_struct.nb_zones);
+      lw6sys_progress_update (sys_context, progress, 0, 8, 4);
       if (ret->map_struct.zones)
 	{
-	  memcpy (ret->map_struct.zones, game_struct->map_struct.zones,
-		  sizeof (_lw6ker_zone_struct_t) * ret->map_struct.nb_zones);
+	  memcpy (ret->map_struct.zones, game_struct->map_struct.zones, sizeof (_lw6ker_zone_struct_t) * ret->map_struct.nb_zones);
 	}
-      lw6sys_progress_update (progress, 0, 8, 5);
-      ret->map_struct.slots =
-	(_lw6ker_slot_struct_t *)
-	LW6SYS_MALLOC (sizeof (_lw6ker_slot_struct_t) *
-		       ret->map_struct.nb_slots);
-      lw6sys_progress_update (progress, 0, 8, 6);
+      lw6sys_progress_update (sys_context, progress, 0, 8, 5);
+      ret->map_struct.slots = (_lw6ker_slot_struct_t *) LW6SYS_MALLOC (sys_context, sizeof (_lw6ker_slot_struct_t) * ret->map_struct.nb_slots);
+      lw6sys_progress_update (sys_context, progress, 0, 8, 6);
       if (ret->map_struct.slots)
 	{
-	  memcpy (ret->map_struct.slots, game_struct->map_struct.slots,
-		  sizeof (_lw6ker_slot_struct_t) * ret->map_struct.nb_slots);
+	  memcpy (ret->map_struct.slots, game_struct->map_struct.slots, sizeof (_lw6ker_slot_struct_t) * ret->map_struct.nb_slots);
 	}
-      lw6sys_progress_update (progress, 0, 8, 7);
+      lw6sys_progress_update (sys_context, progress, 0, 8, 7);
       if ((!ret->map_struct.zones) || (!ret->map_struct.slots))
 	{
 	  if (ret->map_struct.zones)
 	    {
-	      LW6SYS_FREE (ret->map_struct.zones);
+	      LW6SYS_FREE (sys_context, ret->map_struct.zones);
 	    }
 	  if (ret->map_struct.slots)
 	    {
-	      LW6SYS_FREE (ret->map_struct.slots);
+	      LW6SYS_FREE (sys_context, ret->map_struct.slots);
 	    }
-	  LW6SYS_FREE (ret);
+	  LW6SYS_FREE (sys_context, ret);
 	  ret = NULL;
 	}
     }
 
   if (ret)
     {
-      if (_lw6ker_game_struct_checksum (ret) ==
-	  _lw6ker_game_struct_checksum (game_struct))
+      if (_lw6ker_game_struct_checksum (sys_context, ret) == _lw6ker_game_struct_checksum (sys_context, game_struct))
 	{
-	  lw6sys_log (LW6SYS_LOG_INFO, _x_ ("game_struct dup %d->%d"),
-		      game_struct->id, ret->id);
+	  lw6sys_log (sys_context, LW6SYS_LOG_INFO, _x_ ("game_struct dup %d->%d"), game_struct->id, ret->id);
 	}
       else
 	{
-	  lw6sys_log (LW6SYS_LOG_WARNING,
-		      _x_ ("game_struct checkum mismatch after dup"));
+	  lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("game_struct checkum mismatch after dup"));
 	}
     }
 
-  lw6sys_progress_end (progress);
+  lw6sys_progress_end (sys_context, progress);
 
 
   return ret;
@@ -308,6 +282,7 @@ _lw6ker_game_struct_dup (const _lw6ker_game_struct_t * game_struct,
 /**
  * lw6ker_game_struct_dup
  *
+ * @sys_context: global system context
  * @game_struct: the game_struct to copy
  * @progress: progress indicator
  *
@@ -319,28 +294,24 @@ _lw6ker_game_struct_dup (const _lw6ker_game_struct_t * game_struct,
  * Return value: newly created object
  */
 lw6ker_game_struct_t *
-lw6ker_game_struct_dup (const lw6ker_game_struct_t * game_struct,
-			lw6sys_progress_t * progress)
+lw6ker_game_struct_dup (lw6sys_context_t * sys_context, const lw6ker_game_struct_t * game_struct, lw6sys_progress_t * progress)
 {
-  return (lw6ker_game_struct_t *)
-    _lw6ker_game_struct_dup ((const _lw6ker_game_struct_t *) game_struct,
-			     progress);
+  return (lw6ker_game_struct_t *) _lw6ker_game_struct_dup (sys_context, (const _lw6ker_game_struct_t *) game_struct, progress);
 }
 
 void
-_lw6ker_game_struct_update_checksum (const _lw6ker_game_struct_t *
-				     game_struct, u_int32_t * checksum)
+_lw6ker_game_struct_update_checksum (lw6sys_context_t * sys_context, const _lw6ker_game_struct_t * game_struct, u_int32_t * checksum)
 {
-  lw6map_rules_update_checksum (&(game_struct->rules), checksum);
-  _lw6ker_map_struct_update_checksum (&(game_struct->map_struct), checksum);
+  lw6map_rules_update_checksum (sys_context, &(game_struct->rules), checksum);
+  _lw6ker_map_struct_update_checksum (sys_context, &(game_struct->map_struct), checksum);
 }
 
 u_int32_t
-_lw6ker_game_struct_checksum (const _lw6ker_game_struct_t * game_struct)
+_lw6ker_game_struct_checksum (lw6sys_context_t * sys_context, const _lw6ker_game_struct_t * game_struct)
 {
   u_int32_t ret = 0;
 
-  _lw6ker_game_struct_update_checksum (game_struct, &ret);
+  _lw6ker_game_struct_update_checksum (sys_context, game_struct, &ret);
 
   return ret;
 }
@@ -348,6 +319,7 @@ _lw6ker_game_struct_checksum (const _lw6ker_game_struct_t * game_struct)
 /**
  * lw6ker_game_struct_checksum
  *
+ * @sys_context: global system context
  * @game_struct: the game_struct to query
  *
  * Calculates the checksum of a game_struct, this can be very usefull
@@ -357,15 +329,15 @@ _lw6ker_game_struct_checksum (const _lw6ker_game_struct_t * game_struct)
  * Return value: 32-bit checksum
  */
 u_int32_t
-lw6ker_game_struct_checksum (const lw6ker_game_struct_t * game_struct)
+lw6ker_game_struct_checksum (lw6sys_context_t * sys_context, const lw6ker_game_struct_t * game_struct)
 {
-  return _lw6ker_game_struct_checksum ((const _lw6ker_game_struct_t *)
-				       game_struct);
+  return _lw6ker_game_struct_checksum (sys_context, (const _lw6ker_game_struct_t *) game_struct);
 }
 
 /**
  * lw6ker_game_struct_get_shape
  *
+ * @sys_context: global system context
  * @game_struct: the game_struct to query
  * @shape: the shape (out param)
  *
@@ -374,8 +346,7 @@ lw6ker_game_struct_checksum (const lw6ker_game_struct_t * game_struct)
  * Return value: none.
  */
 void
-lw6ker_game_struct_get_shape (const lw6ker_game_struct_t * game_struct,
-			      lw6sys_whd_t * shape)
+lw6ker_game_struct_get_shape (lw6sys_context_t * sys_context, const lw6ker_game_struct_t * game_struct, lw6sys_whd_t * shape)
 {
   (*shape) = ((const _lw6ker_game_struct_t *) game_struct)->map_struct.shape;
 }
@@ -383,6 +354,7 @@ lw6ker_game_struct_get_shape (const lw6ker_game_struct_t * game_struct,
 /**
  * lw6ker_game_struct_get_w
  *
+ * @sys_context: global system context
  * @game_struct: the game_struct to query
  *
  * Retrieves the width (shape.w) of the game_struct.
@@ -390,7 +362,7 @@ lw6ker_game_struct_get_shape (const lw6ker_game_struct_t * game_struct,
  * Return value: the width.
  */
 int
-lw6ker_game_struct_get_w (const lw6ker_game_struct_t * game_struct)
+lw6ker_game_struct_get_w (lw6sys_context_t * sys_context, const lw6ker_game_struct_t * game_struct)
 {
   return ((const _lw6ker_game_struct_t *) game_struct)->map_struct.shape.w;
 }
@@ -398,6 +370,7 @@ lw6ker_game_struct_get_w (const lw6ker_game_struct_t * game_struct)
 /**
  * lw6ker_game_struct_get_h
  *
+ * @sys_context: global system context
  * @game_struct: the game_struct to query
  *
  * Retrieves the height (shape.h) of the game_struct.
@@ -405,7 +378,7 @@ lw6ker_game_struct_get_w (const lw6ker_game_struct_t * game_struct)
  * Return value: the height.
  */
 int
-lw6ker_game_struct_get_h (const lw6ker_game_struct_t * game_struct)
+lw6ker_game_struct_get_h (lw6sys_context_t * sys_context, const lw6ker_game_struct_t * game_struct)
 {
   return ((const _lw6ker_game_struct_t *) game_struct)->map_struct.shape.h;
 }
@@ -413,6 +386,7 @@ lw6ker_game_struct_get_h (const lw6ker_game_struct_t * game_struct)
 /**
  * lw6ker_game_struct_get_d
  *
+ * @sys_context: global system context
  * @game_struct: the game_struct to query
  *
  * Retrieves the depth (shape.d, AKA number of layers) of the game_struct.
@@ -420,7 +394,7 @@ lw6ker_game_struct_get_h (const lw6ker_game_struct_t * game_struct)
  * Return value: the depth.
  */
 int
-lw6ker_game_struct_get_d (const lw6ker_game_struct_t * game_struct)
+lw6ker_game_struct_get_d (lw6sys_context_t * sys_context, const lw6ker_game_struct_t * game_struct)
 {
   return ((const _lw6ker_game_struct_t *) game_struct)->map_struct.shape.d;
 }
@@ -428,6 +402,7 @@ lw6ker_game_struct_get_d (const lw6ker_game_struct_t * game_struct)
 /**
  * lw6ker_game_struct_is_fg
  *
+ * @sys_context: global system context
  * @game_struct: the game_struct to query
  * @x: x position
  * @y: y position
@@ -438,17 +413,15 @@ lw6ker_game_struct_get_d (const lw6ker_game_struct_t * game_struct)
  * Return value: 1 if foreground (wall, fighters can't move), 0 if not
  */
 int
-lw6ker_game_struct_is_fg (const lw6ker_game_struct_t * game_struct, int32_t x,
-			  int32_t y, int32_t z)
+lw6ker_game_struct_is_fg (lw6sys_context_t * sys_context, const lw6ker_game_struct_t * game_struct, int32_t x, int32_t y, int32_t z)
 {
-  return (_lw6ker_map_struct_get_zone_id
-	  (&(((const _lw6ker_game_struct_t *) game_struct)->map_struct), x, y,
-	   z) < 0);
+  return (_lw6ker_map_struct_get_zone_id (&(((const _lw6ker_game_struct_t *) game_struct)->map_struct), x, y, z) < 0);
 }
 
 /**
  * lw6ker_game_struct_is_bg
  *
+ * @sys_context: global system context
  * @game_struct: the game_struct to query
  * @x: x position
  * @y: y position
@@ -459,17 +432,15 @@ lw6ker_game_struct_is_fg (const lw6ker_game_struct_t * game_struct, int32_t x,
  * Return value: 1 if background (wall, fighters can move), 0 if not
  */
 int
-lw6ker_game_struct_is_bg (const lw6ker_game_struct_t * game_struct, int32_t x,
-			  int32_t y, int32_t z)
+lw6ker_game_struct_is_bg (lw6sys_context_t * sys_context, const lw6ker_game_struct_t * game_struct, int32_t x, int32_t y, int32_t z)
 {
-  return (_lw6ker_map_struct_get_zone_id
-	  (&(((const _lw6ker_game_struct_t *) game_struct)->map_struct), x, y,
-	   z) >= 0);
+  return (_lw6ker_map_struct_get_zone_id (&(((const _lw6ker_game_struct_t *) game_struct)->map_struct), x, y, z) >= 0);
 }
 
 /**
  * lw6ker_game_struct_get_zones_info
  *
+ * @sys_context: global system context
  * @game_struct: game_struct to query
  * @nb_zones: the maximum zone size (out param, can be NULL)
  * @max_zone_size: the maximum zone size (out param, can be NULL)
@@ -480,25 +451,22 @@ lw6ker_game_struct_is_bg (const lw6ker_game_struct_t * game_struct, int32_t x,
  * Return value: none.
  */
 void
-lw6ker_game_struct_get_zones_info (const lw6ker_game_struct_t * game_struct,
-				   int *nb_zones, int *max_zone_size)
+lw6ker_game_struct_get_zones_info (lw6sys_context_t * sys_context, const lw6ker_game_struct_t * game_struct, int *nb_zones, int *max_zone_size)
 {
   if (nb_zones)
     {
-      (*nb_zones) =
-	((const _lw6ker_game_struct_t *) game_struct)->map_struct.nb_zones;
+      (*nb_zones) = ((const _lw6ker_game_struct_t *) game_struct)->map_struct.nb_zones;
     }
   if (max_zone_size)
     {
-      (*max_zone_size) =
-	((const _lw6ker_game_struct_t *) game_struct)->
-	map_struct.max_zone_size;
+      (*max_zone_size) = ((const _lw6ker_game_struct_t *) game_struct)->map_struct.max_zone_size;
     }
 }
 
 /**
  * lw6ker_game_struct_get_zone_info
  *
+ * @sys_context: global system context
  * @game_struct: game_struct to query
  * @i: index of the zone to query
  * @zone_pos: coord of the zone, top-left corner (out param, can be NULL)
@@ -510,14 +478,11 @@ lw6ker_game_struct_get_zones_info (const lw6ker_game_struct_t * game_struct,
  * Return value: none
  */
 void
-lw6ker_game_struct_get_zone_info (const lw6ker_game_struct_t * game_struct,
-				  int i,
-				  lw6sys_xyz_t * zone_pos, int *zone_size)
+lw6ker_game_struct_get_zone_info (lw6sys_context_t * sys_context, const lw6ker_game_struct_t * game_struct, int i, lw6sys_xyz_t * zone_pos, int *zone_size)
 {
   _lw6ker_zone_struct_t *zone;
 
-  zone =
-    &(((const _lw6ker_game_struct_t *) game_struct)->map_struct.zones[i]);
+  zone = &(((const _lw6ker_game_struct_t *) game_struct)->map_struct.zones[i]);
   if (zone_pos)
     {
       (*zone_pos) = zone->pos;
@@ -531,6 +496,7 @@ lw6ker_game_struct_get_zone_info (const lw6ker_game_struct_t * game_struct,
 /**
  * lw6ker_game_struct_get_zone_id
  *
+ * @sys_context: global system context
  * @game_struct: the game_struct to query
  * @x: x pos
  * @y: y pos
@@ -542,18 +508,15 @@ lw6ker_game_struct_get_zone_info (const lw6ker_game_struct_t * game_struct,
  * Return value: the zone id
  */
 int32_t
-lw6ker_game_struct_get_zone_id (const lw6ker_game_struct_t * game_struct,
-				int32_t x, int32_t y, int32_t z)
+lw6ker_game_struct_get_zone_id (lw6sys_context_t * sys_context, const lw6ker_game_struct_t * game_struct, int32_t x, int32_t y, int32_t z)
 {
-  return
-    _lw6ker_map_struct_get_zone_id (&
-				    (((const _lw6ker_game_struct_t *)
-				      game_struct)->map_struct), x, y, z);
+  return _lw6ker_map_struct_get_zone_id (&(((const _lw6ker_game_struct_t *) game_struct)->map_struct), x, y, z);
 }
 
 /**
  * lw6ker_game_struct_find_free_slot_near
  *
+ * @sys_context: global system context
  * @game_struct: the game_struct to query
  * @there: the closest free slot (out param)
  * @here: where we'd like to be
@@ -565,13 +528,7 @@ lw6ker_game_struct_get_zone_id (const lw6ker_game_struct_t * game_struct,
  * Return value: none
  */
 void
-lw6ker_game_struct_find_free_slot_near (const lw6ker_game_struct_t *
-					game_struct,
-					lw6sys_xyz_t * there,
-					lw6sys_xyz_t here)
+lw6ker_game_struct_find_free_slot_near (lw6sys_context_t * sys_context, const lw6ker_game_struct_t * game_struct, lw6sys_xyz_t * there, lw6sys_xyz_t here)
 {
-  _lw6ker_map_struct_find_free_slot_near (&
-					  (((const _lw6ker_game_struct_t *)
-					    game_struct)->map_struct), there,
-					  here);
+  _lw6ker_map_struct_find_free_slot_near (sys_context, &(((const _lw6ker_game_struct_t *) game_struct)->map_struct), there, here);
 }
