@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -30,8 +30,7 @@
 #include "ker-internal.h"
 
 void
-_lw6ker_history_set (_lw6ker_history_t * history,
-		     _lw6ker_armies_t * armies, int i)
+_lw6ker_history_set (lw6sys_context_t * sys_context, _lw6ker_history_t * history, _lw6ker_armies_t * armies, int i)
 {
   int j;
 
@@ -50,12 +49,12 @@ _lw6ker_history_set (_lw6ker_history_t * history,
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("bad history index %i"), i);
+      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("bad history index %i"), i);
     }
 }
 
 void
-_lw6ker_history_add (_lw6ker_history_t * history, _lw6ker_armies_t * armies)
+_lw6ker_history_add (lw6sys_context_t * sys_context, _lw6ker_history_t * history, _lw6ker_armies_t * armies)
 {
   int i, j;
 
@@ -72,7 +71,7 @@ _lw6ker_history_add (_lw6ker_history_t * history, _lw6ker_armies_t * armies)
 }
 
 int
-_lw6ker_history_get (const _lw6ker_history_t * history, int i, int team_id)
+_lw6ker_history_get (lw6sys_context_t * sys_context, const _lw6ker_history_t * history, int i, int team_id)
 {
   int offset = 0;
   int ret = 0;
@@ -93,14 +92,14 @@ _lw6ker_history_get (const _lw6ker_history_t * history, int i, int team_id)
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("bad history index %i"), i);
+      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("bad history index %i"), i);
     }
 
   return ret;
 }
 
 int32_t
-_lw6ker_history_get_max (const _lw6ker_history_t * history)
+_lw6ker_history_get_max (lw6sys_context_t * sys_context, const _lw6ker_history_t * history)
 {
   int32_t ret = 0;
   int32_t sub_total;
@@ -120,17 +119,16 @@ _lw6ker_history_get_max (const _lw6ker_history_t * history)
 }
 
 void
-_lw6ker_history_update_checksum (const _lw6ker_history_t * history,
-				 u_int32_t * checksum)
+_lw6ker_history_update_checksum (lw6sys_context_t * sys_context, const _lw6ker_history_t * history, u_int32_t * checksum)
 {
   int i, j;
 
-  lw6sys_checksum_update_int32 (checksum, history->nb_entries);
+  lw6sys_checksum_update_int32 (sys_context, checksum, history->nb_entries);
   for (i = 0; i < LW6KER_HISTORY_SIZE; ++i)
     {
       for (j = 0; j < LW6MAP_MAX_NB_TEAMS; ++j)
 	{
-	  lw6sys_checksum_update_int32 (checksum, history->nb_fighters[i][j]);
+	  lw6sys_checksum_update_int32 (sys_context, checksum, history->nb_fighters[i][j]);
 	}
     }
 }
