@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -30,32 +30,31 @@
 #include "ker-internal.h"
 
 void
-_lw6ker_node_array_init (_lw6ker_node_array_t * node_array)
+_lw6ker_node_array_init (lw6sys_context_t * sys_context, _lw6ker_node_array_t * node_array)
 {
   int i = 0;
 
   node_array->nb_nodes = 0;
   for (i = 0; i < LW6MAP_MAX_NB_NODES; ++i)
     {
-      _lw6ker_node_init (&(node_array->nodes[i]));
+      _lw6ker_node_init (sys_context, &(node_array->nodes[i]));
     }
 }
 
 void
-_lw6ker_node_array_update_checksum (const _lw6ker_node_array_t *
-				    node_array, u_int32_t * checksum)
+_lw6ker_node_array_update_checksum (lw6sys_context_t * sys_context, const _lw6ker_node_array_t * node_array, u_int32_t * checksum)
 {
   int i = 0;
 
-  lw6sys_checksum_update_int32 (checksum, node_array->nb_nodes);
+  lw6sys_checksum_update_int32 (sys_context, checksum, node_array->nb_nodes);
   for (i = 0; i < LW6MAP_MAX_NB_NODES; ++i)
     {
-      _lw6ker_node_update_checksum (&(node_array->nodes[i]), checksum);
+      _lw6ker_node_update_checksum (sys_context, &(node_array->nodes[i]), checksum);
     }
 }
 
 _lw6ker_node_t *
-_lw6ker_node_array_find_free (_lw6ker_node_array_t * node_array)
+_lw6ker_node_array_find_free (lw6sys_context_t * sys_context, _lw6ker_node_array_t * node_array)
 {
   _lw6ker_node_t *ret = NULL;
   int i;
@@ -70,27 +69,26 @@ _lw6ker_node_array_find_free (_lw6ker_node_array_t * node_array)
 
   if (!ret)
     {
-      lw6sys_log (LW6SYS_LOG_DEBUG, _x_ ("unable to find free node"));
+      lw6sys_log (sys_context, LW6SYS_LOG_DEBUG, _x_ ("unable to find free node"));
     }
 
   return ret;
 }
 
 void
-_lw6ker_node_array_reset (_lw6ker_node_array_t * node_array)
+_lw6ker_node_array_reset (lw6sys_context_t * sys_context, _lw6ker_node_array_t * node_array)
 {
   int i;
 
   node_array->nb_nodes = 0;
   for (i = 0; i < LW6MAP_MAX_NB_NODES; ++i)
     {
-      _lw6ker_node_reset (&(node_array->nodes[i]));
+      _lw6ker_node_reset (sys_context, &(node_array->nodes[i]));
     }
 }
 
 _lw6ker_node_t *
-_lw6ker_node_array_get_rw (_lw6ker_node_array_t * node_array,
-			   u_int64_t node_id)
+_lw6ker_node_array_get_rw (lw6sys_context_t * sys_context, _lw6ker_node_array_t * node_array, u_int64_t node_id)
 {
   _lw6ker_node_t *ret = NULL;
   int i;
@@ -107,8 +105,7 @@ _lw6ker_node_array_get_rw (_lw6ker_node_array_t * node_array,
 }
 
 const _lw6ker_node_t *
-_lw6ker_node_array_get_ro (const _lw6ker_node_array_t * node_array,
-			   u_int64_t node_id)
+_lw6ker_node_array_get_ro (lw6sys_context_t * sys_context, const _lw6ker_node_array_t * node_array, u_int64_t node_id)
 {
   const _lw6ker_node_t *ret = NULL;
   int i;
@@ -125,62 +122,53 @@ _lw6ker_node_array_get_ro (const _lw6ker_node_array_t * node_array,
 }
 
 int
-_lw6ker_node_array_enable (_lw6ker_node_array_t * node_array,
-			   u_int64_t node_id)
+_lw6ker_node_array_enable (lw6sys_context_t * sys_context, _lw6ker_node_array_t * node_array, u_int64_t node_id)
 {
   int ret = 0;
   _lw6ker_node_t *node;
 
-  node = _lw6ker_node_array_get_rw (node_array, node_id);
+  node = _lw6ker_node_array_get_rw (sys_context, node_array, node_id);
   if (!node)
     {
-      node = _lw6ker_node_array_find_free (node_array);
+      node = _lw6ker_node_array_find_free (sys_context, node_array);
       if (node)
 	{
-	  _lw6ker_node_enable (node, node_id);
+	  _lw6ker_node_enable (sys_context, node, node_id);
 	  node_array->nb_nodes++;
 	  ret = 1;
 	}
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_DEBUG,
-		  _x_ ("node %" LW6SYS_PRINTF_LL
-		       "x already exists, can't enable it twice"),
-		  (long long) node_id);
+      lw6sys_log (sys_context, LW6SYS_LOG_DEBUG, _x_ ("node %" LW6SYS_PRINTF_LL "x already exists, can't enable it twice"), (long long) node_id);
     }
 
   return ret;
 }
 
 int
-_lw6ker_node_array_disable (_lw6ker_node_array_t * node_array,
-			    u_int64_t node_id)
+_lw6ker_node_array_disable (lw6sys_context_t * sys_context, _lw6ker_node_array_t * node_array, u_int64_t node_id)
 {
   int ret = 0;
   _lw6ker_node_t *node;
 
-  node = _lw6ker_node_array_get_rw (node_array, node_id);
+  node = _lw6ker_node_array_get_rw (sys_context, node_array, node_id);
   if (node)
     {
-      _lw6ker_node_disable (node);
+      _lw6ker_node_disable (sys_context, node);
       node_array->nb_nodes--;
       ret = 1;
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_DEBUG,
-		  _x_ ("node %" LW6SYS_PRINTF_LL
-		       "x already does not exist, can't disable it"),
-		  (long long) node_id);
+      lw6sys_log (sys_context, LW6SYS_LOG_DEBUG, _x_ ("node %" LW6SYS_PRINTF_LL "x already does not exist, can't disable it"), (long long) node_id);
     }
 
   return ret;
 }
 
 int
-_lw6ker_node_array_sanity_check (const _lw6ker_node_array_t * node_array,
-				 const lw6map_rules_t * rules)
+_lw6ker_node_array_sanity_check (lw6sys_context_t * sys_context, const _lw6ker_node_array_t * node_array, const lw6map_rules_t * rules)
 {
   int ret = 1;
   int i;
@@ -188,7 +176,7 @@ _lw6ker_node_array_sanity_check (const _lw6ker_node_array_t * node_array,
 
   for (i = 0; i < LW6MAP_MAX_NB_NODES; ++i)
     {
-      ret = ret && _lw6ker_node_sanity_check (&(node_array->nodes[i]), rules);
+      ret = ret && _lw6ker_node_sanity_check (sys_context, &(node_array->nodes[i]), rules);
       if (node_array->nodes[i].enabled)
 	{
 	  found++;
@@ -196,10 +184,7 @@ _lw6ker_node_array_sanity_check (const _lw6ker_node_array_t * node_array,
     }
   if (found != node_array->nb_nodes)
     {
-      lw6sys_log (LW6SYS_LOG_WARNING,
-		  _x_
-		  ("inconsistency in node_array, found %d nodes but array reports %d"),
-		  found, node_array->nb_nodes);
+      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("inconsistency in node_array, found %d nodes but array reports %d"), found, node_array->nb_nodes);
       ret = 0;
     }
 
