@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -34,6 +34,7 @@
 /**
  * lw6ker_team_mask_get
  *
+ * @sys_context: global system context
  * @even: even team mask (out param)
  * @odd: odd team mask (out param)
  * @round: round concerned
@@ -44,23 +45,22 @@
  * Return value: none.
  */
 void
-lw6ker_team_mask_get (u_int32_t * even, u_int32_t * odd, int32_t round)
+lw6ker_team_mask_get (lw6sys_context_t * sys_context, u_int32_t * even, u_int32_t * odd, int32_t round)
 {
   u_int32_t checksum;
 
-  checksum = lw6sys_checksum_int32 (round);
+  checksum = lw6sys_checksum_int32 (sys_context, round);
 
   (*even) =
     ((checksum & 0x01) ? 0x001 : 0x002) | ((checksum & 0x02) ? 0x004 : 0x008)
-    | ((checksum & 0x08) ? 0x010 : 0x020) | ((checksum & 0x10) ? 0x040 :
-					     0x080) | ((checksum & 0x20) ?
-						       0x100 : 0x200);
+    | ((checksum & 0x08) ? 0x010 : 0x020) | ((checksum & 0x10) ? 0x040 : 0x080) | ((checksum & 0x20) ? 0x100 : 0x200);
   (*odd) = (*even) ^ LW6KER_TEAM_MASK_ALL;
 }
 
 /**
  * lw6ker_team_mask_best
  *
+ * @sys_context: global system context
  * @even: even team mask (out param)
  * @odd: odd team mask (out param)
  * @game_state: the game_state concerned
@@ -73,44 +73,43 @@ lw6ker_team_mask_get (u_int32_t * even, u_int32_t * odd, int32_t round)
  * Return value: none.
  */
 void
-lw6ker_team_mask_best (u_int32_t * even, u_int32_t * odd,
-		       lw6ker_game_state_t * game_state)
+lw6ker_team_mask_best (lw6sys_context_t * sys_context, u_int32_t * even, u_int32_t * odd, lw6ker_game_state_t * game_state)
 {
   int i = 0, j = 0, k = 0, l = 0;
   int delta = LW6MAP_MAX_NB_TEAMS;
   int seed = 0;
 
-  seed = lw6ker_game_state_get_rounds (game_state);
+  seed = lw6ker_game_state_get_rounds (sys_context, game_state);
   while (delta > 1 && l < LW6MAP_MAX_NB_TEAMS)
     {
-      lw6ker_team_mask_get (even, odd, seed);
+      lw6ker_team_mask_get (sys_context, even, odd, seed);
       j = k = 0;
       for (i = 0; i < LW6MAP_MAX_NB_TEAMS; ++i)
 	{
-	  if (lw6ker_game_state_team_exists (game_state, i))
+	  if (lw6ker_game_state_team_exists (sys_context, game_state, i))
 	    {
-	      if (lw6ker_team_mask_is_concerned (i, *even))
+	      if (lw6ker_team_mask_is_concerned (sys_context, i, *even))
 		{
 		  k++;
 		}
 	      j++;
 	    }
 	}
-      seed = lw6sys_checksum_int32 (seed);
+      seed = lw6sys_checksum_int32 (sys_context, seed);
       delta = abs (j - k * 2);
       l++;
     }
 
   if (l >= LW6MAP_MAX_NB_TEAMS)
     {
-      lw6sys_log (LW6SYS_LOG_DEBUG,
-		  _x_ ("team_max_best with l=%d, consider optimizing"), l);
+      lw6sys_log (sys_context, LW6SYS_LOG_DEBUG, _x_ ("team_max_best with l=%d, consider optimizing"), l);
     }
 }
 
 /**
  * lw6ker_team_mask_is_concerned
  *
+ * @sys_context: global system context
  * @team_color: color index
  * @team_mask: team mask
  *
@@ -119,7 +118,7 @@ lw6ker_team_mask_best (u_int32_t * even, u_int32_t * odd,
  * Return value: 1 if concerned, 0 if not.
  */
 int
-lw6ker_team_mask_is_concerned (int team_color, u_int32_t team_mask)
+lw6ker_team_mask_is_concerned (lw6sys_context_t * sys_context, int team_color, u_int32_t team_mask)
 {
   static int matrix[LW6MAP_MAX_NB_TEAMS] = { LW6KER_TEAM_MASK_RED,
     LW6KER_TEAM_MASK_GREEN,
@@ -152,7 +151,7 @@ lw6ker_team_mask_is_concerned (int team_color, u_int32_t team_mask)
  * Return value: bitwise mask.
  */
 int
-lw6ker_team_mask_color2mask (int team_color)
+lw6ker_team_mask_color2mask (lw6sys_context_t * sys_context, int team_color)
 {
   int ret = 0;
 
@@ -189,8 +188,7 @@ lw6ker_team_mask_color2mask (int team_color)
       ret = LW6KER_TEAM_MASK_PINK;
       break;
     default:
-      lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("invalid team index %d"),
-		  team_color);
+      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("invalid team index %d"), team_color);
     }
 
   return ret;
