@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -28,10 +28,9 @@
 #include "ker-internal.h"
 
 void
-_lw6ker_zone_state_update_checksum (const _lw6ker_zone_state_t * zone_state,
-				    u_int32_t * checksum)
+_lw6ker_zone_state_update_checksum (lw6sys_context_t * sys_context, const _lw6ker_zone_state_t * zone_state, u_int32_t * checksum)
 {
-  lw6sys_checksum_update_int32 (checksum, zone_state->potential);
-  lw6sys_checksum_update_int32 (checksum, zone_state->direction_to_cursor);
-  lw6sys_checksum_update_xyz (checksum, &(zone_state->closest_cursor_pos));
+  lw6sys_checksum_update_int32 (sys_context, checksum, zone_state->potential);
+  lw6sys_checksum_update_int32 (sys_context, checksum, zone_state->direction_to_cursor);
+  lw6sys_checksum_update_xyz (sys_context, checksum, &(zone_state->closest_cursor_pos));
 }
