@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -30,8 +30,7 @@
 #include "ldr-internal.h"
 
 int
-_lw6ldr_bw_read (_lw6ldr_image_bw_t * image, const char *png_file,
-		 lw6sys_progress_t * progress)
+_lw6ldr_bw_read (lw6sys_context_t * sys_context, _lw6ldr_image_bw_t * image, const char *png_file, lw6sys_progress_t * progress)
 {
   png_structp png_ptr = NULL;
   png_infop info_ptr = NULL;
@@ -43,7 +42,7 @@ _lw6ldr_bw_read (_lw6ldr_image_bw_t * image, const char *png_file,
   int ret = 0;
   FILE *f = NULL;
 
-  lw6sys_progress_begin (progress);
+  lw6sys_progress_begin (sys_context, progress);
 
   png_ptr = png_create_read_struct (PNG_LIBPNG_VER_STRING, NULL, NULL, NULL);
   if (png_ptr)
@@ -74,15 +73,13 @@ _lw6ldr_bw_read (_lw6ldr_image_bw_t * image, const char *png_file,
 
 		  png_read_info (png_ptr, info_ptr);
 
-		  png_get_IHDR (png_ptr, info_ptr, &width, &height,
-				&bit_depth, &color_type, NULL, NULL, NULL);
+		  png_get_IHDR (png_ptr, info_ptr, &width, &height, &bit_depth, &color_type, NULL, NULL, NULL);
 
 		  png_set_expand (png_ptr);
 		  png_set_strip_16 (png_ptr);
 		  png_set_packswap (png_ptr);
 
-		  if (color_type == PNG_COLOR_TYPE_RGB ||
-		      color_type == PNG_COLOR_TYPE_RGB_ALPHA)
+		  if (color_type == PNG_COLOR_TYPE_RGB || color_type == PNG_COLOR_TYPE_RGB_ALPHA)
 		    {
 		      png_set_rgb_to_gray (png_ptr, 1, -1, -1);
 		    }
@@ -94,64 +91,46 @@ _lw6ldr_bw_read (_lw6ldr_image_bw_t * image, const char *png_file,
 
 		  png_read_update_info (png_ptr, info_ptr);
 
-		  png_get_IHDR (png_ptr, info_ptr, &width, &height,
-				&bit_depth, &color_type, NULL, NULL, NULL);
+		  png_get_IHDR (png_ptr, info_ptr, &width, &height, &bit_depth, &color_type, NULL, NULL, NULL);
 
 		  rowbytes = png_get_rowbytes (png_ptr, info_ptr);
 
-		  step = ((color_type & PNG_COLOR_MASK_COLOR) ? 3 : 1) +
-		    ((color_type & PNG_COLOR_MASK_ALPHA) ? 1 : 0);
+		  step = ((color_type & PNG_COLOR_MASK_COLOR) ? 3 : 1) + ((color_type & PNG_COLOR_MASK_ALPHA) ? 1 : 0);
 
 		  if (color_type & PNG_COLOR_MASK_PALETTE)
 		    {
-		      lw6sys_log (LW6SYS_LOG_WARNING,
-				  _x_
-				  ("can't load B&W PNG file \"%s\", it is still paletted after filtering"),
-				  png_file);
+		      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("can't load B&W PNG file \"%s\", it is still paletted after filtering"), png_file);
 		      format_ok = 0;
 		    }
 
-		  max_width =
-		    lw6sys_imax (LW6MAP_MAX_BODY_WIDTH,
-				 LW6MAP_MAX_TEXTURE_WIDTH);
-		  max_height =
-		    lw6sys_imax (LW6MAP_MAX_BODY_HEIGHT,
-				 LW6MAP_MAX_TEXTURE_HEIGHT);
+		  max_width = lw6sys_imax (LW6MAP_MAX_BODY_WIDTH, LW6MAP_MAX_TEXTURE_WIDTH);
+		  max_height = lw6sys_imax (LW6MAP_MAX_BODY_HEIGHT, LW6MAP_MAX_TEXTURE_HEIGHT);
 		  if (width > max_width || height > max_height)
 		    {
-		      lw6sys_log (LW6SYS_LOG_WARNING,
+		      lw6sys_log (sys_context, LW6SYS_LOG_WARNING,
 				  _x_
 				  ("can't load B&W PNG file \"%s\", it is too big (size=%dx%d max=%dx%d)"),
-				  png_file, (int) width, (int) height,
-				  max_width, max_height);
+				  png_file, (int) width, (int) height, max_width, max_height);
 		      format_ok = 0;
 		    }
 
 		  if (rowbytes != width * step || bit_depth > 8)
 		    {
-		      lw6sys_log (LW6SYS_LOG_WARNING,
+		      lw6sys_log (sys_context, LW6SYS_LOG_WARNING,
 				  _x_
 				  ("can't load B&W PNG file \"%s\", memory footprint is inconsistent, color_type=%d, rowbytes=%d, width=%d, step=%d, bit_depth=%d"),
-				  png_file, color_type,
-				  (int) rowbytes, (int) width, step,
-				  bit_depth);
+				  png_file, color_type, (int) rowbytes, (int) width, step, bit_depth);
 		      format_ok = 0;
 		    }
 
 		  if (format_ok)
 		    {
-		      buf =
-			(unsigned char **) LW6SYS_MALLOC (height *
-							  sizeof (unsigned
-								  char *));
+		      buf = (unsigned char **) LW6SYS_MALLOC (sys_context, height * sizeof (unsigned char *));
 		      if (buf)
 			{
 			  for (row = 0; row < height; ++row)
 			    {
-			      buf[row] =
-				(unsigned char *)
-				LW6SYS_MALLOC (rowbytes *
-					       sizeof (unsigned char));
+			      buf[row] = (unsigned char *) LW6SYS_MALLOC (sys_context, rowbytes * sizeof (unsigned char));
 			      if (!buf[row])
 				{
 				  memory_ok = 0;
@@ -165,9 +144,9 @@ _lw6ldr_bw_read (_lw6ldr_image_bw_t * image, const char *png_file,
 
 		      if (memory_ok)
 			{
-			  lw6sys_progress_update (progress, 0, 3, 1);
+			  lw6sys_progress_update (sys_context, progress, 0, 3, 1);
 			  png_read_image (png_ptr, buf);
-			  lw6sys_progress_update (progress, 0, 3, 2);
+			  lw6sys_progress_update (sys_context, progress, 0, 3, 2);
 			  png_read_end (png_ptr, end_info);
 
 			  image->w = width;
@@ -178,9 +157,7 @@ _lw6ldr_bw_read (_lw6ldr_image_bw_t * image, const char *png_file,
 			}
 		      else
 			{
-			  lw6sys_log (LW6SYS_LOG_WARNING,
-				      _x_
-				      ("unable to allocate memory for B&W PNG file"));
+			  lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("unable to allocate memory for B&W PNG file"));
 			}
 		    }
 
@@ -189,30 +166,27 @@ _lw6ldr_bw_read (_lw6ldr_image_bw_t * image, const char *png_file,
 	    }
 	  else
 	    {
-	      lw6sys_log (LW6SYS_LOG_WARNING,
-			  _x_ ("couldn't create png end info struct"));
+	      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("couldn't create png end info struct"));
 	    }
 	}
       else
 	{
-	  lw6sys_log (LW6SYS_LOG_WARNING,
-		      _x_ ("couldn't create png info struct"));
+	  lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("couldn't create png info struct"));
 	}
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING,
-		  _x_ ("couldn't create png read struct"));
+      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("couldn't create png read struct"));
     }
 
   png_destroy_read_struct (&png_ptr, &info_ptr, &end_info);
 
   if (!ret)
     {
-      _lw6ldr_bw_clear (image);
+      _lw6ldr_bw_clear (sys_context, image);
     }
 
-  lw6sys_progress_end (progress);
+  lw6sys_progress_end (sys_context, progress);
 
   return ret;
 }
@@ -221,7 +195,7 @@ _lw6ldr_bw_read (_lw6ldr_image_bw_t * image, const char *png_file,
  * Clear everything and free data pointers.
  */
 extern void
-_lw6ldr_bw_clear (_lw6ldr_image_bw_t * image)
+_lw6ldr_bw_clear (lw6sys_context_t * sys_context, _lw6ldr_image_bw_t * image)
 {
   int row;
 
@@ -231,17 +205,17 @@ _lw6ldr_bw_clear (_lw6ldr_image_bw_t * image)
 	{
 	  if (image->data[row])
 	    {
-	      LW6SYS_FREE (image->data[row]);
+	      LW6SYS_FREE (sys_context, image->data[row]);
 	    }
 	}
-      LW6SYS_FREE (image->data);
+      LW6SYS_FREE (sys_context, image->data);
     }
 
   memset (image, 0, sizeof (_lw6ldr_image_bw_t));
 }
 
 float
-_lw6ldr_bw_gray_level (_lw6ldr_image_bw_t * image)
+_lw6ldr_bw_gray_level (lw6sys_context_t * sys_context, _lw6ldr_image_bw_t * image)
 {
   int x, y, w, h;
   float ret = 0.0f;
@@ -269,16 +243,14 @@ _lw6ldr_bw_gray_level (_lw6ldr_image_bw_t * image)
   if (ret > 1.0f)
     {
       ret = 1.0f;
-      lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("gray_level=%f, can't be >1"),
-		  ret);
+      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("gray_level=%f, can't be >1"), ret);
     }
   if (ret < 0.0f)
     {
       ret = 0.0f;
-      lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("gray_level=%f, can't be <0"),
-		  ret);
+      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("gray_level=%f, can't be <0"), ret);
     }
-  lw6sys_log (LW6SYS_LOG_DEBUG, _x_ ("gray_level=%f"), ret);
+  lw6sys_log (sys_context, LW6SYS_LOG_DEBUG, _x_ ("gray_level=%f"), ret);
 
   return ret;
 }
