@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -49,22 +49,20 @@ typedef struct color_info_s
 } color_info_t;
 
 static int
-compare_color_info (const void *p1, const void *p2)
+_compare_color_info (const void *p1, const void *p2)
 {
   int ret = 0;
 
   color_info_t *c1 = (color_info_t *) p1;
   color_info_t *c2 = (color_info_t *) p2;
 
-  ret =
-    (c1->color_hsv.v > c2->color_hsv.v) - (c1->color_hsv.v < c2->color_hsv.v);
+  ret = (c1->color_hsv.v > c2->color_hsv.v) - (c1->color_hsv.v < c2->color_hsv.v);
 
   return ret;
 }
 
 static void
-average_color (color_info_t * ret, int size, color_info_t * color_info,
-	       float begin, float end)
+_average_color (lw6sys_context_t * sys_context, color_info_t * ret, int size, color_info_t * color_info, float begin, float end)
 {
   int i1, i2, n, i;
   lw6sys_color_8_t *buf = NULL;
@@ -77,32 +75,31 @@ average_color (color_info_t * ret, int size, color_info_t * color_info,
 
   if (n > 0)
     {
-      buf =
-	(lw6sys_color_8_t *) LW6SYS_MALLOC (n * sizeof (lw6sys_color_8_t));
+      buf = (lw6sys_color_8_t *) LW6SYS_MALLOC (sys_context, n * sizeof (lw6sys_color_8_t));
       if (buf)
 	{
 	  for (i = 0; i < n; ++i)
 	    {
 	      buf[i] = color_info[i1 + i].color_8;
 	    }
-	  ret->color_8 = lw6sys_color_average (n, buf);
-	  LW6SYS_FREE (buf);
+	  ret->color_8 = lw6sys_color_average (sys_context, n, buf);
+	  LW6SYS_FREE (sys_context, buf);
 	}
     }
 
-  lw6sys_color_rgb_to_hsv (&ret->color_hsv, ret->color_8);
+  lw6sys_color_rgb_to_hsv (sys_context, &ret->color_hsv, ret->color_8);
 }
 
 static void
-_set_to_invert (color_info_t * dst, color_info_t * src)
+_set_to_invert (lw6sys_context_t * sys_context, color_info_t * dst, color_info_t * src)
 {
   dst->color_hsv = src->color_hsv;
-  lw6sys_color_hsv_invert (&(dst->color_hsv), 1, 0, 0);
-  dst->color_8 = lw6sys_color_hsv_to_rgb (&(dst->color_hsv));
+  lw6sys_color_hsv_invert (sys_context, &(dst->color_hsv), 1, 0, 0);
+  dst->color_8 = lw6sys_color_hsv_to_rgb (sys_context, &(dst->color_hsv));
 }
 
 int
-_lw6ldr_guess_colors (lw6map_level_t * level, lw6sys_progress_t * progress)
+_lw6ldr_guess_colors (lw6sys_context_t * sys_context, lw6map_level_t * level, lw6sys_progress_t * progress)
 {
   int ret = 0;
   int x, y, i_bg = 0, i_fg = 0;
@@ -128,46 +125,32 @@ _lw6ldr_guess_colors (lw6map_level_t * level, lw6sys_progress_t * progress)
   float distance_base;
   float distance_alternate;
 
-  step =
-    lw6sys_imax (MIN_STEP,
-		 (int)
-		 sqrt ((((float) level->texture.w) *
-			((float) level->texture.h)) / (MAX_STEP_NB *
-						       MAX_STEP_NB)));
+  step = lw6sys_imax (MIN_STEP, (int) sqrt ((((float) level->texture.w) * ((float) level->texture.h)) / (MAX_STEP_NB * MAX_STEP_NB)));
   size = ((level->texture.w + 1) * (level->texture.h + 1)) / (step * step);
   if (size > 0)
     {
-      bg = (color_info_t *) LW6SYS_MALLOC (sizeof (color_info_t) * size);
+      bg = (color_info_t *) LW6SYS_MALLOC (sys_context, sizeof (color_info_t) * size);
       if (bg)
 	{
-	  fg = (color_info_t *) LW6SYS_MALLOC (sizeof (color_info_t) * size);
+	  fg = (color_info_t *) LW6SYS_MALLOC (sys_context, sizeof (color_info_t) * size);
 	  if (fg)
 	    {
-	      for (y = 0;
-		   y < level->texture.h && i_bg < size && i_fg < size;
-		   y += step)
+	      for (y = 0; y < level->texture.h && i_bg < size && i_fg < size; y += step)
 		{
-		  lw6sys_progress_update (progress, 0, level->texture.h, y);
-		  for (x = 0;
-		       x < level->texture.w && i_bg < size
-		       && i_fg < size; x += step)
+		  lw6sys_progress_update (sys_context, progress, 0, level->texture.h, y);
+		  for (x = 0; x < level->texture.w && i_bg < size && i_fg < size; x += step)
 		    {
-		      if (lw6map_body_get_with_texture_coord (level, x, y, 0)
-			  > 0)
+		      if (lw6map_body_get_with_texture_coord (sys_context, level, x, y, 0) > 0)
 			{
-			  bg[i_bg].color_8 =
-			    lw6map_texture_get (&level->texture, x, y);
-			  lw6sys_color_rgb_to_hsv (&(bg[i_bg].color_hsv),
-						   bg[i_bg].color_8);
+			  bg[i_bg].color_8 = lw6map_texture_get (&level->texture, x, y);
+			  lw6sys_color_rgb_to_hsv (sys_context, &(bg[i_bg].color_hsv), bg[i_bg].color_8);
 			  lw6sys_color_8_solid (&(bg[i_bg].color_8));
 			  i_bg++;
 			}
 		      else
 			{
-			  fg[i_fg].color_8 =
-			    lw6map_texture_get (&level->texture, x, y);
-			  lw6sys_color_rgb_to_hsv (&(fg[i_fg].color_hsv),
-						   fg[i_fg].color_8);
+			  fg[i_fg].color_8 = lw6map_texture_get (&level->texture, x, y);
+			  lw6sys_color_rgb_to_hsv (sys_context, &(fg[i_fg].color_hsv), fg[i_fg].color_8);
 			  lw6sys_color_8_solid (&(fg[i_fg].color_8));
 			  i_fg++;
 			}
@@ -176,48 +159,42 @@ _lw6ldr_guess_colors (lw6map_level_t * level, lw6sys_progress_t * progress)
 
 	      if (i_bg > 0)
 		{
-		  qsort (bg, i_bg, sizeof (color_info_t), compare_color_info);
-		  average_color (&global_bg, i_bg, bg, GLOBAL_BEGIN,
-				 GLOBAL_END);
-		  average_color (&dark_bg, i_bg, bg, DARK_BEGIN, DARK_END);
-		  average_color (&light_bg, i_bg, bg, LIGHT_BEGIN, LIGHT_END);
+		  qsort (bg, i_bg, sizeof (color_info_t), _compare_color_info);
+		  _average_color (sys_context, &global_bg, i_bg, bg, GLOBAL_BEGIN, GLOBAL_END);
+		  _average_color (sys_context, &dark_bg, i_bg, bg, DARK_BEGIN, DARK_END);
+		  _average_color (sys_context, &light_bg, i_bg, bg, LIGHT_BEGIN, LIGHT_END);
 		  ok_bg = 1;
 		}
 	      else
 		{
-		  lw6sys_log (LW6SYS_LOG_INFO,
-			      _x_
-			      ("no background color found, unable to guess color"));
+		  lw6sys_log (sys_context, LW6SYS_LOG_INFO, _x_ ("no background color found, unable to guess color"));
 		}
 	      if (i_fg > 0)
 		{
-		  qsort (fg, i_fg, sizeof (color_info_t), compare_color_info);
-		  average_color (&global_fg, i_fg, fg, GLOBAL_BEGIN,
-				 GLOBAL_END);
-		  average_color (&dark_fg, i_fg, fg, DARK_BEGIN, DARK_END);
-		  average_color (&light_fg, i_fg, fg, LIGHT_BEGIN, LIGHT_END);
+		  qsort (fg, i_fg, sizeof (color_info_t), _compare_color_info);
+		  _average_color (sys_context, &global_fg, i_fg, fg, GLOBAL_BEGIN, GLOBAL_END);
+		  _average_color (sys_context, &dark_fg, i_fg, fg, DARK_BEGIN, DARK_END);
+		  _average_color (sys_context, &light_fg, i_fg, fg, LIGHT_BEGIN, LIGHT_END);
 		  ok_fg = 1;
 		}
 	      else
 		{
-		  lw6sys_log (LW6SYS_LOG_INFO,
-			      _x_
-			      ("no foreground color found, unable to guess color"));
+		  lw6sys_log (sys_context, LW6SYS_LOG_INFO, _x_ ("no foreground color found, unable to guess color"));
 		}
 
 	      if (ok_fg && !ok_bg)
 		{
-		  _set_to_invert (&global_bg, &global_fg);
-		  _set_to_invert (&dark_bg, &dark_fg);
-		  _set_to_invert (&light_bg, &light_fg);
+		  _set_to_invert (sys_context, &global_bg, &global_fg);
+		  _set_to_invert (sys_context, &dark_bg, &dark_fg);
+		  _set_to_invert (sys_context, &light_bg, &light_fg);
 		  ok_bg = 1;
 		}
 
 	      if (ok_bg && !ok_fg)
 		{
-		  _set_to_invert (&global_fg, &global_bg);
-		  _set_to_invert (&dark_fg, &dark_bg);
-		  _set_to_invert (&light_fg, &light_bg);
+		  _set_to_invert (sys_context, &global_fg, &global_bg);
+		  _set_to_invert (sys_context, &dark_fg, &dark_bg);
+		  _set_to_invert (sys_context, &light_fg, &light_bg);
 		  ok_fg = 1;
 		}
 
@@ -225,21 +202,14 @@ _lw6ldr_guess_colors (lw6map_level_t * level, lw6sys_progress_t * progress)
 		{
 		  ret = 1;
 		  distance_regular = lw6sys_imin (lw6sys_color_distance
-						  (light_bg.color_8,
-						   light_fg.color_8),
-						  lw6sys_color_distance
-						  (dark_bg.color_8,
-						   dark_fg.color_8));
-		  distance_goofy = lw6sys_imin (lw6sys_color_distance
-						(light_bg.color_8,
-						 dark_fg.color_8),
-						lw6sys_color_distance
-						(dark_bg.color_8,
-						 light_fg.color_8));
+						  (sys_context, light_bg.color_8, light_fg.color_8), lw6sys_color_distance (sys_context, dark_bg.color_8,
+															    dark_fg.color_8));
+		  distance_goofy =
+		    lw6sys_imin (lw6sys_color_distance (sys_context, light_bg.color_8, dark_fg.color_8),
+				 lw6sys_color_distance (sys_context, dark_bg.color_8, light_fg.color_8));
 		  base_bg = dark_bg;
 		  alternate_bg = light_bg;
-		  if (distance_regular <
-		      distance_goofy * SWAP_REGULAR_GOOFY_MAJ)
+		  if (distance_regular < distance_goofy * SWAP_REGULAR_GOOFY_MAJ)
 		    {
 		      base_fg = dark_fg;
 		      alternate_fg = light_fg;
@@ -280,13 +250,9 @@ _lw6ldr_guess_colors (lw6map_level_t * level, lw6sys_progress_t * progress)
 			}
 		    }
 
-		  distance_base =
-		    lw6sys_color_distance (base_bg.color_8, base_fg.color_8);
-		  distance_alternate =
-		    lw6sys_color_distance (alternate_bg.color_8,
-					   alternate_fg.color_8);
-		  if (distance_base >
-		      distance_alternate * SWAP_BASE_ALTERNATE_MAJ)
+		  distance_base = lw6sys_color_distance (sys_context, base_bg.color_8, base_fg.color_8);
+		  distance_alternate = lw6sys_color_distance (sys_context, alternate_bg.color_8, alternate_fg.color_8);
+		  if (distance_base > distance_alternate * SWAP_BASE_ALTERNATE_MAJ)
 		    {
 		      tmp = base_bg;
 		      base_bg = alternate_bg;
@@ -298,40 +264,29 @@ _lw6ldr_guess_colors (lw6map_level_t * level, lw6sys_progress_t * progress)
 
 		  if (alternate_bg.color_hsv.v > alternate_fg.color_hsv.v)
 		    {
-		      alternate_bg.color_hsv.v =
-			1.0f -
-			(LIGHTER_COEF * (1.0f - alternate_bg.color_hsv.v));
-		      alternate_fg.color_hsv.v =
-			DARKER_COEF * alternate_fg.color_hsv.v;
+		      alternate_bg.color_hsv.v = 1.0f - (LIGHTER_COEF * (1.0f - alternate_bg.color_hsv.v));
+		      alternate_fg.color_hsv.v = DARKER_COEF * alternate_fg.color_hsv.v;
 		    }
 		  else
 		    {
-		      alternate_bg.color_hsv.v =
-			DARKER_COEF * alternate_bg.color_hsv.v;
-		      alternate_fg.color_hsv.v =
-			1.0f -
-			(LIGHTER_COEF * (1.0f - alternate_fg.color_hsv.v));
+		      alternate_bg.color_hsv.v = DARKER_COEF * alternate_bg.color_hsv.v;
+		      alternate_fg.color_hsv.v = 1.0f - (LIGHTER_COEF * (1.0f - alternate_fg.color_hsv.v));
 		    }
-		  alternate_bg.color_8 =
-		    lw6sys_color_hsv_to_rgb (&alternate_bg.color_hsv);
-		  alternate_fg.color_8 =
-		    lw6sys_color_hsv_to_rgb (&alternate_fg.color_hsv);
+		  alternate_bg.color_8 = lw6sys_color_hsv_to_rgb (sys_context, &alternate_bg.color_hsv);
+		  alternate_fg.color_8 = lw6sys_color_hsv_to_rgb (sys_context, &alternate_fg.color_hsv);
 
 		  level->texture.guessed_color_base.bg = base_bg.color_8;
 		  level->texture.guessed_color_base.fg = base_fg.color_8;
-		  level->texture.guessed_color_alternate.bg =
-		    alternate_bg.color_8;
-		  level->texture.guessed_color_alternate.fg =
-		    alternate_fg.color_8;
+		  level->texture.guessed_color_alternate.bg = alternate_bg.color_8;
+		  level->texture.guessed_color_alternate.fg = alternate_fg.color_8;
 		}
 	      else
 		{
-		  lw6sys_log (LW6SYS_LOG_WARNING,
-			      _x_ ("unable to guess colors"));
+		  lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("unable to guess colors"));
 		}
-	      LW6SYS_FREE (fg);
+	      LW6SYS_FREE (sys_context, fg);
 	    }
-	  LW6SYS_FREE (bg);
+	  LW6SYS_FREE (sys_context, bg);
 	}
     }
 
@@ -339,11 +294,10 @@ _lw6ldr_guess_colors (lw6map_level_t * level, lw6sys_progress_t * progress)
 }
 
 void
-_lw6ldr_apply_guessed_colors (lw6map_level_t * level)
+_lw6ldr_apply_guessed_colors (lw6sys_context_t * sys_context, lw6map_level_t * level)
 {
   level->param.style.color_set.color_base = level->texture.guessed_color_base;
-  level->param.style.color_set.color_alternate =
-    level->texture.guessed_color_alternate;
+  level->param.style.color_set.color_alternate = level->texture.guessed_color_alternate;
 }
 
 /**
@@ -361,13 +315,12 @@ _lw6ldr_apply_guessed_colors (lw6map_level_t * level)
  * Return value: none.
  */
 void
-lw6ldr_auto_colors (lw6map_style_t * style, const lw6ldr_hints_t * hints)
+lw6ldr_auto_colors (lw6sys_context_t * sys_context, lw6map_style_t * style, const lw6ldr_hints_t * hints)
 {
   if (hints->background_color_auto)
     {
       style->color_set.background_color_root = style->color_set.color_base;
-      style->color_set.background_color_stuff =
-	style->color_set.color_alternate;
+      style->color_set.background_color_stuff = style->color_set.color_alternate;
     }
 
   if (hints->hud_color_auto)
@@ -380,7 +333,7 @@ lw6ldr_auto_colors (lw6map_style_t * style, const lw6ldr_hints_t * hints)
     {
       style->color_set.menu_color_default = style->color_set.color_alternate;
       style->color_set.menu_color_selected = style->color_set.color_alternate;
-      lw6map_color_invert (&style->color_set.menu_color_selected);
+      lw6map_color_invert (sys_context, &style->color_set.menu_color_selected);
       style->color_set.menu_color_disabled = style->color_set.color_base;
     }
 
