@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -30,6 +30,7 @@
 /**
  * lw6ldr_cursor_texture_read
  *
+ * @sys_context: global system context
  * @cursor_texture: the cursor texture (out param)
  * @dirname: the directory we load the data form (map dir)
  *
@@ -38,50 +39,40 @@
  * Return value: 1 on success, 0 on failure.
  */
 int
-lw6ldr_cursor_texture_read (lw6map_cursor_texture_t * cursor_texture,
-			    const char *dirname)
+lw6ldr_cursor_texture_read (lw6sys_context_t * sys_context, lw6map_cursor_texture_t * cursor_texture, const char *dirname)
 {
   int ret = 1;
   int found = 0;
   char *cursor_dot_png;
   char *cursor_color_dot_png;
 
-  lw6map_cursor_texture_clear (cursor_texture);
+  lw6map_cursor_texture_clear (sys_context, cursor_texture);
 
-  cursor_dot_png = lw6sys_path_concat (dirname, _LW6LDR_FILE_CURSOR_PNG);
+  cursor_dot_png = lw6sys_path_concat (sys_context, dirname, _LW6LDR_FILE_CURSOR_PNG);
   if (cursor_dot_png)
     {
-      if (lw6sys_file_exists (cursor_dot_png))
+      if (lw6sys_file_exists (sys_context, cursor_dot_png))
 	{
 	  found = 1;
-	  ret = ret
-	    &&
-	    _lw6ldr_cursor_texture_layer_read_png (&
-						   (cursor_texture->fg_bg_layer),
-						   cursor_dot_png);
+	  ret = ret && _lw6ldr_cursor_texture_layer_read_png (sys_context, &(cursor_texture->fg_bg_layer), cursor_dot_png);
 	}
-      LW6SYS_FREE (cursor_dot_png);
+      LW6SYS_FREE (sys_context, cursor_dot_png);
     }
 
-  cursor_color_dot_png =
-    lw6sys_path_concat (dirname, _LW6LDR_FILE_CURSOR_COLOR_PNG);
+  cursor_color_dot_png = lw6sys_path_concat (sys_context, dirname, _LW6LDR_FILE_CURSOR_COLOR_PNG);
   if (cursor_color_dot_png)
     {
-      if (lw6sys_file_exists (cursor_color_dot_png))
+      if (lw6sys_file_exists (sys_context, cursor_color_dot_png))
 	{
 	  found = 1;
-	  ret = ret
-	    &&
-	    _lw6ldr_cursor_texture_layer_read_png (&
-						   (cursor_texture->color_layer),
-						   cursor_color_dot_png);
+	  ret = ret && _lw6ldr_cursor_texture_layer_read_png (sys_context, &(cursor_texture->color_layer), cursor_color_dot_png);
 	}
-      LW6SYS_FREE (cursor_color_dot_png);
+      LW6SYS_FREE (sys_context, cursor_color_dot_png);
     }
 
   if (!found)
     {
-      lw6map_cursor_texture_builtin (cursor_texture);
+      lw6map_cursor_texture_builtin (sys_context, cursor_texture);
     }
 
   return ret;
