@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -28,13 +28,11 @@
 #include "ldr-internal.h"
 
 static int
-read_image (lw6map_cursor_texture_layer_t * cursor_texture_layer,
-	    _lw6ldr_image_rgba_t * image)
+_read_image (lw6sys_context_t * sys_context, lw6map_cursor_texture_layer_t * cursor_texture_layer, _lw6ldr_image_rgba_t * image)
 {
   int ret = 0;
 
-  if (image->w == LW6MAP_CURSOR_TEXTURE_SIZE &&
-      image->h == LW6MAP_CURSOR_TEXTURE_SIZE)
+  if (image->w == LW6MAP_CURSOR_TEXTURE_SIZE && image->h == LW6MAP_CURSOR_TEXTURE_SIZE)
     {
       int row, col;
       lw6sys_color_8_t value;
@@ -48,8 +46,7 @@ read_image (lw6map_cursor_texture_layer_t * cursor_texture_layer,
 	      value.b = image->data[row][col * 4 + 2];
 	      value.a = image->data[row][col * 4 + 3];
 
-	      lw6map_cursor_texture_layer_set (cursor_texture_layer, col, row,
-					       value);
+	      lw6map_cursor_texture_layer_set (sys_context, cursor_texture_layer, col, row, value);
 	    }
 	}
 
@@ -57,34 +54,28 @@ read_image (lw6map_cursor_texture_layer_t * cursor_texture_layer,
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING,
-		  _x_
-		  ("bad cursor texture layer size %dx%d, should be %dx%d"),
-		  image->w, image->h, LW6MAP_CURSOR_TEXTURE_SIZE,
-		  LW6MAP_CURSOR_TEXTURE_SIZE);
+      lw6sys_log (sys_context, LW6SYS_LOG_WARNING,
+		  _x_ ("bad cursor texture layer size %dx%d, should be %dx%d"), image->w, image->h, LW6MAP_CURSOR_TEXTURE_SIZE, LW6MAP_CURSOR_TEXTURE_SIZE);
     }
 
-  _lw6ldr_rgba_clear (image);
+  _lw6ldr_rgba_clear (sys_context, image);
 
   return ret;
 }
 
 int
-_lw6ldr_cursor_texture_layer_read_png (lw6map_cursor_texture_layer_t *
-				       cursor_texture_layer,
-				       const char *png_file)
+_lw6ldr_cursor_texture_layer_read_png (lw6sys_context_t * sys_context, lw6map_cursor_texture_layer_t * cursor_texture_layer, const char *png_file)
 {
   int ret = 0;
   _lw6ldr_image_rgba_t image;
 
-  lw6sys_log (LW6SYS_LOG_INFO,
-	      _x_ ("reading PNG cursor texture layer \"%s\""), png_file);
+  lw6sys_log (sys_context, LW6SYS_LOG_INFO, _x_ ("reading PNG cursor texture layer \"%s\""), png_file);
 
   memset (&image, 0, sizeof (_lw6ldr_image_rgba_t));
 
-  if (_lw6ldr_rgba_read_png (&image, png_file, NULL))
+  if (_lw6ldr_rgba_read_png (sys_context, &image, png_file, NULL))
     {
-      ret = read_image (cursor_texture_layer, &image);
+      ret = _read_image (sys_context, cursor_texture_layer, &image);
     }
 
   return ret;
