@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -57,8 +57,7 @@ typedef int _grease_table_t[_NB_GREASE_CONFIGURATIONS];
  * -> grease 4 : add the opposite squares configuration (5,a)
  * -> grease 5 : add "only 1 squares arround me" cases (1,2,4,8)
  */
-static _grease_table_t _GREASE_TABLES[LW6LDR_HINTS_MAX_WALL_GREASE] =
-  { {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1},
+static _grease_table_t _GREASE_TABLES[LW6LDR_HINTS_MAX_WALL_GREASE] = { {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1},
 {0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 1, 0, 1, 1, 1},
 {0, 0, 0, 1, 0, 0, 1, 1, 0, 1, 0, 1, 1, 1, 1, 1},
 {0, 0, 0, 1, 0, 1, 1, 1, 0, 1, 1, 1, 1, 1, 1, 1},
@@ -66,8 +65,7 @@ static _grease_table_t _GREASE_TABLES[LW6LDR_HINTS_MAX_WALL_GREASE] =
 };
 
 static int
-_do_grease (lw6map_layer_t * layer, const lw6map_rules_t * rules,
-	    _grease_table_t grease_table, int mode,
+_do_grease (lw6sys_context_t * sys_context, lw6map_layer_t * layer, const lw6map_rules_t * rules, _grease_table_t grease_table, int mode,
 	    lw6sys_progress_t * progress)
 {
   int ret = 0;
@@ -81,7 +79,7 @@ _do_grease (lw6map_layer_t * layer, const lw6map_rules_t * rules,
   tmp.shape = layer->shape;
 
   size = shape.w * shape.h * sizeof (u_int8_t);
-  tmp.data = LW6SYS_MALLOC (size);
+  tmp.data = LW6SYS_MALLOC (sys_context, size);
   if (tmp.data)
     {
       memcpy (tmp.data, layer->data, size);
@@ -167,7 +165,7 @@ _do_grease (lw6map_layer_t * layer, const lw6map_rules_t * rules,
 	    }
 	}
       ret = 1;
-      LW6SYS_FREE (tmp.data);
+      LW6SYS_FREE (sys_context, tmp.data);
     }
 
   return ret;
@@ -176,6 +174,7 @@ _do_grease (lw6map_layer_t * layer, const lw6map_rules_t * rules,
 /**
  * lw6ldr_grease_apply
  *
+ * @sys_context: global system context
  * @layer: the layer on which to apply the grease
  * @rules: map rules
  * @hints: map hints
@@ -186,9 +185,7 @@ _do_grease (lw6map_layer_t * layer, const lw6map_rules_t * rules,
  * Return value: 1 if OK, 0 if failed.
  */
 int
-lw6ldr_grease_apply (lw6map_layer_t * layer,
-		     const lw6map_rules_t * rules,
-		     const lw6ldr_hints_t * hints,
+lw6ldr_grease_apply (lw6sys_context_t * sys_context, lw6map_layer_t * layer, const lw6map_rules_t * rules, const lw6ldr_hints_t * hints,
 		     lw6sys_progress_t * progress)
 {
   int ret = 0;
@@ -196,29 +193,21 @@ lw6ldr_grease_apply (lw6map_layer_t * layer,
 
   if (hints->wall_grease == 0)
     {
-      lw6sys_log (LW6SYS_LOG_DEBUG, _x_ ("grease==0, nothing to do"));
+      lw6sys_log (sys_context, LW6SYS_LOG_DEBUG, _x_ ("grease==0, nothing to do"));
     }
   else
     {
       if (hints->wall_grease > 0)
 	{
-	  i =
-	    lw6sys_imin (hints->wall_grease - 1,
-			 LW6LDR_HINTS_MAX_WALL_GREASE - 1);
-	  lw6sys_log (LW6SYS_LOG_DEBUG,
-		      _x_ ("positive grease %d using table %d"),
-		      hints->wall_grease, i);
-	  _do_grease (layer, rules, _GREASE_TABLES[i], 0, progress);
+	  i = lw6sys_imin (hints->wall_grease - 1, LW6LDR_HINTS_MAX_WALL_GREASE - 1);
+	  lw6sys_log (sys_context, LW6SYS_LOG_DEBUG, _x_ ("positive grease %d using table %d"), hints->wall_grease, i);
+	  _do_grease (sys_context, layer, rules, _GREASE_TABLES[i], 0, progress);
 	}
       else
 	{
-	  i =
-	    lw6sys_imin (-hints->wall_grease - 1,
-			 LW6LDR_HINTS_MAX_WALL_GREASE - 1);
-	  lw6sys_log (LW6SYS_LOG_DEBUG,
-		      _x_ ("negative grease %d using table %d"),
-		      hints->wall_grease, i);
-	  _do_grease (layer, rules, _GREASE_TABLES[i], 1, progress);
+	  i = lw6sys_imin (-hints->wall_grease - 1, LW6LDR_HINTS_MAX_WALL_GREASE - 1);
+	  lw6sys_log (sys_context, LW6SYS_LOG_DEBUG, _x_ ("negative grease %d using table %d"), hints->wall_grease, i);
+	  _do_grease (sys_context, layer, rules, _GREASE_TABLES[i], 1, progress);
 	}
     }
 
