@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -39,6 +39,7 @@ hints_update_data_t;
 /**
  * lw6ldr_hints_defaults
  *
+ * @sys_context: global system context
  * @hints: data to initialize
  *
  * Set the hints struct to its defaults.
@@ -46,7 +47,7 @@ hints_update_data_t;
  * Return value: none.
  */
 void
-lw6ldr_hints_defaults (lw6ldr_hints_t * hints)
+lw6ldr_hints_defaults (lw6sys_context_t * sys_context, lw6ldr_hints_t * hints)
 {
   hints->resample = LW6LDR_HINTS_DEFAULT_RESAMPLE;
   hints->min_map_width = LW6LDR_HINTS_DEFAULT_MIN_MAP_WIDTH;
@@ -56,14 +57,10 @@ lw6ldr_hints_defaults (lw6ldr_hints_t * hints)
   hints->min_map_surface = LW6LDR_HINTS_DEFAULT_MIN_MAP_SURFACE;
   hints->max_map_surface = LW6LDR_HINTS_DEFAULT_MAX_MAP_SURFACE;
   hints->fighter_scale = LW6LDR_HINTS_DEFAULT_FIGHTER_SCALE;
-  hints->downsize_using_fighter_scale =
-    LW6LDR_HINTS_DEFAULT_DOWNSIZE_USING_FIGHTER_SCALE;
-  hints->upsize_using_fighter_scale =
-    LW6LDR_HINTS_DEFAULT_UPSIZE_USING_FIGHTER_SCALE;
-  hints->downsize_using_bench_value =
-    LW6LDR_HINTS_DEFAULT_DOWNSIZE_USING_BENCH_VALUE;
-  hints->upsize_using_bench_value =
-    LW6LDR_HINTS_DEFAULT_UPSIZE_USING_BENCH_VALUE;
+  hints->downsize_using_fighter_scale = LW6LDR_HINTS_DEFAULT_DOWNSIZE_USING_FIGHTER_SCALE;
+  hints->upsize_using_fighter_scale = LW6LDR_HINTS_DEFAULT_UPSIZE_USING_FIGHTER_SCALE;
+  hints->downsize_using_bench_value = LW6LDR_HINTS_DEFAULT_DOWNSIZE_USING_BENCH_VALUE;
+  hints->upsize_using_bench_value = LW6LDR_HINTS_DEFAULT_UPSIZE_USING_BENCH_VALUE;
   hints->guess_colors = LW6LDR_HINTS_DEFAULT_GUESS_COLORS;
   hints->background_color_auto = LW6LDR_HINTS_DEFAULT_BACKGROUND_COLOR_AUTO;
   hints->hud_color_auto = LW6LDR_HINTS_DEFAULT_HUD_COLOR_AUTO;
@@ -78,6 +75,7 @@ lw6ldr_hints_defaults (lw6ldr_hints_t * hints)
 /**
  * lw6ldr_hints_zero
  *
+ * @sys_context: global system context
  * @hints: data to initialize
  *
  * Zeros the hints struct, this is not the same as setting to defaults.
@@ -85,7 +83,7 @@ lw6ldr_hints_defaults (lw6ldr_hints_t * hints)
  * Return value: none.
  */
 void
-lw6ldr_hints_zero (lw6ldr_hints_t * hints)
+lw6ldr_hints_zero (lw6sys_context_t * sys_context, lw6ldr_hints_t * hints)
 {
   memset (hints, 0, sizeof (lw6ldr_hints_t));
 }
@@ -93,6 +91,7 @@ lw6ldr_hints_zero (lw6ldr_hints_t * hints)
 /**
  * lw6ldr_hints_clear
  *
+ * @sys_context: global system context
  * @hints: data to initialize
  *
  * Clears the hints struct, this is not the same as setting to defaults.
@@ -100,25 +99,25 @@ lw6ldr_hints_zero (lw6ldr_hints_t * hints)
  * Return value: none.
  */
 void
-lw6ldr_hints_clear (lw6ldr_hints_t * hints)
+lw6ldr_hints_clear (lw6sys_context_t * sys_context, lw6ldr_hints_t * hints)
 {
-  lw6ldr_hints_zero (hints);
+  lw6ldr_hints_zero (sys_context, hints);
 }
 
 static void
-read_callback (void *callback_data, const char *element, const char *key,
-	       const char *value)
+_read_callback (lw6sys_context_t * sys_context, void *callback_data, const char *element, const char *key, const char *value)
 {
   lw6ldr_hints_t *hints_data;
 
   hints_data = (lw6ldr_hints_t *) callback_data;
 
-  lw6ldr_hints_set (hints_data, key, value);
+  lw6ldr_hints_set (sys_context, hints_data, key, value);
 }
 
 /**
  * lw6ldr_hints_read
  *
+ * @sys_context: global system context
  * @param: the hints struct to fill with values (read/write parameter)
  * @dirname: the directory of the map
  *
@@ -129,21 +128,19 @@ read_callback (void *callback_data, const char *element, const char *key,
  * Return value: 1 if success, 0 if failed.
  */
 int
-lw6ldr_hints_read (lw6ldr_hints_t * hints, const char *dirname)
+lw6ldr_hints_read (lw6sys_context_t * sys_context, lw6ldr_hints_t * hints, const char *dirname)
 {
   int ret = 0;
   char *buf = NULL;
 
-  buf = lw6sys_path_concat (dirname, _LW6LDR_FILE_HINTS_XML);
+  buf = lw6sys_path_concat (sys_context, dirname, _LW6LDR_FILE_HINTS_XML);
 
   if (buf)
     {
-      if (lw6sys_file_exists (buf))
+      if (lw6sys_file_exists (sys_context, buf))
 	{
-	  lw6sys_log (LW6SYS_LOG_INFO, _x_ ("reading hints \"%s\""), buf);
-	  ret =
-	    lw6cfg_read_key_value_xml_file (buf, read_callback,
-					    (void *) hints);
+	  lw6sys_log (sys_context, LW6SYS_LOG_INFO, _x_ ("reading hints \"%s\""), buf);
+	  ret = lw6cfg_read_key_value_xml_file (sys_context, buf, _read_callback, (void *) hints);
 	}
       else
 	{
@@ -151,12 +148,12 @@ lw6ldr_hints_read (lw6ldr_hints_t * hints, const char *dirname)
 	  ret = 1;
 	}
 
-      LW6SYS_FREE (buf);
+      LW6SYS_FREE (sys_context, buf);
     }
 
   if (!ret)
     {
-      lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("unable to read map hints"));
+      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("unable to read map hints"));
     }
 
   return ret;
@@ -165,6 +162,7 @@ lw6ldr_hints_read (lw6ldr_hints_t * hints, const char *dirname)
 /**
  * lw6ldr_hints_set
  *
+ * @sys_context: global system context
  * @hints: the hints to modify
  * @key: the key to modify
  * @value: the value to affect to the key, as a string
@@ -178,103 +176,103 @@ lw6ldr_hints_read (lw6ldr_hints_t * hints, const char *dirname)
  * needs to be worked on.
  */
 int
-lw6ldr_hints_set (lw6ldr_hints_t * hints, const char *key, const char *value)
+lw6ldr_hints_set (lw6sys_context_t * sys_context, lw6ldr_hints_t * hints, const char *key, const char *value)
 {
   int ret = 1;
   char *formatted_key = NULL;
 
-  formatted_key = lw6sys_keyword_as_key (key);
+  formatted_key = lw6sys_keyword_as_key (sys_context, key);
   if (formatted_key)
     {
       if (!strcmp (LW6DEF_RESAMPLE, formatted_key))
 	{
-	  hints->resample = lw6sys_atob (value);
+	  hints->resample = lw6sys_atob (sys_context, value);
 	}
       else if (!strcmp (LW6DEF_MIN_MAP_WIDTH, formatted_key))
 	{
-	  hints->min_map_width = lw6sys_atoi (value);
+	  hints->min_map_width = lw6sys_atoi (sys_context, value);
 	}
       else if (!strcmp (LW6DEF_MAX_MAP_WIDTH, formatted_key))
 	{
-	  hints->max_map_width = lw6sys_atoi (value);
+	  hints->max_map_width = lw6sys_atoi (sys_context, value);
 	}
       else if (!strcmp (LW6DEF_MIN_MAP_HEIGHT, formatted_key))
 	{
-	  hints->min_map_height = lw6sys_atoi (value);
+	  hints->min_map_height = lw6sys_atoi (sys_context, value);
 	}
       else if (!strcmp (LW6DEF_MAX_MAP_HEIGHT, formatted_key))
 	{
-	  hints->max_map_height = lw6sys_atoi (value);
+	  hints->max_map_height = lw6sys_atoi (sys_context, value);
 	}
       else if (!strcmp (LW6DEF_MIN_MAP_SURFACE, formatted_key))
 	{
-	  hints->min_map_surface = lw6sys_atoi (value);
+	  hints->min_map_surface = lw6sys_atoi (sys_context, value);
 	}
       else if (!strcmp (LW6DEF_MAX_MAP_SURFACE, formatted_key))
 	{
-	  hints->max_map_surface = lw6sys_atoi (value);
+	  hints->max_map_surface = lw6sys_atoi (sys_context, value);
 	}
       else if (!strcmp (LW6DEF_FIGHTER_SCALE, formatted_key))
 	{
-	  hints->fighter_scale = lw6sys_atof (value);
+	  hints->fighter_scale = lw6sys_atof (sys_context, value);
 	}
       else if (!strcmp (LW6DEF_DOWNSIZE_USING_FIGHTER_SCALE, formatted_key))
 	{
-	  hints->downsize_using_fighter_scale = lw6sys_atob (value);
+	  hints->downsize_using_fighter_scale = lw6sys_atob (sys_context, value);
 	}
       else if (!strcmp (LW6DEF_UPSIZE_USING_FIGHTER_SCALE, formatted_key))
 	{
-	  hints->upsize_using_fighter_scale = lw6sys_atob (value);
+	  hints->upsize_using_fighter_scale = lw6sys_atob (sys_context, value);
 	}
       else if (!strcmp (LW6DEF_DOWNSIZE_USING_BENCH_VALUE, formatted_key))
 	{
-	  hints->downsize_using_bench_value = lw6sys_atob (value);
+	  hints->downsize_using_bench_value = lw6sys_atob (sys_context, value);
 	}
       else if (!strcmp (LW6DEF_UPSIZE_USING_BENCH_VALUE, formatted_key))
 	{
-	  hints->upsize_using_bench_value = lw6sys_atob (value);
+	  hints->upsize_using_bench_value = lw6sys_atob (sys_context, value);
 	}
       else if (!strcmp (LW6DEF_GUESS_COLORS, formatted_key))
 	{
-	  hints->guess_colors = lw6sys_atob (value);
+	  hints->guess_colors = lw6sys_atob (sys_context, value);
 	}
       else if (!strcmp (LW6DEF_BACKGROUND_COLOR_AUTO, formatted_key))
 	{
-	  hints->background_color_auto = lw6sys_atob (value);
+	  hints->background_color_auto = lw6sys_atob (sys_context, value);
 	}
       else if (!strcmp (LW6DEF_HUD_COLOR_AUTO, formatted_key))
 	{
-	  hints->hud_color_auto = lw6sys_atob (value);
+	  hints->hud_color_auto = lw6sys_atob (sys_context, value);
 	}
       else if (!strcmp (LW6DEF_MENU_COLOR_AUTO, formatted_key))
 	{
-	  hints->menu_color_auto = lw6sys_atob (value);
+	  hints->menu_color_auto = lw6sys_atob (sys_context, value);
 	}
       else if (!strcmp (LW6DEF_VIEW_COLOR_AUTO, formatted_key))
 	{
-	  hints->view_color_auto = lw6sys_atob (value);
+	  hints->view_color_auto = lw6sys_atob (sys_context, value);
 	}
       else if (!strcmp (LW6DEF_SYSTEM_COLOR_AUTO, formatted_key))
 	{
-	  hints->system_color_auto = lw6sys_atob (value);
+	  hints->system_color_auto = lw6sys_atob (sys_context, value);
 	}
       else if (!strcmp (LW6DEF_WALL_GREASE, formatted_key))
 	{
-	  hints->wall_grease = lw6sys_atoi (value);
+	  hints->wall_grease = lw6sys_atoi (sys_context, value);
 	}
       else if (!strcmp (LW6DEF_GUESS_MOVES_PER_SEC, formatted_key))
 	{
-	  hints->guess_moves_per_sec = lw6sys_atob (value);
+	  hints->guess_moves_per_sec = lw6sys_atob (sys_context, value);
 	}
       else if (!strcmp (LW6DEF_SPEED, formatted_key))
 	{
-	  hints->speed = lw6sys_atof (value);
+	  hints->speed = lw6sys_atof (sys_context, value);
 	}
       else
 	{
 	  ret = 0;
 	}
-      LW6SYS_FREE (formatted_key);
+      LW6SYS_FREE (sys_context, formatted_key);
     }
   else
     {
@@ -287,6 +285,7 @@ lw6ldr_hints_set (lw6ldr_hints_t * hints, const char *key, const char *value)
 /**
  * lw6ldr_hints_get
  *
+ * @sys_context: global system context
  * @hints: the hints to modify
  * @key: the key to modify
  *
@@ -296,99 +295,99 @@ lw6ldr_hints_set (lw6ldr_hints_t * hints, const char *key, const char *value)
  * Return value: dynamically allocated string, NULL on error.
  */
 char *
-lw6ldr_hints_get (const lw6ldr_hints_t * hints, const char *key)
+lw6ldr_hints_get (lw6sys_context_t * sys_context, const lw6ldr_hints_t * hints, const char *key)
 {
   char *ret = NULL;
   char *formatted_key = NULL;
 
-  formatted_key = lw6sys_keyword_as_key (key);
+  formatted_key = lw6sys_keyword_as_key (sys_context, key);
   if (formatted_key)
     {
       if (!strcmp (LW6DEF_RESAMPLE, formatted_key))
 	{
-	  ret = lw6sys_btoa (hints->resample);
+	  ret = lw6sys_btoa (sys_context, hints->resample);
 	}
       else if (!strcmp (LW6DEF_MIN_MAP_WIDTH, formatted_key))
 	{
-	  ret = lw6sys_itoa (hints->min_map_width);
+	  ret = lw6sys_itoa (sys_context, hints->min_map_width);
 	}
       else if (!strcmp (LW6DEF_MAX_MAP_WIDTH, formatted_key))
 	{
-	  ret = lw6sys_itoa (hints->max_map_width);
+	  ret = lw6sys_itoa (sys_context, hints->max_map_width);
 	}
       else if (!strcmp (LW6DEF_MIN_MAP_HEIGHT, formatted_key))
 	{
-	  ret = lw6sys_itoa (hints->min_map_height);
+	  ret = lw6sys_itoa (sys_context, hints->min_map_height);
 	}
       else if (!strcmp (LW6DEF_MAX_MAP_HEIGHT, formatted_key))
 	{
-	  ret = lw6sys_itoa (hints->max_map_height);
+	  ret = lw6sys_itoa (sys_context, hints->max_map_height);
 	}
       else if (!strcmp (LW6DEF_MIN_MAP_SURFACE, formatted_key))
 	{
-	  ret = lw6sys_itoa (hints->min_map_surface);
+	  ret = lw6sys_itoa (sys_context, hints->min_map_surface);
 	}
       else if (!strcmp (LW6DEF_MAX_MAP_SURFACE, formatted_key))
 	{
-	  ret = lw6sys_itoa (hints->max_map_surface);
+	  ret = lw6sys_itoa (sys_context, hints->max_map_surface);
 	}
       else if (!strcmp (LW6DEF_FIGHTER_SCALE, formatted_key))
 	{
-	  ret = lw6sys_ftoa (hints->fighter_scale);
+	  ret = lw6sys_ftoa (sys_context, hints->fighter_scale);
 	}
       else if (!strcmp (LW6DEF_DOWNSIZE_USING_FIGHTER_SCALE, formatted_key))
 	{
-	  ret = lw6sys_btoa (hints->downsize_using_fighter_scale);
+	  ret = lw6sys_btoa (sys_context, hints->downsize_using_fighter_scale);
 	}
       else if (!strcmp (LW6DEF_UPSIZE_USING_FIGHTER_SCALE, formatted_key))
 	{
-	  ret = lw6sys_btoa (hints->upsize_using_fighter_scale);
+	  ret = lw6sys_btoa (sys_context, hints->upsize_using_fighter_scale);
 	}
       else if (!strcmp (LW6DEF_DOWNSIZE_USING_BENCH_VALUE, formatted_key))
 	{
-	  ret = lw6sys_btoa (hints->downsize_using_bench_value);
+	  ret = lw6sys_btoa (sys_context, hints->downsize_using_bench_value);
 	}
       else if (!strcmp (LW6DEF_UPSIZE_USING_BENCH_VALUE, formatted_key))
 	{
-	  ret = lw6sys_btoa (hints->upsize_using_bench_value);
+	  ret = lw6sys_btoa (sys_context, hints->upsize_using_bench_value);
 	}
       else if (!strcmp (LW6DEF_GUESS_COLORS, formatted_key))
 	{
-	  ret = lw6sys_btoa (hints->guess_colors);
+	  ret = lw6sys_btoa (sys_context, hints->guess_colors);
 	}
       else if (!strcmp (LW6DEF_BACKGROUND_COLOR_AUTO, formatted_key))
 	{
-	  ret = lw6sys_btoa (hints->background_color_auto);
+	  ret = lw6sys_btoa (sys_context, hints->background_color_auto);
 	}
       else if (!strcmp (LW6DEF_HUD_COLOR_AUTO, formatted_key))
 	{
-	  ret = lw6sys_btoa (hints->hud_color_auto);
+	  ret = lw6sys_btoa (sys_context, hints->hud_color_auto);
 	}
       else if (!strcmp (LW6DEF_MENU_COLOR_AUTO, formatted_key))
 	{
-	  ret = lw6sys_btoa (hints->menu_color_auto);
+	  ret = lw6sys_btoa (sys_context, hints->menu_color_auto);
 	}
       else if (!strcmp (LW6DEF_VIEW_COLOR_AUTO, formatted_key))
 	{
-	  ret = lw6sys_btoa (hints->view_color_auto);
+	  ret = lw6sys_btoa (sys_context, hints->view_color_auto);
 	}
       else if (!strcmp (LW6DEF_SYSTEM_COLOR_AUTO, formatted_key))
 	{
-	  ret = lw6sys_btoa (hints->system_color_auto);
+	  ret = lw6sys_btoa (sys_context, hints->system_color_auto);
 	}
       else if (!strcmp (LW6DEF_WALL_GREASE, formatted_key))
 	{
-	  ret = lw6sys_itoa (hints->wall_grease);
+	  ret = lw6sys_itoa (sys_context, hints->wall_grease);
 	}
       else if (!strcmp (LW6DEF_GUESS_MOVES_PER_SEC, formatted_key))
 	{
-	  ret = lw6sys_btoa (hints->guess_moves_per_sec);
+	  ret = lw6sys_btoa (sys_context, hints->guess_moves_per_sec);
 	}
       else if (!strcmp (LW6DEF_SPEED, formatted_key))
 	{
-	  ret = lw6sys_ftoa (hints->speed);
+	  ret = lw6sys_ftoa (sys_context, hints->speed);
 	}
-      LW6SYS_FREE (formatted_key);
+      LW6SYS_FREE (sys_context, formatted_key);
     }
 
   return ret;
@@ -397,6 +396,7 @@ lw6ldr_hints_get (const lw6ldr_hints_t * hints, const char *key)
 /**
  * lw6ldr_hints_get_default
  *
+ * @sys_context: global system context
  * @key: the key we want informations about.
  *
  * Gets the default value for a given hints key.
@@ -404,33 +404,30 @@ lw6ldr_hints_get (const lw6ldr_hints_t * hints, const char *key)
  * Return value: dynamically allocated string, NULL on error.
  */
 char *
-lw6ldr_hints_get_default (const char *key)
+lw6ldr_hints_get_default (lw6sys_context_t * sys_context, const char *key)
 {
   lw6ldr_hints_t *hints;
   char *ret = NULL;
 
-  hints = (lw6ldr_hints_t *) LW6SYS_CALLOC (sizeof (lw6ldr_hints_t));
+  hints = (lw6ldr_hints_t *) LW6SYS_CALLOC (sys_context, sizeof (lw6ldr_hints_t));
   if (hints)
     {
-      lw6ldr_hints_defaults (hints);
-      ret = lw6ldr_hints_get (hints, key);
-      lw6ldr_hints_clear (hints);
-      LW6SYS_FREE (hints);
+      lw6ldr_hints_defaults (sys_context, hints);
+      ret = lw6ldr_hints_get (sys_context, hints, key);
+      lw6ldr_hints_clear (sys_context, hints);
+      LW6SYS_FREE (sys_context, hints);
     }
 
   if (!ret)
     {
-      lw6sys_log (LW6SYS_LOG_WARNING,
-		  _x_
-		  ("unable to get default value for hints parameter \"%s\""),
-		  key);
+      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("unable to get default value for hints parameter \"%s\""), key);
     }
 
   return ret;
 }
 
 static void
-hints_update_callback (void *func_data, void *data)
+_hints_update_callback (lw6sys_context_t * sys_context, void *func_data, void *data)
 {
   hints_update_data_t *update_data;
   char *key;
@@ -439,16 +436,17 @@ hints_update_callback (void *func_data, void *data)
   key = (char *) data;
   update_data = (hints_update_data_t *) func_data;
 
-  if (lw6sys_assoc_has_key (update_data->values, key))
+  if (lw6sys_assoc_has_key (sys_context, update_data->values, key))
     {
-      value = lw6sys_assoc_get (update_data->values, key);
-      lw6ldr_hints_set (update_data->hints, key, value);
+      value = lw6sys_assoc_get (sys_context, update_data->values, key);
+      lw6ldr_hints_set (sys_context, update_data->hints, key, value);
     }
 }
 
 /**
  * lw6ldr_hints_update
  *
+ * @sys_context: global system context
  * @hints: the hints struct to fill with values (read/write parameter)
  * @values: an assoc containing strings with the new values
  *
@@ -461,7 +459,7 @@ hints_update_callback (void *func_data, void *data)
  * Return value: 1 if success, 0 if failed.
  */
 int
-lw6ldr_hints_update (lw6ldr_hints_t * hints, lw6sys_assoc_t * values)
+lw6ldr_hints_update (lw6sys_context_t * sys_context, lw6ldr_hints_t * hints, lw6sys_assoc_t * values)
 {
   int ret = 0;
   lw6sys_list_t *list;
@@ -469,13 +467,13 @@ lw6ldr_hints_update (lw6ldr_hints_t * hints, lw6sys_assoc_t * values)
 
   if (values)
     {
-      list = lw6hlp_list_map_hints ();
+      list = lw6hlp_list_map_hints (sys_context);
       if (list)
 	{
 	  data.hints = hints;
 	  data.values = values;
-	  lw6sys_list_map (list, hints_update_callback, &data);
-	  lw6sys_list_free (list);
+	  lw6sys_list_map (sys_context, list, _hints_update_callback, &data);
+	  lw6sys_list_free (sys_context, list);
 	  ret = 1;
 	}
     }
