@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -30,19 +30,15 @@
 #include "ldr-internal.h"
 
 static int
-read_png (lw6map_meta_layer_t * meta_layer, _lw6ldr_image_bw_t * image,
-	  lw6ldr_resampler_t * resampler, int analog,
-	  lw6sys_progress_t * progress)
+_read_png (lw6sys_context_t * sys_context, lw6map_meta_layer_t * meta_layer, _lw6ldr_image_bw_t * image, lw6ldr_resampler_t * resampler, int analog,
+	   lw6sys_progress_t * progress)
 {
   int ret = 0;
 
   meta_layer->shape.w = resampler->target_w;
   meta_layer->shape.h = resampler->target_h;
   meta_layer->shape.d = 1;	// allways 1
-  meta_layer->data =
-    (unsigned char *) LW6SYS_MALLOC (meta_layer->shape.w *
-				     meta_layer->shape.h *
-				     sizeof (unsigned char *));
+  meta_layer->data = (unsigned char *) LW6SYS_MALLOC (sys_context, meta_layer->shape.w * meta_layer->shape.h * sizeof (unsigned char *));
 
   if (meta_layer->data)
     {
@@ -51,11 +47,10 @@ read_png (lw6map_meta_layer_t * meta_layer, _lw6ldr_image_bw_t * image,
 
       for (row = 0; row < meta_layer->shape.h; ++row)
 	{
-	  lw6sys_progress_update (progress, 0, meta_layer->shape.h, row);
+	  lw6sys_progress_update (sys_context, progress, 0, meta_layer->shape.h, row);
 	  for (col = 0; col < meta_layer->shape.w; ++col)
 	    {
-	      lw6ldr_resampler_target2source (resampler, &col2, &row2,
-					      col, row);
+	      lw6ldr_resampler_target2source (sys_context, resampler, &col2, &row2, col, row);
 	      /*
 	       * For metalayers, we always "invert" the layer meaning,
 	       * that is black is "metalayer param set to full" and
@@ -67,7 +62,7 @@ read_png (lw6map_meta_layer_t * meta_layer, _lw6ldr_image_bw_t * image,
 		{
 		  value = value ? 1 : 0;
 		}
-	      lw6map_meta_layer_set (meta_layer, col, row, value);
+	      lw6map_meta_layer_set (sys_context, meta_layer, col, row, value);
 	    }
 	}
 
@@ -75,8 +70,7 @@ read_png (lw6map_meta_layer_t * meta_layer, _lw6ldr_image_bw_t * image,
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING,
-		  _x_ ("unable to allocate memory for meta_layer"));
+      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("unable to allocate memory for meta_layer"));
     }
 
   return ret;
@@ -85,6 +79,7 @@ read_png (lw6map_meta_layer_t * meta_layer, _lw6ldr_image_bw_t * image,
 /**
  * lw6ldr_meta_layer_read
  *
+ * @sys_context: global system context
  * @meta_layer: the meta layer to read
  * @filename: the file to open
  * @target_w: the wanted width
@@ -97,28 +92,25 @@ read_png (lw6map_meta_layer_t * meta_layer, _lw6ldr_image_bw_t * image,
  * Return value: 1 on success, 0 on failure
  */
 int
-lw6ldr_meta_layer_read (lw6map_meta_layer_t * meta_layer,
-			const char *filename, int target_w, int target_h,
-			int analog)
+lw6ldr_meta_layer_read (lw6sys_context_t * sys_context, lw6map_meta_layer_t * meta_layer, const char *filename, int target_w, int target_h, int analog)
 {
   int ret = 0;
   lw6ldr_resampler_t resampler;
   _lw6ldr_image_bw_t image;
 
-  lw6map_meta_layer_clear (meta_layer);
+  lw6map_meta_layer_clear (sys_context, meta_layer);
   memset (&image, 0, sizeof (_lw6ldr_image_bw_t));
-  if (_lw6ldr_bw_read (&image, filename, NULL))
+  if (_lw6ldr_bw_read (sys_context, &image, filename, NULL))
     {
-      lw6ldr_resampler_force (&resampler, image.w, image.h, target_w,
-			      target_h);
-      ret = read_png (meta_layer, &image, &resampler, analog, NULL);
+      lw6ldr_resampler_force (sys_context, &resampler, image.w, image.h, target_w, target_h);
+      ret = _read_png (sys_context, meta_layer, &image, &resampler, analog, NULL);
 
-      _lw6ldr_bw_clear (&image);
+      _lw6ldr_bw_clear (sys_context, &image);
     }
 
   if (!ret)
     {
-      lw6map_meta_layer_clear (meta_layer);
+      lw6map_meta_layer_clear (sys_context, meta_layer);
     }
 
   return ret;
@@ -127,6 +119,7 @@ lw6ldr_meta_layer_read (lw6map_meta_layer_t * meta_layer,
 /**
  * lw6ldr_meta_layer_read_if_exists
  *
+ * @sys_context: global system context
  * @meta_layer: the meta layer to read
  * @dirname: the map directory
  * @file_only: the meta-layer file name only (without the path)
@@ -142,21 +135,18 @@ lw6ldr_meta_layer_read (lw6map_meta_layer_t * meta_layer,
  * Return value: 1 on success, 0 on failure
  */
 int
-lw6ldr_meta_layer_read_if_exists (lw6map_meta_layer_t * meta_layer,
-				  const char *dirname, const char *file_only,
-				  int target_w, int target_h, int analog)
+lw6ldr_meta_layer_read_if_exists (lw6sys_context_t * sys_context, lw6map_meta_layer_t * meta_layer, const char *dirname, const char *file_only, int target_w,
+				  int target_h, int analog)
 {
   int ret = 0;
   char *dot_png = NULL;
 
-  dot_png = lw6sys_path_concat (dirname, file_only);
+  dot_png = lw6sys_path_concat (sys_context, dirname, file_only);
   if (dot_png)
     {
-      if (lw6sys_file_exists (dot_png))
+      if (lw6sys_file_exists (sys_context, dot_png))
 	{
-	  ret =
-	    lw6ldr_meta_layer_read (meta_layer,
-				    dot_png, target_w, target_h, analog);
+	  ret = lw6ldr_meta_layer_read (sys_context, meta_layer, dot_png, target_w, target_h, analog);
 	}
       else
 	{
@@ -166,7 +156,7 @@ lw6ldr_meta_layer_read_if_exists (lw6map_meta_layer_t * meta_layer,
 	   */
 	  ret = 1;
 	}
-      LW6SYS_FREE (dot_png);
+      LW6SYS_FREE (sys_context, dot_png);
     }
 
   return ret;
