@@ -1,7 +1,7 @@
 
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -30,6 +30,7 @@
 /**
  * lw6ldr_process_non_run_options:
  *
+ * @sys_context: global system context
  * @argc: the number of command-line args, as passed to main
  * @argv: an array of strings containing command-line args, as passed to main
  * @run_game: a pointer to a boolean which will contain true (1) if the
@@ -45,7 +46,7 @@
  *   instance, the test suite returning "no, tests were not OK".
  */
 int
-lw6ldr_process_non_run_options (int argc, const char *argv[], int *run_game)
+lw6ldr_process_non_run_options (lw6sys_context_t * sys_context, int argc, const char *argv[], int *run_game)
 {
   int i;
   int ret = 1;
@@ -55,29 +56,29 @@ lw6ldr_process_non_run_options (int argc, const char *argv[], int *run_game)
    * check for bad options, and globally, we rely on it,
    * this function just superseds it and adds the XML handling.
    */
-  ret = lw6hlp_process_non_run_options (argc, argv, run_game);
+  ret = lw6hlp_process_non_run_options (sys_context, argc, argv, run_game);
   if (ret && (*run_game))
     {
       for (i = 1; i < argc; ++i)
 	{
-	  if (lw6sys_arg_match (LW6DEF_EXAMPLE_RULES_XML, argv[i]))
+	  if (lw6sys_arg_match (sys_context, LW6DEF_EXAMPLE_RULES_XML, argv[i]))
 	    {
-	      lw6ldr_print_example_rules_xml (stdout);
+	      lw6ldr_print_example_rules_xml (sys_context, stdout);
 	      (*run_game) = 0;
 	    }
-	  else if (lw6sys_arg_match (LW6DEF_EXAMPLE_HINTS_XML, argv[i]))
+	  else if (lw6sys_arg_match (sys_context, LW6DEF_EXAMPLE_HINTS_XML, argv[i]))
 	    {
-	      lw6ldr_print_example_hints_xml (stdout);
+	      lw6ldr_print_example_hints_xml (sys_context, stdout);
 	      (*run_game) = 0;
 	    }
-	  else if (lw6sys_arg_match (LW6DEF_EXAMPLE_STYLE_XML, argv[i]))
+	  else if (lw6sys_arg_match (sys_context, LW6DEF_EXAMPLE_STYLE_XML, argv[i]))
 	    {
-	      lw6ldr_print_example_style_xml (stdout);
+	      lw6ldr_print_example_style_xml (sys_context, stdout);
 	      (*run_game) = 0;
 	    }
-	  else if (lw6sys_arg_match (LW6DEF_EXAMPLE_TEAMS_XML, argv[i]))
+	  else if (lw6sys_arg_match (sys_context, LW6DEF_EXAMPLE_TEAMS_XML, argv[i]))
 	    {
-	      lw6ldr_print_example_teams_xml (stdout);
+	      lw6ldr_print_example_teams_xml (sys_context, stdout);
 	      (*run_game) = 0;
 	    }
 	}
