@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -36,8 +36,7 @@
 #include "ldr-internal.h"
 
 int
-_lw6ldr_rgba_read_png (_lw6ldr_image_rgba_t * image, const char *png_file,
-		       lw6sys_progress_t * progress)
+_lw6ldr_rgba_read_png (lw6sys_context_t * sys_context, _lw6ldr_image_rgba_t * image, const char *png_file, lw6sys_progress_t * progress)
 {
   png_structp png_ptr = NULL;
   png_infop info_ptr = NULL;
@@ -49,7 +48,7 @@ _lw6ldr_rgba_read_png (_lw6ldr_image_rgba_t * image, const char *png_file,
   int ret = 0;
   FILE *f = NULL;
 
-  lw6sys_progress_begin (progress);
+  lw6sys_progress_begin (sys_context, progress);
 
   png_ptr = png_create_read_struct (PNG_LIBPNG_VER_STRING, NULL, NULL, NULL);
   if (png_ptr)
@@ -79,8 +78,7 @@ _lw6ldr_rgba_read_png (_lw6ldr_image_rgba_t * image, const char *png_file,
 
 		  png_read_info (png_ptr, info_ptr);
 
-		  png_get_IHDR (png_ptr, info_ptr, &width, &height,
-				&bit_depth, &color_type, NULL, NULL, NULL);
+		  png_get_IHDR (png_ptr, info_ptr, &width, &height, &bit_depth, &color_type, NULL, NULL, NULL);
 
 		  png_set_expand (png_ptr);
 		  png_set_strip_16 (png_ptr);
@@ -98,60 +96,44 @@ _lw6ldr_rgba_read_png (_lw6ldr_image_rgba_t * image, const char *png_file,
 
 		  png_read_update_info (png_ptr, info_ptr);
 
-		  png_get_IHDR (png_ptr, info_ptr, &width, &height,
-				&bit_depth, &color_type, NULL, NULL, NULL);
+		  png_get_IHDR (png_ptr, info_ptr, &width, &height, &bit_depth, &color_type, NULL, NULL, NULL);
 
 		  rowbytes = png_get_rowbytes (png_ptr, info_ptr);
 
 		  if (color_type & PNG_COLOR_MASK_PALETTE)
 		    {
-		      lw6sys_log (LW6SYS_LOG_WARNING,
-				  _x_
-				  ("can't load RGBA PNG file \"%s\", it is still paletted after filtering"),
-				  png_file);
+		      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("can't load RGBA PNG file \"%s\", it is still paletted after filtering"), png_file);
 		      format_ok = 0;
 		    }
 
-		  max_width =
-		    lw6sys_imax (LW6MAP_MAX_BODY_WIDTH,
-				 LW6MAP_MAX_TEXTURE_WIDTH);
-		  max_height =
-		    lw6sys_imax (LW6MAP_MAX_BODY_HEIGHT,
-				 LW6MAP_MAX_TEXTURE_HEIGHT);
+		  max_width = lw6sys_imax (LW6MAP_MAX_BODY_WIDTH, LW6MAP_MAX_TEXTURE_WIDTH);
+		  max_height = lw6sys_imax (LW6MAP_MAX_BODY_HEIGHT, LW6MAP_MAX_TEXTURE_HEIGHT);
 		  if (width > max_width || height > max_height)
 		    {
-		      lw6sys_log (LW6SYS_LOG_WARNING,
+		      lw6sys_log (sys_context, LW6SYS_LOG_WARNING,
 				  _x_
 				  ("can't load RGBA PNG file \"%s\", it is too big (size=%dx%d max=%dx%d)"),
-				  png_file, (int) width, (int) height,
-				  max_width, max_height);
+				  png_file, (int) width, (int) height, max_width, max_height);
 		      format_ok = 0;
 		    }
 
 		  if (rowbytes != width * 4 || bit_depth > 8)
 		    {
-		      lw6sys_log (LW6SYS_LOG_WARNING,
+		      lw6sys_log (sys_context, LW6SYS_LOG_WARNING,
 				  _x_
 				  ("can't load RGBA PNG file \"%s\", memory footprint is inconsistent, color_type=%d, rowbytes=%d, width=%d, step=%d, bit_depth=%d"),
-				  png_file, color_type,
-				  (int) rowbytes, (int) width, 4, bit_depth);
+				  png_file, color_type, (int) rowbytes, (int) width, 4, bit_depth);
 		      format_ok = 0;
 		    }
 
 		  if (format_ok)
 		    {
-		      buf =
-			(unsigned char **) LW6SYS_MALLOC (height *
-							  sizeof (unsigned
-								  char *));
+		      buf = (unsigned char **) LW6SYS_MALLOC (sys_context, height * sizeof (unsigned char *));
 		      if (buf)
 			{
 			  for (row = 0; row < height; ++row)
 			    {
-			      buf[row] =
-				(unsigned char *)
-				LW6SYS_MALLOC (rowbytes *
-					       sizeof (unsigned char));
+			      buf[row] = (unsigned char *) LW6SYS_MALLOC (sys_context, rowbytes * sizeof (unsigned char));
 			      if (!buf[row])
 				{
 				  memory_ok = 0;
@@ -165,9 +147,9 @@ _lw6ldr_rgba_read_png (_lw6ldr_image_rgba_t * image, const char *png_file,
 
 		      if (memory_ok)
 			{
-			  lw6sys_progress_update (progress, 0, 3, 1);
+			  lw6sys_progress_update (sys_context, progress, 0, 3, 1);
 			  png_read_image (png_ptr, buf);
-			  lw6sys_progress_update (progress, 0, 3, 2);
+			  lw6sys_progress_update (sys_context, progress, 0, 3, 2);
 			  png_read_end (png_ptr, end_info);
 
 			  image->w = width;
@@ -177,9 +159,7 @@ _lw6ldr_rgba_read_png (_lw6ldr_image_rgba_t * image, const char *png_file,
 			}
 		      else
 			{
-			  lw6sys_log (LW6SYS_LOG_WARNING,
-				      _x_
-				      ("unable to allocate memory for RGBA PNG file"));
+			  lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("unable to allocate memory for RGBA PNG file"));
 			}
 		    }
 
@@ -189,37 +169,33 @@ _lw6ldr_rgba_read_png (_lw6ldr_image_rgba_t * image, const char *png_file,
 	    }
 	  else
 	    {
-	      lw6sys_log (LW6SYS_LOG_WARNING,
-			  _x_ ("couldn't create png end info struct"));
+	      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("couldn't create png end info struct"));
 	    }
 	}
       else
 	{
-	  lw6sys_log (LW6SYS_LOG_WARNING,
-		      _x_ ("couldn't create png info struct"));
+	  lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("couldn't create png info struct"));
 	}
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING,
-		  _x_ ("couldn't create png read struct"));
+      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("couldn't create png read struct"));
     }
 
   png_destroy_read_struct (&png_ptr, &info_ptr, &end_info);
 
   if (!ret)
     {
-      _lw6ldr_rgba_clear (image);
+      _lw6ldr_rgba_clear (sys_context, image);
     }
 
-  lw6sys_progress_end (progress);
+  lw6sys_progress_end (sys_context, progress);
 
   return ret;
 }
 
 int
-_lw6ldr_rgba_read_jpeg (_lw6ldr_image_rgba_t * image, const char *jpeg_file,
-			lw6sys_progress_t * progress)
+_lw6ldr_rgba_read_jpeg (lw6sys_context_t * sys_context, _lw6ldr_image_rgba_t * image, const char *jpeg_file, lw6sys_progress_t * progress)
 {
   int ret = 0;
   FILE *f = NULL;
@@ -235,7 +211,7 @@ _lw6ldr_rgba_read_jpeg (_lw6ldr_image_rgba_t * image, const char *jpeg_file,
   int max_width;
   int max_height;
 
-  lw6sys_progress_begin (progress);
+  lw6sys_progress_begin (sys_context, progress);
 
   /*
    * This function probably lacks many error checks.
@@ -253,17 +229,14 @@ _lw6ldr_rgba_read_jpeg (_lw6ldr_image_rgba_t * image, const char *jpeg_file,
       memory_ok = 1;
       size_ok = 1;
 
-      max_width =
-	lw6sys_imax (LW6MAP_MAX_BODY_WIDTH, LW6MAP_MAX_TEXTURE_WIDTH);
-      max_height =
-	lw6sys_imax (LW6MAP_MAX_BODY_HEIGHT, LW6MAP_MAX_TEXTURE_HEIGHT);
+      max_width = lw6sys_imax (LW6MAP_MAX_BODY_WIDTH, LW6MAP_MAX_TEXTURE_WIDTH);
+      max_height = lw6sys_imax (LW6MAP_MAX_BODY_HEIGHT, LW6MAP_MAX_TEXTURE_HEIGHT);
       if (cinfo.output_width > max_width || cinfo.output_height > max_height)
 	{
-	  lw6sys_log (LW6SYS_LOG_WARNING,
+	  lw6sys_log (sys_context, LW6SYS_LOG_WARNING,
 		      _x_
 		      ("can't load RGBA JPEG file \"%s\", it is too big (size=%dx%d max=%dx%d)"),
-		      jpeg_file, (int) cinfo.output_width,
-		      (int) cinfo.output_height, max_width, max_height);
+		      jpeg_file, (int) cinfo.output_width, (int) cinfo.output_height, max_width, max_height);
 	  size_ok = 0;
 	}
 
@@ -271,16 +244,12 @@ _lw6ldr_rgba_read_jpeg (_lw6ldr_image_rgba_t * image, const char *jpeg_file,
 	{
 	  jpeg_start_decompress (&cinfo);
 
-	  buf =
-	    (unsigned char **) LW6SYS_MALLOC (cinfo.output_height *
-					      sizeof (unsigned char *));
+	  buf = (unsigned char **) LW6SYS_MALLOC (sys_context, cinfo.output_height * sizeof (unsigned char *));
 	  if (buf)
 	    {
 	      for (j = 0; j < cinfo.output_height; ++j)
 		{
-		  buf[j] =
-		    (unsigned char *) LW6SYS_MALLOC (cinfo.output_width * 4 *
-						     sizeof (unsigned char));
+		  buf[j] = (unsigned char *) LW6SYS_MALLOC (sys_context, cinfo.output_width * 4 * sizeof (unsigned char));
 		  if (!buf[j])
 		    {
 		      memory_ok = 0;
@@ -298,17 +267,11 @@ _lw6ldr_rgba_read_jpeg (_lw6ldr_image_rgba_t * image, const char *jpeg_file,
 		{
 		case 3:	// color
 		  row_stride = cinfo.output_width * cinfo.output_components;
-		  buffer = (*cinfo.mem->alloc_sarray)
-		    ((j_common_ptr) & cinfo, JPOOL_IMAGE, row_stride, 1);
+		  buffer = (*cinfo.mem->alloc_sarray) ((j_common_ptr) & cinfo, JPOOL_IMAGE, row_stride, 1);
 		  while (cinfo.output_scanline < cinfo.output_height)
 		    {
-		      lw6sys_progress_update (progress, 0,
-					      cinfo.output_height,
-					      cinfo.output_scanline);
-		      j =
-			lw6sys_imax (lw6sys_imin
-				     (cinfo.output_scanline,
-				      cinfo.output_height - 1), 0);
+		      lw6sys_progress_update (sys_context, progress, 0, cinfo.output_height, cinfo.output_scanline);
+		      j = lw6sys_imax (lw6sys_imin (cinfo.output_scanline, cinfo.output_height - 1), 0);
 
 		      jpeg_read_scanlines (&cinfo, buffer, 1);
 		      for (i = 0; i < cinfo.output_width; i++)
@@ -327,24 +290,16 @@ _lw6ldr_rgba_read_jpeg (_lw6ldr_image_rgba_t * image, const char *jpeg_file,
 
 		case 1:	// grayscale
 		  row_stride = cinfo.output_width * cinfo.output_components;
-		  buffer = (*cinfo.mem->alloc_sarray)
-		    ((j_common_ptr) & cinfo, JPOOL_IMAGE, row_stride, 1);
+		  buffer = (*cinfo.mem->alloc_sarray) ((j_common_ptr) & cinfo, JPOOL_IMAGE, row_stride, 1);
 		  while (cinfo.output_scanline < cinfo.output_height)
 		    {
-		      lw6sys_progress_update (progress, 0,
-					      cinfo.output_height,
-					      cinfo.output_scanline);
-		      j =
-			lw6sys_imax (lw6sys_imin
-				     (cinfo.output_scanline,
-				      cinfo.output_height - 1), 0);
+		      lw6sys_progress_update (sys_context, progress, 0, cinfo.output_height, cinfo.output_scanline);
+		      j = lw6sys_imax (lw6sys_imin (cinfo.output_scanline, cinfo.output_height - 1), 0);
 
 		      jpeg_read_scanlines (&cinfo, buffer, 1);
 		      for (i = 0; i < cinfo.output_width; i++)
 			{
-			  buf[j][i * 4 + 0] =
-			    buf[j][i * 4 + 1] = buf[j][i * 4 + 2] =
-			    buffer[0][i];
+			  buf[j][i * 4 + 0] = buf[j][i * 4 + 1] = buf[j][i * 4 + 2] = buffer[0][i];
 			  buf[j][i * 4 + 3] = 255;
 			}
 		    }
@@ -355,17 +310,13 @@ _lw6ldr_rgba_read_jpeg (_lw6ldr_image_rgba_t * image, const char *jpeg_file,
 		  break;
 
 		default:
-		  lw6sys_log (LW6SYS_LOG_WARNING,
-			      _x_
-			      ("unable to handle jpeg file output_components must be 3 (RGB) but is %d"),
-			      cinfo.output_components);
+		  lw6sys_log (sys_context, LW6SYS_LOG_WARNING,
+			      _x_ ("unable to handle jpeg file output_components must be 3 (RGB) but is %d"), cinfo.output_components);
 		}
 	    }
 	  else
 	    {
-	      lw6sys_log (LW6SYS_LOG_WARNING,
-			  _x_
-			  ("unable to allocate memory for RGBA JPEG file"));
+	      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("unable to allocate memory for RGBA JPEG file"));
 	    }
 	  jpeg_finish_decompress (&cinfo);
 	}
@@ -376,16 +327,15 @@ _lw6ldr_rgba_read_jpeg (_lw6ldr_image_rgba_t * image, const char *jpeg_file,
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING,
-		  _x_ ("unable to read jpeg file \"%s\""), jpeg_file);
+      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("unable to read jpeg file \"%s\""), jpeg_file);
     }
 
   if (!ret)
     {
-      _lw6ldr_rgba_clear (image);
+      _lw6ldr_rgba_clear (sys_context, image);
     }
 
-  lw6sys_progress_end (progress);
+  lw6sys_progress_end (sys_context, progress);
 
   return ret;
 }
@@ -395,7 +345,7 @@ _lw6ldr_rgba_read_jpeg (_lw6ldr_image_rgba_t * image, const char *jpeg_file,
  * Clear everything and free data pointers.
  */
 extern void
-_lw6ldr_rgba_clear (_lw6ldr_image_rgba_t * image)
+_lw6ldr_rgba_clear (lw6sys_context_t * sys_context, _lw6ldr_image_rgba_t * image)
 {
   int row;
 
@@ -405,10 +355,10 @@ _lw6ldr_rgba_clear (_lw6ldr_image_rgba_t * image)
 	{
 	  if (image->data[row])
 	    {
-	      LW6SYS_FREE (image->data[row]);
+	      LW6SYS_FREE (sys_context, image->data[row]);
 	    }
 	}
-      LW6SYS_FREE (image->data);
+      LW6SYS_FREE (sys_context, image->data);
     }
 
   memset (image, 0, sizeof (_lw6ldr_image_rgba_t));
