@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -37,19 +37,19 @@ typedef struct teams_update_data_s
 teams_update_data_t;
 
 static void
-read_callback (void *callback_data, const char *element, const char *key,
-	       const char *value)
+_read_callback (lw6sys_context_t * sys_context, void *callback_data, const char *element, const char *key, const char *value)
 {
   lw6map_teams_t *teams_data;
 
   teams_data = (lw6map_teams_t *) callback_data;
 
-  lw6map_teams_set (teams_data, key, value);
+  lw6map_teams_set (sys_context, teams_data, key, value);
 }
 
 /**
  * lw6ldr_teams_read
  *
+ * @sys_context: global system context
  * @param: the teams struct to fill with values (read/write parameter)
  * @dirname: the directory of the map
  *
@@ -60,21 +60,19 @@ read_callback (void *callback_data, const char *element, const char *key,
  * Return value: 1 if success, 0 if failed.
  */
 int
-lw6ldr_teams_read (lw6map_teams_t * teams, const char *dirname)
+lw6ldr_teams_read (lw6sys_context_t * sys_context, lw6map_teams_t * teams, const char *dirname)
 {
   int ret = 0;
   char *buf = NULL;
 
-  buf = lw6sys_path_concat (dirname, _LW6LDR_FILE_TEAMS_XML);
+  buf = lw6sys_path_concat (sys_context, dirname, _LW6LDR_FILE_TEAMS_XML);
 
   if (buf)
     {
-      if (lw6sys_file_exists (buf))
+      if (lw6sys_file_exists (sys_context, buf))
 	{
-	  lw6sys_log (LW6SYS_LOG_INFO, _x_ ("reading teams \"%s\""), buf);
-	  ret =
-	    lw6cfg_read_key_value_xml_file (buf, read_callback,
-					    (void *) teams);
+	  lw6sys_log (sys_context, LW6SYS_LOG_INFO, _x_ ("reading teams \"%s\""), buf);
+	  ret = lw6cfg_read_key_value_xml_file (sys_context, buf, _read_callback, (void *) teams);
 	}
       else
 	{
@@ -82,19 +80,19 @@ lw6ldr_teams_read (lw6map_teams_t * teams, const char *dirname)
 	  ret = 1;
 	}
 
-      LW6SYS_FREE (buf);
+      LW6SYS_FREE (sys_context, buf);
     }
 
   if (!ret)
     {
-      lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("unable to read map teams"));
+      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("unable to read map teams"));
     }
 
   return ret;
 }
 
 static void
-teams_update_callback (void *func_data, void *data)
+_teams_update_callback (lw6sys_context_t * sys_context, void *func_data, void *data)
 {
   teams_update_data_t *update_data;
   char *key;
@@ -103,16 +101,17 @@ teams_update_callback (void *func_data, void *data)
   key = (char *) data;
   update_data = (teams_update_data_t *) func_data;
 
-  if (lw6sys_assoc_has_key (update_data->values, key))
+  if (lw6sys_assoc_has_key (sys_context, update_data->values, key))
     {
-      value = lw6sys_assoc_get (update_data->values, key);
-      lw6map_teams_set (update_data->teams, key, value);
+      value = lw6sys_assoc_get (sys_context, update_data->values, key);
+      lw6map_teams_set (sys_context, update_data->teams, key, value);
     }
 }
 
 /**
  * lw6ldr_teams_update
  *
+ * @sys_context: global system context
  * @teams: the teams struct to fill with values (read/write parameter)
  * @values: an assoc containing strings with the new values
  *
@@ -125,7 +124,7 @@ teams_update_callback (void *func_data, void *data)
  * Return value: 1 if success, 0 if failed.
  */
 int
-lw6ldr_teams_update (lw6map_teams_t * teams, lw6sys_assoc_t * values)
+lw6ldr_teams_update (lw6sys_context_t * sys_context, lw6map_teams_t * teams, lw6sys_assoc_t * values)
 {
   int ret = 0;
   lw6sys_list_t *list;
@@ -133,13 +132,13 @@ lw6ldr_teams_update (lw6map_teams_t * teams, lw6sys_assoc_t * values)
 
   if (values)
     {
-      list = lw6hlp_list_map_teams ();
+      list = lw6hlp_list_map_teams (sys_context);
       if (list)
 	{
 	  data.teams = teams;
 	  data.values = values;
-	  lw6sys_list_map (list, teams_update_callback, &data);
-	  lw6sys_list_free (list);
+	  lw6sys_list_map (sys_context, list, _teams_update_callback, &data);
+	  lw6sys_list_free (sys_context, list);
 	  ret = 1;
 	}
     }
