@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -30,16 +30,13 @@
 #include "ldr-internal.h"
 
 static int
-read_image (lw6map_texture_t * texture, _lw6ldr_image_rgba_t * image)
+_read_image (lw6sys_context_t * sys_context, lw6map_texture_t * texture, _lw6ldr_image_rgba_t * image)
 {
   int ret = 0;
 
   texture->w = image->w;
   texture->h = image->h;
-  texture->data =
-    (lw6sys_color_8_t *) LW6SYS_MALLOC (texture->w *
-					texture->h *
-					sizeof (lw6sys_color_8_t *));
+  texture->data = (lw6sys_color_8_t *) LW6SYS_MALLOC (sys_context, texture->w * texture->h * sizeof (lw6sys_color_8_t *));
 
   if (texture->data)
     {
@@ -63,22 +60,21 @@ read_image (lw6map_texture_t * texture, _lw6ldr_image_rgba_t * image)
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING,
-		  _x_ ("unable to allocate memory for texture"));
+      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("unable to allocate memory for texture"));
     }
 
-  _lw6ldr_rgba_clear (image);
+  _lw6ldr_rgba_clear (sys_context, image);
 
   if (!ret)
     {
-      lw6map_texture_clear (texture);
+      lw6map_texture_clear (sys_context, texture);
     }
 
   return ret;
 }
 
 static int
-read_alpha_image (lw6map_texture_t * texture, _lw6ldr_image_rgba_t * image)
+_read_alpha_image (lw6sys_context_t * sys_context, lw6map_texture_t * texture, _lw6ldr_image_rgba_t * image)
 {
   int ret = 0;
 
@@ -94,8 +90,7 @@ read_alpha_image (lw6map_texture_t * texture, _lw6ldr_image_rgba_t * image)
 	    {
 	      value = lw6map_texture_get (texture, col, row);
 	      alpha = (((u_int32_t) image->data[row][col * 4]) +
-		       ((u_int32_t) image->data[row][col * 4 + 1]) +
-		       ((u_int32_t) image->data[row][col * 4 + 2])) / 3;
+		       ((u_int32_t) image->data[row][col * 4 + 1]) + ((u_int32_t) image->data[row][col * 4 + 2])) / 3;
 	      /*
 	       * This is where we "invert" the layer and consider
 	       * black (0) is opaque (alpha 255).
@@ -109,73 +104,64 @@ read_alpha_image (lw6map_texture_t * texture, _lw6ldr_image_rgba_t * image)
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING,
-		  _x_
-		  ("texture size (%dx%d) and alpha layer size (%dx%d) do not match"),
-		  texture->w, texture->h, image->w, image->h);
+      lw6sys_log (sys_context, LW6SYS_LOG_WARNING,
+		  _x_ ("texture size (%dx%d) and alpha layer size (%dx%d) do not match"), texture->w, texture->h, image->w, image->h);
     }
 
-  _lw6ldr_rgba_clear (image);
+  _lw6ldr_rgba_clear (sys_context, image);
 
   return ret;
 }
 
 static int
-read_png (lw6map_texture_t * texture, const char *texture_dot_png,
-	  lw6sys_progress_t * progress)
+_read_png (lw6sys_context_t * sys_context, lw6map_texture_t * texture, const char *texture_dot_png, lw6sys_progress_t * progress)
 {
   int ret = 0;
   _lw6ldr_image_rgba_t image;
 
-  lw6sys_log (LW6SYS_LOG_INFO, _x_ ("reading PNG texture \"%s\""),
-	      texture_dot_png);
+  lw6sys_log (sys_context, LW6SYS_LOG_INFO, _x_ ("reading PNG texture \"%s\""), texture_dot_png);
 
   memset (&image, 0, sizeof (_lw6ldr_image_rgba_t));
 
-  if (_lw6ldr_rgba_read_png (&image, texture_dot_png, progress))
+  if (_lw6ldr_rgba_read_png (sys_context, &image, texture_dot_png, progress))
     {
-      ret = read_image (texture, &image);
+      ret = _read_image (sys_context, texture, &image);
     }
 
   return ret;
 }
 
 static int
-read_jpeg (lw6map_texture_t * texture, const char *texture_dot_jpeg,
-	   lw6sys_progress_t * progress)
+_read_jpeg (lw6sys_context_t * sys_context, lw6map_texture_t * texture, const char *texture_dot_jpeg, lw6sys_progress_t * progress)
 {
   int ret = 0;
   _lw6ldr_image_rgba_t image;
 
-  lw6sys_log (LW6SYS_LOG_INFO, _x_ ("reading JPEG texture \"%s\""),
-	      texture_dot_jpeg);
+  lw6sys_log (sys_context, LW6SYS_LOG_INFO, _x_ ("reading JPEG texture \"%s\""), texture_dot_jpeg);
 
   memset (&image, 0, sizeof (_lw6ldr_image_rgba_t));
 
-  if (_lw6ldr_rgba_read_jpeg (&image, texture_dot_jpeg, progress))
+  if (_lw6ldr_rgba_read_jpeg (sys_context, &image, texture_dot_jpeg, progress))
     {
-      ret = read_image (texture, &image);
+      ret = _read_image (sys_context, texture, &image);
     }
 
   return ret;
 }
 
 static int
-read_alpha_jpeg (lw6map_texture_t * texture,
-		 const char *texture_alpha_dot_jpeg,
-		 lw6sys_progress_t * progress)
+_read_alpha_jpeg (lw6sys_context_t * sys_context, lw6map_texture_t * texture, const char *texture_alpha_dot_jpeg, lw6sys_progress_t * progress)
 {
   int ret = 0;
   _lw6ldr_image_rgba_t image;
 
-  lw6sys_log (LW6SYS_LOG_INFO, _x_ ("reading JPEG alpha layer \"%s\""),
-	      texture_alpha_dot_jpeg);
+  lw6sys_log (sys_context, LW6SYS_LOG_INFO, _x_ ("reading JPEG alpha layer \"%s\""), texture_alpha_dot_jpeg);
 
   memset (&image, 0, sizeof (_lw6ldr_image_rgba_t));
 
-  if (_lw6ldr_rgba_read_jpeg (&image, texture_alpha_dot_jpeg, progress))
+  if (_lw6ldr_rgba_read_jpeg (sys_context, &image, texture_alpha_dot_jpeg, progress))
     {
-      ret = read_alpha_image (texture, &image);
+      ret = _read_alpha_image (sys_context, texture, &image);
     }
 
   return ret;
@@ -184,6 +170,7 @@ read_alpha_jpeg (lw6map_texture_t * texture,
 /**
  * lw6ldr_texture_read
  *
+ * @sys_context: global system context
  * @texture: structure to hold read data
  * @dirname: map dirname (absolute path)
  * @param: parameters to use
@@ -202,15 +189,14 @@ read_alpha_jpeg (lw6map_texture_t * texture,
  * Return value: 1 on success, 0 on failure.
  */
 int
-lw6ldr_texture_read (lw6map_texture_t * texture, const char *dirname,
+lw6ldr_texture_read (lw6sys_context_t * sys_context, lw6map_texture_t * texture, const char *dirname,
 		     const lw6map_param_t * param,
 		     const lw6ldr_hints_t * hints, int use_texture,
-		     int display_w, int display_h, float *ratio,
-		     int *texture_exists, lw6sys_progress_t * progress)
+		     int display_w, int display_h, float *ratio, int *texture_exists, lw6sys_progress_t * progress)
 {
   int ret = 0;
 
-  lw6map_texture_clear (texture);
+  lw6map_texture_clear (sys_context, texture);
 
   (*texture_exists) = 0;
 
@@ -221,16 +207,15 @@ lw6ldr_texture_read (lw6map_texture_t * texture, const char *dirname,
        */
       char *texture_dot_png;
 
-      texture_dot_png =
-	lw6sys_path_concat (dirname, _LW6LDR_FILE_TEXTURE_PNG);
+      texture_dot_png = lw6sys_path_concat (sys_context, dirname, _LW6LDR_FILE_TEXTURE_PNG);
       if (texture_dot_png)
 	{
-	  if (lw6sys_file_exists (texture_dot_png))
+	  if (lw6sys_file_exists (sys_context, texture_dot_png))
 	    {
-	      ret = read_png (texture, texture_dot_png, progress);
+	      ret = _read_png (sys_context, texture, texture_dot_png, progress);
 	      (*texture_exists) = ret;
 	    }
-	  LW6SYS_FREE (texture_dot_png);
+	  LW6SYS_FREE (sys_context, texture_dot_png);
 	}
     }
 
@@ -241,30 +226,28 @@ lw6ldr_texture_read (lw6map_texture_t * texture, const char *dirname,
        */
       char *texture_dot_jpeg = NULL;
 
-      texture_dot_jpeg =
-	lw6sys_path_concat (dirname, _LW6LDR_FILE_TEXTURE_JPEG);
+      texture_dot_jpeg = lw6sys_path_concat (sys_context, dirname, _LW6LDR_FILE_TEXTURE_JPEG);
       if (texture_dot_jpeg)
 	{
-	  if (lw6sys_file_exists (texture_dot_jpeg))
+	  if (lw6sys_file_exists (sys_context, texture_dot_jpeg))
 	    {
-	      ret = read_jpeg (texture, texture_dot_jpeg, progress);
+	      ret = _read_jpeg (sys_context, texture, texture_dot_jpeg, progress);
 	      (*texture_exists) = ret;
 	    }
-	  LW6SYS_FREE (texture_dot_jpeg);
+	  LW6SYS_FREE (sys_context, texture_dot_jpeg);
 	}
 
       if (!ret)
 	{
-	  texture_dot_jpeg =
-	    lw6sys_path_concat (dirname, _LW6LDR_FILE_TEXTURE_JPG);
+	  texture_dot_jpeg = lw6sys_path_concat (sys_context, dirname, _LW6LDR_FILE_TEXTURE_JPG);
 	  if (texture_dot_jpeg)
 	    {
-	      if (lw6sys_file_exists (texture_dot_jpeg))
+	      if (lw6sys_file_exists (sys_context, texture_dot_jpeg))
 		{
-		  ret = read_jpeg (texture, texture_dot_jpeg, progress);
+		  ret = _read_jpeg (sys_context, texture, texture_dot_jpeg, progress);
 		  (*texture_exists) = ret;
 		}
-	      LW6SYS_FREE (texture_dot_jpeg);
+	      LW6SYS_FREE (sys_context, texture_dot_jpeg);
 	    }
 	}
     }
@@ -277,28 +260,25 @@ lw6ldr_texture_read (lw6map_texture_t * texture, const char *dirname,
        */
       char *texture_alpha_dot_jpeg = NULL;
 
-      texture_alpha_dot_jpeg =
-	lw6sys_path_concat (dirname, _LW6LDR_FILE_TEXTURE_ALPHA_JPEG);
+      texture_alpha_dot_jpeg = lw6sys_path_concat (sys_context, dirname, _LW6LDR_FILE_TEXTURE_ALPHA_JPEG);
       if (texture_alpha_dot_jpeg)
 	{
-	  if (lw6sys_file_exists (texture_alpha_dot_jpeg))
+	  if (lw6sys_file_exists (sys_context, texture_alpha_dot_jpeg))
 	    {
-	      ret = read_alpha_jpeg (texture, texture_alpha_dot_jpeg, NULL);
+	      ret = _read_alpha_jpeg (sys_context, texture, texture_alpha_dot_jpeg, NULL);
 	    }
-	  LW6SYS_FREE (texture_alpha_dot_jpeg);
+	  LW6SYS_FREE (sys_context, texture_alpha_dot_jpeg);
 	}
       if (!ret)
 	{
-	  texture_alpha_dot_jpeg =
-	    lw6sys_path_concat (dirname, _LW6LDR_FILE_TEXTURE_ALPHA_JPG);
+	  texture_alpha_dot_jpeg = lw6sys_path_concat (sys_context, dirname, _LW6LDR_FILE_TEXTURE_ALPHA_JPG);
 	  if (texture_alpha_dot_jpeg)
 	    {
-	      if (lw6sys_file_exists (texture_alpha_dot_jpeg))
+	      if (lw6sys_file_exists (sys_context, texture_alpha_dot_jpeg))
 		{
-		  ret =
-		    read_alpha_jpeg (texture, texture_alpha_dot_jpeg, NULL);
+		  ret = _read_alpha_jpeg (sys_context, texture, texture_alpha_dot_jpeg, NULL);
 		}
-	      LW6SYS_FREE (texture_alpha_dot_jpeg);
+	      LW6SYS_FREE (sys_context, texture_alpha_dot_jpeg);
 	    }
 	}
     }
