@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -193,177 +193,129 @@ typedef struct lw6ldr_entry_s
 lw6ldr_entry_t;
 
 /* ldr-body.c */
-extern int lw6ldr_body_read (lw6map_body_t * body, const char *dirname,
+extern int lw6ldr_body_read (lw6sys_context_t * sys_context, lw6map_body_t * body, const char *dirname,
 			     lw6map_param_t * param,
 			     const lw6ldr_hints_t * hints, int display_w,
-			     int display_h, float ratio, int bench_value,
-			     int magic_number, lw6sys_progress_t * progress);
+			     int display_h, float ratio, int bench_value, int magic_number, lw6sys_progress_t * progress);
 
 /* ldr-color.c */
-extern void lw6ldr_auto_colors (lw6map_style_t * style,
-				const lw6ldr_hints_t * hints);
+extern void lw6ldr_auto_colors (lw6sys_context_t * sys_context, lw6map_style_t * style, const lw6ldr_hints_t * hints);
 
 /* ldr-cursortexture.c */
-extern int lw6ldr_cursor_texture_read (lw6map_cursor_texture_t *
-				       cursor_texture, const char *dirname);
+extern int lw6ldr_cursor_texture_read (lw6sys_context_t * sys_context, lw6map_cursor_texture_t * cursor_texture, const char *dirname);
 
 /* ldr-dir.c */
-extern void lw6ldr_free_entry (lw6ldr_entry_t * entry);
-extern lw6ldr_entry_t *lw6ldr_dup_entry (const lw6ldr_entry_t * entry);
-extern lw6sys_list_t *lw6ldr_get_entries (char const *map_path,
-					  char const *relative_path,
-					  char const *user_dir);
-extern void lw6ldr_for_all_entries (const char *map_path,
+extern void lw6ldr_free_entry (lw6sys_context_t * sys_context, lw6ldr_entry_t * entry);
+extern lw6ldr_entry_t *lw6ldr_dup_entry (lw6sys_context_t * sys_context, const lw6ldr_entry_t * entry);
+extern lw6sys_list_t *lw6ldr_get_entries (lw6sys_context_t * sys_context, char const *map_path, char const *relative_path, char const *user_dir);
+extern void lw6ldr_for_all_entries (lw6sys_context_t * sys_context, const char *map_path,
 				    const char *relative_path,
-				    const char *user_dir, int recursive,
-				    lw6sys_list_callback_func_t callback_func,
-				    void *func_data);
-extern lw6ldr_entry_t *lw6ldr_chain_entry (const char *map_path,
-					   const char *relative_path,
-					   const char *user_dir);
+				    const char *user_dir, int recursive, lw6sys_list_callback_func_t callback_func, void *func_data);
+extern lw6ldr_entry_t *lw6ldr_chain_entry (lw6sys_context_t * sys_context, const char *map_path, const char *relative_path, const char *user_dir);
 
 /* ldr-exp.c */
-extern int lw6ldr_exp_validate (const lw6map_level_t * level,
-				const char *user_dir);
+extern int lw6ldr_exp_validate (lw6sys_context_t * sys_context, const lw6map_level_t * level, const char *user_dir);
 
 /* ldr-grease.c */
-extern int lw6ldr_grease_apply (lw6map_layer_t * layer,
-				const lw6map_rules_t * rules,
-				const lw6ldr_hints_t * hints,
+extern int lw6ldr_grease_apply (lw6sys_context_t * sys_context, lw6map_layer_t * layer, const lw6map_rules_t * rules, const lw6ldr_hints_t * hints,
 				lw6sys_progress_t * progress);
 
 /* ldr-hints.c */
-extern void lw6ldr_hints_defaults (lw6ldr_hints_t * hints);
-extern void lw6ldr_hints_zero (lw6ldr_hints_t * hints);
-extern void lw6ldr_hints_clear (lw6ldr_hints_t * hints);
-extern int lw6ldr_hints_read (lw6ldr_hints_t * hints, const char *dirname);
-extern int lw6ldr_hints_set (lw6ldr_hints_t * hints, const char *key,
-			     const char *value);
-extern char *lw6ldr_hints_get (const lw6ldr_hints_t * hints, const char *key);
-extern char *lw6ldr_hints_get_default (const char *key);
-extern int lw6ldr_hints_update (lw6ldr_hints_t * hints,
-				lw6sys_assoc_t * values);
+extern void lw6ldr_hints_defaults (lw6sys_context_t * sys_context, lw6ldr_hints_t * hints);
+extern void lw6ldr_hints_zero (lw6sys_context_t * sys_context, lw6ldr_hints_t * hints);
+extern void lw6ldr_hints_clear (lw6sys_context_t * sys_context, lw6ldr_hints_t * hints);
+extern int lw6ldr_hints_read (lw6sys_context_t * sys_context, lw6ldr_hints_t * hints, const char *dirname);
+extern int lw6ldr_hints_set (lw6sys_context_t * sys_context, lw6ldr_hints_t * hints, const char *key, const char *value);
+extern char *lw6ldr_hints_get (lw6sys_context_t * sys_context, const lw6ldr_hints_t * hints, const char *key);
+extern char *lw6ldr_hints_get_default (lw6sys_context_t * sys_context, const char *key);
+extern int lw6ldr_hints_update (lw6sys_context_t * sys_context, lw6ldr_hints_t * hints, lw6sys_assoc_t * values);
 
 /* ldr-layer.c */
-extern int lw6ldr_layer_read_first (lw6map_layer_t * layer,
+extern int lw6ldr_layer_read_first (lw6sys_context_t * sys_context, lw6map_layer_t * layer,
 				    const char *filename,
 				    lw6map_param_t * param,
 				    const lw6ldr_hints_t * hints,
 				    int display_w, int display_h,
-				    float target_ratio, int bench_value,
-				    int magic_number, int expected_depth,
-				    lw6sys_progress_t * progress);
-extern int lw6ldr_layer_read_next (lw6map_layer_t * layer,
-				   const char *filename, int target_w,
-				   int target_h);
+				    float target_ratio, int bench_value, int magic_number, int expected_depth, lw6sys_progress_t * progress);
+extern int lw6ldr_layer_read_next (lw6sys_context_t * sys_context, lw6map_layer_t * layer, const char *filename, int target_w, int target_h);
 
 /* ldr-metadata.c */
-extern int lw6ldr_metadata_read (lw6map_metadata_t * metadata,
-				 const char *dirname);
+extern int lw6ldr_metadata_read (lw6sys_context_t * sys_context, lw6map_metadata_t * metadata, const char *dirname);
 
 /* ldr-metalayer.c */
-extern int lw6ldr_meta_layer_read (lw6map_meta_layer_t * meta_layer,
-				   const char *filename, int target_w,
-				   int target_h, int analog);
-extern int lw6ldr_meta_layer_read_if_exists (lw6map_meta_layer_t * meta_layer,
-					     const char *dirname,
-					     const char *file_only,
-					     int target_w, int target_h,
-					     int analog);
+extern int lw6ldr_meta_layer_read (lw6sys_context_t * sys_context, lw6map_meta_layer_t * meta_layer, const char *filename, int target_w, int target_h,
+				   int analog);
+extern int lw6ldr_meta_layer_read_if_exists (lw6sys_context_t * sys_context, lw6map_meta_layer_t * meta_layer, const char *dirname, const char *file_only,
+					     int target_w, int target_h, int analog);
 
 /* ldr-options.c */
-extern int lw6ldr_process_non_run_options (int argc, const char *argv[],
-					   int *run_game);
+extern int lw6ldr_process_non_run_options (lw6sys_context_t * sys_context, int argc, const char *argv[], int *run_game);
 
 /* ldr-rules.c */
-extern int lw6ldr_rules_read (lw6map_rules_t * rules, const char *dirname);
-extern int lw6ldr_rules_update (lw6map_rules_t * rules,
-				lw6sys_assoc_t * values);
+extern int lw6ldr_rules_read (lw6sys_context_t * sys_context, lw6map_rules_t * rules, const char *dirname);
+extern int lw6ldr_rules_update (lw6sys_context_t * sys_context, lw6map_rules_t * rules, lw6sys_assoc_t * values);
 
 /* ldr-param.c */
-extern int lw6ldr_param_read (lw6map_param_t * param, const char *dirname);
-extern int lw6ldr_param_update (lw6map_param_t * param,
-				lw6sys_assoc_t * values);
+extern int lw6ldr_param_read (lw6sys_context_t * sys_context, lw6map_param_t * param, const char *dirname);
+extern int lw6ldr_param_update (lw6sys_context_t * sys_context, lw6map_param_t * param, lw6sys_assoc_t * values);
 
 /* ldr-print.c */
-extern void lw6ldr_print_example_rules_xml (FILE * f);
-extern void lw6ldr_print_example_hints_xml (FILE * f);
-extern void lw6ldr_print_example_style_xml (FILE * f);
-extern void lw6ldr_print_example_teams_xml (FILE * f);
-extern int lw6ldr_print_examples (char *user_dir);
+extern void lw6ldr_print_example_rules_xml (lw6sys_context_t * sys_context, FILE * f);
+extern void lw6ldr_print_example_hints_xml (lw6sys_context_t * sys_context, FILE * f);
+extern void lw6ldr_print_example_style_xml (lw6sys_context_t * sys_context, FILE * f);
+extern void lw6ldr_print_example_teams_xml (lw6sys_context_t * sys_context, FILE * f);
+extern int lw6ldr_print_examples (lw6sys_context_t * sys_context, char *user_dir);
 
 /* ldr-read.c */
-extern lw6map_level_t *lw6ldr_read (const char *dirname,
+extern lw6map_level_t *lw6ldr_read (lw6sys_context_t * sys_context, const char *dirname,
 				    lw6sys_assoc_t * default_param,
 				    lw6sys_assoc_t * forced_param,
-				    int display_w, int display_h,
-				    int bench_value, int magic_number,
-				    const char *user_dir,
-				    lw6sys_progress_t * progress);
-extern lw6map_level_t *lw6ldr_read_relative (const char *map_path,
+				    int display_w, int display_h, int bench_value, int magic_number, const char *user_dir, lw6sys_progress_t * progress);
+extern lw6map_level_t *lw6ldr_read_relative (lw6sys_context_t * sys_context, const char *map_path,
 					     const char *relative_path,
 					     lw6sys_assoc_t * default_param,
 					     lw6sys_assoc_t * forced_param,
 					     int display_w, int display_h,
-					     int bench_value,
-					     int magic_number,
-					     const char *user_dir,
-					     lw6sys_progress_t * progress);
+					     int bench_value, int magic_number, const char *user_dir, lw6sys_progress_t * progress);
 
 /* ldr-resampler.c */
-extern void lw6ldr_resampler_init (lw6ldr_resampler_t * resampler,
+extern void lw6ldr_resampler_init (lw6sys_context_t * sys_context, lw6ldr_resampler_t * resampler,
 				   lw6map_param_t * param,
 				   const lw6ldr_hints_t * hints,
 				   int source_w,
 				   int source_h,
-				   int display_w,
-				   int display_h, float target_ratio,
-				   int bench_value, int magic_number,
-				   int expected_depth, float gray_level);
-extern void lw6ldr_resampler_use_for_gen (int *map_w, int *map_h,
-					  int display_w,
-					  int display_h,
-					  int bench_value, int magic_number);
-extern void lw6ldr_resampler_force (lw6ldr_resampler_t * resampler,
-				    int source_w, int source_h, int target_w,
-				    int target_h);
-extern void lw6ldr_resampler_source2target (const lw6ldr_resampler_t *
-					    resampler, int *target_x,
-					    int *target_y, int source_x,
+				   int display_w, int display_h, float target_ratio, int bench_value, int magic_number, int expected_depth, float gray_level);
+extern void lw6ldr_resampler_use_for_gen (lw6sys_context_t * sys_context, int *map_w, int *map_h, int display_w, int display_h, int bench_value,
+					  int magic_number);
+extern void lw6ldr_resampler_force (lw6sys_context_t * sys_context, lw6ldr_resampler_t * resampler, int source_w, int source_h, int target_w, int target_h);
+extern void lw6ldr_resampler_source2target (lw6sys_context_t * sys_context, const lw6ldr_resampler_t * resampler, int *target_x, int *target_y, int source_x,
 					    int source_y);
-extern void lw6ldr_resampler_target2source (const lw6ldr_resampler_t *
-					    resampler, int *source_x,
-					    int *source_y, int target_x,
+extern void lw6ldr_resampler_target2source (lw6sys_context_t * sys_context, const lw6ldr_resampler_t * resampler, int *source_x, int *source_y, int target_x,
 					    int target_y);
 
 /* ldr-style.c */
-extern int lw6ldr_style_read (lw6map_style_t * style, const char *dirname);
-extern int lw6ldr_style_update (lw6map_style_t * style,
-				lw6sys_assoc_t * values);
+extern int lw6ldr_style_read (lw6sys_context_t * sys_context, lw6map_style_t * style, const char *dirname);
+extern int lw6ldr_style_update (lw6sys_context_t * sys_context, lw6map_style_t * style, lw6sys_assoc_t * values);
 
 /* ldr-teams.c */
-extern int lw6ldr_teams_read (lw6map_teams_t * teams, const char *dirname);
-extern int lw6ldr_teams_update (lw6map_teams_t * teams,
-				lw6sys_assoc_t * values);
+extern int lw6ldr_teams_read (lw6sys_context_t * sys_context, lw6map_teams_t * teams, const char *dirname);
+extern int lw6ldr_teams_update (lw6sys_context_t * sys_context, lw6map_teams_t * teams, lw6sys_assoc_t * values);
 
 /* ldr-test.c */
-extern int lw6ldr_test_register (int mode);
-extern int lw6ldr_test_run (int mode);
+extern int lw6ldr_test_register (lw6sys_context_t * sys_context, int mode);
+extern int lw6ldr_test_run (lw6sys_context_t * sys_context, int mode);
 
 /* ldr-texture.c */
-extern int lw6ldr_texture_read (lw6map_texture_t * texture,
+extern int lw6ldr_texture_read (lw6sys_context_t * sys_context, lw6map_texture_t * texture,
 				const char *dirname,
 				const lw6map_param_t * param,
 				const lw6ldr_hints_t * hints, int use_texture,
-				int display_w, int display_h, float *ratio,
-				int *texture_exists,
-				lw6sys_progress_t * progress);
+				int display_w, int display_h, float *ratio, int *texture_exists, lw6sys_progress_t * progress);
 
 /* ldr-use.c */
-extern void lw6ldr_use_defaults (lw6ldr_use_t * use);
-extern void lw6ldr_use_clear (lw6ldr_use_t * use);
-extern int lw6ldr_use_set (lw6ldr_use_t * use, const char *key,
-			   const char *value);
-extern int lw6ldr_use_update (lw6ldr_use_t * use, lw6sys_assoc_t * values);
+extern void lw6ldr_use_defaults (lw6sys_context_t * sys_context, lw6ldr_use_t * use);
+extern void lw6ldr_use_clear (lw6sys_context_t * sys_context, lw6ldr_use_t * use);
+extern int lw6ldr_use_set (lw6sys_context_t * sys_context, lw6ldr_use_t * use, const char *key, const char *value);
+extern int lw6ldr_use_update (lw6sys_context_t * sys_context, lw6ldr_use_t * use, lw6sys_assoc_t * values);
 
 #endif
