@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -33,13 +33,14 @@ static SCM
 _scm_lw6cfg_defaults ()
 {
   SCM ret = SCM_BOOL_F;
+  lw6sys_context_t *sys_context = lw6_global.sys_context;
 
   LW6SYS_SCRIPT_FUNCTION_BEGIN;
-  lw6scm_coverage_call (lw6_global.coverage, __FUNCTION__);
+  lw6scm_coverage_call (sys_context, lw6_global.coverage, __FUNCTION__);
 
   if (lw6_global.cfg_context != NULL)
     {
-      if (lw6cfg_defaults (lw6_global.cfg_context))
+      if (lw6cfg_defaults (sys_context, lw6_global.cfg_context))
 	{
 	  ret = SCM_BOOL_T;
 	}
@@ -54,9 +55,10 @@ static SCM
 _scm_lw6cfg_load (SCM filename)
 {
   SCM ret = SCM_BOOL_F;
+  lw6sys_context_t *sys_context = lw6_global.sys_context;
 
   LW6SYS_SCRIPT_FUNCTION_BEGIN;
-  lw6scm_coverage_call (lw6_global.coverage, __FUNCTION__);
+  lw6scm_coverage_call (sys_context, lw6_global.coverage, __FUNCTION__);
 
   if (lw6_global.cfg_context != NULL)
     {
@@ -64,10 +66,10 @@ _scm_lw6cfg_load (SCM filename)
 
       SCM_ASSERT (scm_is_string (filename), filename, SCM_ARG1, __FUNCTION__);
 
-      c_filename = lw6scm_utils_to_0str (filename);
+      c_filename = lw6scm_utils_to_0str (sys_context, filename);
       if (c_filename)
 	{
-	  if (lw6cfg_load (lw6_global.cfg_context, c_filename))
+	  if (lw6cfg_load (sys_context, lw6_global.cfg_context, c_filename))
 	    {
 	      ret = SCM_BOOL_T;
 	    }
@@ -75,7 +77,7 @@ _scm_lw6cfg_load (SCM filename)
 	    {
 	      ret = SCM_BOOL_F;
 	    }
-	  LW6SYS_FREE (c_filename);
+	  LW6SYS_FREE (sys_context, c_filename);
 	}
     }
 
@@ -91,9 +93,10 @@ static SCM
 _scm_lw6cfg_option_exists (SCM key)
 {
   SCM ret = SCM_BOOL_F;
+  lw6sys_context_t *sys_context = lw6_global.sys_context;
 
   LW6SYS_SCRIPT_FUNCTION_BEGIN;
-  lw6scm_coverage_call (lw6_global.coverage, __FUNCTION__);
+  lw6scm_coverage_call (sys_context, lw6_global.coverage, __FUNCTION__);
 
   if (lw6_global.cfg_context != NULL)
     {
@@ -101,10 +104,10 @@ _scm_lw6cfg_option_exists (SCM key)
 
       SCM_ASSERT (scm_is_string (key), key, SCM_ARG1, __FUNCTION__);
 
-      c_key = lw6scm_utils_to_0str (key);
+      c_key = lw6scm_utils_to_0str (sys_context, key);
       if (c_key)
 	{
-	  if (lw6cfg_option_exists (lw6_global.cfg_context, c_key))
+	  if (lw6cfg_option_exists (sys_context, lw6_global.cfg_context, c_key))
 	    {
 	      ret = SCM_BOOL_T;
 	    }
@@ -112,7 +115,7 @@ _scm_lw6cfg_option_exists (SCM key)
 	    {
 	      ret = SCM_BOOL_F;
 	    }
-	  LW6SYS_FREE (c_key);
+	  LW6SYS_FREE (sys_context, c_key);
 	}
     }
 
@@ -125,9 +128,10 @@ static SCM
 _scm_lw6cfg_get_option (SCM key)
 {
   SCM ret = SCM_BOOL_F;
+  lw6sys_context_t *sys_context = lw6_global.sys_context;
 
   LW6SYS_SCRIPT_FUNCTION_BEGIN;
-  lw6scm_coverage_call (lw6_global.coverage, __FUNCTION__);
+  lw6scm_coverage_call (sys_context, lw6_global.coverage, __FUNCTION__);
 
   if (lw6_global.cfg_context != NULL)
     {
@@ -135,19 +139,19 @@ _scm_lw6cfg_get_option (SCM key)
 
       SCM_ASSERT (scm_is_string (key), key, SCM_ARG1, __FUNCTION__);
 
-      c_key = lw6scm_utils_to_0str (key);
+      c_key = lw6scm_utils_to_0str (sys_context, key);
       if (c_key)
 	{
 	  char *value = NULL;
 
-	  value = lw6cfg_get_option (lw6_global.cfg_context, c_key);
+	  value = lw6cfg_get_option (sys_context, lw6_global.cfg_context, c_key);
 	  if (value)
 	    {
 	      ret = scm_from_locale_string (value);
-	      LW6SYS_FREE (value);
+	      LW6SYS_FREE (sys_context, value);
 	    }
 
-	  LW6SYS_FREE (c_key);
+	  LW6SYS_FREE (sys_context, c_key);
 	}
     }
 
@@ -159,8 +163,10 @@ _scm_lw6cfg_get_option (SCM key)
 static SCM
 _scm_lw6cfg_set_option (SCM key, SCM value)
 {
+  lw6sys_context_t *sys_context = lw6_global.sys_context;
+
   LW6SYS_SCRIPT_FUNCTION_BEGIN;
-  lw6scm_coverage_call (lw6_global.coverage, __FUNCTION__);
+  lw6scm_coverage_call (sys_context, lw6_global.coverage, __FUNCTION__);
 
   if (lw6_global.cfg_context != NULL)
     {
@@ -170,17 +176,17 @@ _scm_lw6cfg_set_option (SCM key, SCM value)
       SCM_ASSERT (scm_is_string (key), key, SCM_ARG1, __FUNCTION__);
       SCM_ASSERT (scm_is_string (value), value, SCM_ARG2, __FUNCTION__);
 
-      c_key = lw6scm_utils_to_0str (key);
+      c_key = lw6scm_utils_to_0str (sys_context, key);
       if (c_key)
 	{
-	  c_value = lw6scm_utils_to_0str (value);
+	  c_value = lw6scm_utils_to_0str (sys_context, value);
 	  if (c_value)
 	    {
-	      lw6cfg_set_option (lw6_global.cfg_context, c_key, c_value);
+	      lw6cfg_set_option (sys_context, lw6_global.cfg_context, c_key, c_value);
 
-	      LW6SYS_FREE (c_value);
+	      LW6SYS_FREE (sys_context, c_value);
 	    }
-	  LW6SYS_FREE (c_key);
+	  LW6SYS_FREE (sys_context, c_key);
 	}
     }
 
@@ -196,9 +202,10 @@ static SCM
 _scm_lw6cfg_save (SCM filename)
 {
   SCM ret = SCM_BOOL_F;
+  lw6sys_context_t *sys_context = lw6_global.sys_context;
 
   LW6SYS_SCRIPT_FUNCTION_BEGIN;
-  lw6scm_coverage_call (lw6_global.coverage, __FUNCTION__);
+  lw6scm_coverage_call (sys_context, lw6_global.coverage, __FUNCTION__);
 
   if (lw6_global.cfg_context != NULL)
     {
@@ -206,10 +213,10 @@ _scm_lw6cfg_save (SCM filename)
 
       SCM_ASSERT (scm_is_string (filename), filename, SCM_ARG1, __FUNCTION__);
 
-      c_filename = lw6scm_utils_to_0str (filename);
+      c_filename = lw6scm_utils_to_0str (sys_context, filename);
       if (c_filename)
 	{
-	  if (lw6cfg_save (lw6_global.cfg_context, c_filename))
+	  if (lw6cfg_save (sys_context, lw6_global.cfg_context, c_filename))
 	    {
 	      ret = SCM_BOOL_T;
 	    }
@@ -217,7 +224,7 @@ _scm_lw6cfg_save (SCM filename)
 	    {
 	      ret = SCM_BOOL_F;
 	    }
-	  LW6SYS_FREE (c_filename);
+	  LW6SYS_FREE (sys_context, c_filename);
 	}
     }
 
@@ -233,11 +240,12 @@ static SCM
 _scm_lw6cfg_init ()
 {
   SCM ret = SCM_BOOL_F;
+  lw6sys_context_t *sys_context = lw6_global.sys_context;
 
   LW6SYS_SCRIPT_FUNCTION_BEGIN;
-  lw6scm_coverage_call (lw6_global.coverage, __FUNCTION__);
+  lw6scm_coverage_call (sys_context, lw6_global.coverage, __FUNCTION__);
 
-  lw6_global.cfg_context = lw6cfg_init (lw6_global.argc, lw6_global.argv);
+  lw6_global.cfg_context = lw6cfg_init (sys_context, lw6_global.argc, lw6_global.argv);
   lw6_global.cfg_initialized = lw6_global.cfg_context ? 1 : 0;
   ret = lw6_global.cfg_context ? SCM_BOOL_T : SCM_BOOL_F;
 
@@ -249,12 +257,14 @@ _scm_lw6cfg_init ()
 static SCM
 _scm_lw6cfg_quit ()
 {
+  lw6sys_context_t *sys_context = lw6_global.sys_context;
+
   LW6SYS_SCRIPT_FUNCTION_BEGIN;
-  lw6scm_coverage_call (lw6_global.coverage, __FUNCTION__);
+  lw6scm_coverage_call (sys_context, lw6_global.coverage, __FUNCTION__);
 
   if (lw6_global.cfg_context != NULL)
     {
-      lw6cfg_quit (lw6_global.cfg_context);
+      lw6cfg_quit (sys_context, lw6_global.cfg_context);
     }
 
   lw6_global.cfg_context = NULL;
@@ -273,16 +283,17 @@ static SCM
 _scm_lw6cfg_unified_get_user_dir ()
 {
   SCM ret = SCM_BOOL_F;
+  lw6sys_context_t *sys_context = lw6_global.sys_context;
   char *buf = NULL;
 
   LW6SYS_SCRIPT_FUNCTION_BEGIN;
-  lw6scm_coverage_call (lw6_global.coverage, __FUNCTION__);
+  lw6scm_coverage_call (sys_context, lw6_global.coverage, __FUNCTION__);
 
-  buf = lw6cfg_unified_get_user_dir (lw6_global.argc, lw6_global.argv);
+  buf = lw6cfg_unified_get_user_dir (sys_context, lw6_global.argc, lw6_global.argv);
   if (buf)
     {
       ret = scm_from_locale_string (buf);
-      LW6SYS_FREE (buf);
+      LW6SYS_FREE (sys_context, buf);
     }
 
   LW6SYS_SCRIPT_FUNCTION_END;
@@ -294,16 +305,17 @@ static SCM
 _scm_lw6cfg_unified_get_log_file ()
 {
   SCM ret = SCM_BOOL_F;
+  lw6sys_context_t *sys_context = lw6_global.sys_context;
   char *buf = NULL;
 
   LW6SYS_SCRIPT_FUNCTION_BEGIN;
-  lw6scm_coverage_call (lw6_global.coverage, __FUNCTION__);
+  lw6scm_coverage_call (sys_context, lw6_global.coverage, __FUNCTION__);
 
-  buf = lw6cfg_unified_get_log_file (lw6_global.argc, lw6_global.argv);
+  buf = lw6cfg_unified_get_log_file (sys_context, lw6_global.argc, lw6_global.argv);
   if (buf)
     {
       ret = scm_from_locale_string (buf);
-      LW6SYS_FREE (buf);
+      LW6SYS_FREE (sys_context, buf);
     }
 
   LW6SYS_SCRIPT_FUNCTION_END;
@@ -315,16 +327,17 @@ static SCM
 _scm_lw6cfg_unified_get_music_path ()
 {
   SCM ret = SCM_BOOL_F;
+  lw6sys_context_t *sys_context = lw6_global.sys_context;
   char *buf = NULL;
 
   LW6SYS_SCRIPT_FUNCTION_BEGIN;
-  lw6scm_coverage_call (lw6_global.coverage, __FUNCTION__);
+  lw6scm_coverage_call (sys_context, lw6_global.coverage, __FUNCTION__);
 
-  buf = lw6cfg_unified_get_music_path (lw6_global.argc, lw6_global.argv);
+  buf = lw6cfg_unified_get_music_path (sys_context, lw6_global.argc, lw6_global.argv);
   if (buf)
     {
       ret = scm_from_locale_string (buf);
-      LW6SYS_FREE (buf);
+      LW6SYS_FREE (sys_context, buf);
     }
 
   LW6SYS_SCRIPT_FUNCTION_END;
@@ -336,16 +349,17 @@ static SCM
 _scm_lw6cfg_unified_get_map_path ()
 {
   SCM ret = SCM_BOOL_F;
+  lw6sys_context_t *sys_context = lw6_global.sys_context;
   char *buf = NULL;
 
   LW6SYS_SCRIPT_FUNCTION_BEGIN;
-  lw6scm_coverage_call (lw6_global.coverage, __FUNCTION__);
+  lw6scm_coverage_call (sys_context, lw6_global.coverage, __FUNCTION__);
 
-  buf = lw6cfg_unified_get_map_path (lw6_global.argc, lw6_global.argv);
+  buf = lw6cfg_unified_get_map_path (sys_context, lw6_global.argc, lw6_global.argv);
   if (buf)
     {
       ret = scm_from_locale_string (buf);
-      LW6SYS_FREE (buf);
+      LW6SYS_FREE (sys_context, buf);
     }
 
   LW6SYS_SCRIPT_FUNCTION_END;
@@ -356,64 +370,47 @@ _scm_lw6cfg_unified_get_map_path ()
 /**
  * lw6_register_funcs_cfg
  *
+ * @sys_context: global system context
+ *
  * Register the functions of the cfg module, make them callable from Guile.
  *
  * Return value: 1 on success, 0 if failed.
  */
 int
-lw6_register_funcs_cfg ()
+lw6_register_funcs_cfg (lw6sys_context_t * sys_context)
 {
   int ret = 1;
 
   /*
    * In defaults.c
    */
-  ret = ret && lw6scm_c_define_gsubr (LW6DEF_C_LW6CFG_DEFAULTS, 0, 0, 0,
-				      (SCM (*)())_scm_lw6cfg_defaults);
+  ret = ret && lw6scm_c_define_gsubr (sys_context, LW6DEF_C_LW6CFG_DEFAULTS, 0, 0, 0, (SCM (*)())_scm_lw6cfg_defaults);
   /*
    * In load.c
    */
-  ret = ret && lw6scm_c_define_gsubr (LW6DEF_C_LW6CFG_LOAD, 1, 0, 0,
-				      (SCM (*)())_scm_lw6cfg_load);
+  ret = ret && lw6scm_c_define_gsubr (sys_context, LW6DEF_C_LW6CFG_LOAD, 1, 0, 0, (SCM (*)())_scm_lw6cfg_load);
   /*
    * In option.c
    */
-  ret = ret && lw6scm_c_define_gsubr (LW6DEF_C_LW6CFG_OPTION_EXISTS,
-				      1, 0, 0,
-				      (SCM (*)())_scm_lw6cfg_option_exists);
-  ret = ret
-    && lw6scm_c_define_gsubr (LW6DEF_C_LW6CFG_GET_OPTION, 1, 0, 0,
-			      (SCM (*)())_scm_lw6cfg_get_option);
-  ret = ret
-    && lw6scm_c_define_gsubr (LW6DEF_C_LW6CFG_SET_OPTION, 2, 0, 0,
-			      (SCM (*)())_scm_lw6cfg_set_option);
+  ret = ret && lw6scm_c_define_gsubr (sys_context, LW6DEF_C_LW6CFG_OPTION_EXISTS, 1, 0, 0, (SCM (*)())_scm_lw6cfg_option_exists);
+  ret = ret && lw6scm_c_define_gsubr (sys_context, LW6DEF_C_LW6CFG_GET_OPTION, 1, 0, 0, (SCM (*)())_scm_lw6cfg_get_option);
+  ret = ret && lw6scm_c_define_gsubr (sys_context, LW6DEF_C_LW6CFG_SET_OPTION, 2, 0, 0, (SCM (*)())_scm_lw6cfg_set_option);
   /*
    * In save.c
    */
-  ret = ret && lw6scm_c_define_gsubr (LW6DEF_C_LW6CFG_SAVE, 1, 0, 0,
-				      (SCM (*)())_scm_lw6cfg_save);
+  ret = ret && lw6scm_c_define_gsubr (sys_context, LW6DEF_C_LW6CFG_SAVE, 1, 0, 0, (SCM (*)())_scm_lw6cfg_save);
   /*
    * In setup.c
    */
-  ret = ret && lw6scm_c_define_gsubr (LW6DEF_C_LW6CFG_INIT, 0, 0, 0,
-				      (SCM (*)())_scm_lw6cfg_init);
-  ret = ret && lw6scm_c_define_gsubr (LW6DEF_C_LW6CFG_QUIT, 0, 0, 0,
-				      (SCM (*)())_scm_lw6cfg_quit);
+  ret = ret && lw6scm_c_define_gsubr (sys_context, LW6DEF_C_LW6CFG_INIT, 0, 0, 0, (SCM (*)())_scm_lw6cfg_init);
+  ret = ret && lw6scm_c_define_gsubr (sys_context, LW6DEF_C_LW6CFG_QUIT, 0, 0, 0, (SCM (*)())_scm_lw6cfg_quit);
   /*
    * In unified.c
    */
-  ret = ret
-    && lw6scm_c_define_gsubr (LW6DEF_C_LW6CFG_UNIFIED_GET_USER_DIR, 0, 0, 0,
-			      (SCM (*)())_scm_lw6cfg_unified_get_user_dir);
-  ret = ret
-    && lw6scm_c_define_gsubr (LW6DEF_C_LW6CFG_UNIFIED_GET_LOG_FILE, 0, 0, 0,
-			      (SCM (*)())_scm_lw6cfg_unified_get_log_file);
-  ret = ret
-    && lw6scm_c_define_gsubr (LW6DEF_C_LW6CFG_UNIFIED_GET_MUSIC_PATH, 0, 0, 0,
-			      (SCM (*)())_scm_lw6cfg_unified_get_music_path);
-  ret = ret
-    && lw6scm_c_define_gsubr (LW6DEF_C_LW6CFG_UNIFIED_GET_MAP_PATH, 0, 0, 0,
-			      (SCM (*)())_scm_lw6cfg_unified_get_map_path);
+  ret = ret && lw6scm_c_define_gsubr (sys_context, LW6DEF_C_LW6CFG_UNIFIED_GET_USER_DIR, 0, 0, 0, (SCM (*)())_scm_lw6cfg_unified_get_user_dir);
+  ret = ret && lw6scm_c_define_gsubr (sys_context, LW6DEF_C_LW6CFG_UNIFIED_GET_LOG_FILE, 0, 0, 0, (SCM (*)())_scm_lw6cfg_unified_get_log_file);
+  ret = ret && lw6scm_c_define_gsubr (sys_context, LW6DEF_C_LW6CFG_UNIFIED_GET_MUSIC_PATH, 0, 0, 0, (SCM (*)())_scm_lw6cfg_unified_get_music_path);
+  ret = ret && lw6scm_c_define_gsubr (sys_context, LW6DEF_C_LW6CFG_UNIFIED_GET_MAP_PATH, 0, 0, 0, (SCM (*)())_scm_lw6cfg_unified_get_map_path);
 
   return ret;
 }
