@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -37,10 +37,12 @@ static SCM
 _scm_lw6cns_console_support ()
 {
   SCM ret = SCM_BOOL_F;
-  LW6SYS_SCRIPT_FUNCTION_BEGIN;
-  lw6scm_coverage_call (lw6_global.coverage, __FUNCTION__);
+  lw6sys_context_t *sys_context = lw6_global.sys_context;
 
-  ret = lw6cns_console_support ()? SCM_BOOL_T : SCM_BOOL_F;
+  LW6SYS_SCRIPT_FUNCTION_BEGIN;
+  lw6scm_coverage_call (sys_context, lw6_global.coverage, __FUNCTION__);
+
+  ret = lw6cns_console_support (sys_context) ? SCM_BOOL_T : SCM_BOOL_F;
 
   LW6SYS_SCRIPT_FUNCTION_END;
 
@@ -51,10 +53,12 @@ static SCM
 _scm_lw6cns_term_support ()
 {
   SCM ret = SCM_BOOL_F;
-  LW6SYS_SCRIPT_FUNCTION_BEGIN;
-  lw6scm_coverage_call (lw6_global.coverage, __FUNCTION__);
+  lw6sys_context_t *sys_context = lw6_global.sys_context;
 
-  ret = lw6cns_term_support ()? SCM_BOOL_T : SCM_BOOL_F;
+  LW6SYS_SCRIPT_FUNCTION_BEGIN;
+  lw6scm_coverage_call (sys_context, lw6_global.coverage, __FUNCTION__);
+
+  ret = lw6cns_term_support (sys_context) ? SCM_BOOL_T : SCM_BOOL_F;
 
   LW6SYS_SCRIPT_FUNCTION_END;
 
@@ -67,12 +71,14 @@ _scm_lw6cns_term_support ()
 static SCM
 _scm_lw6cns_init ()
 {
+  lw6sys_context_t *sys_context = lw6_global.sys_context;
+
   LW6SYS_SCRIPT_FUNCTION_BEGIN;
-  lw6scm_coverage_call (lw6_global.coverage, __FUNCTION__);
+  lw6scm_coverage_call (sys_context, lw6_global.coverage, __FUNCTION__);
 
   if (!lw6_global.cns_initialized)
     {
-      lw6cns_handler_install (lw6_cns_handler);
+      lw6cns_handler_install (sys_context, lw6_cns_handler);
       lw6_global.cns_initialized = 1;
     }
 
@@ -84,12 +90,14 @@ _scm_lw6cns_init ()
 static SCM
 _scm_lw6cns_quit ()
 {
+  lw6sys_context_t *sys_context = lw6_global.sys_context;
+
   LW6SYS_SCRIPT_FUNCTION_BEGIN;
-  lw6scm_coverage_call (lw6_global.coverage, __FUNCTION__);
+  lw6scm_coverage_call (sys_context, lw6_global.coverage, __FUNCTION__);
 
   if (lw6_global.cns_initialized)
     {
-      lw6cns_handler_remove ();
+      lw6cns_handler_remove (sys_context);
       lw6_global.cns_initialized = 0;
     }
 
@@ -101,12 +109,14 @@ _scm_lw6cns_quit ()
 static SCM
 _scm_lw6cns_poll ()
 {
+  lw6sys_context_t *sys_context = lw6_global.sys_context;
+
   LW6SYS_SCRIPT_FUNCTION_BEGIN;
-  lw6scm_coverage_call (lw6_global.coverage, __FUNCTION__);
+  lw6scm_coverage_call (sys_context, lw6_global.coverage, __FUNCTION__);
 
   if (lw6_global.cns_initialized)
     {
-      lw6cns_handler_poll ();
+      lw6cns_handler_poll (sys_context);
     }
 
   LW6SYS_SCRIPT_FUNCTION_END;
@@ -117,12 +127,14 @@ _scm_lw6cns_poll ()
 /**
  * lw6_register_funcs_cns
  *
+ * @sys_context: global system context
+ *
  * Register the functions of the cns module, make them callable from Guile.
  *
  * Return value: 1 on success, 0 if failed.
  */
 int
-lw6_register_funcs_cns ()
+lw6_register_funcs_cns (lw6sys_context_t * sys_context)
 {
   int ret = 1;
 
@@ -132,21 +144,14 @@ lw6_register_funcs_cns ()
   /*
    * In support.c
    */
-  ret = ret
-    && lw6scm_c_define_gsubr (LW6DEF_C_LW6CNS_CONSOLE_SUPPORT, 0, 0, 0,
-			      (SCM (*)())_scm_lw6cns_console_support);
-  ret = ret
-    && lw6scm_c_define_gsubr (LW6DEF_C_LW6CNS_TERM_SUPPORT, 0, 0, 0,
-			      (SCM (*)())_scm_lw6cns_term_support);
+  ret = ret && lw6scm_c_define_gsubr (sys_context, LW6DEF_C_LW6CNS_CONSOLE_SUPPORT, 0, 0, 0, (SCM (*)())_scm_lw6cns_console_support);
+  ret = ret && lw6scm_c_define_gsubr (sys_context, LW6DEF_C_LW6CNS_TERM_SUPPORT, 0, 0, 0, (SCM (*)())_scm_lw6cns_term_support);
   /*
    * In handler.c
    */
-  ret = ret && lw6scm_c_define_gsubr (LW6DEF_C_LW6CNS_INIT, 0, 0, 0,
-				      (SCM (*)())_scm_lw6cns_init);
-  ret = ret && lw6scm_c_define_gsubr (LW6DEF_C_LW6CNS_QUIT, 0, 0, 0,
-				      (SCM (*)())_scm_lw6cns_quit);
-  ret = ret && lw6scm_c_define_gsubr (LW6DEF_C_LW6CNS_POLL, 0, 0, 0,
-				      (SCM (*)())_scm_lw6cns_poll);
+  ret = ret && lw6scm_c_define_gsubr (sys_context, LW6DEF_C_LW6CNS_INIT, 0, 0, 0, (SCM (*)())_scm_lw6cns_init);
+  ret = ret && lw6scm_c_define_gsubr (sys_context, LW6DEF_C_LW6CNS_QUIT, 0, 0, 0, (SCM (*)())_scm_lw6cns_quit);
+  ret = ret && lw6scm_c_define_gsubr (sys_context, LW6DEF_C_LW6CNS_POLL, 0, 0, 0, (SCM (*)())_scm_lw6cns_poll);
 
   return ret;
 }
