@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -37,15 +37,16 @@ static SCM
 _scm_lw6net_init (SCM net_log)
 {
   SCM ret = SCM_BOOL_F;
+  lw6sys_context_t *sys_context = lw6_global.sys_context;
   int c_net_log = 0;
 
   LW6SYS_SCRIPT_FUNCTION_BEGIN;
-  lw6scm_coverage_call (lw6_global.coverage, __FUNCTION__);
+  lw6scm_coverage_call (sys_context, lw6_global.coverage, __FUNCTION__);
 
   SCM_ASSERT (SCM_BOOLP (net_log), net_log, SCM_ARG1, __FUNCTION__);
 
   c_net_log = SCM_NFALSEP (net_log);
-  if (lw6net_init (lw6_global.argc, lw6_global.argv, c_net_log))
+  if (lw6net_init (sys_context, lw6_global.argc, lw6_global.argv, c_net_log))
     {
       lw6_global.net_initialized = 1;
       ret = SCM_BOOL_F;
@@ -59,12 +60,14 @@ _scm_lw6net_init (SCM net_log)
 static SCM
 _scm_lw6net_quit ()
 {
+  lw6sys_context_t *sys_context = lw6_global.sys_context;
+
   LW6SYS_SCRIPT_FUNCTION_BEGIN;
-  lw6scm_coverage_call (lw6_global.coverage, __FUNCTION__);
+  lw6scm_coverage_call (sys_context, lw6_global.coverage, __FUNCTION__);
 
   if (lw6_global.net_initialized)
     {
-      lw6net_quit ();
+      lw6net_quit (sys_context);
     }
   lw6_global.net_initialized = 0;
 
@@ -76,12 +79,14 @@ _scm_lw6net_quit ()
 /**
  * lw6_register_funcs_net
  *
+ * @sys_context: global system context
+ *
  * Register the functions of the net module, make them callable from Guile.
  *
  * Return value: 1 on success, 0 if failed.
  */
 int
-lw6_register_funcs_net ()
+lw6_register_funcs_net (lw6sys_context_t * sys_context)
 {
   int ret = 1;
 
@@ -91,10 +96,8 @@ lw6_register_funcs_net ()
   /*
    * In setup.c
    */
-  ret = ret && lw6scm_c_define_gsubr (LW6DEF_C_LW6NET_INIT, 1, 0, 0,
-				      (SCM (*)())_scm_lw6net_init);
-  ret = ret && lw6scm_c_define_gsubr (LW6DEF_C_LW6NET_QUIT, 0, 0, 0,
-				      (SCM (*)())_scm_lw6net_quit);
+  ret = ret && lw6scm_c_define_gsubr (sys_context, LW6DEF_C_LW6NET_INIT, 1, 0, 0, (SCM (*)())_scm_lw6net_init);
+  ret = ret && lw6scm_c_define_gsubr (sys_context, LW6DEF_C_LW6NET_QUIT, 0, 0, 0, (SCM (*)())_scm_lw6net_quit);
 
   return ret;
 }
