@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -37,19 +37,20 @@ static SCM
 _scm_lw6srv_get_backends ()
 {
   SCM ret = SCM_BOOL_F;
-  lw6sys_assoc_t *backends;
-  lw6sys_list_t *keys;
-  lw6sys_list_t *key;
-  char *module_id;
-  char *module_name;
+  lw6sys_context_t *sys_context = lw6_global.sys_context;
+  lw6sys_assoc_t *backends = NULL;
+  lw6sys_list_t *keys = NULL;
+  lw6sys_list_t *key = NULL;
+  const char *module_id = NULL;
+  const char *module_name = NULL;
 
   LW6SYS_SCRIPT_FUNCTION_BEGIN;
-  lw6scm_coverage_call (lw6_global.coverage, __FUNCTION__);
+  lw6scm_coverage_call (sys_context, lw6_global.coverage, __FUNCTION__);
 
-  backends = lw6srv_get_backends (lw6_global.argc, lw6_global.argv);
+  backends = lw6srv_get_backends (sys_context, lw6_global.argc, lw6_global.argv);
   if (backends)
     {
-      keys = lw6sys_assoc_keys (backends);
+      keys = lw6sys_assoc_keys (sys_context, backends);
       if (keys)
 	{
 	  ret = SCM_EOL;
@@ -58,20 +59,16 @@ _scm_lw6srv_get_backends ()
 	    {
 	      if (key->data)
 		{
-		  module_id = (char *) key->data;
-		  module_name =
-		    (char *) lw6sys_assoc_get (backends, module_id);
-		  ret =
-		    scm_cons (scm_cons
-			      (scm_from_locale_string (module_id),
-			       scm_from_locale_string (module_name)), ret);
+		  module_id = (const char *) key->data;
+		  module_name = (const char *) lw6sys_assoc_get (sys_context, backends, module_id);
+		  ret = scm_cons (scm_cons (scm_from_locale_string (module_id), scm_from_locale_string (module_name)), ret);
 		}
-	      key = lw6sys_list_next (key);
+	      key = lw6sys_list_next (sys_context, key);
 	    }
-	  lw6sys_list_free (keys);
+	  lw6sys_list_free (sys_context, keys);
 	  ret = scm_reverse (ret);
 	}
-      lw6sys_assoc_free (backends);
+      lw6sys_assoc_free (sys_context, backends);
     }
 
   LW6SYS_SCRIPT_FUNCTION_END;
@@ -82,12 +79,14 @@ _scm_lw6srv_get_backends ()
 /**
  * lw6_register_funcs_srv
  *
+ * @sys_context: global system context
+ *
  * Register the functions of the srv module, make them callable from Guile.
  *
  * Return value: 1 on success, 0 if failed.
  */
 int
-lw6_register_funcs_srv ()
+lw6_register_funcs_srv (lw6sys_context_t * sys_context)
 {
   int ret = 1;
 
@@ -97,8 +96,7 @@ lw6_register_funcs_srv ()
   /*
    * In backend.c
    */
-  ret = ret && lw6scm_c_define_gsubr (LW6DEF_C_LW6SRV_GET_BACKENDS, 0, 0, 0,
-				      (SCM (*)())_scm_lw6srv_get_backends);
+  ret = ret && lw6scm_c_define_gsubr (sys_context, LW6DEF_C_LW6SRV_GET_BACKENDS, 0, 0, 0, (SCM (*)())_scm_lw6srv_get_backends);
 
   return ret;
 }
