@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -26,7 +26,7 @@
 #include "liquidwar6.h"
 
 static void *
-guile_main (void *data)
+_guile_main (lw6sys_context_t * sys_context, void *data)
 {
   char *script = NULL;
 
@@ -39,24 +39,22 @@ guile_main (void *data)
   SCM_RESET_DEBUG_MODE;
 #endif
 
-  lw6sys_log (LW6SYS_LOG_INFO,
-	      _x_ ("registering C types and functions for Guile"));
-  lw6_register_smobs ();
-  lw6_register_funcs ();
+  lw6sys_log (sys_context, LW6SYS_LOG_INFO, _x_ ("registering C types and functions for Guile"));
+  lw6_register_smobs (sys_context);
+  lw6_register_funcs (sys_context);
 
-  script = lw6sys_get_script_file (lw6_global.argc, lw6_global.argv);
+  script = lw6sys_get_script_file (sys_context, lw6_global.argc, lw6_global.argv);
   if (script)
     {
-      if (lw6sys_file_exists (script))
+      if (lw6sys_file_exists (sys_context, script))
 	{
-	  lw6scm_c_primitive_load (script);
+	  lw6scm_c_primitive_load (sys_context, script);
 	}
       else
 	{
-	  lw6sys_log (LW6SYS_LOG_ERROR,
-		      _("unable to read main script file \"%s\""), script);
+	  lw6sys_log (sys_context, LW6SYS_LOG_ERROR, _("unable to read main script file \"%s\""), script);
 	}
-      LW6SYS_FREE (script);
+      LW6SYS_FREE (sys_context, script);
     }
 
   scm_gc ();
@@ -67,34 +65,35 @@ guile_main (void *data)
    * so we just wait, and Guile does the job for real.
    * Weird, I told you.
    */
-  lw6sys_snooze ();
+  lw6sys_snooze (sys_context);
   scm_gc ();
   /*
    * In older versions there was a lw6_quit_global_1 function to
    * cleanup the dsp/gfx module in the same thread than the caller
    * (SDL limitation on Mac OS X). Now this is done before by the
-   * script using a call to lw6_release (c-lw6-release).
+   * script using a call to lw6_release (sys_context,c-lw6-release).
    */
 
   return NULL;
 }
 
 static void
-_run (void *data)
+_run (lw6sys_context_t * sys_context, void *data)
 {
-  lw6sys_log (LW6SYS_LOG_DEBUG, _x_ ("main run data=%p"), data);
-  lw6scm_with_guile (guile_main, data);
+  lw6sys_log (sys_context, LW6SYS_LOG_DEBUG, _x_ ("main run data=%p"), data);
+  lw6scm_with_guile (sys_context, _guile_main, data);
 }
 
 static void
-_end (void *data)
+_end (lw6sys_context_t * sys_context, void *data)
 {
-  lw6sys_log (LW6SYS_LOG_DEBUG, _x_ ("main end data=%p"), data);
+  lw6sys_log (sys_context, LW6SYS_LOG_DEBUG, _x_ ("main end data=%p"), data);
 }
 
 /**
  * lw6_main:
  *
+ * @sys_context: global system context
  * @argc: the argc parameter of the @main function, that is, the number
  *   of command-line args.
  * @argv: the argv parameter of the @main function, that is, an array
@@ -114,7 +113,7 @@ _end (void *data)
  *   use is "return !lw6_main(argc, argv);".
  */
 int
-lw6_main (int argc, const char *argv[])
+lw6_main (lw6sys_context_t * sys_context, int argc, const char *argv[])
 {
   int ret = 0;
   char *debug_str = NULL;
@@ -125,60 +124,58 @@ lw6_main (int argc, const char *argv[])
   int run_game = 1;
   char *pid_file = NULL;
 
-  ret = lw6_process_non_run_options (argc, argv, &run_game);
+  ret = lw6_process_non_run_options (sys_context, argc, argv, &run_game);
   if (run_game)
     {
-      debug_str = lw6sys_arg_get_value_with_env (argc, argv, LW6DEF_DEBUG);
+      debug_str = lw6sys_arg_get_value_with_env (sys_context, argc, argv, LW6DEF_DEBUG);
       if (debug_str)
 	{
-	  debug = lw6sys_atob (debug_str);
-	  lw6sys_debug_set (debug);
-	  LW6SYS_FREE (debug_str);
+	  debug = lw6sys_atob (sys_context, debug_str);
+	  lw6sys_debug_set (sys_context, debug);
+	  LW6SYS_FREE (sys_context, debug_str);
 	}
-      log_level_str = lw6cfg_unified_get_value (argc, argv, LW6DEF_LOG_LEVEL);
+      log_level_str = lw6cfg_unified_get_value (sys_context, argc, argv, LW6DEF_LOG_LEVEL);
       if (log_level_str)
 	{
-	  log_level = lw6sys_atoi (log_level_str);
-	  lw6sys_log_set_level (log_level);
-	  LW6SYS_FREE (log_level_str);
+	  log_level = lw6sys_atoi (sys_context, log_level_str);
+	  lw6sys_log_set_level (sys_context, log_level);
+	  LW6SYS_FREE (sys_context, log_level_str);
 	}
-      log_file = lw6cfg_unified_get_log_file (argc, argv);
+      log_file = lw6cfg_unified_get_log_file (sys_context, argc, argv);
       if (log_file)
 	{
-	  lw6sys_log_clear (log_file);
-	  LW6SYS_FREE (log_file);
+	  lw6sys_log_clear (sys_context, log_file);
+	  LW6SYS_FREE (sys_context, log_file);
 	}
       else
 	{
-	  lw6sys_log_critical (_x_ ("can't determine log file"));
+	  lw6sys_log_critical (sys_context, _x_ ("can't determine log file"));
 	}
 
-      lw6hlp_print_hello (argc, argv);
-      lw6_fix_env (argc, argv);
+      lw6hlp_print_hello (sys_context, argc, argv);
+      lw6_fix_env (sys_context, argc, argv);
 
-      if (lw6_init_global (argc, argv))
+      if (lw6_init_global (sys_context, argc, argv))
 	{
 #ifdef LW6_MAC_OS_X
-	  if (!lw6sys_vthread_run (_run, _end, NULL))
+	  if (!lw6sys_vthread_run (sys_context, _run, _end, NULL))
 	    {
 	      ret = 0;
 	    }
 #else
-	  _run (NULL);
-	  _end (NULL);
+	  _run (sys_context, NULL);
+	  _end (sys_context, NULL);
 #endif
 
 	  if (ret)
 	    {
 	      if (lw6_global.ret)
 		{
-		  lw6sys_log (LW6SYS_LOG_INFO, _x_ ("script returned true"));
+		  lw6sys_log (sys_context, LW6SYS_LOG_INFO, _x_ ("script returned true"));
 		}
 	      else
 		{
-		  lw6sys_log (LW6SYS_LOG_WARNING,
-			      _x_
-			      ("script returned false, something is wrong"));
+		  lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("script returned false, something is wrong"));
 		  ret = 0;
 		}
 	    }
@@ -190,21 +187,21 @@ lw6_main (int argc, const char *argv[])
 	   * destructors (even for "chained" objects like game_struct)
 	   * do not need to access SCM objects.
 	   */
-	  lw6_quit_global ();
+	  lw6_quit_global (sys_context);
 	}
 
-      lw6hlp_print_goodbye ();
+      lw6hlp_print_goodbye (sys_context);
     }
   else
     {
-      lw6sys_clear_memory_bazooka ();
+      lw6sys_clear_memory_bazooka (sys_context);
     }
 
-  pid_file = lw6sys_daemon_pid_file (argc, argv);
+  pid_file = lw6sys_daemon_pid_file (sys_context, argc, argv);
   if (pid_file)
     {
-      lw6sys_daemon_stop (pid_file);
-      LW6SYS_FREE (pid_file);
+      lw6sys_daemon_stop (sys_context, pid_file);
+      LW6SYS_FREE (sys_context, pid_file);
     }
 
   return ret;
