@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -65,6 +65,7 @@ _lw6_test_param_t;
 typedef struct _lw6_test_data_s
 {
   int ret;
+  lw6sys_context_t *sys_context;
   _lw6_test_param_t param;
   _lw6_test_param_t param_a;
   _lw6_test_param_t param_b;
@@ -72,25 +73,24 @@ typedef struct _lw6_test_data_s
   int default_log_level_id;
 } _lw6_test_data_t;
 
-static _lw6_test_data_t _test_data =
-  { 0, {0, 0, NULL, 0, 0, 0, 0}, {0, 0, NULL, 0, 0, 0, 0}, {0, 0, NULL, 0, 0,
-							    0, 0}, {0, 0,
-								    NULL, 0,
-								    0, 0, 0},
+static _lw6_test_data_t _test_data = { 0, NULL, {0, 0, NULL, 0, 0, 0, 0}, {0, 0, NULL, 0, 0, 0, 0}, {0, 0, NULL, 0, 0,
+												     0, 0}, {0, 0,
+													     NULL, 0,
+													     0, 0, 0},
 0
 };
 
 static char *
-get_test_file (int argc, const char **argv, int mode, int suite)
+_get_test_file (lw6sys_context_t * sys_context, int argc, const char **argv, int mode, int suite)
 {
   char *script_file = NULL;
   char *script_dir = NULL;
   char *ret = NULL;
 
-  script_file = lw6sys_get_script_file (argc, argv);
+  script_file = lw6sys_get_script_file (sys_context, argc, argv);
   if (script_file)
     {
-      script_dir = lw6sys_path_parent (script_file);
+      script_dir = lw6sys_path_parent (sys_context, script_file);
       if (script_dir)
 	{
 	  if (!(mode & LW6SYS_TEST_MODE_FULL_TEST))
@@ -98,16 +98,16 @@ get_test_file (int argc, const char **argv, int mode, int suite)
 	      switch (suite)
 		{
 		case _TEST_SUITE_NODE_A:
-		  ret = lw6sys_path_concat (script_dir, _TEST_FILE_0_NODE_A);
+		  ret = lw6sys_path_concat (sys_context, script_dir, _TEST_FILE_0_NODE_A);
 		  break;
 		case _TEST_SUITE_NODE_B:
-		  ret = lw6sys_path_concat (script_dir, _TEST_FILE_0_NODE_B);
+		  ret = lw6sys_path_concat (sys_context, script_dir, _TEST_FILE_0_NODE_B);
 		  break;
 		case _TEST_SUITE_NODE_C:
-		  ret = lw6sys_path_concat (script_dir, _TEST_FILE_0_NODE_C);
+		  ret = lw6sys_path_concat (sys_context, script_dir, _TEST_FILE_0_NODE_C);
 		  break;
 		default:
-		  ret = lw6sys_path_concat (script_dir, _TEST_FILE_0_MAIN);
+		  ret = lw6sys_path_concat (sys_context, script_dir, _TEST_FILE_0_MAIN);
 		  break;
 		}
 	    }
@@ -116,28 +116,28 @@ get_test_file (int argc, const char **argv, int mode, int suite)
 	      switch (suite)
 		{
 		case _TEST_SUITE_NODE_A:
-		  ret = lw6sys_path_concat (script_dir, _TEST_FILE_1_NODE_A);
+		  ret = lw6sys_path_concat (sys_context, script_dir, _TEST_FILE_1_NODE_A);
 		  break;
 		case _TEST_SUITE_NODE_B:
-		  ret = lw6sys_path_concat (script_dir, _TEST_FILE_1_NODE_B);
+		  ret = lw6sys_path_concat (sys_context, script_dir, _TEST_FILE_1_NODE_B);
 		  break;
 		case _TEST_SUITE_NODE_C:
-		  ret = lw6sys_path_concat (script_dir, _TEST_FILE_1_NODE_C);
+		  ret = lw6sys_path_concat (sys_context, script_dir, _TEST_FILE_1_NODE_C);
 		  break;
 		default:
-		  ret = lw6sys_path_concat (script_dir, _TEST_FILE_1_MAIN);
+		  ret = lw6sys_path_concat (sys_context, script_dir, _TEST_FILE_1_MAIN);
 		  break;
 		}
 	    }
-	  LW6SYS_FREE (script_dir);
+	  LW6SYS_FREE (sys_context, script_dir);
 	}
-      LW6SYS_FREE (script_file);
+      LW6SYS_FREE (sys_context, script_file);
     }
 
-  if (ret && !lw6sys_file_exists (ret))
+  if (ret && !lw6sys_file_exists (sys_context, ret))
     {
-      lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("can't open \"%s\""), ret);
-      LW6SYS_FREE (ret);
+      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("can't open \"%s\""), ret);
+      LW6SYS_FREE (sys_context, ret);
       ret = NULL;
     }
 
@@ -148,6 +148,7 @@ static void
 _guile_test_callback (_lw6_test_param_t * param)
 {
   int ret = 1;
+  lw6sys_context_t *sys_context = NULL;
 
   LW6SYS_TEST_FUNCTION_BEGIN;
 
@@ -161,35 +162,32 @@ _guile_test_callback (_lw6_test_param_t * param)
      * are no logs and this avoids dirty interferences.
      * Will will run each test in the main thread anyway.
      */
-    lw6sys_log_set_level (param->log_level_id);
+    lw6sys_log_set_level (sys_context, param->log_level_id);
 
-    lw6sys_log (LW6SYS_LOG_NOTICE, _x_ ("registering Guile smobs"));
-    if (lw6_register_smobs ())
+    lw6sys_log (sys_context, LW6SYS_LOG_NOTICE, _x_ ("registering Guile smobs"));
+    if (lw6_register_smobs (sys_context))
       {
 
-	lw6sys_log (LW6SYS_LOG_NOTICE, _x_ ("registering Guile functions"));
-	if (lw6_register_funcs ())
+	lw6sys_log (sys_context, LW6SYS_LOG_NOTICE, _x_ ("registering Guile functions"));
+	if (lw6_register_funcs (sys_context))
 	  {
-	    test_file =
-	      get_test_file (param->argc, param->argv, param->mode,
-			     param->suite);
+	    test_file = _get_test_file (sys_context, param->argc, param->argv, param->mode, param->suite);
 	    if (test_file)
 	      {
-		lw6sys_log (LW6SYS_LOG_NOTICE, _x_ ("loading \"%s\""),
-			    test_file);
-		lw6scm_c_primitive_load (test_file);
-		LW6SYS_FREE (test_file);
+		lw6sys_log (sys_context, LW6SYS_LOG_NOTICE, _x_ ("loading \"%s\""), test_file);
+		lw6scm_c_primitive_load (sys_context, test_file);
+		LW6SYS_FREE (sys_context, test_file);
 	      }
 	  }
 	else
 	  {
-	    lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("unable to register funcs"));
+	    lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("unable to register funcs"));
 	    ret = 0;
 	  }
       }
     else
       {
-	lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("unable to register smobs"));
+	lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("unable to register smobs"));
 	ret = 0;
       }
 
@@ -197,51 +195,41 @@ _guile_test_callback (_lw6_test_param_t * param)
 
     if (param->coverage_check)
       {
-	funcs = lw6hlp_list_funcs ();
+	funcs = lw6hlp_list_funcs (sys_context);
 	if (funcs)
 	  {
-	    if (lw6scm_coverage_check
-		(&coverage_percent, lw6_global.coverage, funcs)
-		|| coverage_percent >= _TEST_COVERAGE_PERCENT_MIN)
+	    if (lw6scm_coverage_check (sys_context, &coverage_percent, lw6_global.coverage, funcs) || coverage_percent >= _TEST_COVERAGE_PERCENT_MIN)
 	      {
-		lw6sys_log (LW6SYS_LOG_NOTICE,
-			    _x_ ("script coverage OK %d%% (%d%% required)"),
-			    coverage_percent, _TEST_COVERAGE_PERCENT_MIN);
+		lw6sys_log (sys_context, LW6SYS_LOG_NOTICE, _x_ ("script coverage OK %d%% (%d%% required)"), coverage_percent, _TEST_COVERAGE_PERCENT_MIN);
 	      }
 	    else
 	      {
-		lw6sys_log (LW6SYS_LOG_WARNING,
-			    _x_
-			    ("script coverage is only %d%% (%d%% required)"),
-			    coverage_percent, _TEST_COVERAGE_PERCENT_MIN);
+		lw6sys_log (sys_context, LW6SYS_LOG_WARNING,
+			    _x_ ("script coverage is only %d%% (%d%% required)"), coverage_percent, _TEST_COVERAGE_PERCENT_MIN);
 		ret = 0;
 	      }
-	    lw6sys_list_free (funcs);
+	    lw6sys_list_free (sys_context, funcs);
 	  }
 	else
 	  {
-	    lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("unable to get funcs list"));
+	    lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("unable to get funcs list"));
 	    ret = 0;
 	  }
       }
     else
       {
-	lw6sys_log (LW6SYS_LOG_NOTICE, _x_ ("skipping coverage check"));
+	lw6sys_log (sys_context, LW6SYS_LOG_NOTICE, _x_ ("skipping coverage check"));
       }
 
     if (ret)
       {
 	if (lw6_global.ret)
 	  {
-	    lw6sys_log (LW6SYS_LOG_NOTICE,
-			_x_
-			("script returned true, looks like tests were OK"));
+	    lw6sys_log (sys_context, LW6SYS_LOG_NOTICE, _x_ ("script returned true, looks like tests were OK"));
 	  }
 	else
 	  {
-	    lw6sys_log (LW6SYS_LOG_WARNING,
-			_x_
-			("script returned false, at least one test failed"));
+	    lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("script returned false, at least one test failed"));
 	    ret = 0;
 	  }
       }
@@ -257,7 +245,7 @@ _guile_test_callback (_lw6_test_param_t * param)
 }
 
 static void *
-_guile_test (void *data)
+_guile_test (lw6sys_context_t * sys_context, void *data)
 {
   _lw6_test_param_t *param = (_lw6_test_param_t *) data;
 
@@ -267,18 +255,18 @@ _guile_test (void *data)
 }
 
 static void
-_guile_test_run (void *data)
+_guile_test_run (lw6sys_context_t * sys_context, void *data)
 {
   /*
    * We wait (or not) for some time, to simulate, (randomly!)
    * some time shift between various network flavors of tests.
    */
-  if (!lw6sys_random (_TEST_RUN_RANDOM_RANGE))
+  if (!lw6sys_random (sys_context, _TEST_RUN_RANDOM_RANGE))
     {
-      lw6sys_snooze ();
+      lw6sys_snooze (sys_context);
     }
 
-  lw6scm_with_guile (_guile_test, data);
+  lw6scm_with_guile (sys_context, _guile_test, data);
 }
 
 /*
@@ -287,12 +275,15 @@ _guile_test_run (void *data)
 static void
 _test_main ()
 {
-  _guile_test_run (&_test_data.param);
+  lw6sys_context_t *sys_context = _test_data.sys_context;
+
+  _guile_test_run (sys_context, &_test_data.param);
 }
 
 static void
 _test_node_abc ()
 {
+  lw6sys_context_t *sys_context = _test_data.sys_context;
   u_int64_t pid_b = 0LL;
   u_int64_t pid_c = 0LL;
 
@@ -301,7 +292,7 @@ _test_node_abc ()
    * closed sockets, make double-sure a previous node won't
    * be left and used by next set of nodes.
    */
-  lw6sys_sleep (_TEST_NET_SLEEP);
+  lw6sys_sleep (sys_context, _TEST_NET_SLEEP);
 
   /*
    * First network test, we launch node_a in the main thread,
@@ -312,19 +303,19 @@ _test_node_abc ()
    */
   _test_data.param_b.log_level_id = LW6SYS_LOG_ERROR_ID;
   _test_data.param_c.log_level_id = LW6SYS_LOG_ERROR_ID;
-  pid_b = lw6sys_process_fork_and_call (_guile_test_run, &_test_data.param_b);
-  pid_c = lw6sys_process_fork_and_call (_guile_test_run, &_test_data.param_c);
+  pid_b = lw6sys_process_fork_and_call (sys_context, _guile_test_run, &_test_data.param_b);
+  pid_c = lw6sys_process_fork_and_call (sys_context, _guile_test_run, &_test_data.param_c);
   if (pid_b != 0 && pid_c != 0)
     {
-      _guile_test_run (&_test_data.param_a);
+      _guile_test_run (sys_context, &_test_data.param_a);
     }
   if (pid_b != 0)
     {
-      lw6sys_process_kill_1_9 (pid_b);
+      lw6sys_process_kill_1_9 (sys_context, pid_b);
     }
   if (pid_c != 0)
     {
-      lw6sys_process_kill_1_9 (pid_c);
+      lw6sys_process_kill_1_9 (sys_context, pid_c);
     }
   _test_data.param_b.log_level_id = _test_data.default_log_level_id;
   _test_data.param_c.log_level_id = _test_data.default_log_level_id;
@@ -333,6 +324,7 @@ _test_node_abc ()
 static void
 _test_node_bca ()
 {
+  lw6sys_context_t *sys_context = _test_data.sys_context;
   u_int64_t pid_c = 0LL;
   u_int64_t pid_a = 0LL;
 
@@ -341,7 +333,7 @@ _test_node_bca ()
    * closed sockets, make double-sure a previous node won't
    * be left and used by next set of nodes.
    */
-  lw6sys_sleep (_TEST_NET_SLEEP);
+  lw6sys_sleep (sys_context, _TEST_NET_SLEEP);
 
   /*
    * Second network test, we launch node_b in the main thread,
@@ -352,19 +344,19 @@ _test_node_bca ()
    */
   _test_data.param_c.log_level_id = LW6SYS_LOG_ERROR_ID;
   _test_data.param_a.log_level_id = LW6SYS_LOG_ERROR_ID;
-  pid_c = lw6sys_process_fork_and_call (_guile_test_run, &_test_data.param_c);
-  pid_a = lw6sys_process_fork_and_call (_guile_test_run, &_test_data.param_a);
+  pid_c = lw6sys_process_fork_and_call (sys_context, _guile_test_run, &_test_data.param_c);
+  pid_a = lw6sys_process_fork_and_call (sys_context, _guile_test_run, &_test_data.param_a);
   if (pid_c != 0 && pid_a != 0)
     {
-      _guile_test_run (&_test_data.param_b);
+      _guile_test_run (sys_context, &_test_data.param_b);
     }
   if (pid_c != 0)
     {
-      lw6sys_process_kill_1_9 (pid_c);
+      lw6sys_process_kill_1_9 (sys_context, pid_c);
     }
   if (pid_a != 0)
     {
-      lw6sys_process_kill_1_9 (pid_a);
+      lw6sys_process_kill_1_9 (sys_context, pid_a);
     }
   _test_data.param_c.log_level_id = _test_data.default_log_level_id;
   _test_data.param_a.log_level_id = _test_data.default_log_level_id;
@@ -373,6 +365,7 @@ _test_node_bca ()
 static void
 _test_node_cab ()
 {
+  lw6sys_context_t *sys_context = _test_data.sys_context;
   u_int64_t pid_a = 0LL;
   u_int64_t pid_b = 0LL;
 
@@ -381,7 +374,7 @@ _test_node_cab ()
    * closed sockets, make double-sure a previous node won't
    * be left and used by next set of nodes.
    */
-  lw6sys_sleep (_TEST_NET_SLEEP);
+  lw6sys_sleep (sys_context, _TEST_NET_SLEEP);
 
   /*
    * Third network test, we launch node_c in the main thread,
@@ -392,19 +385,19 @@ _test_node_cab ()
    */
   _test_data.param_a.log_level_id = LW6SYS_LOG_ERROR_ID;
   _test_data.param_b.log_level_id = LW6SYS_LOG_ERROR_ID;
-  pid_a = lw6sys_process_fork_and_call (_guile_test_run, &_test_data.param_a);
-  pid_b = lw6sys_process_fork_and_call (_guile_test_run, &_test_data.param_b);
+  pid_a = lw6sys_process_fork_and_call (sys_context, _guile_test_run, &_test_data.param_a);
+  pid_b = lw6sys_process_fork_and_call (sys_context, _guile_test_run, &_test_data.param_b);
   if (pid_a != 0 && pid_b != 0)
     {
-      _guile_test_run (&_test_data.param_c);
+      _guile_test_run (sys_context, &_test_data.param_c);
     }
   if (pid_a != 0)
     {
-      lw6sys_process_kill_1_9 (pid_a);
+      lw6sys_process_kill_1_9 (sys_context, pid_a);
     }
   if (pid_b != 0)
     {
-      lw6sys_process_kill_1_9 (pid_b);
+      lw6sys_process_kill_1_9 (sys_context, pid_b);
     }
   _test_data.param_a.log_level_id = _test_data.default_log_level_id;
   _test_data.param_b.log_level_id = _test_data.default_log_level_id;
@@ -414,26 +407,24 @@ static int
 _setup_init ()
 {
   int ret = CUE_SINIT_FAILED;
+  lw6sys_context_t *sys_context = _test_data.sys_context;
   const int argc = _TEST_ARGC;
   const char *argv[] = { _TEST_ARGV0 };
 
-  lw6sys_log (LW6SYS_LOG_NOTICE, _x_ ("init lw6 CUnit test suite"));
+  lw6sys_log (sys_context, LW6SYS_LOG_NOTICE, _x_ ("init lw6 CUnit test suite"));
 
-  if (lw6_init_global (argc, argv))
+  if (lw6_init_global (sys_context, argc, argv))
     {
       _test_data.param.argc = argc;
       _test_data.param.argv = argv;
       _test_data.param.suite = _TEST_SUITE_MAIN;
       _test_data.param.coverage_check = 1;
-      _test_data.param.log_level_id = lw6sys_log_get_level ();
+      _test_data.param.log_level_id = lw6sys_log_get_level (sys_context);
       _test_data.default_log_level_id = _test_data.param.log_level_id;
 
-      memcpy (&_test_data.param_a, &_test_data.param,
-	      sizeof (_lw6_test_param_t));
-      memcpy (&_test_data.param_b, &_test_data.param,
-	      sizeof (_lw6_test_param_t));
-      memcpy (&_test_data.param_c, &_test_data.param,
-	      sizeof (_lw6_test_param_t));
+      memcpy (&_test_data.param_a, &_test_data.param, sizeof (_lw6_test_param_t));
+      memcpy (&_test_data.param_b, &_test_data.param, sizeof (_lw6_test_param_t));
+      memcpy (&_test_data.param_c, &_test_data.param, sizeof (_lw6_test_param_t));
 
       _test_data.param_a.suite = _TEST_SUITE_NODE_A;
       _test_data.param_b.suite = _TEST_SUITE_NODE_B;
@@ -453,11 +444,12 @@ static int
 _setup_quit ()
 {
   int ret = CUE_SCLEAN_FAILED;
+  lw6sys_context_t *sys_context = _test_data.sys_context;
 
-  lw6sys_log (LW6SYS_LOG_NOTICE, _x_ ("quit lw6 CUnit test suite"));
+  lw6sys_log (sys_context, LW6SYS_LOG_NOTICE, _x_ ("quit lw6 CUnit test suite"));
 
-  lw6_quit_global ();
-  lw6sys_log_set_level (_test_data.default_log_level_id);
+  lw6_quit_global (sys_context);
+  lw6sys_log_set_level (sys_context, _test_data.default_log_level_id);
 
   ret = CUE_SUCCESS;
 
@@ -467,6 +459,7 @@ _setup_quit ()
 /**
  * lw6_test_register
  *
+ * @sys_context: global system context
  * @mode: test mode (bitmask)
  *
  * Registers all tests for the lw6 module.
@@ -474,51 +467,54 @@ _setup_quit ()
  * Return value: 1 if test is successfull, 0 on error.
  */
 int
-lw6_test_register (int mode)
+lw6_test_register (lw6sys_context_t * sys_context, int mode)
 {
   int ret = 1;
-  CU_Suite *suite;
+  CU_Suite *suite = NULL;
+
+  _test_data.sys_context = sys_context;
 
   if (lw6sys_false ())
     {
       /*
        * Just to make sure most functions are stuffed in the binary
        */
-      lw6sys_test_register (mode);
-      lw6glb_test_register (mode);
-      lw6map_test_register (mode);
-      lw6ker_test_register (mode);
-      lw6gen_test_register (mode);
-      lw6pil_test_register (mode);
-      lw6bot_test_register (mode);
-      lw6sim_test_register (mode);
-      lw6cns_test_register (mode);
-      lw6hlp_test_register (mode);
-      lw6cfg_test_register (mode);
-      lw6ldr_test_register (mode);
-      lw6tsk_test_register (mode);
-      lw6mat_test_register (mode);
-      lw6gui_test_register (mode);
-      lw6vox_test_register (mode);
-      lw6gfx_test_register (mode);
-      lw6dsp_test_register (mode);
-      lw6snd_test_register (mode);
-      lw6img_test_register (mode);
-      lw6net_test_register (mode);
-      lw6nod_test_register (mode);
-      lw6cnx_test_register (mode);
-      lw6msg_test_register (mode);
-      lw6cli_test_register (mode);
-      lw6srv_test_register (mode);
-      lw6dat_test_register (mode);
-      lw6p2p_test_register (mode);
-      lw6scm_test_register (mode);
+      lw6sys_test_register (sys_context, mode);
+      lw6glb_test_register (sys_context, mode);
+      lw6map_test_register (sys_context, mode);
+      lw6ker_test_register (sys_context, mode);
+      lw6gen_test_register (sys_context, mode);
+      lw6pil_test_register (sys_context, mode);
+      lw6bot_test_register (sys_context, mode);
+      lw6sim_test_register (sys_context, mode);
+      lw6cns_test_register (sys_context, mode);
+      lw6hlp_test_register (sys_context, mode);
+      lw6cfg_test_register (sys_context, mode);
+      lw6ldr_test_register (sys_context, mode);
+      lw6tsk_test_register (sys_context, mode);
+      lw6mat_test_register (sys_context, mode);
+      lw6gui_test_register (sys_context, mode);
+      lw6vox_test_register (sys_context, mode);
+      lw6gfx_test_register (sys_context, mode);
+      lw6dsp_test_register (sys_context, mode);
+      lw6snd_test_register (sys_context, mode);
+      lw6img_test_register (sys_context, mode);
+      lw6net_test_register (sys_context, mode);
+      lw6nod_test_register (sys_context, mode);
+      lw6cnx_test_register (sys_context, mode);
+      lw6msg_test_register (sys_context, mode);
+      lw6cli_test_register (sys_context, mode);
+      lw6srv_test_register (sys_context, mode);
+      lw6dat_test_register (sys_context, mode);
+      lw6p2p_test_register (sys_context, mode);
+      lw6scm_test_register (sys_context, mode);
     }
 
   memset (&_test_data.param, 0, sizeof (_lw6_test_param_t));
   memset (&_test_data.param_a, 0, sizeof (_lw6_test_param_t));
   memset (&_test_data.param_b, 0, sizeof (_lw6_test_param_t));
   memset (&_test_data.param_c, 0, sizeof (_lw6_test_param_t));
+
   _test_data.param.mode = mode;
 
   suite = CU_add_suite ("lw6", _setup_init, _setup_quit);
@@ -532,7 +528,7 @@ lw6_test_register (int mode)
 	{
 	  LW6SYS_CUNIT_ADD_TEST (suite, _test_main);
 	}
-      if (lw6sys_process_is_fully_supported ())
+      if (lw6sys_process_is_fully_supported (sys_context))
 	{
 	  /*
 	   * Switch between lw6sys_true / lw6sys_false to
@@ -561,9 +557,8 @@ lw6_test_register (int mode)
 	}
       else
 	{
-	  lw6sys_log (LW6SYS_LOG_WARNING,
-		      _x_
-		      ("skipping client/server test, platform does not have adequate process support and/or it's likely to fail anyway"));
+	  lw6sys_log (sys_context, LW6SYS_LOG_WARNING,
+		      _x_ ("skipping client/server test, platform does not have adequate process support and/or it's likely to fail anyway"));
 	  _test_data.param_a.ret = 1;
 	  _test_data.param_b.ret = 1;
 	  _test_data.param_c.ret = 1;
@@ -571,9 +566,7 @@ lw6_test_register (int mode)
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING,
-		  _x_ ("unable to add CUnit test suite, error msg is \"%s\""),
-		  CU_get_error_msg ());
+      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("unable to add CUnit test suite, error msg is \"%s\""), CU_get_error_msg ());
       ret = 0;
     }
 
@@ -583,6 +576,7 @@ lw6_test_register (int mode)
 /**
  * lw6_test_run
  *
+ * @sys_context: global system context
  * @mode: test mode (bitmask)
  *
  * Runs the liquidwar6 core module test suite, this will mostly
@@ -593,18 +587,18 @@ lw6_test_register (int mode)
  * Return value: 1 if test is successfull, 0 on error.
  */
 int
-lw6_test_run (int mode)
+lw6_test_run (lw6sys_context_t * sys_context, int mode)
 {
   int ret = 0;
 
   _test_data.ret = 1;
-  if (lw6sys_cunit_run_tests (mode))
+  _test_data.sys_context = sys_context;
+
+  if (lw6sys_cunit_run_tests (sys_context, mode))
     {
       if (mode & LW6SYS_TEST_MODE_FULL_TEST)
 	{
-	  ret = _test_data.ret && _test_data.param.ret
-	    && _test_data.param_a.ret && _test_data.param_b.ret
-	    && _test_data.param_c.ret;;
+	  ret = _test_data.ret && _test_data.param.ret && _test_data.param_a.ret && _test_data.param_b.ret && _test_data.param_c.ret;;
 	}
       else
 	{
@@ -614,7 +608,7 @@ lw6_test_run (int mode)
 
   if (ret)
     {
-      lw6sys_log (LW6SYS_LOG_NOTICE, _x_ ("scripts tests OK"));
+      lw6sys_log (sys_context, LW6SYS_LOG_NOTICE, _x_ ("scripts tests OK"));
     }
   else
     {
@@ -623,11 +617,10 @@ lw6_test_run (int mode)
        * else standard output is pretty much undreadable since one must
        * scroll up to the test that failed, this being akward.
        */
-      lw6sys_log (LW6SYS_LOG_WARNING,
+      lw6sys_log (sys_context, LW6SYS_LOG_WARNING,
 		  _x_
 		  ("script tests failed main=%d node-a=%d node-b=%d node-c=%d"),
-		  _test_data.param.ret, _test_data.param_a.ret,
-		  _test_data.param_b.ret, _test_data.param_c.ret);
+		  _test_data.param.ret, _test_data.param_a.ret, _test_data.param_b.ret, _test_data.param_c.ret);
     }
 
   return ret;
