@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -48,13 +48,14 @@ main (int argc, const char *argv[])
 #endif				// LW6_MAX_OS_X
 {
   int ret = 0;
+  lw6sys_context_t *sys_context = NULL;
   int mode = 0;
 
-  LW6SYS_MAIN_BEGIN;
-  LW6HLP_MAIN_BEGIN;
+  LW6SYS_MAIN_BEGIN (sys_context);
+  LW6HLP_MAIN_BEGIN (sys_context);
 
-  lw6sys_log_clear (NULL);
-  mode = lw6sys_arg_test_mode (argc, (const char **) argv);
+  lw6sys_log_clear (sys_context, NULL);
+  mode = lw6sys_arg_test_mode (sys_context, argc, (const char **) argv);
 
   /*
    * We need to call fix_env now and can't call it later since
@@ -64,21 +65,21 @@ main (int argc, const char *argv[])
    * calling fix_env twice when running from LW6 context, and we
    * don't want that.
    */
-  lw6_fix_env (argc, (const char **) argv);
+  lw6_fix_env (sys_context, argc, (const char **) argv);
 
   if (CU_initialize_registry () == CUE_SUCCESS)
     {
-      if (lw6_test_register (mode))
+      if (lw6_test_register (sys_context, mode))
 	{
-	  ret = lw6_test_run (mode);
+	  ret = lw6_test_run (sys_context, mode);
 	}
       CU_cleanup_registry ();
     }
 
   LW6SYS_TEST_OUTPUT;
 
-  LW6HLP_MAIN_END;
-  LW6SYS_MAIN_END;
+  LW6HLP_MAIN_END (sys_context);
+  LW6SYS_MAIN_END (sys_context);
 
   return (!ret);
 }
