@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -31,6 +31,7 @@
 /**
  * lw6map_color_invert
  *
+ * @sys_context: global system context
  * @color: the color to invert
  *
  * Inverts a color couple, that is, replace fg by bg and vice-versa.
@@ -38,7 +39,7 @@
  * Return value: none.
  */
 void
-lw6map_color_invert (lw6map_color_couple_t * color)
+lw6map_color_invert (lw6sys_context_t * sys_context, lw6map_color_couple_t * color)
 {
   lw6sys_color_8_t tmp;
 
@@ -50,6 +51,7 @@ lw6map_color_invert (lw6map_color_couple_t * color)
 /**
  * lw6map_color_is_same
  *
+ * @sys_context: global system context
  * @color1: 1st color to compare
  * @color2: 2nd color to compare
  *
@@ -58,16 +60,15 @@ lw6map_color_invert (lw6map_color_couple_t * color)
  * Return value: 1 if equal, 0 if not.
  */
 int
-lw6map_color_is_same (const lw6map_color_couple_t * color1,
-		      const lw6map_color_couple_t * color2)
+lw6map_color_is_same (lw6sys_context_t * sys_context, const lw6map_color_couple_t * color1, const lw6map_color_couple_t * color2)
 {
-  return lw6sys_color_is_same (color1->fg, color2->fg)
-    && lw6sys_color_is_same (color1->bg, color2->bg);
+  return lw6sys_color_is_same (sys_context, color1->fg, color2->fg) && lw6sys_color_is_same (sys_context, color1->bg, color2->bg);
 }
 
 /**
  * lw6map_team_color_index_to_key
  *
+ * @sys_context: global system context
  * @index: index of the color between 0 & 9
  *
  * Transforms a team color index into its readable string form,
@@ -76,7 +77,7 @@ lw6map_color_is_same (const lw6map_color_couple_t * color1,
  * Return value: a string, must *not* be freed.
  */
 char *
-lw6map_team_color_index_to_key (int index)
+lw6map_team_color_index_to_key (lw6sys_context_t * sys_context, int index)
 {
   char *ret = LW6DEF_RED;
 
@@ -113,8 +114,7 @@ lw6map_team_color_index_to_key (int index)
       ret = LW6DEF_PINK;
       break;
     default:
-      lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("team color index %d isn't valid"),
-		  index);
+      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("team color index %d isn't valid"), index);
     }
 
   return ret;
@@ -123,6 +123,7 @@ lw6map_team_color_index_to_key (int index)
 /**
  * lw6map_team_color_key_to_index
  *
+ * @sys_context: global system context
  * @key: key of the color, for instance "red"
  *
  * The index of the color, between 0 & 9
@@ -130,7 +131,7 @@ lw6map_team_color_index_to_key (int index)
  * Return value: an integer.
  */
 int
-lw6map_team_color_key_to_index (const char *key)
+lw6map_team_color_key_to_index (lw6sys_context_t * sys_context, const char *key)
 {
   int ret = LW6MAP_TEAM_COLOR_INVALID;
 
@@ -176,8 +177,7 @@ lw6map_team_color_key_to_index (const char *key)
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("team color key %s isn't valid"),
-		  key);
+      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("team color key %s isn't valid"), key);
     }
 
   return ret;
@@ -186,6 +186,7 @@ lw6map_team_color_key_to_index (const char *key)
 /**
  * lw6map_team_color_index_to_label
  *
+ * @sys_context: global system context
  * @index: index of the color between 0 & 9
  *
  * Transforms a team color index into its readable string form,
@@ -194,7 +195,7 @@ lw6map_team_color_key_to_index (const char *key)
  * Return value: a string, must *not* be freed.
  */
 char *
-lw6map_team_color_index_to_label (int index)
+lw6map_team_color_index_to_label (lw6sys_context_t * sys_context, int index)
 {
   char *ret = LW6SYS_STR_EMPTY;
 
