@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -30,6 +30,7 @@
 
 /**
  * lw6map_coords_fix_xy
+ *
  * @rules: set of rules to use
  * @shape: shape of the map
  * @x: x coord (in/out param)
@@ -43,8 +44,7 @@
  * Return value: none.
  */
 void
-lw6map_coords_fix_xy (const lw6map_rules_t * rules,
-		      const lw6sys_whd_t * shape, int *x, int *y)
+lw6map_coords_fix_xy (const lw6map_rules_t * rules, const lw6sys_whd_t * shape, int *x, int *y)
 {
   if ((*x) < 0 || (*y) < 0 || (*x) >= shape->w || (*y) >= shape->h)
     {
@@ -131,6 +131,7 @@ lw6map_coords_fix_xy (const lw6map_rules_t * rules,
 
 /**
  * lw6map_coords_fix_z
+ *
  * @rules: set of rules to use
  * @shape: shape of the map
  * @z: z coord (in/out param)
@@ -143,8 +144,7 @@ lw6map_coords_fix_xy (const lw6map_rules_t * rules,
  * Return value: none.
  */
 void
-lw6map_coords_fix_z (const lw6map_rules_t * rules, const lw6sys_whd_t * shape,
-		     int *z)
+lw6map_coords_fix_z (const lw6map_rules_t * rules, const lw6sys_whd_t * shape, int *z)
 {
 
   if ((*z) < 0 || (*z) >= shape->d)
