@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -31,6 +31,7 @@
 /**
  * lw6map_cursor_texture_layer_set
  *
+ * @sys_context: global system context
  * @cursor_texture_layer: the cursor texture_layer to change
  * @x: x coord
  * @y: y coord
@@ -41,9 +42,7 @@
  * Return value: none
  */
 void
-lw6map_cursor_texture_layer_set (lw6map_cursor_texture_layer_t *
-				 cursor_texture_layer, int x, int y,
-				 lw6sys_color_8_t color)
+lw6map_cursor_texture_layer_set (lw6sys_context_t * sys_context, lw6map_cursor_texture_layer_t * cursor_texture_layer, int x, int y, lw6sys_color_8_t color)
 {
   cursor_texture_layer->data[y][x] = color;
 }
@@ -51,6 +50,7 @@ lw6map_cursor_texture_layer_set (lw6map_cursor_texture_layer_t *
 /**
  * lw6map_cursor_texture_layer_get
  *
+ * @sys_context: global system context
  * @cursor_texture_layer: the cursor texture_layer to query
  * @x: x coord
  * @y: y coord
@@ -60,8 +60,7 @@ lw6map_cursor_texture_layer_set (lw6map_cursor_texture_layer_t *
  * Return value: the color
  */
 lw6sys_color_8_t
-lw6map_cursor_texture_layer_get (const lw6map_cursor_texture_layer_t *
-				 cursor_texture_layer, int x, int y)
+lw6map_cursor_texture_layer_get (lw6sys_context_t * sys_context, const lw6map_cursor_texture_layer_t * cursor_texture_layer, int x, int y)
 {
   return cursor_texture_layer->data[y][x];
 }
