@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -172,7 +172,7 @@ static char *_LAYER_DEFAULT_SOURCE[LW6MAP_BUILTIN_DEFAULT_HEIGHT + 1] = {
 };
 
 static int
-_default_source (lw6map_layer_t * layer, int width, int height)
+_default_source (lw6sys_context_t * sys_context, lw6map_layer_t * layer, int width, int height)
 {
   int ret = 0;
   int x, y;
@@ -182,9 +182,7 @@ _default_source (lw6map_layer_t * layer, int width, int height)
   layer->shape.w = width;
   layer->shape.h = height;
   layer->shape.d = 1;		// allways 1
-  layer->data =
-    (unsigned char *) LW6SYS_CALLOC (layer->shape.w * layer->shape.h *
-				     sizeof (unsigned char));
+  layer->data = (unsigned char *) LW6SYS_CALLOC (sys_context, layer->shape.w * layer->shape.h * sizeof (unsigned char));
 
   if (layer->data)
     {
@@ -193,17 +191,8 @@ _default_source (lw6map_layer_t * layer, int width, int height)
 	{
 	  for (x = 0; x < width; ++x)
 	    {
-	      source_x =
-		lw6sys_imax (0,
-			     lw6sys_imin ((x * LW6MAP_BUILTIN_DEFAULT_WIDTH) /
-					  width,
-					  LW6MAP_BUILTIN_DEFAULT_WIDTH - 1));
-	      source_y =
-		lw6sys_imax (0,
-			     lw6sys_imin ((y *
-					   LW6MAP_BUILTIN_DEFAULT_HEIGHT) /
-					  height,
-					  LW6MAP_BUILTIN_DEFAULT_HEIGHT - 1));
+	      source_x = lw6sys_imax (0, lw6sys_imin ((x * LW6MAP_BUILTIN_DEFAULT_WIDTH) / width, LW6MAP_BUILTIN_DEFAULT_WIDTH - 1));
+	      source_y = lw6sys_imax (0, lw6sys_imin ((y * LW6MAP_BUILTIN_DEFAULT_HEIGHT) / height, LW6MAP_BUILTIN_DEFAULT_HEIGHT - 1));
 	      c = _LAYER_DEFAULT_SOURCE[source_y][source_x];
 	      switch (c)
 		{
@@ -214,10 +203,8 @@ _default_source (lw6map_layer_t * layer, int width, int height)
 		  lw6map_layer_set (layer, x, y, 0);
 		  break;
 		default:
-		  lw6sys_log (LW6SYS_LOG_WARNING,
-			      _x_
-			      ("inconsistent default source layer data '%c' at %d,%d for %d,%d"),
-			      c, source_x, source_y, x, y);
+		  lw6sys_log (sys_context, LW6SYS_LOG_WARNING,
+			      _x_ ("inconsistent default source layer data '%c' at %d,%d for %d,%d"), c, source_x, source_y, x, y);
 		  ret = 0;
 		}
 	    }
@@ -228,7 +215,7 @@ _default_source (lw6map_layer_t * layer, int width, int height)
     {
       if (layer->data)
 	{
-	  LW6SYS_FREE (layer->data);
+	  LW6SYS_FREE (sys_context, layer->data);
 	  layer->data = NULL;
 	}
     }
@@ -239,6 +226,7 @@ _default_source (lw6map_layer_t * layer, int width, int height)
 /**
  * lw6map_layer_builtin_custom
  *
+ * @sys_context: global system context
  * @layer: the layer to init
  * @w: width
  * @h: height
@@ -249,14 +237,13 @@ _default_source (lw6map_layer_t * layer, int width, int height)
  * Return value: none
  */
 void
-lw6map_layer_builtin_custom (lw6map_layer_t * layer, int w, int h)
+lw6map_layer_builtin_custom (lw6sys_context_t * sys_context, lw6map_layer_t * layer, int w, int h)
 {
-  lw6map_layer_clear (layer);
+  lw6map_layer_clear (sys_context, layer);
 
-  if (!_default_source (layer, w, h))
+  if (!_default_source (sys_context, layer, w, h))
     {
-      lw6sys_log (LW6SYS_LOG_WARNING,
-		  _x_ ("unable to construct default map layer"));
+      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("unable to construct default map layer"));
       layer->shape.w = 0;
       layer->shape.h = 0;
       layer->shape.d = 0;
@@ -266,6 +253,7 @@ lw6map_layer_builtin_custom (lw6map_layer_t * layer, int w, int h)
 /**
  * lw6map_layer_clear
  *
+ * @sys_context: global system context
  * @layer: the layer to init
  *
  * Clears a layer struct. This means freeing the pointer
@@ -274,11 +262,11 @@ lw6map_layer_builtin_custom (lw6map_layer_t * layer, int w, int h)
  * Return value: none
  */
 void
-lw6map_layer_clear (lw6map_layer_t * layer)
+lw6map_layer_clear (lw6sys_context_t * sys_context, lw6map_layer_t * layer)
 {
   if (layer->data)
     {
-      LW6SYS_FREE (layer->data);
+      LW6SYS_FREE (sys_context, layer->data);
     }
 
   memset (layer, 0, sizeof (lw6map_layer_t));
