@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -29,6 +29,7 @@
 /**
  * lw6map_meta_layer_set
  *
+ * @sys_context: global system context
  * @meta_layer: the meta_layer structure
  * @x: x coord
  * @y: y coord
@@ -39,8 +40,7 @@
  * Return value: none
  */
 void
-lw6map_meta_layer_set (lw6map_meta_layer_t * meta_layer, int x, int y,
-		       u_int8_t value)
+lw6map_meta_layer_set (lw6sys_context_t * sys_context, lw6map_meta_layer_t * meta_layer, int x, int y, u_int8_t value)
 {
   if (meta_layer->data)
     {
@@ -51,6 +51,7 @@ lw6map_meta_layer_set (lw6map_meta_layer_t * meta_layer, int x, int y,
 /**
  * lw6map_meta_layer_get
  *
+ * @sys_context: global system context
  * @meta_layer: the meta_layer structure
  * @x: x coord
  * @y: y coord
@@ -60,7 +61,7 @@ lw6map_meta_layer_set (lw6map_meta_layer_t * meta_layer, int x, int y,
  * Return value: the value at this place
  */
 u_int8_t
-lw6map_meta_layer_get (const lw6map_meta_layer_t * meta_layer, int x, int y)
+lw6map_meta_layer_get (lw6sys_context_t * sys_context, const lw6map_meta_layer_t * meta_layer, int x, int y)
 {
   int ret = 0;
 
@@ -75,6 +76,7 @@ lw6map_meta_layer_get (const lw6map_meta_layer_t * meta_layer, int x, int y)
 /**
  * lw6map_meta_layer_clear
  *
+ * @sys_context: global system context
  * @meta_layer: the meta_layer to clear
  *
  * Clears a meta_layer struct. This means freeing the pointer
@@ -83,11 +85,11 @@ lw6map_meta_layer_get (const lw6map_meta_layer_t * meta_layer, int x, int y)
  * Return value: none
  */
 void
-lw6map_meta_layer_clear (lw6map_meta_layer_t * meta_layer)
+lw6map_meta_layer_clear (lw6sys_context_t * sys_context, lw6map_meta_layer_t * meta_layer)
 {
   if (meta_layer->data)
     {
-      LW6SYS_FREE (meta_layer->data);
+      LW6SYS_FREE (sys_context, meta_layer->data);
     }
 
   memset (meta_layer, 0, sizeof (lw6map_meta_layer_t));
@@ -96,6 +98,7 @@ lw6map_meta_layer_clear (lw6map_meta_layer_t * meta_layer)
 /**
  * lw6map_meta_layer_builtin_custom
  *
+ * @sys_context: global system context
  * @meta_layer: the object to init
  * @w: width
  * @h: height
@@ -110,15 +113,13 @@ lw6map_meta_layer_clear (lw6map_meta_layer_t * meta_layer)
  * Return value: 1 if OK, 0 on failure.
  */
 int
-lw6map_meta_layer_builtin_custom (lw6map_meta_layer_t * meta_layer, int w,
-				  int h, int analog, int noise_percent,
-				  int seed)
+lw6map_meta_layer_builtin_custom (lw6sys_context_t * sys_context, lw6map_meta_layer_t * meta_layer, int w, int h, int analog, int noise_percent, int seed)
 {
   int ret = 0;
   int i, n;
   u_int32_t checksum;
 
-  lw6map_meta_layer_clear (meta_layer);
+  lw6map_meta_layer_clear (sys_context, meta_layer);
   if (noise_percent == 0)
     {
       // ok, we leave pointer NULL, code should handler this fine
@@ -128,9 +129,8 @@ lw6map_meta_layer_builtin_custom (lw6map_meta_layer_t * meta_layer, int w,
     {
       noise_percent = lw6sys_imax (1, noise_percent);
       noise_percent = lw6sys_imin (100, noise_percent);
-      seed = lw6sys_checksum_int32 (seed);
-      meta_layer->data =
-	(u_int8_t *) LW6SYS_CALLOC (w * h * sizeof (u_int8_t));
+      seed = lw6sys_checksum_int32 (sys_context, seed);
+      meta_layer->data = (u_int8_t *) LW6SYS_CALLOC (sys_context, w * h * sizeof (u_int8_t));
       if (meta_layer->data)
 	{
 	  meta_layer->shape.w = w;
@@ -139,7 +139,7 @@ lw6map_meta_layer_builtin_custom (lw6map_meta_layer_t * meta_layer, int w,
 	  n = w * h;
 	  for (i = 0; i < n; ++i)
 	    {
-	      checksum = lw6sys_checksum_int32 (seed + i);
+	      checksum = lw6sys_checksum_int32 (sys_context, seed + i);
 	      if ((checksum % 100) < noise_percent)
 		{
 		  if (analog)
