@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -31,6 +31,7 @@
 /**
  * lw6map_param_zero
  *
+ * @sys_context: global system context
  * @param: struct to initialize
  *
  * Sets a param struct to zero, simply puts zero everywhere
@@ -39,7 +40,7 @@
  * Return value: none.
  */
 void
-lw6map_param_zero (lw6map_param_t * param)
+lw6map_param_zero (lw6sys_context_t * sys_context, lw6map_param_t * param)
 {
   memset (param, 0, sizeof (lw6map_param_t));
 }
@@ -47,6 +48,7 @@ lw6map_param_zero (lw6map_param_t * param)
 /**
  * lw6map_param_defaults:
  *
+ * @sys_context: global system context
  * @param: the param struct to modify
  *
  * Sets a param structure to its default value, note that current
@@ -55,16 +57,17 @@ lw6map_param_zero (lw6map_param_t * param)
  * Return value: none
  */
 void
-lw6map_param_defaults (lw6map_param_t * param)
+lw6map_param_defaults (lw6sys_context_t * sys_context, lw6map_param_t * param)
 {
-  lw6map_rules_defaults (&(param->rules));
-  lw6map_style_defaults (&(param->style));
-  lw6map_teams_defaults (&(param->teams));
+  lw6map_rules_defaults (sys_context, &(param->rules));
+  lw6map_style_defaults (sys_context, &(param->style));
+  lw6map_teams_defaults (sys_context, &(param->teams));
 }
 
 /**
  * lw6map_param_clear:
  *
+ * @sys_context: global system context
  * @param: the param struct to modify
  *
  * Resets a param structure to nothing. Note that current
@@ -74,13 +77,13 @@ lw6map_param_defaults (lw6map_param_t * param)
  * Return value: none
  */
 void
-lw6map_param_clear (lw6map_param_t * param)
+lw6map_param_clear (lw6sys_context_t * sys_context, lw6map_param_t * param)
 {
   if (param)
     {
-      lw6map_rules_clear (&(param->rules));
-      lw6map_style_clear (&(param->style));
-      lw6map_teams_clear (&(param->teams));
+      lw6map_rules_clear (sys_context, &(param->rules));
+      lw6map_style_clear (sys_context, &(param->style));
+      lw6map_teams_clear (sys_context, &(param->teams));
 
       /*
        * We don't free the param pointer itself, this
@@ -92,6 +95,7 @@ lw6map_param_clear (lw6map_param_t * param)
 /**
  * lw6map_param_copy:
  *
+ * @sys_context: global system context
  * @src: the source param struct
  * @dst: the destination param struct
  *
@@ -101,16 +105,17 @@ lw6map_param_clear (lw6map_param_t * param)
  * Return value: none
  */
 void
-lw6map_param_copy (lw6map_param_t * dst, const lw6map_param_t * src)
+lw6map_param_copy (lw6sys_context_t * sys_context, lw6map_param_t * dst, const lw6map_param_t * src)
 {
-  lw6map_rules_copy (&(dst->rules), &(src->rules));
-  lw6map_style_copy (&(dst->style), &(src->style));
-  lw6map_teams_copy (&(dst->teams), &(src->teams));
+  lw6map_rules_copy (sys_context, &(dst->rules), &(src->rules));
+  lw6map_style_copy (sys_context, &(dst->style), &(src->style));
+  lw6map_teams_copy (sys_context, &(dst->teams), &(src->teams));
 }
 
 /**
  * lw6map_param_set:
  *
+ * @sys_context: global system context
  * @param: the param struct to modify
  * @key: the name of the parameter to modify
  * @value: the value of the parameter to modify
@@ -123,23 +128,23 @@ lw6map_param_copy (lw6map_param_t * dst, const lw6map_param_t * src)
  * Return value: 1 if parameter successfully set, 0 on error.
  */
 int
-lw6map_param_set (lw6map_param_t * param, const char *key, const char *value)
+lw6map_param_set (lw6sys_context_t * sys_context, lw6map_param_t * param, const char *key, const char *value)
 {
   int ret = 0;
 
-  if (lw6map_style_set (&param->style, key, value))
+  if (lw6map_style_set (sys_context, &param->style, key, value))
     {
       // ok, it's a style member
       ret = 1;
     }
-  else if (lw6map_teams_set (&param->teams, key, value))
+  else if (lw6map_teams_set (sys_context, &param->teams, key, value))
     {
       // ok, it's a teams member
       ret = 1;
     }
   else
     {
-      ret = lw6map_rules_set_int (&param->rules, key, lw6sys_atoi (value));
+      ret = lw6map_rules_set_int (sys_context, &param->rules, key, lw6sys_atoi (sys_context, value));
     }
 
   return ret;
@@ -148,6 +153,7 @@ lw6map_param_set (lw6map_param_t * param, const char *key, const char *value)
 /**
  * lw6map_param_get:
  *
+ * @sys_context: global system context
  * @param: the param struct to query
  * @key: the name of the parameter to get
  *
@@ -159,17 +165,17 @@ lw6map_param_set (lw6map_param_t * param, const char *key, const char *value)
  *   might return a string containing 0 on bad keys.
  */
 char *
-lw6map_param_get (const lw6map_param_t * param, const char *key)
+lw6map_param_get (lw6sys_context_t * sys_context, const lw6map_param_t * param, const char *key)
 {
   char *ret = NULL;
 
-  ret = lw6map_style_get (&param->style, key);
+  ret = lw6map_style_get (sys_context, &param->style, key);
   if (!ret)
     {
-      ret = lw6map_teams_get (&param->teams, key);
+      ret = lw6map_teams_get (sys_context, &param->teams, key);
       if (!ret)
 	{
-	  ret = lw6sys_itoa (lw6map_rules_get_int (&param->rules, key));
+	  ret = lw6sys_itoa (sys_context, lw6map_rules_get_int (sys_context, &param->rules, key));
 	}
     }
 
@@ -179,6 +185,7 @@ lw6map_param_get (const lw6map_param_t * param, const char *key)
 /**
  * lw6map_param_is_same
  *
+ * @sys_context: global system context
  * @param_a: one struct to compare
  * @param_b: another struct to compare
  *
@@ -187,14 +194,13 @@ lw6map_param_get (const lw6map_param_t * param, const char *key)
  * Return value: 1 if they contain the same thing, 0 if not
  */
 int
-lw6map_param_is_same (const lw6map_param_t * param_a,
-		      const lw6map_param_t * param_b)
+lw6map_param_is_same (lw6sys_context_t * sys_context, const lw6map_param_t * param_a, const lw6map_param_t * param_b)
 {
   int ret = 1;
 
-  ret = ret && lw6map_rules_is_same (&(param_a->rules), &(param_b->rules));
-  ret = ret && lw6map_style_is_same (&(param_a->style), &(param_b->style));
-  ret = ret && lw6map_teams_is_same (&(param_a->teams), &(param_b->teams));
+  ret = ret && lw6map_rules_is_same (sys_context, &(param_a->rules), &(param_b->rules));
+  ret = ret && lw6map_style_is_same (sys_context, &(param_a->style), &(param_b->style));
+  ret = ret && lw6map_teams_is_same (sys_context, &(param_a->teams), &(param_b->teams));
 
   return ret;
 }
