@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -31,6 +31,7 @@
 /**
  * lw6map_texture_from_body
  *
+ * @sys_context: global system context
  * @texture: texture to load (out param)
  * @body: body to pick data from
  * @color: colors to use
@@ -43,21 +44,16 @@
  * Return value: 1 on success, 0 on failure.
  */
 int
-lw6map_texture_from_body (lw6map_texture_t * texture,
-			  const lw6map_body_t * body,
-			  const lw6map_color_couple_t * color)
+lw6map_texture_from_body (lw6sys_context_t * sys_context, lw6map_texture_t * texture, const lw6map_body_t * body, const lw6map_color_couple_t * color)
 {
   int ret = 0;
   int x, y;
 
-  lw6map_texture_clear (texture);
+  lw6map_texture_clear (sys_context, texture);
 
   texture->w = body->shape.w;
   texture->h = body->shape.h;
-  texture->data =
-    (lw6sys_color_8_t *) LW6SYS_MALLOC (texture->w *
-					texture->h *
-					sizeof (lw6sys_color_8_t));
+  texture->data = (lw6sys_color_8_t *) LW6SYS_MALLOC (sys_context, texture->w * texture->h * sizeof (lw6sys_color_8_t));
 
   if (texture->data)
     {
@@ -65,18 +61,14 @@ lw6map_texture_from_body (lw6map_texture_t * texture,
 	{
 	  for (x = 0; x < texture->w; ++x)
 	    {
-	      lw6map_texture_set (texture, x, y,
-				  lw6map_body_get (body, x,
-						   y, 0) >
-				  0 ? color->bg : color->fg);
+	      lw6map_texture_set (texture, x, y, lw6map_body_get (body, x, y, 0) > 0 ? color->bg : color->fg);
 	    }
 	}
       ret = 1;
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING,
-		  _x_ ("unable to construct texture from body"));
+      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("unable to construct texture from body"));
       texture->w = 0;
       texture->h = 0;
     }
@@ -87,6 +79,7 @@ lw6map_texture_from_body (lw6map_texture_t * texture,
 /**
  * lw6map_texture_clear
  *
+ * @sys_context: global system context
  * @texture: data to clear
  *
  * Clears a texture object, expects it to be in a consitent
@@ -95,11 +88,11 @@ lw6map_texture_from_body (lw6map_texture_t * texture,
  * Return value: none.
  */
 void
-lw6map_texture_clear (lw6map_texture_t * texture)
+lw6map_texture_clear (lw6sys_context_t * sys_context, lw6map_texture_t * texture)
 {
   if (texture->data)
     {
-      LW6SYS_FREE (texture->data);
+      LW6SYS_FREE (sys_context, texture->data);
     }
 
   memset (texture, 0, sizeof (lw6map_texture_t));
@@ -108,6 +101,7 @@ lw6map_texture_clear (lw6map_texture_t * texture)
 /**
  * lw6map_texture_coord_from_body
  *
+ * @sys_context: global system context
  * @level: map to work on
  * @texture_x: texture x coordinate (out param)
  * @texture_y: texture y coordinate (out param)
@@ -120,8 +114,7 @@ lw6map_texture_clear (lw6map_texture_t * texture)
  * Return value: 1 on success, 0 if failure.
  */
 int
-lw6map_texture_coord_from_body (const lw6map_level_t * level, int *texture_x,
-				int *texture_y, int body_x, int body_y)
+lw6map_texture_coord_from_body (lw6sys_context_t * sys_context, const lw6map_level_t * level, int *texture_x, int *texture_y, int body_x, int body_y)
 {
   int ret = 0;
 
@@ -129,10 +122,8 @@ lw6map_texture_coord_from_body (const lw6map_level_t * level, int *texture_x,
     {
       (*texture_x) = (body_x * level->texture.w) / level->body.shape.w;
       (*texture_y) = (body_y * level->texture.h) / level->body.shape.h;
-      (*texture_x) =
-	lw6sys_imax (0, lw6sys_imin (level->texture.w - 1, *texture_x));
-      (*texture_y) =
-	lw6sys_imax (0, lw6sys_imin (level->texture.h - 1, *texture_y));
+      (*texture_x) = lw6sys_imax (0, lw6sys_imin (level->texture.w - 1, *texture_x));
+      (*texture_y) = lw6sys_imax (0, lw6sys_imin (level->texture.h - 1, *texture_y));
       ret = 1;
     }
   else
@@ -147,6 +138,7 @@ lw6map_texture_coord_from_body (const lw6map_level_t * level, int *texture_x,
 /**
  * lw6map_texture_get_with_body_coord
  *
+ * @sys_context: global system context
  * @level: map to use
  * @body_x: x coordinate in body space
  * @body_y: y coordinate in body space
@@ -157,15 +149,13 @@ lw6map_texture_coord_from_body (const lw6map_level_t * level, int *texture_x,
  * Return value: RGBA 8-bit color.
  */
 lw6sys_color_8_t
-lw6map_texture_get_with_body_coord (const lw6map_level_t * level, int body_x,
-				    int body_y)
+lw6map_texture_get_with_body_coord (lw6sys_context_t * sys_context, const lw6map_level_t * level, int body_x, int body_y)
 {
   lw6sys_color_8_t ret = LW6SYS_COLOR_8_BLACK;
   int texture_x;
   int texture_y;
 
-  if (lw6map_texture_coord_from_body
-      (level, &texture_x, &texture_y, body_x, body_y))
+  if (lw6map_texture_coord_from_body (sys_context, level, &texture_x, &texture_y, body_x, body_y))
     {
       ret = lw6map_texture_get (&level->texture, texture_x, texture_y);
     }
@@ -176,6 +166,7 @@ lw6map_texture_get_with_body_coord (const lw6map_level_t * level, int body_x,
 /**
  * lw6map_texture_has_alpha
  *
+ * @sys_context: global system context
  * @texture: texture object to test
  *
  * Finds out if the texture is fully opaque or not. If it has
@@ -188,7 +179,7 @@ lw6map_texture_get_with_body_coord (const lw6map_level_t * level, int body_x,
  * Return value: 1 if has used alpha layer, 0 if opaque.
  */
 int
-lw6map_texture_has_alpha (lw6map_texture_t * texture)
+lw6map_texture_has_alpha (lw6sys_context_t * sys_context, lw6map_texture_t * texture)
 {
   int ret = 0;
   int x = 0;
