@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -1006,9 +1006,7 @@ typedef enum lw6map_team_color_e
   LW6MAP_TEAM_COLOR_RED =
     0, LW6MAP_TEAM_COLOR_GREEN = 1, LW6MAP_TEAM_COLOR_BLUE =
     2, LW6MAP_TEAM_COLOR_YELLOW = 3, LW6MAP_TEAM_COLOR_CYAN =
-    4, LW6MAP_TEAM_COLOR_MAGENTA = 5, LW6MAP_TEAM_COLOR_ORANGE =
-    6, LW6MAP_TEAM_COLOR_LIGHTBLUE = 7, LW6MAP_TEAM_COLOR_PURPLE =
-    8, LW6MAP_TEAM_COLOR_PINK = 9
+    4, LW6MAP_TEAM_COLOR_MAGENTA = 5, LW6MAP_TEAM_COLOR_ORANGE = 6, LW6MAP_TEAM_COLOR_LIGHTBLUE = 7, LW6MAP_TEAM_COLOR_PURPLE = 8, LW6MAP_TEAM_COLOR_PINK = 9
 } lw6map_team_color_t;
 
 #define LW6MAP_TEAMS_NB_PLAYERS 4
@@ -1248,8 +1246,7 @@ typedef struct lw6map_texture_s
 typedef struct lw6map_cursor_texture_layer_s
 {
   /// Color for each pixel.
-  lw6sys_color_8_t
-    data[LW6MAP_CURSOR_TEXTURE_SIZE][LW6MAP_CURSOR_TEXTURE_SIZE];
+  lw6sys_color_8_t data[LW6MAP_CURSOR_TEXTURE_SIZE][LW6MAP_CURSOR_TEXTURE_SIZE];
 } lw6map_cursor_texture_layer_t;
 
 /**
@@ -1434,8 +1431,7 @@ lw6map_layer_get (const lw6map_layer_t * layer, int x, int y)
 }
 
 static inline void
-lw6map_texture_set (lw6map_texture_t * texture, int x, int y,
-		    lw6sys_color_8_t value)
+lw6map_texture_set (lw6map_texture_t * texture, int x, int y, lw6sys_color_8_t value)
 {
   texture->data[y * texture->w + x] = value;
 }
@@ -1447,28 +1443,21 @@ lw6map_texture_get (const lw6map_texture_t * texture, int x, int y)
 }
 
 /* map-body.c */
-extern void lw6map_body_builtin_custom (lw6map_body_t * body, int w, int h,
-					int d, int noise_percent,
-					const lw6map_rules_t * rules);
-extern void lw6map_body_clear (lw6map_body_t * body);
-extern void lw6map_body_fix_checksum (lw6map_body_t * body);
-extern int lw6map_body_check_and_fix_holes (lw6map_body_t * body,
-					    const lw6map_rules_t * rules);
-extern int lw6map_body_coord_from_texture (const lw6map_level_t * level,
-					   int *body_x, int *body_y,
-					   int texture_x, int texture_y);
-extern u_int8_t lw6map_body_get_with_texture_coord (const lw6map_level_t *
-						    level,
-						    int texture_x,
-						    int texture_y, int z);
+extern void lw6map_body_builtin_custom (lw6sys_context_t * sys_context,
+					lw6map_body_t * body, int w, int h, int d, int noise_percent, const lw6map_rules_t * rules);
+extern void lw6map_body_clear (lw6sys_context_t * sys_context, lw6map_body_t * body);
+extern void lw6map_body_fix_checksum (lw6sys_context_t * sys_context, lw6map_body_t * body);
+extern int lw6map_body_check_and_fix_holes (lw6sys_context_t * sys_context, lw6map_body_t * body, const lw6map_rules_t * rules);
+extern int lw6map_body_coord_from_texture (lw6sys_context_t * sys_context,
+					   const lw6map_level_t * level, int *body_x, int *body_y, int texture_x, int texture_y);
+extern u_int8_t lw6map_body_get_with_texture_coord (lw6sys_context_t * sys_context, const lw6map_level_t * level, int texture_x, int texture_y, int z);
 
 /* map-color.c */
-extern void lw6map_color_invert (lw6map_color_couple_t * color);
-extern int lw6map_color_is_same (const lw6map_color_couple_t * color1,
-				 const lw6map_color_couple_t * color2);
-extern char *lw6map_team_color_index_to_key (int index);
-extern int lw6map_team_color_key_to_index (const char *key);
-extern char *lw6map_team_color_index_to_label (int index);
+extern void lw6map_color_invert (lw6sys_context_t * sys_context, lw6map_color_couple_t * color);
+extern int lw6map_color_is_same (lw6sys_context_t * sys_context, const lw6map_color_couple_t * color1, const lw6map_color_couple_t * color2);
+extern char *lw6map_team_color_index_to_key (lw6sys_context_t * sys_context, int index);
+extern int lw6map_team_color_key_to_index (lw6sys_context_t * sys_context, const char *key);
+extern char *lw6map_team_color_index_to_label (lw6sys_context_t * sys_context, int index);
 static inline int
 lw6map_team_color_is_valid (int team_color)
 {
@@ -1476,169 +1465,128 @@ lw6map_team_color_is_valid (int team_color)
 }
 
 /* map-coords.c */
-extern void lw6map_coords_fix_xy (const lw6map_rules_t * rules,
-				  const lw6sys_whd_t * shape, int *x, int *y);
-extern void lw6map_coords_fix_z (const lw6map_rules_t * rules,
-				 const lw6sys_whd_t * shape, int *z);
+extern void lw6map_coords_fix_xy (const lw6map_rules_t * rules, const lw6sys_whd_t * shape, int *x, int *y);
+extern void lw6map_coords_fix_z (const lw6map_rules_t * rules, const lw6sys_whd_t * shape, int *z);
 
 /* map-cursortexture.c */
-extern void lw6map_cursor_texture_layer_set (lw6map_cursor_texture_layer_t *
-					     cursor_texture, int x, int y,
-					     lw6sys_color_8_t color);
-extern lw6sys_color_8_t
-lw6map_cursor_texture_layer_get (const lw6map_cursor_texture_layer_t *
-				 cursor_texture, int x, int y);
-extern void lw6map_cursor_texture_clear (lw6map_cursor_texture_t *
-					 cursor_texture);
-extern void lw6map_cursor_texture_builtin (lw6map_cursor_texture_t *
-					   cursor_texture);
+extern void lw6map_cursor_texture_layer_set (lw6sys_context_t * sys_context,
+					     lw6map_cursor_texture_layer_t * cursor_texture, int x, int y, lw6sys_color_8_t color);
+extern lw6sys_color_8_t lw6map_cursor_texture_layer_get (lw6sys_context_t * sys_context, const lw6map_cursor_texture_layer_t * cursor_texture, int x, int y);
+extern void lw6map_cursor_texture_clear (lw6sys_context_t * sys_context, lw6map_cursor_texture_t * cursor_texture);
+extern void lw6map_cursor_texture_builtin (lw6sys_context_t * sys_context, lw6map_cursor_texture_t * cursor_texture);
 
 /* map-dup.c */
-extern lw6map_level_t *lw6map_dup (lw6map_level_t * source,
-				   lw6sys_progress_t * progress);
+extern lw6map_level_t *lw6map_dup (lw6sys_context_t * sys_context, lw6map_level_t * source, lw6sys_progress_t * progress);
 
 /* map-exp.c */
-extern int lw6map_exp_get_highest_team_color_allowed (int exp);
-extern int lw6map_exp_get_highest_weapon_allowed (int exp);
-extern int lw6map_exp_is_team_color_allowed (const lw6map_rules_t * rules,
-					     int team_color_id);
-extern int lw6map_exp_is_weapon_allowed (const lw6map_rules_t * rules,
-					 int weapon_id);
-extern int lw6map_exp_get_unlocked_team_color (int exp);
-extern int lw6map_exp_get_unlocked_weapon (int exp);
+extern int lw6map_exp_get_highest_team_color_allowed (lw6sys_context_t * sys_context, int exp);
+extern int lw6map_exp_get_highest_weapon_allowed (lw6sys_context_t * sys_context, int exp);
+extern int lw6map_exp_is_team_color_allowed (lw6sys_context_t * sys_context, const lw6map_rules_t * rules, int team_color_id);
+extern int lw6map_exp_is_weapon_allowed (lw6sys_context_t * sys_context, const lw6map_rules_t * rules, int weapon_id);
+extern int lw6map_exp_get_unlocked_team_color (lw6sys_context_t * sys_context, int exp);
+extern int lw6map_exp_get_unlocked_weapon (lw6sys_context_t * sys_context, int exp);
 
 /* map-hexa.c */
-extern char *lw6map_to_hexa (const lw6map_level_t * level);
-extern lw6map_level_t *lw6map_from_hexa (const char *hexa);
+extern char *lw6map_to_hexa (lw6sys_context_t * sys_context, const lw6map_level_t * level);
+extern lw6map_level_t *lw6map_from_hexa (lw6sys_context_t * sys_context, const char *hexa);
 
 /* map-layer.c */
-extern void lw6map_layer_builtin_custom (lw6map_layer_t * layer, int w,
-					 int h);
-extern void lw6map_layer_clear (lw6map_layer_t * layer);
+extern void lw6map_layer_builtin_custom (lw6sys_context_t * sys_context, lw6map_layer_t * layer, int w, int h);
+extern void lw6map_layer_clear (lw6sys_context_t * sys_context, lw6map_layer_t * layer);
 
 /* map-level.c */
-extern lw6map_level_t *lw6map_new ();
-extern lw6map_level_t *lw6map_builtin_defaults ();
-extern lw6map_level_t *lw6map_builtin_scale (int percent_factor);
-extern lw6map_level_t *lw6map_builtin_custom (int w, int h, int d,
-					      int noise_percent);
-extern void lw6map_free (lw6map_level_t * level);
-extern int lw6map_memory_footprint (const lw6map_level_t * level);
-extern char *lw6map_repr (const lw6map_level_t * level);
-extern int lw6map_is_same (const lw6map_level_t * level_a,
-			   const lw6map_level_t * level_b);
-extern const char *lw6map_get_title (const lw6map_level_t * level);
-extern int lw6map_get_max_nb_colors (const lw6map_level_t * level);
-extern int lw6map_get_max_nb_cursors (const lw6map_level_t * level);
-extern int lw6map_get_max_nb_nodes (const lw6map_level_t * level);
+extern lw6map_level_t *lw6map_new (lw6sys_context_t * sys_context);
+extern lw6map_level_t *lw6map_builtin_defaults (lw6sys_context_t * sys_context);
+extern lw6map_level_t *lw6map_builtin_scale (lw6sys_context_t * sys_context, int percent_factor);
+extern lw6map_level_t *lw6map_builtin_custom (lw6sys_context_t * sys_context, int w, int h, int d, int noise_percent);
+extern void lw6map_free (lw6sys_context_t * sys_context, lw6map_level_t * level);
+extern int lw6map_memory_footprint (lw6sys_context_t * sys_context, const lw6map_level_t * level);
+extern char *lw6map_repr (lw6sys_context_t * sys_context, const lw6map_level_t * level);
+extern int lw6map_is_same (lw6sys_context_t * sys_context, const lw6map_level_t * level_a, const lw6map_level_t * level_b);
+extern const char *lw6map_get_title (lw6sys_context_t * sys_context, const lw6map_level_t * level);
+extern int lw6map_get_max_nb_colors (lw6sys_context_t * sys_context, const lw6map_level_t * level);
+extern int lw6map_get_max_nb_cursors (lw6sys_context_t * sys_context, const lw6map_level_t * level);
+extern int lw6map_get_max_nb_nodes (lw6sys_context_t * sys_context, const lw6map_level_t * level);
 
 /* map-localinfo.c */
-extern int lw6map_local_info_set_music_dir (lw6map_local_info_t *
-					    local_info,
-					    const char *music_dir);
-extern void lw6map_local_info_clear (lw6map_local_info_t * local_info);
+extern int lw6map_local_info_set_music_dir (lw6sys_context_t * sys_context, lw6map_local_info_t * local_info, const char *music_dir);
+extern void lw6map_local_info_clear (lw6sys_context_t * sys_context, lw6map_local_info_t * local_info);
 
 /* map-metadata.c */
-extern void lw6map_metadata_defaults (lw6map_metadata_t * metadata);
-extern void lw6map_metadata_clear (lw6map_metadata_t * metadata);
-extern int lw6map_metadata_is_same (const lw6map_metadata_t * metadata_a,
-				    const lw6map_metadata_t * metadata_b);
+extern void lw6map_metadata_defaults (lw6sys_context_t * sys_context, lw6map_metadata_t * metadata);
+extern void lw6map_metadata_clear (lw6sys_context_t * sys_context, lw6map_metadata_t * metadata);
+extern int lw6map_metadata_is_same (lw6sys_context_t * sys_context, const lw6map_metadata_t * metadata_a, const lw6map_metadata_t * metadata_b);
 
 /* map-metalayer.c */
-extern void lw6map_meta_layer_set (lw6map_meta_layer_t * meta_layer, int x,
-				   int y, u_int8_t value);
-extern u_int8_t lw6map_meta_layer_get (const lw6map_meta_layer_t * meta_layer,
-				       int x, int y);
-extern void lw6map_meta_layer_clear (lw6map_meta_layer_t * meta_layer);
-extern int lw6map_meta_layer_builtin_custom (lw6map_meta_layer_t * meta_layer,
-					     int w, int h, int analog,
-					     int noise_percent, int seed);
+extern void lw6map_meta_layer_set (lw6sys_context_t * sys_context, lw6map_meta_layer_t * meta_layer, int x, int y, u_int8_t value);
+extern u_int8_t lw6map_meta_layer_get (lw6sys_context_t * sys_context, const lw6map_meta_layer_t * meta_layer, int x, int y);
+extern void lw6map_meta_layer_clear (lw6sys_context_t * sys_context, lw6map_meta_layer_t * meta_layer);
+extern int lw6map_meta_layer_builtin_custom (lw6sys_context_t * sys_context,
+					     lw6map_meta_layer_t * meta_layer, int w, int h, int analog, int noise_percent, int seed);
 
 /* map-rules.c */
-extern void lw6map_rules_zero (lw6map_rules_t * rules);
-extern void lw6map_rules_defaults (lw6map_rules_t * rules);
-extern void lw6map_rules_copy (lw6map_rules_t * dst,
-			       const lw6map_rules_t * src);
-extern void lw6map_rules_update_checksum (const lw6map_rules_t * rules,
-					  u_int32_t * checksum);
-extern int32_t lw6map_rules_get_default (const char *key);
-extern int32_t lw6map_rules_get_min (const char *key);
-extern int32_t lw6map_rules_get_max (const char *key);
-extern int32_t lw6map_rules_get_int (const lw6map_rules_t * rules,
-				     const char *key);
-extern int lw6map_rules_set_int (lw6map_rules_t * rules, const char *key,
-				 int32_t value);
-extern int lw6map_rules_get_bool (const lw6map_rules_t * rules,
-				  const char *key);
-extern int lw6map_rules_set_bool (lw6map_rules_t * rules, const char *key,
-				  int value);
-extern void lw6map_rules_clear (lw6map_rules_t * rules);
-extern int lw6map_rules_is_same (const lw6map_rules_t * rules_a,
-				 const lw6map_rules_t * rules_b);
-extern int lw6map_rules_sanity_check (const lw6map_rules_t * rules);
+extern void lw6map_rules_zero (lw6sys_context_t * sys_context, lw6map_rules_t * rules);
+extern void lw6map_rules_defaults (lw6sys_context_t * sys_context, lw6map_rules_t * rules);
+extern void lw6map_rules_copy (lw6sys_context_t * sys_context, lw6map_rules_t * dst, const lw6map_rules_t * src);
+extern void lw6map_rules_update_checksum (lw6sys_context_t * sys_context, const lw6map_rules_t * rules, u_int32_t * checksum);
+extern int32_t lw6map_rules_get_default (lw6sys_context_t * sys_context, const char *key);
+extern int32_t lw6map_rules_get_min (lw6sys_context_t * sys_context, const char *key);
+extern int32_t lw6map_rules_get_max (lw6sys_context_t * sys_context, const char *key);
+extern int32_t lw6map_rules_get_int (lw6sys_context_t * sys_context, const lw6map_rules_t * rules, const char *key);
+extern int lw6map_rules_set_int (lw6sys_context_t * sys_context, lw6map_rules_t * rules, const char *key, int32_t value);
+extern int lw6map_rules_get_bool (lw6sys_context_t * sys_context, const lw6map_rules_t * rules, const char *key);
+extern int lw6map_rules_set_bool (lw6sys_context_t * sys_context, lw6map_rules_t * rules, const char *key, int value);
+extern void lw6map_rules_clear (lw6sys_context_t * sys_context, lw6map_rules_t * rules);
+extern int lw6map_rules_is_same (lw6sys_context_t * sys_context, const lw6map_rules_t * rules_a, const lw6map_rules_t * rules_b);
+extern int lw6map_rules_sanity_check (lw6sys_context_t * sys_context, const lw6map_rules_t * rules);
 
 /* map-param.c */
-extern void lw6map_param_zero (lw6map_param_t * param);
-extern void lw6map_param_defaults (lw6map_param_t * param);
-extern void lw6map_param_clear (lw6map_param_t * param);
-extern void lw6map_param_copy (lw6map_param_t * dst,
-			       const lw6map_param_t * src);
-extern int lw6map_param_set (lw6map_param_t * param, const char *key,
-			     const char *value);
-extern char *lw6map_param_get (const lw6map_param_t * param, const char *key);
-extern int lw6map_param_is_same (const lw6map_param_t * param_a,
-				 const lw6map_param_t * param_b);
+extern void lw6map_param_zero (lw6sys_context_t * sys_context, lw6map_param_t * param);
+extern void lw6map_param_defaults (lw6sys_context_t * sys_context, lw6map_param_t * param);
+extern void lw6map_param_clear (lw6sys_context_t * sys_context, lw6map_param_t * param);
+extern void lw6map_param_copy (lw6sys_context_t * sys_context, lw6map_param_t * dst, const lw6map_param_t * src);
+extern int lw6map_param_set (lw6sys_context_t * sys_context, lw6map_param_t * param, const char *key, const char *value);
+extern char *lw6map_param_get (lw6sys_context_t * sys_context, const lw6map_param_t * param, const char *key);
+extern int lw6map_param_is_same (lw6sys_context_t * sys_context, const lw6map_param_t * param_a, const lw6map_param_t * param_b);
 
 /* map-style.c */
-extern void lw6map_style_zero (lw6map_style_t * style);
-extern void lw6map_style_defaults (lw6map_style_t * style);
-extern void lw6map_style_clear (lw6map_style_t * style);
-extern void lw6map_style_copy (lw6map_style_t * dst,
-			       const lw6map_style_t * src);
-extern int lw6map_style_set (lw6map_style_t * style, const char *key,
-			     const char *value);
-extern char *lw6map_style_get (const lw6map_style_t * style, const char *key);
-extern char *lw6map_style_get_default (const char *key);
-extern int lw6map_color_set_is_same (const lw6map_color_set_t * color_set_a,
-				     const lw6map_color_set_t * color_set_b);
-extern int lw6map_style_is_same (const lw6map_style_t * style_a,
-				 const lw6map_style_t * style_b);
+extern void lw6map_style_zero (lw6sys_context_t * sys_context, lw6map_style_t * style);
+extern void lw6map_style_defaults (lw6sys_context_t * sys_context, lw6map_style_t * style);
+extern void lw6map_style_clear (lw6sys_context_t * sys_context, lw6map_style_t * style);
+extern void lw6map_style_copy (lw6sys_context_t * sys_context, lw6map_style_t * dst, const lw6map_style_t * src);
+extern int lw6map_style_set (lw6sys_context_t * sys_context, lw6map_style_t * style, const char *key, const char *value);
+extern char *lw6map_style_get (lw6sys_context_t * sys_context, const lw6map_style_t * style, const char *key);
+extern char *lw6map_style_get_default (lw6sys_context_t * sys_context, const char *key);
+extern int lw6map_color_set_is_same (lw6sys_context_t * sys_context, const lw6map_color_set_t * color_set_a, const lw6map_color_set_t * color_set_b);
+extern int lw6map_style_is_same (lw6sys_context_t * sys_context, const lw6map_style_t * style_a, const lw6map_style_t * style_b);
 
 /* map-teams.c */
-extern void lw6map_teams_zero (lw6map_teams_t * teams);
-extern void lw6map_teams_defaults (lw6map_teams_t * teams);
-extern void lw6map_teams_clear (lw6map_teams_t * teams);
-extern void lw6map_teams_copy (lw6map_teams_t * dst,
-			       const lw6map_teams_t * src);
-extern int lw6map_teams_set (lw6map_teams_t * teams, const char *key,
-			     const char *value);
-extern char *lw6map_teams_get (const lw6map_teams_t * teams, const char *key);
-extern char *lw6map_teams_get_default (const char *key);
-extern int lw6map_teams_is_same (const lw6map_teams_t * teams_a,
-				 const lw6map_teams_t * teams_b);
+extern void lw6map_teams_zero (lw6sys_context_t * sys_context, lw6map_teams_t * teams);
+extern void lw6map_teams_defaults (lw6sys_context_t * sys_context, lw6map_teams_t * teams);
+extern void lw6map_teams_clear (lw6sys_context_t * sys_context, lw6map_teams_t * teams);
+extern void lw6map_teams_copy (lw6sys_context_t * sys_context, lw6map_teams_t * dst, const lw6map_teams_t * src);
+extern int lw6map_teams_set (lw6sys_context_t * sys_context, lw6map_teams_t * teams, const char *key, const char *value);
+extern char *lw6map_teams_get (lw6sys_context_t * sys_context, const lw6map_teams_t * teams, const char *key);
+extern char *lw6map_teams_get_default (lw6sys_context_t * sys_context, const char *key);
+extern int lw6map_teams_is_same (lw6sys_context_t * sys_context, const lw6map_teams_t * teams_a, const lw6map_teams_t * teams_b);
 
 /* map-test.c */
-extern int lw6map_test_register (int mode);
-extern int lw6map_test_run (int mode);
+extern int lw6map_test_register (lw6sys_context_t * sys_context, int mode);
+extern int lw6map_test_run (lw6sys_context_t * sys_context, int mode);
 
 /* map-texture.c */
-extern int lw6map_texture_from_body (lw6map_texture_t * texture,
-				     const lw6map_body_t * body,
-				     const lw6map_color_couple_t * color);
-extern void lw6map_texture_clear (lw6map_texture_t * texture);
-extern int lw6map_texture_coord_from_body (const lw6map_level_t * level,
-					   int *texture_x, int *texture_y,
-					   int body_x, int body_y);
-extern lw6sys_color_8_t lw6map_texture_get_with_body_coord (const
-							    lw6map_level_t *
-							    level, int body_x,
-							    int body_y);
-extern int lw6map_texture_has_alpha (lw6map_texture_t * texture);
+extern int lw6map_texture_from_body (lw6sys_context_t * sys_context,
+				     lw6map_texture_t * texture, const lw6map_body_t * body, const lw6map_color_couple_t * color);
+extern void lw6map_texture_clear (lw6sys_context_t * sys_context, lw6map_texture_t * texture);
+extern int lw6map_texture_coord_from_body (lw6sys_context_t * sys_context,
+					   const lw6map_level_t * level, int *texture_x, int *texture_y, int body_x, int body_y);
+extern lw6sys_color_8_t lw6map_texture_get_with_body_coord (lw6sys_context_t * sys_context, const lw6map_level_t * level, int body_x, int body_y);
+extern int lw6map_texture_has_alpha (lw6sys_context_t * sys_context, lw6map_texture_t * texture);
 
 /* map-weapon.c */
-extern char *lw6map_weapon_index_to_key (int index);
-extern int lw6map_weapon_key_to_index (const char *key);
-extern char *lw6map_weapon_index_to_label (int index);
+extern char *lw6map_weapon_index_to_key (lw6sys_context_t * sys_context, int index);
+extern int lw6map_weapon_key_to_index (lw6sys_context_t * sys_context, const char *key);
+extern char *lw6map_weapon_index_to_label (lw6sys_context_t * sys_context, int index);
 static inline int
 lw6map_weapon_is_valid (int weapon)
 {
