@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -44,7 +44,7 @@ lw6mat_dmat4_zero (lw6mat_dmat4_t * dmat4)
 }
 
 /**
- * lw6mat_dmat4_id
+ * lw6mat_dmat4_identity
  *
  * @dmat4: the matrix to initialize.
  *
@@ -54,7 +54,7 @@ lw6mat_dmat4_zero (lw6mat_dmat4_t * dmat4)
  * Return value: none.
  */
 void
-lw6mat_dmat4_id (lw6mat_dmat4_t * dmat4)
+lw6mat_dmat4_identity (lw6mat_dmat4_t * dmat4)
 {
   int i;
 
@@ -66,6 +66,226 @@ lw6mat_dmat4_id (lw6mat_dmat4_t * dmat4)
     }
 }
 
+/**
+ * lw6mat_dmat4_translation
+ *
+ * @dmat4: the matrix to initialize.
+ * @dvec3: vector which defines the translation.
+ *
+ * Loads the matrix with a translation transformation matrix.
+ * By multiplicating by this matrix, a translation is done.
+ *
+ * Return value: none.
+ */
+void
+lw6mat_dmat4_translation (lw6mat_dmat4_t * dmat4, const lw6mat_dvec3_t * dvec3)
+{
+  int i;
+
+  lw6mat_dmat4_identity (dmat4);
+
+  for (i = 0; i < LW6MAT_VEC3_V_SIZE; ++i)
+    {
+      dmat4->m[LW6MAT_VEC3_V_SIZE][i] = dvec3->v[i];
+    }
+}
+
+/**
+ * lw6mat_dmat4_scale
+ *
+ * @dmat4: the matrix to initialize.
+ * @dvec3: value used to scale matrix.
+ *
+ * Loads the matrix with a scale matrix. By multiplicating by this
+ * matrix, a scaling is done.
+ *
+ * Return value: none.
+ */
+void
+lw6mat_dmat4_scale (lw6mat_dmat4_t * dmat4, const lw6mat_dvec3_t * dvec3)
+{
+  int i;
+
+  lw6mat_dmat4_identity (dmat4);
+
+  for (i = 0; i < LW6MAT_VEC3_V_SIZE; ++i)
+    {
+      dmat4->m[i][i] = dvec3->v[i];
+    }
+}
+
+/**
+ * lw6mat_dmat4_rot_x
+ *
+ * @dmat4: the matrix to initialize.
+ * @r: value used to for the rotation, angle in radians.
+ *
+ * Loads the matrix with a rotation matrix. By multiplicating by this
+ * matrix, a rotation is done, over the X axis.
+ *
+ * Return value: none.
+ */
+void
+lw6mat_dmat4_rot_x (lw6mat_dmat4_t * dmat4, double r)
+{
+  float c = cos (r);
+  float s = sin (r);
+
+  lw6mat_dmat4_identity (dmat4);
+
+  dmat4->m[1][1] = c;
+  dmat4->m[1][2] = s;
+  dmat4->m[2][1] = -s;
+  dmat4->m[2][2] = c;
+}
+
+/**
+ * lw6mat_dmat4_rot_y
+ *
+ * @dmat4: the matrix to initialize.
+ * @r: value used to for the rotation, angle in radians.
+ *
+ * Loads the matrix with a rotation matrix. By multiplicating by this
+ * matrix, a rotation is done, over the Y axis.
+ *
+ * Return value: none.
+ */
+void
+lw6mat_dmat4_rot_y (lw6mat_dmat4_t * dmat4, double r)
+{
+  float c = cos (r);
+  float s = sin (r);
+
+  lw6mat_dmat4_identity (dmat4);
+
+  dmat4->m[2][2] = c;
+  dmat4->m[2][0] = s;
+  dmat4->m[0][2] = -s;
+  dmat4->m[0][0] = c;
+}
+
+/**
+ * lw6mat_dmat4_rot_z
+ *
+ * @dmat4: the matrix to initialize.
+ * @r: value used to for the rotation, angle in radians.
+ *
+ * Loads the matrix with a rotation matrix. By multiplicating by this
+ * matrix, a rotation is done, over the Z axis.
+ *
+ * Return value: none.
+ */
+void
+lw6mat_dmat4_rot_z (lw6mat_dmat4_t * dmat4, double r)
+{
+  float c = cos (r);
+  float s = sin (r);
+
+  lw6mat_dmat4_identity (dmat4);
+
+  dmat4->m[0][0] = c;
+  dmat4->m[0][1] = s;
+  dmat4->m[1][0] = -s;
+  dmat4->m[1][1] = c;
+}
+
+/**
+ * lw6mat_dmat4_ortho
+ *
+ * @dmat4: the matrix to initialize.
+ * @left: left plane coordinate
+ * @right: right plane coordinate
+ * @bottom: bottom plane coordinate
+ * @top: top plane coordinate
+ * @nearval: near plane coordinate
+ * @farval: far plane coordinate
+ *
+ * Loads the matrix with an orthogonal projection matrix.
+ * Does it the way glOrtho would, see
+ * https://www.opengl.org/sdk/docs/man2/xhtml/glOrtho.xml
+ * for details.
+ * Note: use -nearVal and -farVal to initialize.
+ * It's a little akward, if you expect to pass vectors with positions
+ * ranging from nearVal to farVal then you need to pass -nearVal and
+ * -farVal to this function. This is probably due to the fact that
+ * with a right-handed basis and X,Y set up "as usual", then Z is negative
+ * when going farther and farther. This tweak allows farVal to yield
+ * +1 and nearVal -1. We keep this function as is here, as this is the
+ * way OpenGL functions seem to work.
+ *
+ * Return value: none.
+ */
+void
+lw6mat_dmat4_ortho (lw6mat_dmat4_t * dmat4, double left, double right, double bottom, double top, double nearval, double farval)
+{
+  double dx = right - left;
+  double dy = top - bottom;
+  double dz = farval - nearval;
+
+  lw6mat_dmat4_identity (dmat4);
+
+  if (dx != 0.0f)
+    {
+      dmat4->m[0][0] = 2.0f / dx;
+      dmat4->m[3][0] = -(right + left) / dx;
+    }
+  if (dy != 0.0f)
+    {
+      dmat4->m[1][1] = 2.0f / dy;
+      dmat4->m[3][1] = -(top + bottom) / dy;
+    }
+  if (dz != 0.0f)
+    {
+      dmat4->m[2][2] = -2.0f / dz;
+      dmat4->m[3][2] = -(nearval + farval) / dz;
+    }
+}
+
+/**
+ * lw6mat_dmat4_perspective
+ *
+ * @dmat4: the matrix to initialize.
+ * @fovy: vertical field of view (degrees, not radians)
+ * @aspect: x/y ratio
+ * @znear: near plane coordinate (use -znear to initialize)
+ * @zfar: far plane coordinate (use -zfar to initialize)
+ *
+ * Loads the matrix with a projection matrix.
+ * Does it the way gluPerspective would, see
+ * https://www.opengl.org/sdk/docs/man2/xhtml/gluPerspective.xml
+ * for details.
+ *
+ * Return value: none.
+ */
+void
+lw6mat_dmat4_perspective (lw6mat_dmat4_t * dmat4, double fovy, double aspect, double znear, double zfar)
+{
+  double radfovy2 = lw6sys_math_deg2rad (fovy) / 2.0;
+  double s = sin (radfovy2);
+  double dz = znear - zfar;
+
+  lw6mat_dmat4_zero (dmat4);
+
+  if (s != 0.0f)
+    {
+      double f = cos (radfovy2) / s;
+
+      if (aspect != 0.0f)
+	{
+	  dmat4->m[0][0] = f / aspect;
+	  dmat4->m[1][1] = f;
+	}
+    }
+
+  if (dz != 0.0f)
+    {
+      dmat4->m[2][2] = (znear + zfar) / dz;
+      dmat4->m[3][2] = 2.0f * znear * zfar / dz;
+    }
+
+  dmat4->m[2][3] = -LW6MAT_D_1;
+}
+
 /**
  * lw6mat_dmat4_is_same
  *
@@ -77,15 +297,13 @@ lw6mat_dmat4_id (lw6mat_dmat4_t * dmat4)
  * Return value: 1 if equal, 0 if different.
  */
 int
-lw6mat_dmat4_is_same (const lw6mat_dmat4_t * dmat4_a,
-		      const lw6mat_dmat4_t * dmat4_b)
+lw6mat_dmat4_is_same (const lw6mat_dmat4_t * dmat4_a, const lw6mat_dmat4_t * dmat4_b)
 {
-  return (!memcmp
-	  ((void *) dmat4_a, (void *) dmat4_b, sizeof (lw6mat_dmat4_t)));
+  return (!memcmp ((void *) dmat4_a, (void *) dmat4_b, sizeof (lw6mat_dmat4_t)));
 }
 
 /**
- * lw6mat_dmat4_trans
+ * lw6mat_dmat4_transpose
  *
  * @dmat4: the matrix to transpose
  *
@@ -94,7 +312,7 @@ lw6mat_dmat4_is_same (const lw6mat_dmat4_t * dmat4_a,
  * Return value: none.
  */
 void
-lw6mat_dmat4_trans (lw6mat_dmat4_t * dmat4)
+lw6mat_dmat4_transpose (lw6mat_dmat4_t * dmat4)
 {
   int i, j;
   double tmp;
@@ -148,12 +366,11 @@ lw6mat_dmat4_det (const lw6mat_dmat4_t * dmat4)
     dmat4->m[0][1] * dmat4->m[1][2] * dmat4->m[2][0] * dmat4->m[3][3] +
     dmat4->m[0][2] * dmat4->m[1][0] * dmat4->m[2][1] * dmat4->m[3][3] -
     dmat4->m[0][0] * dmat4->m[1][2] * dmat4->m[2][1] * dmat4->m[3][3] -
-    dmat4->m[0][1] * dmat4->m[1][0] * dmat4->m[2][2] * dmat4->m[3][3] +
-    dmat4->m[0][0] * dmat4->m[1][1] * dmat4->m[2][2] * dmat4->m[3][3];
+    dmat4->m[0][1] * dmat4->m[1][0] * dmat4->m[2][2] * dmat4->m[3][3] + dmat4->m[0][0] * dmat4->m[1][1] * dmat4->m[2][2] * dmat4->m[3][3];
 }
 
 /**
- * lw6mat_dmat4_scale
+ * lw6mat_dmat4_mul_scale
  *
  * @dmat4: matrix to modify
  * @f: scale factor
@@ -163,7 +380,7 @@ lw6mat_dmat4_det (const lw6mat_dmat4_t * dmat4)
  * Return value: none
  */
 void
-lw6mat_dmat4_scale (lw6mat_dmat4_t * dmat4, double f)
+lw6mat_dmat4_mul_scale (lw6mat_dmat4_t * dmat4, double f)
 {
   int i;
 
@@ -176,6 +393,7 @@ lw6mat_dmat4_scale (lw6mat_dmat4_t * dmat4, double f)
 /**
  * lw6mat_dmat4_inv
  *
+ * @sys_context: global system context
  * @dmat4_dst: the matrix inverted
  * @dmat4_src: the matrix to invert
  *
@@ -187,8 +405,7 @@ lw6mat_dmat4_scale (lw6mat_dmat4_t * dmat4, double f)
  * can not be inverted.
  */
 int
-lw6mat_dmat4_inv (lw6mat_dmat4_t * dmat4_dst,
-		  const lw6mat_dmat4_t * dmat4_src)
+lw6mat_dmat4_inv (lw6sys_context_t * sys_context, lw6mat_dmat4_t * dmat4_dst, const lw6mat_dmat4_t * dmat4_src)
 {
   /*
    * In case src and dst or the same, recursively call this
@@ -199,7 +416,7 @@ lw6mat_dmat4_inv (lw6mat_dmat4_t * dmat4_dst,
     {
       lw6mat_dmat4_t dmat4_tmp = *dmat4_src;
 
-      return lw6mat_dmat4_inv (dmat4_dst, &dmat4_tmp);
+      return lw6mat_dmat4_inv (sys_context, dmat4_dst, &dmat4_tmp);
     }
   else
     {
@@ -217,137 +434,103 @@ lw6mat_dmat4_inv (lw6mat_dmat4_t * dmat4_dst,
 	     dmat4_src->m[1][3] * dmat4_src->m[2][2] * dmat4_src->m[3][1] +
 	     dmat4_src->m[1][3] * dmat4_src->m[2][1] * dmat4_src->m[3][2] -
 	     dmat4_src->m[1][1] * dmat4_src->m[2][3] * dmat4_src->m[3][2] -
-	     dmat4_src->m[1][2] * dmat4_src->m[2][1] * dmat4_src->m[3][3] +
-	     dmat4_src->m[1][1] * dmat4_src->m[2][2] * dmat4_src->m[3][3]) /
-	    det;
+	     dmat4_src->m[1][2] * dmat4_src->m[2][1] * dmat4_src->m[3][3] + dmat4_src->m[1][1] * dmat4_src->m[2][2] * dmat4_src->m[3][3]) / det;
 	  dmat4_dst->m[0][1] =
 	    (dmat4_src->m[0][3] * dmat4_src->m[2][2] * dmat4_src->m[3][1] -
 	     dmat4_src->m[0][2] * dmat4_src->m[2][3] * dmat4_src->m[3][1] -
 	     dmat4_src->m[0][3] * dmat4_src->m[2][1] * dmat4_src->m[3][2] +
 	     dmat4_src->m[0][1] * dmat4_src->m[2][3] * dmat4_src->m[3][2] +
-	     dmat4_src->m[0][2] * dmat4_src->m[2][1] * dmat4_src->m[3][3] -
-	     dmat4_src->m[0][1] * dmat4_src->m[2][2] * dmat4_src->m[3][3]) /
-	    det;
+	     dmat4_src->m[0][2] * dmat4_src->m[2][1] * dmat4_src->m[3][3] - dmat4_src->m[0][1] * dmat4_src->m[2][2] * dmat4_src->m[3][3]) / det;
 	  dmat4_dst->m[0][2] =
 	    (dmat4_src->m[0][2] * dmat4_src->m[1][3] * dmat4_src->m[3][1] -
 	     dmat4_src->m[0][3] * dmat4_src->m[1][2] * dmat4_src->m[3][1] +
 	     dmat4_src->m[0][3] * dmat4_src->m[1][1] * dmat4_src->m[3][2] -
 	     dmat4_src->m[0][1] * dmat4_src->m[1][3] * dmat4_src->m[3][2] -
-	     dmat4_src->m[0][2] * dmat4_src->m[1][1] * dmat4_src->m[3][3] +
-	     dmat4_src->m[0][1] * dmat4_src->m[1][2] * dmat4_src->m[3][3]) /
-	    det;
+	     dmat4_src->m[0][2] * dmat4_src->m[1][1] * dmat4_src->m[3][3] + dmat4_src->m[0][1] * dmat4_src->m[1][2] * dmat4_src->m[3][3]) / det;
 	  dmat4_dst->m[0][3] =
 	    (dmat4_src->m[0][3] * dmat4_src->m[1][2] * dmat4_src->m[2][1] -
 	     dmat4_src->m[0][2] * dmat4_src->m[1][3] * dmat4_src->m[2][1] -
 	     dmat4_src->m[0][3] * dmat4_src->m[1][1] * dmat4_src->m[2][2] +
 	     dmat4_src->m[0][1] * dmat4_src->m[1][3] * dmat4_src->m[2][2] +
-	     dmat4_src->m[0][2] * dmat4_src->m[1][1] * dmat4_src->m[2][3] -
-	     dmat4_src->m[0][1] * dmat4_src->m[1][2] * dmat4_src->m[2][3]) /
-	    det;
+	     dmat4_src->m[0][2] * dmat4_src->m[1][1] * dmat4_src->m[2][3] - dmat4_src->m[0][1] * dmat4_src->m[1][2] * dmat4_src->m[2][3]) / det;
 	  dmat4_dst->m[1][0] =
 	    (dmat4_src->m[1][3] * dmat4_src->m[2][2] * dmat4_src->m[3][0] -
 	     dmat4_src->m[1][2] * dmat4_src->m[2][3] * dmat4_src->m[3][0] -
 	     dmat4_src->m[1][3] * dmat4_src->m[2][0] * dmat4_src->m[3][2] +
 	     dmat4_src->m[1][0] * dmat4_src->m[2][3] * dmat4_src->m[3][2] +
-	     dmat4_src->m[1][2] * dmat4_src->m[2][0] * dmat4_src->m[3][3] -
-	     dmat4_src->m[1][0] * dmat4_src->m[2][2] * dmat4_src->m[3][3]) /
-	    det;
+	     dmat4_src->m[1][2] * dmat4_src->m[2][0] * dmat4_src->m[3][3] - dmat4_src->m[1][0] * dmat4_src->m[2][2] * dmat4_src->m[3][3]) / det;
 	  dmat4_dst->m[1][1] =
 	    (dmat4_src->m[0][2] * dmat4_src->m[2][3] * dmat4_src->m[3][0] -
 	     dmat4_src->m[0][3] * dmat4_src->m[2][2] * dmat4_src->m[3][0] +
 	     dmat4_src->m[0][3] * dmat4_src->m[2][0] * dmat4_src->m[3][2] -
 	     dmat4_src->m[0][0] * dmat4_src->m[2][3] * dmat4_src->m[3][2] -
-	     dmat4_src->m[0][2] * dmat4_src->m[2][0] * dmat4_src->m[3][3] +
-	     dmat4_src->m[0][0] * dmat4_src->m[2][2] * dmat4_src->m[3][3]) /
-	    det;
+	     dmat4_src->m[0][2] * dmat4_src->m[2][0] * dmat4_src->m[3][3] + dmat4_src->m[0][0] * dmat4_src->m[2][2] * dmat4_src->m[3][3]) / det;
 	  dmat4_dst->m[1][2] =
 	    (dmat4_src->m[0][3] * dmat4_src->m[1][2] * dmat4_src->m[3][0] -
 	     dmat4_src->m[0][2] * dmat4_src->m[1][3] * dmat4_src->m[3][0] -
 	     dmat4_src->m[0][3] * dmat4_src->m[1][0] * dmat4_src->m[3][2] +
 	     dmat4_src->m[0][0] * dmat4_src->m[1][3] * dmat4_src->m[3][2] +
-	     dmat4_src->m[0][2] * dmat4_src->m[1][0] * dmat4_src->m[3][3] -
-	     dmat4_src->m[0][0] * dmat4_src->m[1][2] * dmat4_src->m[3][3]) /
-	    det;
+	     dmat4_src->m[0][2] * dmat4_src->m[1][0] * dmat4_src->m[3][3] - dmat4_src->m[0][0] * dmat4_src->m[1][2] * dmat4_src->m[3][3]) / det;
 	  dmat4_dst->m[1][3] =
 	    (dmat4_src->m[0][2] * dmat4_src->m[1][3] * dmat4_src->m[2][0] -
 	     dmat4_src->m[0][3] * dmat4_src->m[1][2] * dmat4_src->m[2][0] +
 	     dmat4_src->m[0][3] * dmat4_src->m[1][0] * dmat4_src->m[2][2] -
 	     dmat4_src->m[0][0] * dmat4_src->m[1][3] * dmat4_src->m[2][2] -
-	     dmat4_src->m[0][2] * dmat4_src->m[1][0] * dmat4_src->m[2][3] +
-	     dmat4_src->m[0][0] * dmat4_src->m[1][2] * dmat4_src->m[2][3]) /
-	    det;
+	     dmat4_src->m[0][2] * dmat4_src->m[1][0] * dmat4_src->m[2][3] + dmat4_src->m[0][0] * dmat4_src->m[1][2] * dmat4_src->m[2][3]) / det;
 	  dmat4_dst->m[2][0] =
 	    (dmat4_src->m[1][1] * dmat4_src->m[2][3] * dmat4_src->m[3][0] -
 	     dmat4_src->m[1][3] * dmat4_src->m[2][1] * dmat4_src->m[3][0] +
 	     dmat4_src->m[1][3] * dmat4_src->m[2][0] * dmat4_src->m[3][1] -
 	     dmat4_src->m[1][0] * dmat4_src->m[2][3] * dmat4_src->m[3][1] -
-	     dmat4_src->m[1][1] * dmat4_src->m[2][0] * dmat4_src->m[3][3] +
-	     dmat4_src->m[1][0] * dmat4_src->m[2][1] * dmat4_src->m[3][3]) /
-	    det;
+	     dmat4_src->m[1][1] * dmat4_src->m[2][0] * dmat4_src->m[3][3] + dmat4_src->m[1][0] * dmat4_src->m[2][1] * dmat4_src->m[3][3]) / det;
 	  dmat4_dst->m[2][1] =
 	    (dmat4_src->m[0][3] * dmat4_src->m[2][1] * dmat4_src->m[3][0] -
 	     dmat4_src->m[0][1] * dmat4_src->m[2][3] * dmat4_src->m[3][0] -
 	     dmat4_src->m[0][3] * dmat4_src->m[2][0] * dmat4_src->m[3][1] +
 	     dmat4_src->m[0][0] * dmat4_src->m[2][3] * dmat4_src->m[3][1] +
-	     dmat4_src->m[0][1] * dmat4_src->m[2][0] * dmat4_src->m[3][3] -
-	     dmat4_src->m[0][0] * dmat4_src->m[2][1] * dmat4_src->m[3][3]) /
-	    det;
+	     dmat4_src->m[0][1] * dmat4_src->m[2][0] * dmat4_src->m[3][3] - dmat4_src->m[0][0] * dmat4_src->m[2][1] * dmat4_src->m[3][3]) / det;
 	  dmat4_dst->m[2][2] =
 	    (dmat4_src->m[0][1] * dmat4_src->m[1][3] * dmat4_src->m[3][0] -
 	     dmat4_src->m[0][3] * dmat4_src->m[1][1] * dmat4_src->m[3][0] +
 	     dmat4_src->m[0][3] * dmat4_src->m[1][0] * dmat4_src->m[3][1] -
 	     dmat4_src->m[0][0] * dmat4_src->m[1][3] * dmat4_src->m[3][1] -
-	     dmat4_src->m[0][1] * dmat4_src->m[1][0] * dmat4_src->m[3][3] +
-	     dmat4_src->m[0][0] * dmat4_src->m[1][1] * dmat4_src->m[3][3]) /
-	    det;
+	     dmat4_src->m[0][1] * dmat4_src->m[1][0] * dmat4_src->m[3][3] + dmat4_src->m[0][0] * dmat4_src->m[1][1] * dmat4_src->m[3][3]) / det;
 	  dmat4_dst->m[2][3] =
 	    (dmat4_src->m[0][3] * dmat4_src->m[1][1] * dmat4_src->m[2][0] -
 	     dmat4_src->m[0][1] * dmat4_src->m[1][3] * dmat4_src->m[2][0] -
 	     dmat4_src->m[0][3] * dmat4_src->m[1][0] * dmat4_src->m[2][1] +
 	     dmat4_src->m[0][0] * dmat4_src->m[1][3] * dmat4_src->m[2][1] +
-	     dmat4_src->m[0][1] * dmat4_src->m[1][0] * dmat4_src->m[2][3] -
-	     dmat4_src->m[0][0] * dmat4_src->m[1][1] * dmat4_src->m[2][3]) /
-	    det;
+	     dmat4_src->m[0][1] * dmat4_src->m[1][0] * dmat4_src->m[2][3] - dmat4_src->m[0][0] * dmat4_src->m[1][1] * dmat4_src->m[2][3]) / det;
 	  dmat4_dst->m[3][0] =
 	    (dmat4_src->m[1][2] * dmat4_src->m[2][1] * dmat4_src->m[3][0] -
 	     dmat4_src->m[1][1] * dmat4_src->m[2][2] * dmat4_src->m[3][0] -
 	     dmat4_src->m[1][2] * dmat4_src->m[2][0] * dmat4_src->m[3][1] +
 	     dmat4_src->m[1][0] * dmat4_src->m[2][2] * dmat4_src->m[3][1] +
-	     dmat4_src->m[1][1] * dmat4_src->m[2][0] * dmat4_src->m[3][2] -
-	     dmat4_src->m[1][0] * dmat4_src->m[2][1] * dmat4_src->m[3][2]) /
-	    det;
+	     dmat4_src->m[1][1] * dmat4_src->m[2][0] * dmat4_src->m[3][2] - dmat4_src->m[1][0] * dmat4_src->m[2][1] * dmat4_src->m[3][2]) / det;
 	  dmat4_dst->m[3][1] =
 	    (dmat4_src->m[0][1] * dmat4_src->m[2][2] * dmat4_src->m[3][0] -
 	     dmat4_src->m[0][2] * dmat4_src->m[2][1] * dmat4_src->m[3][0] +
 	     dmat4_src->m[0][2] * dmat4_src->m[2][0] * dmat4_src->m[3][1] -
 	     dmat4_src->m[0][0] * dmat4_src->m[2][2] * dmat4_src->m[3][1] -
-	     dmat4_src->m[0][1] * dmat4_src->m[2][0] * dmat4_src->m[3][2] +
-	     dmat4_src->m[0][0] * dmat4_src->m[2][1] * dmat4_src->m[3][2]) /
-	    det;
+	     dmat4_src->m[0][1] * dmat4_src->m[2][0] * dmat4_src->m[3][2] + dmat4_src->m[0][0] * dmat4_src->m[2][1] * dmat4_src->m[3][2]) / det;
 	  dmat4_dst->m[3][2] =
 	    (dmat4_src->m[0][2] * dmat4_src->m[1][1] * dmat4_src->m[3][0] -
 	     dmat4_src->m[0][1] * dmat4_src->m[1][2] * dmat4_src->m[3][0] -
 	     dmat4_src->m[0][2] * dmat4_src->m[1][0] * dmat4_src->m[3][1] +
 	     dmat4_src->m[0][0] * dmat4_src->m[1][2] * dmat4_src->m[3][1] +
-	     dmat4_src->m[0][1] * dmat4_src->m[1][0] * dmat4_src->m[3][2] -
-	     dmat4_src->m[0][0] * dmat4_src->m[1][1] * dmat4_src->m[3][2]) /
-	    det;
+	     dmat4_src->m[0][1] * dmat4_src->m[1][0] * dmat4_src->m[3][2] - dmat4_src->m[0][0] * dmat4_src->m[1][1] * dmat4_src->m[3][2]) / det;
 	  dmat4_dst->m[3][3] =
 	    (dmat4_src->m[0][1] * dmat4_src->m[1][2] * dmat4_src->m[2][0] -
 	     dmat4_src->m[0][2] * dmat4_src->m[1][1] * dmat4_src->m[2][0] +
 	     dmat4_src->m[0][2] * dmat4_src->m[1][0] * dmat4_src->m[2][1] -
 	     dmat4_src->m[0][0] * dmat4_src->m[1][2] * dmat4_src->m[2][1] -
-	     dmat4_src->m[0][1] * dmat4_src->m[1][0] * dmat4_src->m[2][2] +
-	     dmat4_src->m[0][0] * dmat4_src->m[1][1] * dmat4_src->m[2][2]) /
-	    det;
+	     dmat4_src->m[0][1] * dmat4_src->m[1][0] * dmat4_src->m[2][2] + dmat4_src->m[0][0] * dmat4_src->m[1][1] * dmat4_src->m[2][2]) / det;
 
 	  return 1;
 	}
       else
 	{
-	  lw6sys_log (LW6SYS_LOG_INFO,
-		      _x_
-		      ("trying to invert non-invertible dmat4 matrix, determinant is 0"));
+	  lw6sys_log (sys_context, LW6SYS_LOG_INFO, _x_ ("trying to invert non-invertible dmat4 matrix, determinant is 0"));
 
 	  return 0;
 	}
@@ -366,9 +549,7 @@ lw6mat_dmat4_inv (lw6mat_dmat4_t * dmat4_dst,
  * Return value: none.
  */
 void
-lw6mat_dmat4_mul_dmat4 (lw6mat_dmat4_t * dmat4,
-			const lw6mat_dmat4_t * dmat4_a,
-			const lw6mat_dmat4_t * dmat4_b)
+lw6mat_dmat4_mul_dmat4 (lw6mat_dmat4_t * dmat4, const lw6mat_dmat4_t * dmat4_a, const lw6mat_dmat4_t * dmat4_b)
 {
   /*
    * In case src(s) and dst or the same, recursively call this
@@ -396,9 +577,7 @@ lw6mat_dmat4_mul_dmat4 (lw6mat_dmat4_t * dmat4,
 	  for (j = 0; j < LW6MAT_MAT4_M_SIZE; ++j)
 	    {
 	      dmat4->m[i][j] = dmat4_a->m[0][j] * dmat4_b->m[i][0]
-		+ dmat4_a->m[1][j] * dmat4_b->m[i][1]
-		+ dmat4_a->m[2][j] * dmat4_b->m[i][2]
-		+ dmat4_a->m[3][j] * dmat4_b->m[i][3];
+		+ dmat4_a->m[1][j] * dmat4_b->m[i][1] + dmat4_a->m[2][j] * dmat4_b->m[i][2] + dmat4_a->m[3][j] * dmat4_b->m[i][3];
 	    }
 	}
     }
@@ -421,9 +600,7 @@ lw6mat_dmat4_mul_dmat4 (lw6mat_dmat4_t * dmat4,
  * Return value: none.
  */
 void
-lw6mat_dmat4_mul_dvec4 (lw6mat_dvec4_t * dvec4_dst,
-			const lw6mat_dmat4_t * dmat4,
-			const lw6mat_dvec4_t * dvec4_src)
+lw6mat_dmat4_mul_dvec4 (lw6mat_dvec4_t * dvec4_dst, const lw6mat_dmat4_t * dmat4, const lw6mat_dvec4_t * dvec4_src)
 {
   /*
    * In case src and dst or the same, recursively call this
@@ -439,17 +616,13 @@ lw6mat_dmat4_mul_dvec4 (lw6mat_dvec4_t * dvec4_dst,
   else
     {
       dvec4_dst->v[0] =
-	dmat4->m[0][0] * dvec4_src->v[0] + dmat4->m[1][0] * dvec4_src->v[1] +
-	dmat4->m[2][0] * dvec4_src->v[2] + dmat4->m[3][0] * dvec4_src->v[3];
+	dmat4->m[0][0] * dvec4_src->v[0] + dmat4->m[1][0] * dvec4_src->v[1] + dmat4->m[2][0] * dvec4_src->v[2] + dmat4->m[3][0] * dvec4_src->v[3];
       dvec4_dst->v[1] =
-	dmat4->m[0][1] * dvec4_src->v[0] + dmat4->m[1][1] * dvec4_src->v[1] +
-	dmat4->m[2][1] * dvec4_src->v[2] + dmat4->m[3][1] * dvec4_src->v[3];
+	dmat4->m[0][1] * dvec4_src->v[0] + dmat4->m[1][1] * dvec4_src->v[1] + dmat4->m[2][1] * dvec4_src->v[2] + dmat4->m[3][1] * dvec4_src->v[3];
       dvec4_dst->v[2] =
-	dmat4->m[0][2] * dvec4_src->v[0] + dmat4->m[1][2] * dvec4_src->v[1] +
-	dmat4->m[2][2] * dvec4_src->v[2] + dmat4->m[3][2] * dvec4_src->v[3];
+	dmat4->m[0][2] * dvec4_src->v[0] + dmat4->m[1][2] * dvec4_src->v[1] + dmat4->m[2][2] * dvec4_src->v[2] + dmat4->m[3][2] * dvec4_src->v[3];
       dvec4_dst->v[3] =
-	dmat4->m[0][3] * dvec4_src->v[0] + dmat4->m[1][3] * dvec4_src->v[1] +
-	dmat4->m[2][3] * dvec4_src->v[2] + dmat4->m[3][3] * dvec4_src->v[3];
+	dmat4->m[0][3] * dvec4_src->v[0] + dmat4->m[1][3] * dvec4_src->v[1] + dmat4->m[2][3] * dvec4_src->v[2] + dmat4->m[3][3] * dvec4_src->v[3];
     }
 }
 
@@ -473,9 +646,7 @@ lw6mat_dmat4_mul_dvec4 (lw6mat_dvec4_t * dvec4_dst,
  * Return value: none.
  */
 void
-lw6mat_dmat4_mul_dvec3 (lw6mat_dvec3_t * dvec3_dst,
-			const lw6mat_dmat4_t * dmat4,
-			const lw6mat_dvec3_t * dvec3_src)
+lw6mat_dmat4_mul_dvec3 (lw6mat_dvec3_t * dvec3_dst, const lw6mat_dmat4_t * dmat4, const lw6mat_dvec3_t * dvec3_src)
 {
   /*
    * In case src and dst or the same, recursively call this
@@ -490,21 +661,16 @@ lw6mat_dmat4_mul_dvec3 (lw6mat_dvec3_t * dvec3_dst,
     }
   else
     {
-      dvec3_dst->v[0] =
-	dmat4->m[0][0] * dvec3_src->v[0] + dmat4->m[1][0] * dvec3_src->v[1] +
-	dmat4->m[2][0] * dvec3_src->v[2] + dmat4->m[3][0];
-      dvec3_dst->v[1] =
-	dmat4->m[0][1] * dvec3_src->v[0] + dmat4->m[1][1] * dvec3_src->v[1] +
-	dmat4->m[2][1] * dvec3_src->v[2] + dmat4->m[3][1];
-      dvec3_dst->v[2] =
-	dmat4->m[0][2] * dvec3_src->v[0] + dmat4->m[1][2] * dvec3_src->v[1] +
-	dmat4->m[2][2] * dvec3_src->v[2] + dmat4->m[3][2];
+      dvec3_dst->v[0] = dmat4->m[0][0] * dvec3_src->v[0] + dmat4->m[1][0] * dvec3_src->v[1] + dmat4->m[2][0] * dvec3_src->v[2] + dmat4->m[3][0];
+      dvec3_dst->v[1] = dmat4->m[0][1] * dvec3_src->v[0] + dmat4->m[1][1] * dvec3_src->v[1] + dmat4->m[2][1] * dvec3_src->v[2] + dmat4->m[3][1];
+      dvec3_dst->v[2] = dmat4->m[0][2] * dvec3_src->v[0] + dmat4->m[1][2] * dvec3_src->v[1] + dmat4->m[2][2] * dvec3_src->v[2] + dmat4->m[3][2];
     }
 }
 
 /**
  * lw6mat_dmat4_repr
  *
+ * @sys_context: global system context
  * @dmat: matrix to represent
  *
  * Gives a readable version of the matrix, the representation
@@ -513,19 +679,17 @@ lw6mat_dmat4_mul_dvec3 (lw6mat_dvec3_t * dvec3_dst,
  * Return value: newly allocated string
  */
 char *
-lw6mat_dmat4_repr (const lw6mat_dmat4_t * dmat4)
+lw6mat_dmat4_repr (lw6sys_context_t * sys_context, const lw6mat_dmat4_t * dmat4)
 {
   char *repr = NULL;
 
   repr =
     lw6sys_new_sprintf
-    ("%s %s %dx%d\n[ \t%f\t%f\t%f\t%f\n\t%f\t%f\t%f\t%f\n\t%f\t%f\t%f\t%f\n\t%f\t%f\t%f\t%f ]",
+    (sys_context, "%s %s %dx%d\n[ \t%f\t%f\t%f\t%f\n\t%f\t%f\t%f\t%f\n\t%f\t%f\t%f\t%f\n\t%f\t%f\t%f\t%f ]",
      LW6MAT_REPR_D, LW6MAT_REPR_MAT, LW6MAT_MAT4_M_SIZE,
      LW6MAT_MAT4_M_SIZE, dmat4->m[0][0], dmat4->m[1][0], dmat4->m[2][0],
      dmat4->m[3][0], dmat4->m[0][1], dmat4->m[1][1], dmat4->m[2][1],
-     dmat4->m[3][1], dmat4->m[0][2], dmat4->m[1][2], dmat4->m[2][2],
-     dmat4->m[3][2], dmat4->m[0][3], dmat4->m[1][3], dmat4->m[2][3],
-     dmat4->m[3][3]);
+     dmat4->m[3][1], dmat4->m[0][2], dmat4->m[1][2], dmat4->m[2][2], dmat4->m[3][2], dmat4->m[0][3], dmat4->m[1][3], dmat4->m[2][3], dmat4->m[3][3]);
 
   return repr;
 }
