@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -56,11 +56,9 @@ lw6mat_dvec2_zero (lw6mat_dvec2_t * dvec2)
  * Return value: 1 if equal, 0 if different.
  */
 int
-lw6mat_dvec2_is_same (const lw6mat_dvec2_t * dvec2_a,
-		      const lw6mat_dvec2_t * dvec2_b)
+lw6mat_dvec2_is_same (const lw6mat_dvec2_t * dvec2_a, const lw6mat_dvec2_t * dvec2_b)
 {
-  return (!memcmp
-	  ((void *) dvec2_a, (void *) dvec2_b, sizeof (lw6mat_dvec2_t)));
+  return (!memcmp ((void *) dvec2_a, (void *) dvec2_b, sizeof (lw6mat_dvec2_t)));
 }
 
 /**
@@ -98,8 +96,9 @@ lw6mat_dvec2_len (const lw6mat_dvec2_t * dvec2)
 }
 
 /**
- * Normalizes a vector
+ * lw6mat_dvec2_normalize
  *
+ * @sys_context: global system context
  * @dvec2: the vector to normalize.
  *
  * Normalizes a vector, that is, make its length be 1.
@@ -107,7 +106,7 @@ lw6mat_dvec2_len (const lw6mat_dvec2_t * dvec2)
  * Return value: 1 if OK, 0 if error, such as trying to normalize vector zero.
  */
 int
-lw6mat_dvec2_norm (lw6mat_dvec2_t * dvec2)
+lw6mat_dvec2_normalize (lw6sys_context_t * sys_context, lw6mat_dvec2_t * dvec2)
 {
   double len = lw6mat_dvec2_len (dvec2);
 
@@ -120,7 +119,40 @@ lw6mat_dvec2_norm (lw6mat_dvec2_t * dvec2)
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_INFO, _x_ ("trying to normalize vector zero"));
+      lw6sys_log (sys_context, LW6SYS_LOG_INFO, _x_ ("trying to normalize vector zero"));
+
+      return 0;
+    }
+}
+
+/**
+ * lw6mat_dvec2_homogeneous
+ *
+ * Homogeneouss a vector
+ *
+ * @sys_context: global system context
+ * @dvec2: the vector to homogeneous.
+ *
+ * Transforms a vector into homegeneous coords, that is, scales it so
+ * that its last member is 1.
+ *
+ * Return value: 1 if OK, 0 if error, such as trying to operate on vector zero.
+ */
+int
+lw6mat_dvec2_homogeneous (lw6sys_context_t * sys_context, lw6mat_dvec2_t * dvec2)
+{
+  double d = dvec2->v[1];
+
+  if (d != 0.0f)
+    {
+      dvec2->p.x /= d;
+      dvec2->v[1] = LW6MAT_D_1;
+
+      return 1;
+    }
+  else
+    {
+      lw6sys_log (sys_context, LW6SYS_LOG_INFO, _x_ ("trying to make homogeneous a vector with zero last member"));
 
       return 0;
     }
@@ -154,8 +186,7 @@ lw6mat_dvec2_neg (lw6mat_dvec2_t * dvec2)
  * Return value: none
  */
 void
-lw6mat_dvec2_add (lw6mat_dvec2_t * dvec2, const lw6mat_dvec2_t * dvec2_a,
-		  const lw6mat_dvec2_t * dvec2_b)
+lw6mat_dvec2_add (lw6mat_dvec2_t * dvec2, const lw6mat_dvec2_t * dvec2_a, const lw6mat_dvec2_t * dvec2_b)
 {
   dvec2->p.x = dvec2_a->p.x + dvec2_b->p.x;
   dvec2->p.y = dvec2_a->p.y + dvec2_b->p.y;
@@ -173,8 +204,7 @@ lw6mat_dvec2_add (lw6mat_dvec2_t * dvec2, const lw6mat_dvec2_t * dvec2_a,
  * Return value: none
  */
 void
-lw6mat_dvec2_sub (lw6mat_dvec2_t * dvec2, const lw6mat_dvec2_t * dvec2_a,
-		  const lw6mat_dvec2_t * dvec2_b)
+lw6mat_dvec2_sub (lw6mat_dvec2_t * dvec2, const lw6mat_dvec2_t * dvec2_a, const lw6mat_dvec2_t * dvec2_b)
 {
   dvec2->p.x = dvec2_a->p.x - dvec2_b->p.x;
   dvec2->p.y = dvec2_a->p.y - dvec2_b->p.y;
@@ -191,8 +221,7 @@ lw6mat_dvec2_sub (lw6mat_dvec2_t * dvec2, const lw6mat_dvec2_t * dvec2_a,
  * Return value: none
  */
 double
-lw6mat_dvec2_dot (const lw6mat_dvec2_t * dvec2_a,
-		  const lw6mat_dvec2_t * dvec2_b)
+lw6mat_dvec2_dot (const lw6mat_dvec2_t * dvec2_a, const lw6mat_dvec2_t * dvec2_b)
 {
   return dvec2_a->p.x * dvec2_b->p.x + dvec2_a->p.y * dvec2_b->p.y;
 }
@@ -212,8 +241,7 @@ lw6mat_dvec2_dot (const lw6mat_dvec2_t * dvec2_a,
  * Return value: none
  */
 void
-lw6mat_dvec2_cross (lw6mat_dvec3_t * dvec3, const lw6mat_dvec2_t * dvec2_a,
-		    const lw6mat_dvec2_t * dvec2_b)
+lw6mat_dvec2_cross (lw6mat_dvec3_t * dvec3, const lw6mat_dvec2_t * dvec2_a, const lw6mat_dvec2_t * dvec2_b)
 {
   dvec3->p.x = LW6MAT_F_0;
   dvec3->p.y = LW6MAT_F_0;
@@ -221,7 +249,7 @@ lw6mat_dvec2_cross (lw6mat_dvec3_t * dvec3, const lw6mat_dvec2_t * dvec2_a,
 }
 
 /**
- * lw6mat_dvec2_scale
+ * lw6mat_dvec2_mul_scale
  *
  * @dvec2: vector to modify
  * @f: scale factor
@@ -231,7 +259,7 @@ lw6mat_dvec2_cross (lw6mat_dvec3_t * dvec3, const lw6mat_dvec2_t * dvec2_a,
  * Return value: none
  */
 void
-lw6mat_dvec2_scale (lw6mat_dvec2_t * dvec2, double f)
+lw6mat_dvec2_mul_scale (lw6mat_dvec2_t * dvec2, double f)
 {
   dvec2->p.x *= f;
   dvec2->p.y *= f;
@@ -249,9 +277,7 @@ lw6mat_dvec2_scale (lw6mat_dvec2_t * dvec2, double f)
  * Return value: none
  */
 void
-lw6mat_dvec2_mul_dvec2 (lw6mat_dmat2_t * dmat2,
-			const lw6mat_dvec2_t * dvec2_a,
-			const lw6mat_dvec2_t * dvec2_b)
+lw6mat_dvec2_mul_dvec2 (lw6mat_dmat2_t * dmat2, const lw6mat_dvec2_t * dvec2_a, const lw6mat_dvec2_t * dvec2_b)
 {
   int i, j;
 
@@ -267,6 +293,7 @@ lw6mat_dvec2_mul_dvec2 (lw6mat_dmat2_t * dmat2,
 /**
  * lw6mat_dvec2_repr
  *
+ * @sys_context: global system context
  * @dvec: vector to represent
  *
  * Gives a readable version of the vector
@@ -274,13 +301,11 @@ lw6mat_dvec2_mul_dvec2 (lw6mat_dmat2_t * dmat2,
  * Return value: newly allocated string
  */
 char *
-lw6mat_dvec2_repr (const lw6mat_dvec2_t * dvec2)
+lw6mat_dvec2_repr (lw6sys_context_t * sys_context, const lw6mat_dvec2_t * dvec2)
 {
   char *repr = NULL;
 
-  repr =
-    lw6sys_new_sprintf ("%s %s %d [ %f %f ]", LW6MAT_REPR_D, LW6MAT_REPR_VEC,
-			LW6MAT_VEC2_V_SIZE, dvec2->v[0], dvec2->v[1]);
+  repr = lw6sys_new_sprintf (sys_context, "%s %s %d [ %f %f ]", LW6MAT_REPR_D, LW6MAT_REPR_VEC, LW6MAT_VEC2_V_SIZE, dvec2->v[0], dvec2->v[1]);
 
   return repr;
 }
