@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -56,11 +56,9 @@ lw6mat_dvec4_zero (lw6mat_dvec4_t * dvec4)
  * Return value: 1 if equal, 0 if different.
  */
 int
-lw6mat_dvec4_is_same (const lw6mat_dvec4_t * dvec4_a,
-		      const lw6mat_dvec4_t * dvec4_b)
+lw6mat_dvec4_is_same (const lw6mat_dvec4_t * dvec4_a, const lw6mat_dvec4_t * dvec4_b)
 {
-  return (!memcmp
-	  ((void *) dvec4_a, (void *) dvec4_b, sizeof (lw6mat_dvec4_t)));
+  return (!memcmp ((void *) dvec4_a, (void *) dvec4_b, sizeof (lw6mat_dvec4_t)));
 }
 
 /**
@@ -78,8 +76,7 @@ lw6mat_dvec4_is_same (const lw6mat_dvec4_t * dvec4_a,
 double
 lw6mat_dvec4_len_sq (const lw6mat_dvec4_t * dvec4)
 {
-  return dvec4->p.x * dvec4->p.x + dvec4->p.y * dvec4->p.y +
-    dvec4->p.z * dvec4->p.z + dvec4->p.w * dvec4->p.w;
+  return dvec4->p.x * dvec4->p.x + dvec4->p.y * dvec4->p.y + dvec4->p.z * dvec4->p.z + dvec4->p.w * dvec4->p.w;
 }
 
 /**
@@ -99,8 +96,9 @@ lw6mat_dvec4_len (const lw6mat_dvec4_t * dvec4)
 }
 
 /**
- * Normalizes a vector
+ * lw6mat_dvec4_normalize
  *
+ * @sys_context: global system context
  * @dvec4: the vector to normalize.
  *
  * Normalizes a vector, that is, make its length be 1.
@@ -108,7 +106,7 @@ lw6mat_dvec4_len (const lw6mat_dvec4_t * dvec4)
  * Return value: 1 if OK, 0 if error, such as trying to normalize vector zero.
  */
 int
-lw6mat_dvec4_norm (lw6mat_dvec4_t * dvec4)
+lw6mat_dvec4_normalize (lw6sys_context_t * sys_context, lw6mat_dvec4_t * dvec4)
 {
   double len = lw6mat_dvec4_len (dvec4);
 
@@ -123,7 +121,42 @@ lw6mat_dvec4_norm (lw6mat_dvec4_t * dvec4)
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_INFO, _x_ ("trying to normalize vector zero"));
+      lw6sys_log (sys_context, LW6SYS_LOG_INFO, _x_ ("trying to normalize vector zero"));
+
+      return 0;
+    }
+}
+
+/**
+ * lw6mat_dvec4_homogeneous
+ *
+ * Homogeneouss a vector
+ *
+ * @sys_context: global system context
+ * @dvec4: the vector to homogeneous.
+ *
+ * Transforms a vector into homegeneous coords, that is, scales it so
+ * that its last member is 1.
+ *
+ * Return value: 1 if OK, 0 if error, such as trying to operate on vector zero.
+ */
+int
+lw6mat_dvec4_homogeneous (lw6sys_context_t * sys_context, lw6mat_dvec4_t * dvec4)
+{
+  double d = dvec4->v[3];
+
+  if (d != 0.0f)
+    {
+      dvec4->p.x /= d;
+      dvec4->p.y /= d;
+      dvec4->p.z /= d;
+      dvec4->v[3] = LW6MAT_D_1;
+
+      return 1;
+    }
+  else
+    {
+      lw6sys_log (sys_context, LW6SYS_LOG_INFO, _x_ ("trying to make homogeneous a vector with zero last member"));
 
       return 0;
     }
@@ -159,8 +192,7 @@ lw6mat_dvec4_neg (lw6mat_dvec4_t * dvec4)
  * Return value: none
  */
 void
-lw6mat_dvec4_add (lw6mat_dvec4_t * dvec4, const lw6mat_dvec4_t * dvec4_a,
-		  const lw6mat_dvec4_t * dvec4_b)
+lw6mat_dvec4_add (lw6mat_dvec4_t * dvec4, const lw6mat_dvec4_t * dvec4_a, const lw6mat_dvec4_t * dvec4_b)
 {
   dvec4->p.x = dvec4_a->p.x + dvec4_b->p.x;
   dvec4->p.y = dvec4_a->p.y + dvec4_b->p.y;
@@ -180,8 +212,7 @@ lw6mat_dvec4_add (lw6mat_dvec4_t * dvec4, const lw6mat_dvec4_t * dvec4_a,
  * Return value: none
  */
 void
-lw6mat_dvec4_sub (lw6mat_dvec4_t * dvec4, const lw6mat_dvec4_t * dvec4_a,
-		  const lw6mat_dvec4_t * dvec4_b)
+lw6mat_dvec4_sub (lw6mat_dvec4_t * dvec4, const lw6mat_dvec4_t * dvec4_a, const lw6mat_dvec4_t * dvec4_b)
 {
   dvec4->p.x = dvec4_a->p.x - dvec4_b->p.x;
   dvec4->p.y = dvec4_a->p.y - dvec4_b->p.y;
@@ -200,11 +231,9 @@ lw6mat_dvec4_sub (lw6mat_dvec4_t * dvec4, const lw6mat_dvec4_t * dvec4_a,
  * Return value: none
  */
 double
-lw6mat_dvec4_dot (const lw6mat_dvec4_t * dvec4_a,
-		  const lw6mat_dvec4_t * dvec4_b)
+lw6mat_dvec4_dot (const lw6mat_dvec4_t * dvec4_a, const lw6mat_dvec4_t * dvec4_b)
 {
-  return dvec4_a->p.x * dvec4_b->p.x + dvec4_a->p.y * dvec4_b->p.y +
-    dvec4_a->p.z * dvec4_b->p.z + dvec4_a->p.w * dvec4_b->p.w;
+  return dvec4_a->p.x * dvec4_b->p.x + dvec4_a->p.y * dvec4_b->p.y + dvec4_a->p.z * dvec4_b->p.z + dvec4_a->p.w * dvec4_b->p.w;
 }
 
 /**
@@ -222,8 +251,7 @@ lw6mat_dvec4_dot (const lw6mat_dvec4_t * dvec4_a,
  * Return value: none
  */
 void
-lw6mat_dvec4_cross (lw6mat_dvec3_t * dvec3, const lw6mat_dvec4_t * dvec4_a,
-		    const lw6mat_dvec4_t * dvec4_b)
+lw6mat_dvec4_cross (lw6mat_dvec3_t * dvec3, const lw6mat_dvec4_t * dvec4_a, const lw6mat_dvec4_t * dvec4_b)
 {
   dvec3->p.x = dvec4_a->p.y * dvec4_b->p.z - dvec4_a->p.z * dvec4_b->p.y;
   dvec3->p.y = dvec4_a->p.z * dvec4_b->p.x - dvec4_a->p.x * dvec4_b->p.z;
@@ -231,7 +259,7 @@ lw6mat_dvec4_cross (lw6mat_dvec3_t * dvec3, const lw6mat_dvec4_t * dvec4_a,
 }
 
 /**
- * lw6mat_dvec4_scale
+ * lw6mat_dvec4_mul_scale
  *
  * @dvec4: vector to modify
  * @f: scale factor
@@ -241,7 +269,7 @@ lw6mat_dvec4_cross (lw6mat_dvec3_t * dvec3, const lw6mat_dvec4_t * dvec4_a,
  * Return value: none
  */
 void
-lw6mat_dvec4_scale (lw6mat_dvec4_t * dvec4, double f)
+lw6mat_dvec4_mul_scale (lw6mat_dvec4_t * dvec4, double f)
 {
   dvec4->p.x *= f;
   dvec4->p.y *= f;
@@ -261,9 +289,7 @@ lw6mat_dvec4_scale (lw6mat_dvec4_t * dvec4, double f)
  * Return value: none
  */
 void
-lw6mat_dvec4_mul_dvec4 (lw6mat_dmat4_t * dmat4,
-			const lw6mat_dvec4_t * dvec4_a,
-			const lw6mat_dvec4_t * dvec4_b)
+lw6mat_dvec4_mul_dvec4 (lw6mat_dmat4_t * dmat4, const lw6mat_dvec4_t * dvec4_a, const lw6mat_dvec4_t * dvec4_b)
 {
   int i, j;
 
@@ -279,6 +305,7 @@ lw6mat_dvec4_mul_dvec4 (lw6mat_dmat4_t * dmat4,
 /**
  * lw6mat_dvec4_repr
  *
+ * @sys_context: global system context
  * @dvec: vector to represent
  *
  * Gives a readable version of the vector
@@ -286,14 +313,13 @@ lw6mat_dvec4_mul_dvec4 (lw6mat_dmat4_t * dmat4,
  * Return value: newly allocated string
  */
 char *
-lw6mat_dvec4_repr (const lw6mat_dvec4_t * dvec4)
+lw6mat_dvec4_repr (lw6sys_context_t * sys_context, const lw6mat_dvec4_t * dvec4)
 {
   char *repr = NULL;
 
   repr =
-    lw6sys_new_sprintf ("%s %s %d [ %f %f %f %f ]", LW6MAT_REPR_D,
-			LW6MAT_REPR_VEC, LW6MAT_VEC4_V_SIZE, dvec4->v[0],
-			dvec4->v[1], dvec4->v[2], dvec4->v[3]);
+    lw6sys_new_sprintf (sys_context, "%s %s %d [ %f %f %f %f ]", LW6MAT_REPR_D, LW6MAT_REPR_VEC, LW6MAT_VEC4_V_SIZE, dvec4->v[0], dvec4->v[1], dvec4->v[2],
+			dvec4->v[3]);
 
   return repr;
 }
