@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -56,11 +56,9 @@ lw6mat_fvec2_zero (lw6mat_fvec2_t * fvec2)
  * Return value: 1 if equal, 0 if different.
  */
 int
-lw6mat_fvec2_is_same (const lw6mat_fvec2_t * fvec2_a,
-		      const lw6mat_fvec2_t * fvec2_b)
+lw6mat_fvec2_is_same (const lw6mat_fvec2_t * fvec2_a, const lw6mat_fvec2_t * fvec2_b)
 {
-  return (!memcmp
-	  ((void *) fvec2_a, (void *) fvec2_b, sizeof (lw6mat_fvec2_t)));
+  return (!memcmp ((void *) fvec2_a, (void *) fvec2_b, sizeof (lw6mat_fvec2_t)));
 }
 
 /**
@@ -98,8 +96,9 @@ lw6mat_fvec2_len (const lw6mat_fvec2_t * fvec2)
 }
 
 /**
- * Normalizes a vector
+ * lw6mat_fvec2_normalize
  *
+ * @sys_context: global system context
  * @fvec2: the vector to normalize.
  *
  * Normalizes a vector, that is, make its length be 1.
@@ -107,7 +106,7 @@ lw6mat_fvec2_len (const lw6mat_fvec2_t * fvec2)
  * Return value: 1 if OK, 0 if error, such as trying to normalize vector zero.
  */
 int
-lw6mat_fvec2_norm (lw6mat_fvec2_t * fvec2)
+lw6mat_fvec2_normalize (lw6sys_context_t * sys_context, lw6mat_fvec2_t * fvec2)
 {
   float len = lw6mat_fvec2_len (fvec2);
 
@@ -120,7 +119,40 @@ lw6mat_fvec2_norm (lw6mat_fvec2_t * fvec2)
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_INFO, _x_ ("trying to normalize vector zero"));
+      lw6sys_log (sys_context, LW6SYS_LOG_INFO, _x_ ("trying to normalize vector zero"));
+
+      return 0;
+    }
+}
+
+/**
+ * lw6mat_fvec2_homogeneous
+ *
+ * Homogeneouss a vector
+ *
+ * @sys_context: global system context
+ * @fvec2: the vector to homogeneous.
+ *
+ * Transforms a vector into homegeneous coords, that is, scales it so
+ * that its last member is 1.
+ *
+ * Return value: 1 if OK, 0 if error, such as trying to operate on vector zero.
+ */
+int
+lw6mat_fvec2_homogeneous (lw6sys_context_t * sys_context, lw6mat_fvec2_t * fvec2)
+{
+  float f = fvec2->v[1];
+
+  if (f != 0.0f)
+    {
+      fvec2->p.x /= f;
+      fvec2->v[1] = LW6MAT_F_1;
+
+      return 1;
+    }
+  else
+    {
+      lw6sys_log (sys_context, LW6SYS_LOG_INFO, _x_ ("trying to make homogeneous a vector with zero last member"));
 
       return 0;
     }
@@ -154,8 +186,7 @@ lw6mat_fvec2_neg (lw6mat_fvec2_t * fvec2)
  * Return value: none
  */
 void
-lw6mat_fvec2_add (lw6mat_fvec2_t * fvec2, const lw6mat_fvec2_t * fvec2_a,
-		  const lw6mat_fvec2_t * fvec2_b)
+lw6mat_fvec2_add (lw6mat_fvec2_t * fvec2, const lw6mat_fvec2_t * fvec2_a, const lw6mat_fvec2_t * fvec2_b)
 {
   fvec2->p.x = fvec2_a->p.x + fvec2_b->p.x;
   fvec2->p.y = fvec2_a->p.y + fvec2_b->p.y;
@@ -173,8 +204,7 @@ lw6mat_fvec2_add (lw6mat_fvec2_t * fvec2, const lw6mat_fvec2_t * fvec2_a,
  * Return value: none
  */
 void
-lw6mat_fvec2_sub (lw6mat_fvec2_t * fvec2, const lw6mat_fvec2_t * fvec2_a,
-		  const lw6mat_fvec2_t * fvec2_b)
+lw6mat_fvec2_sub (lw6mat_fvec2_t * fvec2, const lw6mat_fvec2_t * fvec2_a, const lw6mat_fvec2_t * fvec2_b)
 {
   fvec2->p.x = fvec2_a->p.x - fvec2_b->p.x;
   fvec2->p.y = fvec2_a->p.y - fvec2_b->p.y;
@@ -191,8 +221,7 @@ lw6mat_fvec2_sub (lw6mat_fvec2_t * fvec2, const lw6mat_fvec2_t * fvec2_a,
  * Return value: none
  */
 float
-lw6mat_fvec2_dot (const lw6mat_fvec2_t * fvec2_a,
-		  const lw6mat_fvec2_t * fvec2_b)
+lw6mat_fvec2_dot (const lw6mat_fvec2_t * fvec2_a, const lw6mat_fvec2_t * fvec2_b)
 {
   return fvec2_a->p.x * fvec2_b->p.x + fvec2_a->p.y * fvec2_b->p.y;
 }
@@ -212,8 +241,7 @@ lw6mat_fvec2_dot (const lw6mat_fvec2_t * fvec2_a,
  * Return value: none
  */
 void
-lw6mat_fvec2_cross (lw6mat_fvec3_t * fvec3, const lw6mat_fvec2_t * fvec2_a,
-		    const lw6mat_fvec2_t * fvec2_b)
+lw6mat_fvec2_cross (lw6mat_fvec3_t * fvec3, const lw6mat_fvec2_t * fvec2_a, const lw6mat_fvec2_t * fvec2_b)
 {
   fvec3->p.x = LW6MAT_F_0;
   fvec3->p.y = LW6MAT_F_0;
@@ -221,7 +249,7 @@ lw6mat_fvec2_cross (lw6mat_fvec3_t * fvec3, const lw6mat_fvec2_t * fvec2_a,
 }
 
 /**
- * lw6mat_fvec2_scale
+ * lw6mat_fvec2_mul_scale
  *
  * @fvec2: vector to modify
  * @f: scale factor
@@ -231,7 +259,7 @@ lw6mat_fvec2_cross (lw6mat_fvec3_t * fvec3, const lw6mat_fvec2_t * fvec2_a,
  * Return value: none
  */
 void
-lw6mat_fvec2_scale (lw6mat_fvec2_t * fvec2, float f)
+lw6mat_fvec2_mul_scale (lw6mat_fvec2_t * fvec2, float f)
 {
   fvec2->p.x *= f;
   fvec2->p.y *= f;
@@ -249,9 +277,7 @@ lw6mat_fvec2_scale (lw6mat_fvec2_t * fvec2, float f)
  * Return value: none
  */
 void
-lw6mat_fvec2_mul_fvec2 (lw6mat_fmat2_t * fmat2,
-			const lw6mat_fvec2_t * fvec2_a,
-			const lw6mat_fvec2_t * fvec2_b)
+lw6mat_fvec2_mul_fvec2 (lw6mat_fmat2_t * fmat2, const lw6mat_fvec2_t * fvec2_a, const lw6mat_fvec2_t * fvec2_b)
 {
   int i, j;
 
@@ -267,6 +293,7 @@ lw6mat_fvec2_mul_fvec2 (lw6mat_fmat2_t * fmat2,
 /**
  * lw6mat_fvec2_repr
  *
+ * @sys_context: global system context
  * @fvec: vector to represent
  *
  * Gives a readable version of the vector
@@ -274,13 +301,11 @@ lw6mat_fvec2_mul_fvec2 (lw6mat_fmat2_t * fmat2,
  * Return value: newly allocated string
  */
 char *
-lw6mat_fvec2_repr (const lw6mat_fvec2_t * fvec2)
+lw6mat_fvec2_repr (lw6sys_context_t * sys_context, const lw6mat_fvec2_t * fvec2)
 {
   char *repr = NULL;
 
-  repr =
-    lw6sys_new_sprintf ("%s %s %d [ %f %f ]", LW6MAT_REPR_F, LW6MAT_REPR_VEC,
-			LW6MAT_VEC2_V_SIZE, fvec2->v[0], fvec2->v[1]);
+  repr = lw6sys_new_sprintf (sys_context, "%s %s %d [ %f %f ]", LW6MAT_REPR_F, LW6MAT_REPR_VEC, LW6MAT_VEC2_V_SIZE, fvec2->v[0], fvec2->v[1]);
 
   return repr;
 }
