@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -56,11 +56,9 @@ lw6mat_fvec3_zero (lw6mat_fvec3_t * fvec3)
  * Return value: 1 if equal, 0 if different.
  */
 int
-lw6mat_fvec3_is_same (const lw6mat_fvec3_t * fvec3_a,
-		      const lw6mat_fvec3_t * fvec3_b)
+lw6mat_fvec3_is_same (const lw6mat_fvec3_t * fvec3_a, const lw6mat_fvec3_t * fvec3_b)
 {
-  return (!memcmp
-	  ((void *) fvec3_a, (void *) fvec3_b, sizeof (lw6mat_fvec3_t)));
+  return (!memcmp ((void *) fvec3_a, (void *) fvec3_b, sizeof (lw6mat_fvec3_t)));
 }
 
 /**
@@ -78,8 +76,7 @@ lw6mat_fvec3_is_same (const lw6mat_fvec3_t * fvec3_a,
 float
 lw6mat_fvec3_len_sq (const lw6mat_fvec3_t * fvec3)
 {
-  return fvec3->p.x * fvec3->p.x + fvec3->p.y * fvec3->p.y +
-    fvec3->p.z * fvec3->p.z;
+  return fvec3->p.x * fvec3->p.x + fvec3->p.y * fvec3->p.y + fvec3->p.z * fvec3->p.z;
 }
 
 /**
@@ -99,8 +96,9 @@ lw6mat_fvec3_len (const lw6mat_fvec3_t * fvec3)
 }
 
 /**
- * Normalizes a vector
+ * lw6mat_fvec3_normalize
  *
+ * @sys_context: global system context
  * @fvec3: the vector to normalize.
  *
  * Normalizes a vector, that is, make its length be 1.
@@ -108,7 +106,7 @@ lw6mat_fvec3_len (const lw6mat_fvec3_t * fvec3)
  * Return value: 1 if OK, 0 if error, such as trying to normalize vector zero.
  */
 int
-lw6mat_fvec3_norm (lw6mat_fvec3_t * fvec3)
+lw6mat_fvec3_normalize (lw6sys_context_t * sys_context, lw6mat_fvec3_t * fvec3)
 {
   float len = lw6mat_fvec3_len (fvec3);
 
@@ -122,7 +120,41 @@ lw6mat_fvec3_norm (lw6mat_fvec3_t * fvec3)
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_INFO, _x_ ("trying to normalize vector zero"));
+      lw6sys_log (sys_context, LW6SYS_LOG_INFO, _x_ ("trying to normalize vector zero"));
+
+      return 0;
+    }
+}
+
+/**
+ * lw6mat_fvec3_homogeneous
+ *
+ * Homogeneouss a vector
+ *
+ * @sys_context: global system context
+ * @fvec3: the vector to homogeneous.
+ *
+ * Transforms a vector into homegeneous coords, that is, scales it so
+ * that its last member is 1.
+ *
+ * Return value: 1 if OK, 0 if error, such as trying to operate on vector zero.
+ */
+int
+lw6mat_fvec3_homogeneous (lw6sys_context_t * sys_context, lw6mat_fvec3_t * fvec3)
+{
+  float f = fvec3->v[2];
+
+  if (f != 0.0f)
+    {
+      fvec3->p.x /= f;
+      fvec3->p.y /= f;
+      fvec3->v[2] = LW6MAT_F_1;
+
+      return 1;
+    }
+  else
+    {
+      lw6sys_log (sys_context, LW6SYS_LOG_INFO, _x_ ("trying to make homogeneous a vector with zero last member"));
 
       return 0;
     }
@@ -157,8 +189,7 @@ lw6mat_fvec3_neg (lw6mat_fvec3_t * fvec3)
  * Return value: none
  */
 void
-lw6mat_fvec3_add (lw6mat_fvec3_t * fvec3, const lw6mat_fvec3_t * fvec3_a,
-		  const lw6mat_fvec3_t * fvec3_b)
+lw6mat_fvec3_add (lw6mat_fvec3_t * fvec3, const lw6mat_fvec3_t * fvec3_a, const lw6mat_fvec3_t * fvec3_b)
 {
   fvec3->p.x = fvec3_a->p.x + fvec3_b->p.x;
   fvec3->p.y = fvec3_a->p.y + fvec3_b->p.y;
@@ -177,8 +208,7 @@ lw6mat_fvec3_add (lw6mat_fvec3_t * fvec3, const lw6mat_fvec3_t * fvec3_a,
  * Return value: none
  */
 void
-lw6mat_fvec3_sub (lw6mat_fvec3_t * fvec3, const lw6mat_fvec3_t * fvec3_a,
-		  const lw6mat_fvec3_t * fvec3_b)
+lw6mat_fvec3_sub (lw6mat_fvec3_t * fvec3, const lw6mat_fvec3_t * fvec3_a, const lw6mat_fvec3_t * fvec3_b)
 {
   fvec3->p.x = fvec3_a->p.x - fvec3_b->p.x;
   fvec3->p.y = fvec3_a->p.y - fvec3_b->p.y;
@@ -196,11 +226,9 @@ lw6mat_fvec3_sub (lw6mat_fvec3_t * fvec3, const lw6mat_fvec3_t * fvec3_a,
  * Return value: none
  */
 float
-lw6mat_fvec3_dot (const lw6mat_fvec3_t * fvec3_a,
-		  const lw6mat_fvec3_t * fvec3_b)
+lw6mat_fvec3_dot (const lw6mat_fvec3_t * fvec3_a, const lw6mat_fvec3_t * fvec3_b)
 {
-  return fvec3_a->p.x * fvec3_b->p.x + fvec3_a->p.y * fvec3_b->p.y +
-    fvec3_a->p.z * fvec3_b->p.z;
+  return fvec3_a->p.x * fvec3_b->p.x + fvec3_a->p.y * fvec3_b->p.y + fvec3_a->p.z * fvec3_b->p.z;
 }
 
 /**
@@ -215,8 +243,7 @@ lw6mat_fvec3_dot (const lw6mat_fvec3_t * fvec3_a,
  * Return value: none
  */
 void
-lw6mat_fvec3_cross (lw6mat_fvec3_t * fvec3, const lw6mat_fvec3_t * fvec3_a,
-		    const lw6mat_fvec3_t * fvec3_b)
+lw6mat_fvec3_cross (lw6mat_fvec3_t * fvec3, const lw6mat_fvec3_t * fvec3_a, const lw6mat_fvec3_t * fvec3_b)
 {
   fvec3->p.x = fvec3_a->p.y * fvec3_b->p.z - fvec3_a->p.z * fvec3_b->p.y;
   fvec3->p.y = fvec3_a->p.z * fvec3_b->p.x - fvec3_a->p.x * fvec3_b->p.z;
@@ -224,7 +251,7 @@ lw6mat_fvec3_cross (lw6mat_fvec3_t * fvec3, const lw6mat_fvec3_t * fvec3_a,
 }
 
 /**
- * lw6mat_fvec3_scale
+ * lw6mat_fvec3_mul_scale
  *
  * @fvec3: vector to modify
  * @f: scale factor
@@ -234,7 +261,7 @@ lw6mat_fvec3_cross (lw6mat_fvec3_t * fvec3, const lw6mat_fvec3_t * fvec3_a,
  * Return value: none
  */
 void
-lw6mat_fvec3_scale (lw6mat_fvec3_t * fvec3, float f)
+lw6mat_fvec3_mul_scale (lw6mat_fvec3_t * fvec3, float f)
 {
   fvec3->p.x *= f;
   fvec3->p.y *= f;
@@ -253,9 +280,7 @@ lw6mat_fvec3_scale (lw6mat_fvec3_t * fvec3, float f)
  * Return value: none
  */
 void
-lw6mat_fvec3_mul_fvec3 (lw6mat_fmat3_t * fmat3,
-			const lw6mat_fvec3_t * fvec3_a,
-			const lw6mat_fvec3_t * fvec3_b)
+lw6mat_fvec3_mul_fvec3 (lw6mat_fmat3_t * fmat3, const lw6mat_fvec3_t * fvec3_a, const lw6mat_fvec3_t * fvec3_b)
 {
   int i, j;
 
@@ -271,6 +296,7 @@ lw6mat_fvec3_mul_fvec3 (lw6mat_fmat3_t * fmat3,
 /**
  * lw6mat_fvec3_repr
  *
+ * @sys_context: global system context
  * @fvec: vector to represent
  *
  * Gives a readable version of the vector
@@ -278,14 +304,11 @@ lw6mat_fvec3_mul_fvec3 (lw6mat_fmat3_t * fmat3,
  * Return value: newly allocated string
  */
 char *
-lw6mat_fvec3_repr (const lw6mat_fvec3_t * fvec3)
+lw6mat_fvec3_repr (lw6sys_context_t * sys_context, const lw6mat_fvec3_t * fvec3)
 {
   char *repr = NULL;
 
-  repr =
-    lw6sys_new_sprintf ("%s %s %d [ %f %f %f ]", LW6MAT_REPR_F,
-			LW6MAT_REPR_VEC, LW6MAT_VEC3_V_SIZE, fvec3->v[0],
-			fvec3->v[1], fvec3->v[2]);
+  repr = lw6sys_new_sprintf (sys_context, "%s %s %d [ %f %f %f ]", LW6MAT_REPR_F, LW6MAT_REPR_VEC, LW6MAT_VEC3_V_SIZE, fvec3->v[0], fvec3->v[1], fvec3->v[2]);
 
   return repr;
 }
