@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -29,6 +29,7 @@
 /**
  * lw6msg_envelope_generate
  *
+ * @sys_context: global system context
  * @mode: mode to use (a la TELNET or URL compatible)
  * @version: the program version to use (note: can be changed when testing)
  * @password_checksum: the password string to send
@@ -46,13 +47,11 @@
  * Return value: newly allocated string.
  */
 char *
-lw6msg_envelope_generate (lw6msg_envelope_mode_t mode, const char *version,
+lw6msg_envelope_generate (lw6sys_context_t * sys_context, lw6msg_envelope_mode_t mode, const char *version,
 			  const char *password_checksum,
 			  u_int32_t physical_ticket_sig,
 			  u_int32_t logical_ticket_sig,
-			  u_int64_t physical_from_id,
-			  u_int64_t physical_to_id, u_int64_t logical_from_id,
-			  u_int64_t logical_to_id, const char *msg)
+			  u_int64_t physical_from_id, u_int64_t physical_to_id, u_int64_t logical_from_id, u_int64_t logical_to_id, const char *msg)
 {
   char *ret = NULL;
   char sep = '\0';
@@ -79,7 +78,7 @@ lw6msg_envelope_generate (lw6msg_envelope_mode_t mode, const char *version,
       need_base64 = 1;
       break;
     default:
-      lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("unknown mode %d"), (int) mode);
+      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("unknown mode %d"), (int) mode);
       sep = LW6MSG_TELNET_SEP;
       lw6 = LW6MSG_LW6;
       need_base64 = 0;
@@ -88,15 +87,14 @@ lw6msg_envelope_generate (lw6msg_envelope_mode_t mode, const char *version,
   body = msg;
   if (need_base64)
     {
-      base64_str = lw6glb_base64_encode_str (msg);
+      base64_str = lw6glb_base64_encode_str (sys_context, msg);
       if (base64_str)
 	{
 	  body = base64_str;
 	}
       else
 	{
-	  lw6sys_log (LW6SYS_LOG_WARNING,
-		      _x_ ("unable to base64 encode, sending as is"));
+	  lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("unable to base64 encode, sending as is"));
 	}
     }
 
@@ -106,8 +104,7 @@ lw6msg_envelope_generate (lw6msg_envelope_mode_t mode, const char *version,
     }
   else
     {
-      physical_ticket_sig_str =
-	lw6sys_new_sprintf ("%08x", physical_ticket_sig);
+      physical_ticket_sig_str = lw6sys_new_sprintf (sys_context, "%08x", physical_ticket_sig);
     }
 
   if (logical_ticket_sig == 0 || logical_ticket_sig == physical_ticket_sig)
@@ -116,8 +113,7 @@ lw6msg_envelope_generate (lw6msg_envelope_mode_t mode, const char *version,
     }
   else
     {
-      logical_ticket_sig_str =
-	lw6sys_new_sprintf ("%08x", logical_ticket_sig);
+      logical_ticket_sig_str = lw6sys_new_sprintf (sys_context, "%08x", logical_ticket_sig);
     }
 
   if (physical_from_id == logical_from_id)
@@ -126,7 +122,7 @@ lw6msg_envelope_generate (lw6msg_envelope_mode_t mode, const char *version,
     }
   else
     {
-      logical_from_id_str = lw6sys_id_ltoa (logical_from_id);
+      logical_from_id_str = lw6sys_id_ltoa (sys_context, logical_from_id);
     }
 
   if (physical_to_id == logical_to_id)
@@ -135,46 +131,43 @@ lw6msg_envelope_generate (lw6msg_envelope_mode_t mode, const char *version,
     }
   else
     {
-      logical_to_id_str = lw6sys_id_ltoa (logical_to_id);
+      logical_to_id_str = lw6sys_id_ltoa (sys_context, logical_to_id);
     }
 
   if (logical_from_id_str && logical_to_id_str)
     {
       ret =
-	lw6sys_new_sprintf ("%s%c%s%c%s%c%s%c%s%c%" LW6SYS_PRINTF_LL "x%c%"
+	lw6sys_new_sprintf (sys_context, "%s%c%s%c%s%c%s%c%s%c%" LW6SYS_PRINTF_LL "x%c%"
 			    LW6SYS_PRINTF_LL "x%c%s%c%s%c%s", lw6, sep,
 			    version, sep, password_checksum, sep,
 			    physical_ticket_sig_str, sep,
 			    logical_ticket_sig_str, sep,
-			    (long long) physical_from_id, sep,
-			    (long long) physical_to_id, sep,
-			    logical_from_id_str, sep, logical_to_id_str, sep,
-			    body);
+			    (long long) physical_from_id, sep, (long long) physical_to_id, sep, logical_from_id_str, sep, logical_to_id_str, sep, body);
     }
 
   if (base64_str)
     {
-      LW6SYS_FREE (base64_str);
+      LW6SYS_FREE (sys_context, base64_str);
     }
 
   if (physical_ticket_sig_str && physical_ticket_sig_str != msg_undef)
     {
-      LW6SYS_FREE (physical_ticket_sig_str);
+      LW6SYS_FREE (sys_context, physical_ticket_sig_str);
     }
 
   if (logical_ticket_sig_str && logical_ticket_sig_str != msg_undef)
     {
-      LW6SYS_FREE (logical_ticket_sig_str);
+      LW6SYS_FREE (sys_context, logical_ticket_sig_str);
     }
 
   if (logical_from_id_str && logical_from_id_str != msg_undef)
     {
-      LW6SYS_FREE (logical_from_id_str);
+      LW6SYS_FREE (sys_context, logical_from_id_str);
     }
 
   if (logical_to_id_str && logical_to_id_str != msg_undef)
     {
-      LW6SYS_FREE (logical_to_id_str);
+      LW6SYS_FREE (sys_context, logical_to_id_str);
     }
 
   return ret;
@@ -183,6 +176,7 @@ lw6msg_envelope_generate (lw6msg_envelope_mode_t mode, const char *version,
 /**
  * lw6msg_envelope_analyse
  *
+ * @sys_context: global system context
  * @envelope: the envelope to analyse
  * @mode: mode to use (a la TELNET or URL compatible)
  * @local_url: the url of local server (usefull for password)
@@ -204,16 +198,14 @@ lw6msg_envelope_generate (lw6msg_envelope_mode_t mode, const char *version,
  * Return value: newly allocated string.
  */
 int
-lw6msg_envelope_analyse (const char *envelope, lw6msg_envelope_mode_t mode,
+lw6msg_envelope_analyse (lw6sys_context_t * sys_context, const char *envelope, lw6msg_envelope_mode_t mode,
 			 const char *local_url, const char *password,
 			 u_int64_t expected_physical_from_id,
 			 u_int64_t expected_physical_to_id, char **msg,
 			 u_int32_t * physical_ticket_sig,
 			 u_int32_t * logical_ticket_sig,
 			 u_int64_t * physical_from_id,
-			 u_int64_t * physical_to_id,
-			 u_int64_t * logical_from_id,
-			 u_int64_t * logical_to_id, char **physical_from_url)
+			 u_int64_t * physical_to_id, u_int64_t * logical_from_id, u_int64_t * logical_to_id, char **physical_from_url)
 {
   int ret = 0;
   char *lw6 = NULL;
@@ -243,7 +235,7 @@ lw6msg_envelope_analyse (const char *envelope, lw6msg_envelope_mode_t mode,
       need_base64 = 1;
       break;
     default:
-      lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("unknown mode %d"), (int) mode);
+      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("unknown mode %d"), (int) mode);
       lw6 = LW6MSG_LW6;
       need_base64 = 0;
     }
@@ -285,99 +277,72 @@ lw6msg_envelope_analyse (const char *envelope, lw6msg_envelope_mode_t mode,
 
   pos = envelope;
   seek = (char *) pos;
-  if (lw6msg_word_first_x (&received_lw6, &seek, pos))
+  if (lw6msg_word_first_x (sys_context, &received_lw6, &seek, pos))
     {
-      if (lw6sys_str_is_same (received_lw6.buf, lw6))
+      if (lw6sys_str_is_same (sys_context, received_lw6.buf, lw6))
 	{
 	  pos = seek;
-	  if (lw6msg_word_first_x (&received_version, &seek, pos))
+	  if (lw6msg_word_first_x (sys_context, &received_version, &seek, pos))
 	    {
-	      if (lw6sys_version_is_compatible
-		  (received_version.buf, version))
+	      if (lw6sys_version_is_compatible (sys_context, received_version.buf, version))
 		{
 		  pos = seek;
-		  if (lw6msg_word_first_x (&received_password, &seek, pos))
+		  if (lw6msg_word_first_x (sys_context, &received_password, &seek, pos))
 		    {
-		      if (lw6cnx_password_verify
-			  (local_url, password, received_password.buf))
+		      if (lw6cnx_password_verify (sys_context, local_url, password, received_password.buf))
 			{
 			  pos = seek;
-			  if (lw6msg_word_first_x (&tmp_word, &seek, pos))
+			  if (lw6msg_word_first_x (sys_context, &tmp_word, &seek, pos))
 			    {
 			      pos = seek;
 			      /*
 			       * Bad and/or 0 ticket accepted at this stage
 			       */
-			      sscanf
-				(tmp_word.buf, "%x",
-				 &received_physical_ticket_sig_int);
-			      if (lw6msg_word_first_x (&tmp_word, &seek, pos))
+			      sscanf (tmp_word.buf, "%x", &received_physical_ticket_sig_int);
+			      if (lw6msg_word_first_x (sys_context, &tmp_word, &seek, pos))
 				{
 				  pos = seek;
 				  /*
 				   * Bad and/or 0 ticket accepted at this stage
 				   */
-				  sscanf
-				    (tmp_word.buf, "%x",
-				     &received_logical_ticket_sig_int);
+				  sscanf (tmp_word.buf, "%x", &received_logical_ticket_sig_int);
 				  if (!received_logical_ticket_sig_int)
 				    {
-				      received_logical_ticket_sig_int =
-					received_physical_ticket_sig_int;
+				      received_logical_ticket_sig_int = received_physical_ticket_sig_int;
 				    }
-				  if (lw6msg_word_first_id_64
-				      (&received_physical_from_id, &seek,
-				       pos))
+				  if (lw6msg_word_first_id_64 (sys_context, &received_physical_from_id, &seek, pos))
 				    {
-				      if (expected_physical_from_id == 0LL
-					  ||
-					  (expected_physical_from_id ==
-					   received_physical_from_id))
+				      if (expected_physical_from_id == 0LL || (expected_physical_from_id == received_physical_from_id))
 					{
 					  pos = seek;
-					  if (lw6msg_word_first_id_64
-					      (&received_physical_to_id,
-					       &seek, pos))
+					  if (lw6msg_word_first_id_64 (sys_context, &received_physical_to_id, &seek, pos))
 					    {
-					      if (expected_physical_from_id ==
-						  0LL
-						  ||
-						  (expected_physical_to_id
-						   ==
-						   received_physical_to_id))
+					      if (expected_physical_from_id == 0LL || (expected_physical_to_id == received_physical_to_id))
 						{
 						  pos = seek;
 						  if (lw6msg_word_first_id_64
-						      (&received_logical_from_id,
-						       &seek, pos)
-						      ||
-						      lw6msg_word_first_x
-						      (&tmp_word, &seek, pos))
+						      (sys_context, &received_logical_from_id, &seek, pos)
+						      || lw6msg_word_first_x (sys_context, &tmp_word, &seek, pos))
 						    {
 						      pos = seek;
 						      if (!received_logical_from_id)
 							{
-							  received_logical_from_id
-							    =
-							    received_physical_from_id;
+							  received_logical_from_id = received_physical_from_id;
 							}
-						      if (lw6msg_word_first_id_64 (&received_logical_to_id, &seek, pos) || lw6msg_word_first_x (&tmp_word, &seek, pos))
+						      if (lw6msg_word_first_id_64 (sys_context, &received_logical_to_id, &seek, pos)
+							  || lw6msg_word_first_x (sys_context, &tmp_word, &seek, pos))
 							{
 							  pos = seek;
 							  if (!received_logical_to_id)
 							    {
-							      received_logical_to_id
-								=
-								received_physical_to_id;
+							      received_logical_to_id = received_physical_to_id;
 							    }
 							  ret = 1;
 							  if (msg)
 							    {
 							      if (need_base64)
 								{
-								  (*msg) =
-								    lw6glb_base64_decode_str
-								    (pos);
+								  (*msg) = lw6glb_base64_decode_str (sys_context, pos);
 								  if (!(*msg))
 								    {
 								      /*
@@ -387,20 +352,13 @@ lw6msg_envelope_analyse (const char *envelope, lw6msg_envelope_mode_t mode,
 								       * it anyway in case this function would
 								       *  be called just to check the protocol
 								       */
-								      lw6sys_log
-									(LW6SYS_LOG_DEBUG,
-									 _x_
-									 ("forcing clear text instead of base64"));
-								      (*msg) =
-									lw6sys_str_copy
-									(pos);
+								      lw6sys_log (sys_context, LW6SYS_LOG_DEBUG, _x_ ("forcing clear text instead of base64"));
+								      (*msg) = lw6sys_str_copy (sys_context, pos);
 								    }
 								}
 							      else
 								{
-								  (*msg) =
-								    lw6sys_str_copy
-								    (pos);
+								  (*msg) = lw6sys_str_copy (sys_context, pos);
 								}
 							    }
 							  if (physical_ticket_sig)
@@ -425,142 +383,104 @@ lw6msg_envelope_analyse (const char *envelope, lw6msg_envelope_mode_t mode,
 							    }
 							  if (logical_to_id)
 							    {
-							      (*logical_to_id)
-								=
-								received_logical_to_id;
+							      (*logical_to_id) = received_logical_to_id;
 							    }
 							  if (physical_from_url && msg && (*msg))
 							    {
-							      (*physical_from_url) = lw6msg_cmd_guess_from_url (*msg);
+							      (*physical_from_url) = lw6msg_cmd_guess_from_url (sys_context, *msg);
 							    }
 							}
 						      else
 							{
 							  lw6sys_log
-							    (LW6SYS_LOG_INFO,
-							     _x_
-							     ("can't parse \"logical_to\" (final destination) id in envelope \"%s\""),
-							     envelope);
+							    (sys_context, LW6SYS_LOG_INFO,
+							     _x_ ("can't parse \"logical_to\" (final destination) id in envelope \"%s\""), envelope);
 							}
 						    }
 						  else
 						    {
 						      lw6sys_log
-							(LW6SYS_LOG_INFO,
-							 _x_
-							 ("can't parse \"logical_from\" (creator) id in envelope \"%s\""),
+							(sys_context, LW6SYS_LOG_INFO, _x_ ("can't parse \"logical_from\" (creator) id in envelope \"%s\""),
 							 envelope);
 						    }
 						}
 					      else
 						{
 						  lw6sys_log
-						    (LW6SYS_LOG_INFO,
+						    (sys_context, LW6SYS_LOG_INFO,
 						     _x_
 						     ("wrong \"physical_to\" (receiver) id expected %"
 						      LW6SYS_PRINTF_LL
 						      "x received %"
 						      LW6SYS_PRINTF_LL
 						      "x in envelope \"%s\""),
-						     (long long)
-						     expected_physical_to_id,
-						     (long long)
-						     received_physical_to_id,
-						     envelope);
+						     (long long) expected_physical_to_id, (long long) received_physical_to_id, envelope);
 						}
 					    }
 					  else
 					    {
-					      lw6sys_log (LW6SYS_LOG_INFO,
-							  _x_
-							  ("can't parse \"physical_to\" (receiver) id in envelope \"%s\""),
-							  envelope);
+					      lw6sys_log (sys_context,
+							  LW6SYS_LOG_INFO, _x_ ("can't parse \"physical_to\" (receiver) id in envelope \"%s\""), envelope);
 					    }
 					}
 				      else
 					{
-					  lw6sys_log (LW6SYS_LOG_INFO,
+					  lw6sys_log (sys_context,
+						      LW6SYS_LOG_INFO,
 						      _x_
 						      ("wrong \"physical_from\" (sender) id expected %"
 						       LW6SYS_PRINTF_LL
 						       "x received %"
 						       LW6SYS_PRINTF_LL
 						       "x in envelope \"%s\""),
-						      (long long)
-						      expected_physical_from_id,
-						      (long long)
-						      received_physical_from_id,
-						      envelope);
+						      (long long) expected_physical_from_id, (long long) received_physical_from_id, envelope);
 					}
 				    }
 				  else
 				    {
-				      lw6sys_log (LW6SYS_LOG_INFO,
-						  _x_
-						  ("can't parse \"physical_from\" (sender) id in envelope \"%s\""),
-						  envelope);
+				      lw6sys_log (sys_context,
+						  LW6SYS_LOG_INFO, _x_ ("can't parse \"physical_from\" (sender) id in envelope \"%s\""), envelope);
 				    }
 				}
 			      else
 				{
-				  lw6sys_log (LW6SYS_LOG_INFO,
-					      _x_
-					      ("can't parse logical ticket sig in envelope \"%s\""),
-					      envelope);
+				  lw6sys_log (sys_context, LW6SYS_LOG_INFO, _x_ ("can't parse logical ticket sig in envelope \"%s\""), envelope);
 				}
 			    }
 			  else
 			    {
-			      lw6sys_log (LW6SYS_LOG_INFO,
-					  _x_
-					  ("can't parse physical ticket sig in envelope \"%s\""),
-					  envelope);
+			      lw6sys_log (sys_context, LW6SYS_LOG_INFO, _x_ ("can't parse physical ticket sig in envelope \"%s\""), envelope);
 			    }
 			}
 		      else
 			{
-			  lw6sys_log (LW6SYS_LOG_INFO,
-				      _x_ ("bad password in envelope \"%s\""),
-				      envelope);
+			  lw6sys_log (sys_context, LW6SYS_LOG_INFO, _x_ ("bad password in envelope \"%s\""), envelope);
 			}
 		    }
 		  else
 		    {
-		      lw6sys_log (LW6SYS_LOG_INFO,
-				  _x_
-				  ("can't parse password in envelope \"%s\""),
-				  envelope);
+		      lw6sys_log (sys_context, LW6SYS_LOG_INFO, _x_ ("can't parse password in envelope \"%s\""), envelope);
 		    }
 		}
 	      else
 		{
-		  lw6sys_log (LW6SYS_LOG_INFO,
-			      _x_
-			      ("bad version, received \"%s\", need \"%s\" in envelope \"%s\""),
-			      received_version.buf, version, envelope);
+		  lw6sys_log (sys_context, LW6SYS_LOG_INFO,
+			      _x_ ("bad version, received \"%s\", need \"%s\" in envelope \"%s\""), received_version.buf, version, envelope);
 		}
 	    }
 	  else
 	    {
-	      lw6sys_log (LW6SYS_LOG_INFO,
-			  _x_ ("can't parse version in envelope \"%s\""),
-			  envelope);
+	      lw6sys_log (sys_context, LW6SYS_LOG_INFO, _x_ ("can't parse version in envelope \"%s\""), envelope);
 	    }
 	}
       else
 	{
-	  lw6sys_log (LW6SYS_LOG_INFO,
-		      _x_
-		      ("bad lw6 key, received \"%s\", need \"%s\" in envelope \"%s\""),
-		      received_lw6.buf, lw6, envelope);
+	  lw6sys_log (sys_context, LW6SYS_LOG_INFO, _x_ ("bad lw6 key, received \"%s\", need \"%s\" in envelope \"%s\""), received_lw6.buf, lw6, envelope);
 	}
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_INFO,
-		  _x_
-		  ("message does not start with \"%s\" in envelope \"%s\""),
-		  lw6, envelope);
+      lw6sys_log (sys_context, LW6SYS_LOG_INFO, _x_ ("message does not start with \"%s\" in envelope \"%s\""), lw6, envelope);
     }
 
   return ret;
