@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -29,6 +29,7 @@
 /**
  * lw6msg_meta_array_zero
  *
+ * @sys_context: global system context
  * @meta_array: meta meta_array (list of nodes) to modify
  *
  * Fills the meta meta_array with zeroes, emptying all nodes.
@@ -36,7 +37,7 @@
  * Return value: none
  */
 void
-lw6msg_meta_array_zero (lw6msg_meta_array_t * meta_array)
+lw6msg_meta_array_zero (lw6sys_context_t * sys_context, lw6msg_meta_array_t * meta_array)
 {
   memset ((void *) meta_array, 0, sizeof (lw6msg_meta_array_t));
 }
@@ -44,6 +45,7 @@ lw6msg_meta_array_zero (lw6msg_meta_array_t * meta_array)
 /**
  * lw6msg_meta_array_find
  *
+ * @sys_context: global system context
  * @meta_array: meta meta_array (list of nodes) to modify
  * @node_id: the ID (64-bit) of the node to seartch
  *
@@ -52,8 +54,7 @@ lw6msg_meta_array_zero (lw6msg_meta_array_t * meta_array)
  * Return value: 1 if registered, 0 if not (possible error: no place left)
  */
 int
-lw6msg_meta_array_find (const lw6msg_meta_array_t * meta_array,
-			u_int64_t node_id)
+lw6msg_meta_array_find (lw6sys_context_t * sys_context, const lw6msg_meta_array_t * meta_array, u_int64_t node_id)
 {
   int ret = -1;
   int i = 0;
@@ -72,6 +73,7 @@ lw6msg_meta_array_find (const lw6msg_meta_array_t * meta_array,
 /**
  * lw6msg_meta_array_exists
  *
+ * @sys_context: global system context
  * @meta_array: meta meta_array (list of nodes) to modify
  * @node_id: the ID (64-bit) of the node to test
  *
@@ -80,15 +82,15 @@ lw6msg_meta_array_find (const lw6msg_meta_array_t * meta_array,
  * Return value: 1 if registered, 0 if not (possible error: no place left)
  */
 int
-lw6msg_meta_array_exists (const lw6msg_meta_array_t * meta_array,
-			  u_int64_t node_id)
+lw6msg_meta_array_exists (lw6sys_context_t * sys_context, const lw6msg_meta_array_t * meta_array, u_int64_t node_id)
 {
-  return (lw6msg_meta_array_find (meta_array, node_id) >= 0) ? 1 : 0;
+  return (lw6msg_meta_array_find (sys_context, meta_array, node_id) >= 0) ? 1 : 0;
 }
 
 /**
  * lw6msg_meta_array_set
  *
+ * @sys_context: global system context
  * @meta_array: meta meta_array (list of nodes) to modify
  * @node_id: the ID (64-bit) of the node to add
  * @serial_0: base serialfor the node to add
@@ -99,8 +101,7 @@ lw6msg_meta_array_exists (const lw6msg_meta_array_t * meta_array,
  * Return value: 1 if registered, 0 if not (possible error: no place left)
  */
 int
-lw6msg_meta_array_set (lw6msg_meta_array_t * meta_array, u_int64_t node_id,
-		       int serial_0, int64_t seq_0)
+lw6msg_meta_array_set (lw6sys_context_t * sys_context, lw6msg_meta_array_t * meta_array, u_int64_t node_id, int serial_0, int64_t seq_0)
 {
   int ret = 0;
   int i = -1;
@@ -108,7 +109,7 @@ lw6msg_meta_array_set (lw6msg_meta_array_t * meta_array, u_int64_t node_id,
   /*
    * Searching wether node is already registered
    */
-  i = lw6msg_meta_array_find (meta_array, node_id);
+  i = lw6msg_meta_array_find (sys_context, meta_array, node_id);
   if (i >= 0)
     {
       meta_array->items[i].serial_0 = serial_0;
@@ -120,7 +121,7 @@ lw6msg_meta_array_set (lw6msg_meta_array_t * meta_array, u_int64_t node_id,
       /*
        * Searching for a free slot
        */
-      i = lw6msg_meta_array_find (meta_array, 0LL);
+      i = lw6msg_meta_array_find (sys_context, meta_array, 0LL);
       if (i >= 0)
 	{
 	  meta_array->items[i].node_id = node_id;
@@ -136,6 +137,7 @@ lw6msg_meta_array_set (lw6msg_meta_array_t * meta_array, u_int64_t node_id,
 /**
  * lw6msg_meta_array_unset
  *
+ * @sys_context: global system context
  * @meta_array: meta meta_array (list of nodes) to modify
  * @node_id: the ID (64-bit) of the node to remove
  *
@@ -144,7 +146,7 @@ lw6msg_meta_array_set (lw6msg_meta_array_t * meta_array, u_int64_t node_id,
  * Return value: 1 if node existed, 0 if it was not here
  */
 int
-lw6msg_meta_array_unset (lw6msg_meta_array_t * meta_array, u_int64_t node_id)
+lw6msg_meta_array_unset (lw6sys_context_t * sys_context, lw6msg_meta_array_t * meta_array, u_int64_t node_id)
 {
   int ret = 0;
   int i = -1;
@@ -152,7 +154,7 @@ lw6msg_meta_array_unset (lw6msg_meta_array_t * meta_array, u_int64_t node_id)
   /*
    * Searching wether node is already registered
    */
-  i = lw6msg_meta_array_find (meta_array, node_id);
+  i = lw6msg_meta_array_find (sys_context, meta_array, node_id);
   if (i >= 0)
     {
       memset (&(meta_array->items[i]), 0, sizeof (lw6msg_meta_array_item_t));
@@ -165,6 +167,7 @@ lw6msg_meta_array_unset (lw6msg_meta_array_t * meta_array, u_int64_t node_id)
 /**
  * lw6msg_meta_str2array
  *
+ * @sys_context: global system context
  * @meta_array: meta meta_array (list of nodes) to get (out param)
  * @str: meta string (list of nodes) to be put in the meta_array
  *
@@ -174,7 +177,7 @@ lw6msg_meta_array_unset (lw6msg_meta_array_t * meta_array, u_int64_t node_id)
  * Return value: 1 if parseable and success, 0 if not.
  */
 int
-lw6msg_meta_str2array (lw6msg_meta_array_t * meta_array, const char *str)
+lw6msg_meta_str2array (lw6sys_context_t * sys_context, lw6msg_meta_array_t * meta_array, const char *str)
 {
   int ret = 0;
   const char *pos = NULL;
@@ -187,17 +190,16 @@ lw6msg_meta_str2array (lw6msg_meta_array_t * meta_array, const char *str)
   pos = str;
   while (still_ok)
     {
-      if (lw6msg_word_first_id_64 (&node_id, &seek, pos))
+      if (lw6msg_word_first_id_64 (sys_context, &node_id, &seek, pos))
 	{
 	  pos = seek;
-	  if (lw6msg_word_first_int_32_ge0 (&serial_0, &seek, pos))
+	  if (lw6msg_word_first_int_32_ge0 (sys_context, &serial_0, &seek, pos))
 	    {
 	      pos = seek;
-	      if (lw6msg_word_first_int_64_gt0 (&seq_0, &seek, pos))
+	      if (lw6msg_word_first_int_64_gt0 (sys_context, &seq_0, &seek, pos))
 		{
 		  pos = seek;
-		  if (lw6msg_meta_array_set
-		      (meta_array, node_id, serial_0, seq_0))
+		  if (lw6msg_meta_array_set (sys_context, meta_array, node_id, serial_0, seq_0))
 		    {
 		      ret = 1;
 		    }
@@ -235,6 +237,7 @@ lw6msg_meta_str2array (lw6msg_meta_array_t * meta_array, const char *str)
 /**
  * lw6msg_meta_array2str
  *
+ * @sys_context: global system context
  * @meta_array: meta meta_array (list of nodes) to transform as a string
  *
  * Transforms a C struct describing the nodes and their id/serial/seq
@@ -243,7 +246,7 @@ lw6msg_meta_str2array (lw6msg_meta_array_t * meta_array, const char *str)
  * Return value: dynamically allocated string
  */
 char *
-lw6msg_meta_array2str (const lw6msg_meta_array_t * meta_array)
+lw6msg_meta_array2str (lw6sys_context_t * sys_context, const lw6msg_meta_array_t * meta_array)
 {
   char *str = NULL;
   char *tmp = NULL;
@@ -256,25 +259,21 @@ lw6msg_meta_array2str (const lw6msg_meta_array_t * meta_array)
 	  if (str)
 	    {
 	      tmp =
-		lw6sys_new_sprintf ("%s %" LW6SYS_PRINTF_LL "x %d %"
+		lw6sys_new_sprintf (sys_context, "%s %" LW6SYS_PRINTF_LL "x %d %"
 				    LW6SYS_PRINTF_LL "d", str,
-				    (long long) meta_array->items[i].node_id,
-				    meta_array->items[i].serial_0,
-				    (long long) meta_array->items[i].seq_0);
+				    (long long) meta_array->items[i].node_id, meta_array->items[i].serial_0, (long long) meta_array->items[i].seq_0);
 	      if (tmp)
 		{
-		  LW6SYS_FREE (str);
+		  LW6SYS_FREE (sys_context, str);
 		  str = tmp;
 		}
 	    }
 	  else
 	    {
 	      str =
-		lw6sys_new_sprintf ("%" LW6SYS_PRINTF_LL "x %d %"
+		lw6sys_new_sprintf (sys_context, "%" LW6SYS_PRINTF_LL "x %d %"
 				    LW6SYS_PRINTF_LL "d",
-				    (long long) meta_array->items[i].node_id,
-				    meta_array->items[i].serial_0,
-				    (long long) meta_array->items[i].seq_0);
+				    (long long) meta_array->items[i].node_id, meta_array->items[i].serial_0, (long long) meta_array->items[i].seq_0);
 	    }
 	}
     }
