@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -30,6 +30,7 @@
 /**
  * lw6msg_oob_generate_info
  *
+ * @sys_context: global system context
  * @info: the node to generate info about
  *
  * Generates a standard response to the INFO question for OOB
@@ -40,7 +41,7 @@
  * Return value: newly allocated string.
  */
 char *
-lw6msg_oob_generate_info (lw6nod_info_t * info)
+lw6msg_oob_generate_info (lw6sys_context_t * sys_context, lw6nod_info_t * info)
 {
   char *ret = NULL;
   lw6nod_dyn_info_t *dyn_info = NULL;
@@ -48,67 +49,32 @@ lw6msg_oob_generate_info (lw6nod_info_t * info)
   char *open_relay = NULL;
   char *has_password = NULL;
 
-  dyn_info = lw6nod_info_dup_dyn (info);
+  dyn_info = lw6nod_info_dup_dyn (sys_context, info);
   if (dyn_info)
     {
       has_password = info->const_info.has_password ? LW6MSG_YES : LW6MSG_NO;
       open_relay = info->const_info.open_relay ? LW6MSG_YES : LW6MSG_NO;
-      uptime =
-	(lw6sys_get_timestamp () -
-	 info->const_info.creation_timestamp) / 1000;
+      uptime = (lw6sys_get_timestamp (sys_context) - info->const_info.creation_timestamp) / 1000;
       ret =
 	lw6sys_new_sprintf
-	("%s %s\n%s %s\n%s %s\n%s %s\n%s %s\n%s %s\n%s %s\n%s %s\n%s %s\n%s %d\n%s %s\n%s %d\n%s %s\n%s %d\n%s %s\n%s %d\n%s %d\n%s %d\n%s %d\n%s %d\n%s %d\n%s %d\n\n",
-	 LW6MSG_OOB_PROGRAM,
-	 lw6sys_build_get_package_tarname (),
-	 LW6MSG_OOB_VERSION,
-	 lw6sys_build_get_version (),
-	 LW6MSG_OOB_CODENAME,
-	 lw6sys_build_get_codename (),
-	 LW6MSG_OOB_STAMP,
-	 lw6sys_build_get_stamp (),
-	 LW6MSG_OOB_ID,
-	 info->const_info.ref_info.id_str,
-	 LW6MSG_OOB_URL,
-	 info->const_info.ref_info.url,
-	 LW6MSG_OOB_TITLE,
-	 info->const_info.title,
-	 LW6MSG_OOB_DESCRIPTION,
-	 info->const_info.description,
-	 LW6MSG_OOB_HAS_PASSWORD,
-	 has_password,
-	 LW6MSG_OOB_BENCH,
-	 info->const_info.bench,
-	 LW6MSG_OOB_OPEN_RELAY,
-	 open_relay,
-	 LW6MSG_OOB_UPTIME,
-	 uptime,
-	 LW6MSG_OOB_COMMUNITY,
-	 lw6sys_str_empty_if_null (dyn_info->community_id_str),
-	 LW6MSG_OOB_ROUND,
-	 dyn_info->round,
-	 LW6MSG_OOB_LEVEL,
-	 lw6sys_str_empty_if_null (dyn_info->level),
-	 LW6MSG_OOB_REQUIRED_BENCH,
-	 dyn_info->required_bench,
-	 LW6MSG_OOB_NB_COLORS,
-	 dyn_info->nb_colors,
-	 LW6MSG_OOB_MAX_NB_COLORS,
-	 dyn_info->max_nb_colors,
-	 LW6MSG_OOB_NB_CURSORS,
-	 dyn_info->nb_cursors,
-	 LW6MSG_OOB_MAX_NB_CURSORS,
-	 dyn_info->max_nb_cursors,
-	 LW6MSG_OOB_NB_NODES,
-	 dyn_info->nb_nodes, LW6MSG_OOB_MAX_NB_NODES, dyn_info->max_nb_nodes);
-      lw6nod_dyn_info_free (dyn_info);
+	(sys_context,
+	 "%s %s\n%s %s\n%s %s\n%s %s\n%s %s\n%s %s\n%s %s\n%s %s\n%s %s\n%s %d\n%s %s\n%s %d\n%s %s\n%s %d\n%s %s\n%s %d\n%s %d\n%s %d\n%s %d\n%s %d\n%s %d\n%s %d\n\n",
+	 LW6MSG_OOB_PROGRAM, lw6sys_build_get_package_tarname (), LW6MSG_OOB_VERSION, lw6sys_build_get_version (), LW6MSG_OOB_CODENAME,
+	 lw6sys_build_get_codename (), LW6MSG_OOB_STAMP, lw6sys_build_get_stamp (), LW6MSG_OOB_ID, info->const_info.ref_info.id_str, LW6MSG_OOB_URL,
+	 info->const_info.ref_info.url, LW6MSG_OOB_TITLE, info->const_info.title, LW6MSG_OOB_DESCRIPTION, info->const_info.description,
+	 LW6MSG_OOB_HAS_PASSWORD, has_password, LW6MSG_OOB_BENCH, info->const_info.bench, LW6MSG_OOB_OPEN_RELAY, open_relay, LW6MSG_OOB_UPTIME, uptime,
+	 LW6MSG_OOB_COMMUNITY, lw6sys_str_empty_if_null (sys_context, dyn_info->community_id_str), LW6MSG_OOB_ROUND, dyn_info->round, LW6MSG_OOB_LEVEL,
+	 lw6sys_str_empty_if_null (sys_context, dyn_info->level), LW6MSG_OOB_REQUIRED_BENCH, dyn_info->required_bench, LW6MSG_OOB_NB_COLORS,
+	 dyn_info->nb_colors, LW6MSG_OOB_MAX_NB_COLORS, dyn_info->max_nb_colors, LW6MSG_OOB_NB_CURSORS, dyn_info->nb_cursors, LW6MSG_OOB_MAX_NB_CURSORS,
+	 dyn_info->max_nb_cursors, LW6MSG_OOB_NB_NODES, dyn_info->nb_nodes, LW6MSG_OOB_MAX_NB_NODES, dyn_info->max_nb_nodes);
+      lw6nod_dyn_info_free (sys_context, dyn_info);
     }
 
   return ret;
 }
 
 static void
-_add_node_txt (void *func_data, void *data)
+_add_node_txt (lw6sys_context_t * sys_context, void *func_data, void *data)
 {
   char **list = (char **) func_data;
   lw6nod_info_t *verified_node = (lw6nod_info_t *) data;
@@ -119,26 +85,21 @@ _add_node_txt (void *func_data, void *data)
    * on the list object? This is because we can only
    * access it through the map function because of locking issues
    */
-  if (list && (*list) && verified_node
-      && verified_node->const_info.ref_info.url)
+  if (list && (*list) && verified_node && verified_node->const_info.ref_info.url)
     {
-      if (strlen (*list) + strlen (verified_node->const_info.ref_info.url) <=
-	  LW6NET_PPPOE_MTU - 1)
+      if (strlen (*list) + strlen (verified_node->const_info.ref_info.url) <= LW6NET_PPPOE_MTU - 1)
 	{
-	  tmp =
-	    lw6sys_new_sprintf ("%s%s\n", *list,
-				verified_node->const_info.ref_info.url);
+	  tmp = lw6sys_new_sprintf (sys_context, "%s%s\n", *list, verified_node->const_info.ref_info.url);
 	  if (tmp)
 	    {
-	      LW6SYS_FREE (*list);
+	      LW6SYS_FREE (sys_context, *list);
 	      (*list) = tmp;
 	    }
 	}
       else
 	{
-	  lw6sys_log (LW6SYS_LOG_DEBUG,
-		      _x_
-		      ("truncating list, very long lists do not make any sense anyway, and it could cause problems on UDP"));
+	  lw6sys_log (sys_context, LW6SYS_LOG_DEBUG,
+		      _x_ ("truncating list, very long lists do not make any sense anyway, and it could cause problems on UDP"));
 	}
     }
 }
@@ -146,6 +107,7 @@ _add_node_txt (void *func_data, void *data)
 /**
  * lw6msg_oob_generate_list
  *
+ * @sys_context: global system context
  * @info: the node to generate info about
  *
  * Generates a standard response to the LIST question for OOB
@@ -158,30 +120,30 @@ _add_node_txt (void *func_data, void *data)
  * Return value: newly allocated string.
  */
 char *
-lw6msg_oob_generate_list (lw6nod_info_t * info)
+lw6msg_oob_generate_list (lw6sys_context_t * sys_context, lw6nod_info_t * info)
 {
   char *ret = NULL;
   lw6nod_dyn_info_t *dyn_info = NULL;
   char *tmp;
 
-  dyn_info = lw6nod_info_dup_dyn (info);
+  dyn_info = lw6nod_info_dup_dyn (sys_context, info);
   if (dyn_info)
     {
-      ret = lw6sys_str_copy (LW6SYS_STR_EMPTY);
+      ret = lw6sys_str_copy (sys_context, LW6SYS_STR_EMPTY);
       if (ret)
 	{
-	  lw6nod_info_map_verified_nodes (info, _add_node_txt, &ret);
+	  lw6nod_info_map_verified_nodes (sys_context, info, _add_node_txt, &ret);
 	  if (ret)
 	    {
-	      tmp = lw6sys_str_concat (ret, "\n");
+	      tmp = lw6sys_str_concat (sys_context, ret, "\n");
 	      if (tmp)
 		{
-		  LW6SYS_FREE (ret);
+		  LW6SYS_FREE (sys_context, ret);
 		  ret = tmp;
 		}
 	    }
 	}
-      lw6nod_dyn_info_free (dyn_info);
+      lw6nod_dyn_info_free (sys_context, dyn_info);
     }
 
   return ret;
@@ -190,6 +152,7 @@ lw6msg_oob_generate_list (lw6nod_info_t * info)
 /**
  * lw6msg_oob_generate_pong
  *
+ * @sys_context: global system context
  * @info: the node to generate info about
  *
  * Generates a standard response to the PING question for OOB
@@ -200,11 +163,11 @@ lw6msg_oob_generate_list (lw6nod_info_t * info)
  * Return value: newly allocated string.
  */
 char *
-lw6msg_oob_generate_pong (lw6nod_info_t * info)
+lw6msg_oob_generate_pong (lw6sys_context_t * sys_context, lw6nod_info_t * info)
 {
   char *ret = NULL;
 
-  ret = lw6sys_new_sprintf ("PONG %s\n\n", info->const_info.ref_info.url);
+  ret = lw6sys_new_sprintf (sys_context, "PONG %s\n\n", info->const_info.ref_info.url);
 
   return ret;
 }
@@ -212,6 +175,7 @@ lw6msg_oob_generate_pong (lw6nod_info_t * info)
 /**
  * lw6msg_oob_generate_request
  *
+ * @sys_context: global system context
  * @command: the command to send (PING, INFO, LIST)
  * @remote_url: the remote URL (used to seed password)
  * @password: the password, can be NULL or ""
@@ -222,40 +186,36 @@ lw6msg_oob_generate_pong (lw6nod_info_t * info)
  * Return value: a newly allocated string
  */
 char *
-lw6msg_oob_generate_request (const char *command, const char *remote_url,
-			     const char *password, const char *local_url)
+lw6msg_oob_generate_request (lw6sys_context_t * sys_context, const char *command, const char *remote_url, const char *password, const char *local_url)
 {
   char *ret = NULL;
   char *password_checksum = NULL;
 
-  if (remote_url && strlen (remote_url) > 0 && password
-      && strlen (password) > 0)
+  if (remote_url && strlen (remote_url) > 0 && password && strlen (password) > 0)
     {
-      password_checksum = lw6cnx_password_checksum (remote_url, password);
+      password_checksum = lw6cnx_password_checksum (sys_context, remote_url, password);
     }
   if (password_checksum)
     {
       if (local_url && strlen (local_url) > 0)
 	{
-	  ret =
-	    lw6sys_new_sprintf ("%s %s %s", command, password_checksum,
-				local_url);
+	  ret = lw6sys_new_sprintf (sys_context, "%s %s %s", command, password_checksum, local_url);
 	}
       else
 	{
-	  ret = lw6sys_new_sprintf ("%s %s", command, password_checksum);
+	  ret = lw6sys_new_sprintf (sys_context, "%s %s", command, password_checksum);
 	}
-      LW6SYS_FREE (password_checksum);
+      LW6SYS_FREE (sys_context, password_checksum);
     }
   else
     {
       if (local_url && strlen (local_url) > 0)
 	{
-	  ret = lw6sys_new_sprintf ("%s %s", command, local_url);
+	  ret = lw6sys_new_sprintf (sys_context, "%s %s", command, local_url);
 	}
       else
 	{
-	  ret = lw6sys_new_sprintf ("%s", command);
+	  ret = lw6sys_new_sprintf (sys_context, "%s", command);
 	}
     }
 
@@ -265,6 +225,7 @@ lw6msg_oob_generate_request (const char *command, const char *remote_url,
 /**
  * lw6msg_oob_analyse_request
  *
+ * @sys_context: global system context
  * @syntax_ok: will contain 1 if syntax is OK, 0 if not
  * @command: the command (out param, needs *not* to be freed)
  * @password_ok: will contain 1 if password is OK, 0 if not
@@ -278,9 +239,8 @@ lw6msg_oob_generate_request (const char *command, const char *remote_url,
  * Return value: 1 if OK, 0 if not. If 0, check the value of password_ok.
  */
 int
-lw6msg_oob_analyse_request (int *syntax_ok, char **command, int *password_ok,
-			    char **remote_url, const char *request,
-			    const char *local_url, const char *password)
+lw6msg_oob_analyse_request (lw6sys_context_t * sys_context, int *syntax_ok, char **command, int *password_ok,
+			    char **remote_url, const char *request, const char *local_url, const char *password)
 {
   int ret = 0;
   char *copy = NULL;
@@ -297,7 +257,7 @@ lw6msg_oob_analyse_request (int *syntax_ok, char **command, int *password_ok,
   (*password_ok) = 0;
   (*remote_url) = NULL;
 
-  copy = lw6sys_str_copy (request);
+  copy = lw6sys_str_copy (sys_context, request);
   if (copy)
     {
       seek = copy;
@@ -307,18 +267,18 @@ lw6msg_oob_analyse_request (int *syntax_ok, char **command, int *password_ok,
 	}
       pos = seek;
 
-      if (lw6sys_str_starts_with_no_case (pos, LW6MSG_OOB_PING))
+      if (lw6sys_str_starts_with_no_case (sys_context, pos, LW6MSG_OOB_PING))
 	{
 	  (*command) = LW6MSG_OOB_PING;
 	  (*password_ok) = 1;
 	  seek += strlen (LW6MSG_OOB_PING);
 	}
-      else if (lw6sys_str_starts_with_no_case (pos, LW6MSG_OOB_INFO))
+      else if (lw6sys_str_starts_with_no_case (sys_context, pos, LW6MSG_OOB_INFO))
 	{
 	  (*command) = LW6MSG_OOB_INFO;
 	  seek += strlen (LW6MSG_OOB_INFO);
 	}
-      else if (lw6sys_str_starts_with_no_case (pos, LW6MSG_OOB_LIST))
+      else if (lw6sys_str_starts_with_no_case (sys_context, pos, LW6MSG_OOB_LIST))
 	{
 	  (*command) = LW6MSG_OOB_LIST;
 	  seek += strlen (LW6MSG_OOB_LIST);
@@ -337,8 +297,7 @@ lw6msg_oob_analyse_request (int *syntax_ok, char **command, int *password_ok,
 	      if (seek != pos)
 		{
 		  pos = seek;
-		  while ((*seek) && !lw6sys_chr_is_space (*seek)
-			 && !lw6sys_chr_is_eol (*seek))
+		  while ((*seek) && !lw6sys_chr_is_space (*seek) && !lw6sys_chr_is_eol (*seek))
 		    {
 		      seek++;
 		    }
@@ -346,7 +305,7 @@ lw6msg_oob_analyse_request (int *syntax_ok, char **command, int *password_ok,
 		    {
 		      seek_c = (*seek);
 		      (*seek) = '\0';
-		      param1 = lw6sys_str_copy (pos);
+		      param1 = lw6sys_str_copy (sys_context, pos);
 		      (*seek) = seek_c;
 		      pos = seek;
 		      while (lw6sys_chr_is_space (*seek))
@@ -356,8 +315,7 @@ lw6msg_oob_analyse_request (int *syntax_ok, char **command, int *password_ok,
 		      if (seek != pos)
 			{
 			  pos = seek;
-			  while ((*seek) && !lw6sys_chr_is_space (*seek)
-				 && !lw6sys_chr_is_eol (*seek))
+			  while ((*seek) && !lw6sys_chr_is_space (*seek) && !lw6sys_chr_is_eol (*seek))
 			    {
 			      seek++;
 			    }
@@ -365,7 +323,7 @@ lw6msg_oob_analyse_request (int *syntax_ok, char **command, int *password_ok,
 			    {
 			      seek_c = (*seek);
 			      (*seek) = '\0';
-			      param2 = lw6sys_str_copy (pos);
+			      param2 = lw6sys_str_copy (sys_context, pos);
 			    }
 			}
 		    }
@@ -379,20 +337,14 @@ lw6msg_oob_analyse_request (int *syntax_ok, char **command, int *password_ok,
 		}
 	      if (param1)
 		{
-		  if (lw6sys_url_is_canonized (param1))
+		  if (lw6sys_url_is_canonized (sys_context, param1))
 		    {
-		      lw6sys_log (LW6SYS_LOG_DEBUG,
-				  _x_
-				  ("param1=\"%s\" is canonized URL, considering it an URL"),
-				  param1);
+		      lw6sys_log (sys_context, LW6SYS_LOG_DEBUG, _x_ ("param1=\"%s\" is canonized URL, considering it an URL"), param1);
 		      received_url = param1;
 		    }
 		  else
 		    {
-		      lw6sys_log (LW6SYS_LOG_DEBUG,
-				  _x_
-				  ("param1=\"%s\" is not a canonized URL, considering it a password"),
-				  param1);
+		      lw6sys_log (sys_context, LW6SYS_LOG_DEBUG, _x_ ("param1=\"%s\" is not a canonized URL, considering it a password"), param1);
 		      received_password = param1;
 		    }
 		  param1 = NULL;
@@ -402,8 +354,7 @@ lw6msg_oob_analyse_request (int *syntax_ok, char **command, int *password_ok,
 	       * We only check password now that we have chosen which
 	       * field is password, even if the value is NULL
 	       */
-	      if (lw6cnx_password_verify (local_url, password,
-					  received_password))
+	      if (lw6cnx_password_verify (sys_context, local_url, password, received_password))
 		{
 		  (*password_ok) = 1;
 		}
@@ -416,24 +367,24 @@ lw6msg_oob_analyse_request (int *syntax_ok, char **command, int *password_ok,
 		{
 		  if (received_url)
 		    {
-		      LW6SYS_FREE (received_url);
+		      LW6SYS_FREE (sys_context, received_url);
 		    }
 		}
 	      if (received_password)
 		{
-		  LW6SYS_FREE (received_password);
+		  LW6SYS_FREE (sys_context, received_password);
 		}
 	      if (!ret)
 		{
 		  if (*remote_url)
 		    {
-		      LW6SYS_FREE (*remote_url);
+		      LW6SYS_FREE (sys_context, *remote_url);
 		      (*remote_url) = NULL;
 		    }
 		}
 	    }
 	}
-      LW6SYS_FREE (copy);
+      LW6SYS_FREE (sys_context, copy);
     }
 
   return ret;
@@ -442,6 +393,7 @@ lw6msg_oob_analyse_request (int *syntax_ok, char **command, int *password_ok,
 /**
  * lw6msg_oob_analyse_pong
  *
+ * @sys_context: global system context
  * @text: the text of the message to parse
  *
  * Analyses a PONG message and gets the public_url from it, if
@@ -450,29 +402,29 @@ lw6msg_oob_analyse_request (int *syntax_ok, char **command, int *password_ok,
  * Return value: newly allocated string containing public_url if OK, NULL on error.
  */
 char *
-lw6msg_oob_analyse_pong (const char *text)
+lw6msg_oob_analyse_pong (lw6sys_context_t * sys_context, const char *text)
 {
   char *ret = NULL;
   char *copy = NULL;
   char *key = NULL;
   char *value = NULL;
 
-  copy = lw6sys_str_copy (text);
+  copy = lw6sys_str_copy (sys_context, text);
   if (copy)
     {
-      if (lw6msg_utils_parse_key_value_to_ptr (&key, &value, text))
+      if (lw6msg_utils_parse_key_value_to_ptr (sys_context, &key, &value, text))
 	{
-	  if (lw6sys_str_is_same (key, LW6MSG_OOB_PONG))
+	  if (lw6sys_str_is_same (sys_context, key, LW6MSG_OOB_PONG))
 	    {
 	      ret = value;
 	    }
 	  else
 	    {
-	      LW6SYS_FREE (value);
+	      LW6SYS_FREE (sys_context, value);
 	    }
-	  LW6SYS_FREE (key);
+	  LW6SYS_FREE (sys_context, key);
 	}
-      LW6SYS_FREE (copy);
+      LW6SYS_FREE (sys_context, copy);
     }
 
   return ret;
