@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -29,6 +29,7 @@
 /**
  * lw6msg_ticket_calc_sig
  *
+ * @sys_context: global system context
  * @ticket: the (private) ticket to use
  * @from_id: the sender/creator
  * @to_id: the receiver/target
@@ -43,8 +44,7 @@
  * Return value: the sig, always non-zero
  */
 u_int32_t
-lw6msg_ticket_calc_sig (u_int64_t ticket, u_int64_t from_id, u_int64_t to_id,
-			const char *msg)
+lw6msg_ticket_calc_sig (lw6sys_context_t * sys_context, u_int64_t ticket, u_int64_t from_id, u_int64_t to_id, const char *msg)
 {
   u_int32_t calc_sig = 0;
   unsigned char key_buf[3 * sizeof (u_int64_t)];
@@ -52,12 +52,10 @@ lw6msg_ticket_calc_sig (u_int64_t ticket, u_int64_t from_id, u_int64_t to_id,
   if (ticket)
     {
       memset (key_buf, 0, 3 * sizeof (u_int64_t));
-      lw6sys_serialize_int64 (key_buf, ticket);
-      lw6sys_serialize_int64 (key_buf + sizeof (u_int64_t), from_id);
-      lw6sys_serialize_int64 (key_buf + 2 * sizeof (u_int64_t), to_id);
-      calc_sig =
-	lw6glb_sha1_hmac_32_bin ((char *) key_buf,
-				 3 * sizeof (u_int64_t), msg, strlen (msg));
+      lw6sys_serialize_int64 (sys_context, key_buf, ticket);
+      lw6sys_serialize_int64 (sys_context, key_buf + sizeof (u_int64_t), from_id);
+      lw6sys_serialize_int64 (sys_context, key_buf + 2 * sizeof (u_int64_t), to_id);
+      calc_sig = lw6glb_sha1_hmac_32_bin (sys_context, (char *) key_buf, 3 * sizeof (u_int64_t), msg, strlen (msg));
       if (!calc_sig)
 	{
 	  /*
@@ -65,18 +63,16 @@ lw6msg_ticket_calc_sig (u_int64_t ticket, u_int64_t from_id, u_int64_t to_id,
 	   */
 	  calc_sig--;
 	}
-      lw6sys_log (LW6SYS_LOG_DEBUG,
+      lw6sys_log (sys_context, LW6SYS_LOG_DEBUG,
 		  _x_ ("calculating sig with ticket %" LW6SYS_PRINTF_LL
 		       "x from=%" LW6SYS_PRINTF_LL "x to=%" LW6SYS_PRINTF_LL
-		       "x message=\"%s\" calc_sig=%x"), (long long) ticket,
-		  (long long) from_id, (long long) to_id, msg, calc_sig);
+		       "x message=\"%s\" calc_sig=%x"), (long long) ticket, (long long) from_id, (long long) to_id, msg, calc_sig);
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_DEBUG,
+      lw6sys_log (sys_context, LW6SYS_LOG_DEBUG,
 		  _x_ ("using ticket=0 from=%" LW6SYS_PRINTF_LL "x to=%"
-		       LW6SYS_PRINTF_LL "x to calc sig for message \"%s\""),
-		  (long long) from_id, (long long) to_id, msg);
+		       LW6SYS_PRINTF_LL "x to calc sig for message \"%s\""), (long long) from_id, (long long) to_id, msg);
       calc_sig--;
     }
 
@@ -86,6 +82,7 @@ lw6msg_ticket_calc_sig (u_int64_t ticket, u_int64_t from_id, u_int64_t to_id,
 /**
  * lw6msg_ticket_check_sig
  *
+ * @sys_context: global system context
  * @ticket: the (private) ticket to use
  * @from_id: the sender/creator
  * @to_id: the receiver/target
@@ -97,22 +94,19 @@ lw6msg_ticket_calc_sig (u_int64_t ticket, u_int64_t from_id, u_int64_t to_id,
  * Return value: 1 if they are the same, 0 if not.
  */
 int
-lw6msg_ticket_check_sig (u_int64_t ticket, u_int64_t from_id, u_int64_t to_id,
-			 const char *msg, u_int32_t ticket_sig)
+lw6msg_ticket_check_sig (lw6sys_context_t * sys_context, u_int64_t ticket, u_int64_t from_id, u_int64_t to_id, const char *msg, u_int32_t ticket_sig)
 {
   int ret = 0;
   u_int32_t calc_sig = 0;
 
-  calc_sig = lw6msg_ticket_calc_sig (ticket, from_id, to_id, msg);
+  calc_sig = lw6msg_ticket_calc_sig (sys_context, ticket, from_id, to_id, msg);
   if (calc_sig == ticket_sig)
     {
       ret = 1;
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_DEBUG,
-		  _x_ ("sigs do not match calc_sig=%x ticket_sig=%x"),
-		  calc_sig, ticket_sig);
+      lw6sys_log (sys_context, LW6SYS_LOG_DEBUG, _x_ ("sigs do not match calc_sig=%x ticket_sig=%x"), calc_sig, ticket_sig);
     }
 
   return ret;
