@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -29,6 +29,7 @@
 /**
  * lw6msg_utils_parse_key_value_to_ptr
  *
+ * @sys_context: global system context
  * @key: will contain the key detected
  * @value: will contain the value detected
  * @line: the line to analyse
@@ -39,8 +40,7 @@
  * Return value: 1 if line OK (and in this case @key and @value are set), 0 if not.
  */
 int
-lw6msg_utils_parse_key_value_to_ptr (char **key, char **value,
-				     const char *line)
+lw6msg_utils_parse_key_value_to_ptr (lw6sys_context_t * sys_context, char **key, char **value, const char *line)
 {
   int ret = 0;
   char *seek = NULL;
@@ -52,7 +52,7 @@ lw6msg_utils_parse_key_value_to_ptr (char **key, char **value,
   (*key) = NULL;
   (*value) = NULL;
 
-  copy = lw6sys_str_copy (line);
+  copy = lw6sys_str_copy (sys_context, line);
   if (copy)
     {
       seek = pos = copy;
@@ -61,18 +61,16 @@ lw6msg_utils_parse_key_value_to_ptr (char **key, char **value,
 	  seek++;
 	}
       pos = seek;
-      while (lw6sys_chr_is_alnum (*seek) || ((*seek) == '_')
-	     || ((*seek) == '-'))
+      while (lw6sys_chr_is_alnum (*seek) || ((*seek) == '_') || ((*seek) == '-'))
 	{
 	  seek++;
 	}
       seek_c = *seek;
       (*seek) = '\0';
-      (*key) = lw6sys_str_copy (pos);
+      (*key) = lw6sys_str_copy (sys_context, pos);
       (*seek) = seek_c;
       pos = seek;
-      while (lw6sys_chr_is_space (*seek) || ((*seek) == ':')
-	     || ((*seek) == '='))
+      while (lw6sys_chr_is_space (*seek) || ((*seek) == ':') || ((*seek) == '='))
 	{
 	  found_space = 1;
 	  seek++;
@@ -84,7 +82,7 @@ lw6msg_utils_parse_key_value_to_ptr (char **key, char **value,
 	}
       seek_c = *seek;
       (*seek) = '\0';
-      (*value) = lw6sys_str_copy (pos);
+      (*value) = lw6sys_str_copy (sys_context, pos);
 
       if (*key && *value && strlen (*key) > 0)
 	{
@@ -98,17 +96,17 @@ lw6msg_utils_parse_key_value_to_ptr (char **key, char **value,
 	{
 	  if (*key)
 	    {
-	      LW6SYS_FREE (*key);
+	      LW6SYS_FREE (sys_context, *key);
 	      (*key) = NULL;
 	    }
 	  if (*value)
 	    {
-	      LW6SYS_FREE (*value);
+	      LW6SYS_FREE (sys_context, *value);
 	      (*value) = NULL;
 	    }
 	}
 
-      LW6SYS_FREE (copy);
+      LW6SYS_FREE (sys_context, copy);
     }
 
   return ret;
@@ -117,6 +115,7 @@ lw6msg_utils_parse_key_value_to_ptr (char **key, char **value,
 /**
  * lw6msg_utils_parse_key_value_to_assoc
  *
+ * @sys_context: global system context
  * @assoc: an assoc object which will contain the result
  * @line: the line to analyse
  *
@@ -127,25 +126,23 @@ lw6msg_utils_parse_key_value_to_ptr (char **key, char **value,
  * Return value: 1 if line OK (and in this case @assoc is updated), 0 if not.
  */
 int
-lw6msg_utils_parse_key_value_to_assoc (lw6sys_assoc_t ** assoc,
-				       const char *line)
+lw6msg_utils_parse_key_value_to_assoc (lw6sys_context_t * sys_context, lw6sys_assoc_t ** assoc, const char *line)
 {
   int ret = 0;
   char *key = NULL;
   char *value = NULL;
 
-  ret = lw6msg_utils_parse_key_value_to_ptr (&key, &value, line);
+  ret = lw6msg_utils_parse_key_value_to_ptr (sys_context, &key, &value, line);
   if (ret)
     {
       if (key && value)
 	{
-	  lw6sys_assoc_set (assoc, key, value);
+	  lw6sys_assoc_set (sys_context, assoc, key, value);
 	  if ((*assoc) == NULL)
 	    {
-	      lw6sys_log (LW6SYS_LOG_WARNING,
-			  _x_ ("assoc_set failed, assoc is now NULL"));
+	      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("assoc_set failed, assoc is now NULL"));
 	    }
-	  LW6SYS_FREE (key);
+	  LW6SYS_FREE (sys_context, key);
 	}
     }
 
@@ -155,6 +152,7 @@ lw6msg_utils_parse_key_value_to_assoc (lw6sys_assoc_t ** assoc,
 /**
  * lw6msg_utils_get_assoc_str_with_default
  *
+ * @sys_context: global system context
  * @assoc: the string assoc to query
  * @key: the key to find in the assoc
  * @default_value: the default value to return
@@ -167,13 +165,11 @@ lw6msg_utils_parse_key_value_to_assoc (lw6sys_assoc_t ** assoc,
  * Return value: a string, must not be freed.
  */
 char *
-lw6msg_utils_get_assoc_str_with_default (lw6sys_assoc_t * assoc,
-					 const char *key,
-					 const char *default_value)
+lw6msg_utils_get_assoc_str_with_default (lw6sys_context_t * sys_context, lw6sys_assoc_t * assoc, const char *key, const char *default_value)
 {
   char *ret = NULL;
 
-  ret = lw6sys_assoc_get (assoc, key);
+  ret = lw6sys_assoc_get (sys_context, assoc, key);
   if (!ret)
     {
       ret = (char *) default_value;
@@ -185,6 +181,7 @@ lw6msg_utils_get_assoc_str_with_default (lw6sys_assoc_t * assoc,
 /**
  * lw6msg_utils_get_assoc_int_with_default
  *
+ * @sys_context: global system context
  * @assoc: the string assoc to query
  * @key: the key to find in the assoc
  * @default_value: the default value to return
@@ -197,16 +194,15 @@ lw6msg_utils_get_assoc_str_with_default (lw6sys_assoc_t * assoc,
  * Return value: a string, must not be freed.
  */
 int
-lw6msg_utils_get_assoc_int_with_default (lw6sys_assoc_t * assoc,
-					 const char *key, int default_value)
+lw6msg_utils_get_assoc_int_with_default (lw6sys_context_t * sys_context, lw6sys_assoc_t * assoc, const char *key, int default_value)
 {
   int ret = 0;
   char *tmp = NULL;
 
-  tmp = lw6sys_assoc_get (assoc, key);
+  tmp = lw6sys_assoc_get (sys_context, assoc, key);
   if (tmp)
     {
-      ret = lw6sys_atoi (tmp);
+      ret = lw6sys_atoi (sys_context, tmp);
     }
   else
     {
