@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -31,6 +31,7 @@
 /**
  * lw6msg_word_first
  *
+ * @sys_context: global system context
  * @word: will contain the parsed word
  * @next: if NOT NULL, will contain a (non freeable) pointer on remaining message
  * @msg: the message to parse
@@ -42,7 +43,7 @@
  * Return value: 1 on success, 0 on failure.
  */
 int
-lw6msg_word_first (lw6msg_word_t * word, char **next, const char *msg)
+lw6msg_word_first (lw6sys_context_t * sys_context, lw6msg_word_t * word, char **next, const char *msg)
 {
   int ret = 0;
   int i = 0, j = 0;
@@ -68,8 +69,7 @@ lw6msg_word_first (lw6msg_word_t * word, char **next, const char *msg)
       /*
        * Note: (len=(j-i)<=...) must really be the first test else len is false
        */
-      while ((len = (j - i)) <= LW6MSG_MAX_WORD_SIZE && msg[j]
-	     && msg[j] != _QUOTE && !lw6sys_chr_is_eol (msg[j]))
+      while ((len = (j - i)) <= LW6MSG_MAX_WORD_SIZE && msg[j] && msg[j] != _QUOTE && !lw6sys_chr_is_eol (msg[j]))
 	{
 	  j++;
 	}
@@ -79,8 +79,7 @@ lw6msg_word_first (lw6msg_word_t * word, char **next, const char *msg)
       /*
        * Note: (len=(j-i)<=...) must really be the first test else len is false
        */
-      while ((len = (j - i)) <= LW6MSG_MAX_WORD_SIZE && msg[j]
-	     && !lw6sys_chr_is_space (msg[j]) && !lw6sys_chr_is_eol (msg[j]))
+      while ((len = (j - i)) <= LW6MSG_MAX_WORD_SIZE && msg[j] && !lw6sys_chr_is_space (msg[j]) && !lw6sys_chr_is_eol (msg[j]))
 	{
 	  j++;
 	}
@@ -109,7 +108,7 @@ lw6msg_word_first (lw6msg_word_t * word, char **next, const char *msg)
 	}
       else
 	{
-	  lw6sys_log (LW6SYS_LOG_DEBUG, _x_ ("word too long"));
+	  lw6sys_log (sys_context, LW6SYS_LOG_DEBUG, _x_ ("word too long"));
 	}
     }
 
@@ -119,6 +118,7 @@ lw6msg_word_first (lw6msg_word_t * word, char **next, const char *msg)
 /**
  * lw6msg_word_first_x
  *
+ * @sys_context: global system context
  * @word: will contain the parsed word
  * @next: if NOT NULL, will contain a (non freeable) pointer on remaining message
  * @msg: the message to parse
@@ -133,7 +133,7 @@ lw6msg_word_first (lw6msg_word_t * word, char **next, const char *msg)
  * Return value: 1 on success, 0 on failure.
  */
 int
-lw6msg_word_first_x (lw6msg_word_t * word, char **next, const char *msg)
+lw6msg_word_first_x (lw6sys_context_t * sys_context, lw6msg_word_t * word, char **next, const char *msg)
 {
   int ret = 0;
   int i = 0, j = 0;
@@ -159,8 +159,7 @@ lw6msg_word_first_x (lw6msg_word_t * word, char **next, const char *msg)
       /*
        * Note: (len=(j-i)<=...) must really be the first test else len is false
        */
-      while ((len = (j - i)) <= LW6MSG_MAX_WORD_SIZE && msg[j]
-	     && msg[j] != _QUOTE && !lw6sys_chr_is_eol (msg[j]))
+      while ((len = (j - i)) <= LW6MSG_MAX_WORD_SIZE && msg[j] && msg[j] != _QUOTE && !lw6sys_chr_is_eol (msg[j]))
 	{
 	  j++;
 	}
@@ -170,9 +169,7 @@ lw6msg_word_first_x (lw6msg_word_t * word, char **next, const char *msg)
       /*
        * Note: (len=(j-i)<=...) must really be the first test else len is false
        */
-      while ((len = (j - i)) <= LW6MSG_MAX_WORD_SIZE && msg[j]
-	     && !lw6sys_chr_is_space (msg[j]) && msg[j] != LW6MSG_URL_SEP
-	     && !lw6sys_chr_is_eol (msg[j]))
+      while ((len = (j - i)) <= LW6MSG_MAX_WORD_SIZE && msg[j] && !lw6sys_chr_is_space (msg[j]) && msg[j] != LW6MSG_URL_SEP && !lw6sys_chr_is_eol (msg[j]))
 	{
 	  j++;
 	}
@@ -201,7 +198,7 @@ lw6msg_word_first_x (lw6msg_word_t * word, char **next, const char *msg)
 	}
       else
 	{
-	  lw6sys_log (LW6SYS_LOG_DEBUG, _x_ ("word too long"));
+	  lw6sys_log (sys_context, LW6SYS_LOG_DEBUG, _x_ ("word too long"));
 	}
     }
 
@@ -211,6 +208,7 @@ lw6msg_word_first_x (lw6msg_word_t * word, char **next, const char *msg)
 /**
  * lw6msg_word_first_base64
  *
+ * @sys_context: global system context
  * @word: will contain the parsed word
  * @next: if NOT NULL, will contain a (non freeable) pointer on remaining message
  * @msg: the message to parse
@@ -223,7 +221,7 @@ lw6msg_word_first_x (lw6msg_word_t * word, char **next, const char *msg)
  * Return value: 1 on success, 0 on failure.
  */
 int
-lw6msg_word_first_base64 (lw6msg_word_t * word, char **next, const char *msg)
+lw6msg_word_first_base64 (lw6sys_context_t * sys_context, lw6msg_word_t * word, char **next, const char *msg)
 {
   int ret = 0;
   lw6msg_word_t tmp_word;
@@ -231,11 +229,11 @@ lw6msg_word_first_base64 (lw6msg_word_t * word, char **next, const char *msg)
   char *decoded = NULL;
   int decoded_len = 0;
 
-  ret = lw6msg_word_first_x (&tmp_word, &tmp_next, msg);
+  ret = lw6msg_word_first_x (sys_context, &tmp_word, &tmp_next, msg);
   if (ret)
     {
       ret = 0;
-      decoded = lw6glb_base64_decode_bin (&decoded_len, tmp_word.buf);
+      decoded = lw6glb_base64_decode_bin (sys_context, &decoded_len, tmp_word.buf);
       if (decoded)
 	{
 	  if (decoded_len <= LW6MSG_MAX_WORD_SIZE)
@@ -249,7 +247,7 @@ lw6msg_word_first_base64 (lw6msg_word_t * word, char **next, const char *msg)
 		}
 	      ret = 1;
 	    }
-	  LW6SYS_FREE (decoded);
+	  LW6SYS_FREE (sys_context, decoded);
 	}
     }
 
@@ -259,6 +257,7 @@ lw6msg_word_first_base64 (lw6msg_word_t * word, char **next, const char *msg)
 /**
  * lw6msg_word_first_int_32
  *
+ * @sys_context: global system context
  * @parsed_value: will contain the parsed value
  * @next: if NOT NULL, will contain a (non freeable) pointer on remaining message
  * @msg: the message to parse
@@ -268,8 +267,7 @@ lw6msg_word_first_base64 (lw6msg_word_t * word, char **next, const char *msg)
  * Return value: 1 on success, 0 on failure.
  */
 int
-lw6msg_word_first_int_32 (int32_t * parsed_value, char **next,
-			  const char *msg)
+lw6msg_word_first_int_32 (lw6sys_context_t * sys_context, int32_t * parsed_value, char **next, const char *msg)
 {
   int ret = 0;
   lw6msg_word_t word;
@@ -278,11 +276,11 @@ lw6msg_word_first_int_32 (int32_t * parsed_value, char **next,
     {
       (*parsed_value) = 0;
     }
-  if (lw6msg_word_first_x (&word, next, msg))
+  if (lw6msg_word_first_x (sys_context, &word, next, msg))
     {
       if (parsed_value)
 	{
-	  (*parsed_value) = lw6sys_atoi (word.buf);
+	  (*parsed_value) = lw6sys_atoi (sys_context, word.buf);
 	}
       ret = 1;
     }
@@ -293,6 +291,7 @@ lw6msg_word_first_int_32 (int32_t * parsed_value, char **next,
 /**
  * lw6msg_word_first_int_32_ge0
  *
+ * @sys_context: global system context
  * @parsed_value: will contain the parsed value
  * @next: if NOT NULL, will contain a (non freeable) pointer on remaining message
  * @msg: the message to parse
@@ -303,8 +302,7 @@ lw6msg_word_first_int_32 (int32_t * parsed_value, char **next,
  * Return value: 1 on success, 0 on failure.
  */
 int
-lw6msg_word_first_int_32_ge0 (int32_t * parsed_value, char **next,
-			      const char *msg)
+lw6msg_word_first_int_32_ge0 (lw6sys_context_t * sys_context, int32_t * parsed_value, char **next, const char *msg)
 {
   int ret = 0;
   int32_t tmp_value = 0;
@@ -313,7 +311,7 @@ lw6msg_word_first_int_32_ge0 (int32_t * parsed_value, char **next,
     {
       (*parsed_value) = 0;
     }
-  if (lw6msg_word_first_int_32 (&tmp_value, next, msg))
+  if (lw6msg_word_first_int_32 (sys_context, &tmp_value, next, msg))
     {
       if (tmp_value >= 0)
 	{
@@ -325,9 +323,7 @@ lw6msg_word_first_int_32_ge0 (int32_t * parsed_value, char **next,
 	}
       else
 	{
-	  lw6sys_log (LW6SYS_LOG_DEBUG,
-		      _x_ ("bad int32 value %d, not greater or equal to 0"),
-		      tmp_value);
+	  lw6sys_log (sys_context, LW6SYS_LOG_DEBUG, _x_ ("bad int32 value %d, not greater or equal to 0"), tmp_value);
 	}
     }
 
@@ -337,6 +333,7 @@ lw6msg_word_first_int_32_ge0 (int32_t * parsed_value, char **next,
 /**
  * lw6msg_word_first_int_32_gt0
  *
+ * @sys_context: global system context
  * @parsed_value: will contain the parsed value
  * @next: if NOT NULL, will contain a (non freeable) pointer on remaining message
  * @msg: the message to parse
@@ -347,8 +344,7 @@ lw6msg_word_first_int_32_ge0 (int32_t * parsed_value, char **next,
  * Return value: 1 on success, 0 on failure.
  */
 int
-lw6msg_word_first_int_32_gt0 (int32_t * parsed_value, char **next,
-			      const char *msg)
+lw6msg_word_first_int_32_gt0 (lw6sys_context_t * sys_context, int32_t * parsed_value, char **next, const char *msg)
 {
   int ret = 0;
   int32_t tmp_value = 0;
@@ -357,7 +353,7 @@ lw6msg_word_first_int_32_gt0 (int32_t * parsed_value, char **next,
     {
       (*parsed_value) = 0;
     }
-  if (lw6msg_word_first_int_32 (&tmp_value, next, msg))
+  if (lw6msg_word_first_int_32 (sys_context, &tmp_value, next, msg))
     {
       if (tmp_value > 0)
 	{
@@ -369,9 +365,7 @@ lw6msg_word_first_int_32_gt0 (int32_t * parsed_value, char **next,
 	}
       else
 	{
-	  lw6sys_log (LW6SYS_LOG_DEBUG,
-		      _x_ ("bad int32 value %d, not strictly greater than 0"),
-		      tmp_value);
+	  lw6sys_log (sys_context, LW6SYS_LOG_DEBUG, _x_ ("bad int32 value %d, not strictly greater than 0"), tmp_value);
 	}
     }
 
@@ -381,6 +375,7 @@ lw6msg_word_first_int_32_gt0 (int32_t * parsed_value, char **next,
 /**
  * lw6msg_word_first_int_64
  *
+ * @sys_context: global system context
  * @parsed_value: will contain the parsed value
  * @next: if NOT NULL, will contain a (non freeable) pointer on remaining message
  * @msg: the message to parse
@@ -390,8 +385,7 @@ lw6msg_word_first_int_32_gt0 (int32_t * parsed_value, char **next,
  * Return value: 1 on success, 0 on failure.
  */
 int
-lw6msg_word_first_int_64 (int64_t * parsed_value, char **next,
-			  const char *msg)
+lw6msg_word_first_int_64 (lw6sys_context_t * sys_context, int64_t * parsed_value, char **next, const char *msg)
 {
   int ret = 0;
   lw6msg_word_t word;
@@ -400,11 +394,11 @@ lw6msg_word_first_int_64 (int64_t * parsed_value, char **next,
     {
       (*parsed_value) = 0LL;
     }
-  if (lw6msg_word_first_x (&word, next, msg))
+  if (lw6msg_word_first_x (sys_context, &word, next, msg))
     {
       if (parsed_value)
 	{
-	  (*parsed_value) = lw6sys_atoll (word.buf);
+	  (*parsed_value) = lw6sys_atoll (sys_context, word.buf);
 	}
       ret = 1;
     }
@@ -415,6 +409,7 @@ lw6msg_word_first_int_64 (int64_t * parsed_value, char **next,
 /**
  * lw6msg_word_first_int_64_ge0
  *
+ * @sys_context: global system context
  * @parsed_value: will contain the parsed value
  * @next: if NOT NULL, will contain a (non freeable) pointer on remaining message
  * @msg: the message to parse
@@ -425,8 +420,7 @@ lw6msg_word_first_int_64 (int64_t * parsed_value, char **next,
  * Return value: 1 on success, 0 on failure.
  */
 int
-lw6msg_word_first_int_64_ge0 (int64_t * parsed_value, char **next,
-			      const char *msg)
+lw6msg_word_first_int_64_ge0 (lw6sys_context_t * sys_context, int64_t * parsed_value, char **next, const char *msg)
 {
   int64_t ret = 0;
   int64_t tmp_value = 0;
@@ -435,7 +429,7 @@ lw6msg_word_first_int_64_ge0 (int64_t * parsed_value, char **next,
     {
       (*parsed_value) = 0LL;
     }
-  if (lw6msg_word_first_int_64 (&tmp_value, next, msg))
+  if (lw6msg_word_first_int_64 (sys_context, &tmp_value, next, msg))
     {
       if (tmp_value >= 0)
 	{
@@ -447,10 +441,7 @@ lw6msg_word_first_int_64_ge0 (int64_t * parsed_value, char **next,
 	}
       else
 	{
-	  lw6sys_log (LW6SYS_LOG_DEBUG,
-		      _x_ ("bad int64 value %" LW6SYS_PRINTF_LL
-			   "d, not greater or equal to 0"),
-		      (long long) tmp_value);
+	  lw6sys_log (sys_context, LW6SYS_LOG_DEBUG, _x_ ("bad int64 value %" LW6SYS_PRINTF_LL "d, not greater or equal to 0"), (long long) tmp_value);
 	}
     }
 
@@ -460,6 +451,7 @@ lw6msg_word_first_int_64_ge0 (int64_t * parsed_value, char **next,
 /**
  * lw6msg_word_first_int_64_gt0
  *
+ * @sys_context: global system context
  * @parsed_value: will contain the parsed value
  * @next: if NOT NULL, will contain a (non freeable) pointer on remaining message
  * @msg: the message to parse
@@ -470,8 +462,7 @@ lw6msg_word_first_int_64_ge0 (int64_t * parsed_value, char **next,
  * Return value: 1 on success, 0 on failure.
  */
 int
-lw6msg_word_first_int_64_gt0 (int64_t * parsed_value, char **next,
-			      const char *msg)
+lw6msg_word_first_int_64_gt0 (lw6sys_context_t * sys_context, int64_t * parsed_value, char **next, const char *msg)
 {
   int ret = 0;
   int64_t tmp_value = 0;
@@ -480,7 +471,7 @@ lw6msg_word_first_int_64_gt0 (int64_t * parsed_value, char **next,
     {
       (*parsed_value) = 0LL;
     }
-  if (lw6msg_word_first_int_64 (&tmp_value, next, msg))
+  if (lw6msg_word_first_int_64 (sys_context, &tmp_value, next, msg))
     {
       if (tmp_value > 0)
 	{
@@ -492,10 +483,7 @@ lw6msg_word_first_int_64_gt0 (int64_t * parsed_value, char **next,
 	}
       else
 	{
-	  lw6sys_log (LW6SYS_LOG_DEBUG,
-		      _x_ ("bad int64 value %" LW6SYS_PRINTF_LL
-			   "d, not strictly greater than 0"),
-		      (long long) tmp_value);
+	  lw6sys_log (sys_context, LW6SYS_LOG_DEBUG, _x_ ("bad int64 value %" LW6SYS_PRINTF_LL "d, not strictly greater than 0"), (long long) tmp_value);
 	}
     }
 
@@ -505,6 +493,7 @@ lw6msg_word_first_int_64_gt0 (int64_t * parsed_value, char **next,
 /**
  * lw6msg_word_first_id_16
  *
+ * @sys_context: global system context
  * @parsed_value: will contain the parsed value
  * @next: if NOT NULL, will contain a (non freeable) pointer on remaining message
  * @msg: the message to parse
@@ -514,8 +503,7 @@ lw6msg_word_first_int_64_gt0 (int64_t * parsed_value, char **next,
  * Return value: 1 on success, 0 on failure.
  */
 int
-lw6msg_word_first_id_16 (u_int16_t * parsed_value, char **next,
-			 const char *msg)
+lw6msg_word_first_id_16 (lw6sys_context_t * sys_context, u_int16_t * parsed_value, char **next, const char *msg)
 {
   int ret = 0;
   lw6msg_word_t word;
@@ -525,10 +513,10 @@ lw6msg_word_first_id_16 (u_int16_t * parsed_value, char **next,
     {
       (*parsed_value) = 0;
     }
-  if (lw6msg_word_first_x (&word, next, msg))
+  if (lw6msg_word_first_x (sys_context, &word, next, msg))
     {
-      tmp_value = lw6sys_id_atol (word.buf);
-      if (tmp_value && lw6sys_check_id_16 (tmp_value))
+      tmp_value = lw6sys_id_atol (sys_context, word.buf);
+      if (tmp_value && lw6sys_check_id_16 (sys_context, tmp_value))
 	{
 	  if (parsed_value)
 	    {
@@ -538,7 +526,7 @@ lw6msg_word_first_id_16 (u_int16_t * parsed_value, char **next,
 	}
       else
 	{
-	  lw6sys_log (LW6SYS_LOG_DEBUG, _x_ ("bad id 16 \"%s\""), word.buf);
+	  lw6sys_log (sys_context, LW6SYS_LOG_DEBUG, _x_ ("bad id 16 \"%s\""), word.buf);
 	}
     }
 
@@ -548,6 +536,7 @@ lw6msg_word_first_id_16 (u_int16_t * parsed_value, char **next,
 /**
  * lw6msg_word_first_id_32
  *
+ * @sys_context: global system context
  * @parsed_value: will contain the parsed value
  * @next: if NOT NULL, will contain a (non freeable) pointer on remaining message
  * @msg: the message to parse
@@ -557,8 +546,7 @@ lw6msg_word_first_id_16 (u_int16_t * parsed_value, char **next,
  * Return value: 1 on success, 0 on failure.
  */
 int
-lw6msg_word_first_id_32 (u_int32_t * parsed_value, char **next,
-			 const char *msg)
+lw6msg_word_first_id_32 (lw6sys_context_t * sys_context, u_int32_t * parsed_value, char **next, const char *msg)
 {
   int ret = 0;
   lw6msg_word_t word;
@@ -568,10 +556,10 @@ lw6msg_word_first_id_32 (u_int32_t * parsed_value, char **next,
     {
       (*parsed_value) = 0;
     }
-  if (lw6msg_word_first_x (&word, next, msg))
+  if (lw6msg_word_first_x (sys_context, &word, next, msg))
     {
-      tmp_value = lw6sys_id_atol (word.buf);
-      if (tmp_value && lw6sys_check_id_32 (tmp_value))
+      tmp_value = lw6sys_id_atol (sys_context, word.buf);
+      if (tmp_value && lw6sys_check_id_32 (sys_context, tmp_value))
 	{
 	  if (parsed_value)
 	    {
@@ -581,7 +569,7 @@ lw6msg_word_first_id_32 (u_int32_t * parsed_value, char **next,
 	}
       else
 	{
-	  lw6sys_log (LW6SYS_LOG_DEBUG, _x_ ("bad id 32 \"%s\""), word.buf);
+	  lw6sys_log (sys_context, LW6SYS_LOG_DEBUG, _x_ ("bad id 32 \"%s\""), word.buf);
 	}
     }
 
@@ -591,6 +579,7 @@ lw6msg_word_first_id_32 (u_int32_t * parsed_value, char **next,
 /**
  * lw6msg_word_first_id_64
  *
+ * @sys_context: global system context
  * @parsed_value: will contain the parsed value
  * @next: if NOT NULL, will contain a (non freeable) pointer on remaining message
  * @msg: the message to parse
@@ -600,8 +589,7 @@ lw6msg_word_first_id_32 (u_int32_t * parsed_value, char **next,
  * Return value: 1 on success, 0 on failure.
  */
 int
-lw6msg_word_first_id_64 (u_int64_t * parsed_value, char **next,
-			 const char *msg)
+lw6msg_word_first_id_64 (lw6sys_context_t * sys_context, u_int64_t * parsed_value, char **next, const char *msg)
 {
   int ret = 0;
   lw6msg_word_t word;
@@ -611,10 +599,10 @@ lw6msg_word_first_id_64 (u_int64_t * parsed_value, char **next,
     {
       (*parsed_value) = 0;
     }
-  if (lw6msg_word_first_x (&word, next, msg))
+  if (lw6msg_word_first_x (sys_context, &word, next, msg))
     {
-      tmp_value = lw6sys_id_atol (word.buf);
-      if (tmp_value && lw6sys_check_id_64 (tmp_value))
+      tmp_value = lw6sys_id_atol (sys_context, word.buf);
+      if (tmp_value && lw6sys_check_id_64 (sys_context, tmp_value))
 	{
 	  if (parsed_value)
 	    {
@@ -624,7 +612,7 @@ lw6msg_word_first_id_64 (u_int64_t * parsed_value, char **next,
 	}
       else
 	{
-	  lw6sys_log (LW6SYS_LOG_DEBUG, _x_ ("bad id 64 \"%s\""), word.buf);
+	  lw6sys_log (sys_context, LW6SYS_LOG_DEBUG, _x_ ("bad id 64 \"%s\""), word.buf);
 	}
     }
 
