@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -35,7 +35,7 @@
  *  http://www.zlib.net/zlib_how.html
  */
 static int
-_encode_buffer_len (int in_len)
+_encode_buffer_len (lw6sys_context_t * sys_context, int in_len)
 {
   int out_len = 0;
   /*
@@ -50,7 +50,7 @@ _encode_buffer_len (int in_len)
 }
 
 static int
-_z_encode (char *out_buf, int *out_buf_len, const char *msg, int msg_len)
+_z_encode (lw6sys_context_t * sys_context, char *out_buf, int *out_buf_len, const char *msg, int msg_len)
 {
   int ret = 0;
   uLongf _out_buf_len = (*out_buf_len);
@@ -62,7 +62,7 @@ _z_encode (char *out_buf, int *out_buf_len, const char *msg, int msg_len)
 }
 
 static int
-_z_decode (char *out_buf, int *out_buf_len, const char *msg, int msg_len)
+_z_decode (lw6sys_context_t * sys_context, char *out_buf, int *out_buf_len, const char *msg, int msg_len)
 {
   int ret = 0;
   uLongf _out_buf_len = (*out_buf_len);
@@ -76,6 +76,7 @@ _z_decode (char *out_buf, int *out_buf_len, const char *msg, int msg_len)
 /**
  * lw6msg_z_encode
  *
+ * @sys_context: global system context
  * @msg: message to encode
  * @limit: if under this limit (length in bytes), do not encode, return as is
  *
@@ -89,7 +90,7 @@ _z_decode (char *out_buf, int *out_buf_len, const char *msg, int msg_len)
  * Return value: newly allocated string, 0 terminated, NULL on error.
  */
 char *
-lw6msg_z_encode (const char *msg, int limit)
+lw6msg_z_encode (lw6sys_context_t * sys_context, const char *msg, int limit)
 {
   char *ret = NULL;
   int in_len = 0;
@@ -100,51 +101,41 @@ lw6msg_z_encode (const char *msg, int limit)
   in_len = strlen (msg);
   if (in_len > limit)
     {
-      out_len = _encode_buffer_len (in_len);
-      out_buf = (char *) LW6SYS_MALLOC (out_len);
+      out_len = _encode_buffer_len (sys_context, in_len);
+      out_buf = (char *) LW6SYS_MALLOC (sys_context, out_len);
       if (out_buf)
 	{
-	  z_ret = _z_encode (out_buf, &out_len, msg, in_len);
+	  z_ret = _z_encode (sys_context, out_buf, &out_len, msg, in_len);
 	  if (z_ret == Z_OK)
 	    {
-	      ret =
-		lw6glb_base64_encode_bin_prefix (out_buf, out_len,
-						 LW6MSG_Z_PREFIX);
+	      ret = lw6glb_base64_encode_bin_prefix (sys_context, out_buf, out_len, LW6MSG_Z_PREFIX);
 	    }
 	  else
 	    {
 	      switch (z_ret)
 		{
 		case Z_BUF_ERROR:
-		  lw6sys_log (LW6SYS_LOG_WARNING,
-			      _x_
-			      ("zlib error, buffer is too small (in_len=%d out_len=%d)"),
-			      in_len, out_len);
+		  lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("zlib error, buffer is too small (in_len=%d out_len=%d)"), in_len, out_len);
 		  break;
 		case Z_MEM_ERROR:
-		  lw6sys_log (LW6SYS_LOG_WARNING,
-			      _x_
-			      ("zlib error, not enough memory (in_len=%d out_len=%d)"),
-			      in_len, out_len);
+		  lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("zlib error, not enough memory (in_len=%d out_len=%d)"), in_len, out_len);
 		  break;
 		default:
-		  lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("zlib error, ret=%d"),
-			      z_ret);
+		  lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("zlib error, ret=%d"), z_ret);
 		  break;
 		}
 	    }
-	  LW6SYS_FREE (out_buf);
+	  LW6SYS_FREE (sys_context, out_buf);
 	}
     }
   else
     {
-      ret = lw6sys_str_copy (msg);
+      ret = lw6sys_str_copy (sys_context, msg);
     }
 
   if (ret)
     {
-      lw6sys_log (LW6SYS_LOG_DEBUG, _x_ ("z-encode \"%s\" -> \"%s\""), msg,
-		  ret);
+      lw6sys_log (sys_context, LW6SYS_LOG_DEBUG, _x_ ("z-encode \"%s\" -> \"%s\""), msg, ret);
     }
 
   return ret;
@@ -153,6 +144,7 @@ lw6msg_z_encode (const char *msg, int limit)
 /**
  * lw6msg_z_decode
  *
+ * @sys_context: global system context
  * @msg: message to decode
  *
  * Z-decode a message, by "Z-encoding" we mean pass the string through
@@ -164,7 +156,7 @@ lw6msg_z_encode (const char *msg, int limit)
  * Return value: newly allocated string, 0 terminated, NULL on error.
  */
 char *
-lw6msg_z_decode (const char *msg)
+lw6msg_z_decode (lw6sys_context_t * sys_context, const char *msg)
 {
   char *ret = NULL;
   int in_len = 0;
@@ -173,10 +165,9 @@ lw6msg_z_decode (const char *msg)
   char *in_buf = NULL;
   int out_alloc_len = 0;
 
-  if (lw6sys_str_starts_with_no_case (msg, LW6MSG_Z_PREFIX))
+  if (lw6sys_str_starts_with_no_case (sys_context, msg, LW6MSG_Z_PREFIX))
     {
-      in_buf =
-	lw6glb_base64_decode_bin_prefix (&in_len, msg, LW6MSG_Z_PREFIX);
+      in_buf = lw6glb_base64_decode_bin_prefix (sys_context, &in_len, msg, LW6MSG_Z_PREFIX);
       if (in_buf)
 	{
 	  out_alloc_len = 1;	// too small, on purpose, to check auto-extend works
@@ -184,10 +175,10 @@ lw6msg_z_decode (const char *msg)
 	  while (z_ret == Z_BUF_ERROR && !ret)
 	    {
 	      out_len = out_alloc_len;
-	      ret = (char *) LW6SYS_MALLOC (out_alloc_len);
+	      ret = (char *) LW6SYS_MALLOC (sys_context, out_alloc_len);
 	      if (ret)
 		{
-		  z_ret = _z_decode (ret, &out_len, in_buf, in_len);
+		  z_ret = _z_decode (sys_context, ret, &out_len, in_buf, in_len);
 		  switch (z_ret)
 		    {
 		    case Z_OK:
@@ -206,8 +197,7 @@ lw6msg_z_decode (const char *msg)
 			}
 		      break;
 		    case Z_DATA_ERROR:
-		      lw6sys_log (LW6SYS_LOG_INFO,
-				  _x_ ("corrupted zlib data"));
+		      lw6sys_log (sys_context, LW6SYS_LOG_INFO, _x_ ("corrupted zlib data"));
 		      break;
 		    case Z_BUF_ERROR:
 		      out_alloc_len += in_len + 1;
@@ -222,47 +212,33 @@ lw6msg_z_decode (const char *msg)
 		{
 		  if (ret)
 		    {
-		      LW6SYS_FREE (ret);
+		      LW6SYS_FREE (sys_context, ret);
 		      ret = NULL;
 		    }
 		}
 	    }
 	  if (ret)
 	    {
-	      lw6sys_log (LW6SYS_LOG_DEBUG, _x_ ("z-decode \"%s\" -> \"%s\""),
-			  msg, ret);
+	      lw6sys_log (sys_context, LW6SYS_LOG_DEBUG, _x_ ("z-decode \"%s\" -> \"%s\""), msg, ret);
 	    }
 	  else
 	    {
 	      switch (z_ret)
 		{
 		case Z_BUF_ERROR:
-		  lw6sys_log (LW6SYS_LOG_WARNING,
-			      _x_
-			      ("zlib error, buffer is too small (in_len=%d out_len=%d)"),
-			      in_len, out_len);
+		  lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("zlib error, buffer is too small (in_len=%d out_len=%d)"), in_len, out_len);
 		  break;
 		case Z_MEM_ERROR:
-		  lw6sys_log (LW6SYS_LOG_WARNING,
-			      _x_
-			      ("zlib error, not enough memory (in_len=%d out_len=%d)"),
-			      in_len, out_len);
+		  lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("zlib error, not enough memory (in_len=%d out_len=%d)"), in_len, out_len);
 		  break;
 		case Z_DATA_ERROR:
-		  lw6sys_log (LW6SYS_LOG_WARNING,
-			      _x_
-			      ("zlib error, data error (in_len=%d out_len=%d)"),
-			      in_len, out_len);
+		  lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("zlib error, data error (in_len=%d out_len=%d)"), in_len, out_len);
 		  break;
 		case Z_STREAM_ERROR:
-		  lw6sys_log (LW6SYS_LOG_WARNING,
-			      _x_
-			      ("zlib error, stream error (in_len=%d out_len=%d)"),
-			      in_len, out_len);
+		  lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("zlib error, stream error (in_len=%d out_len=%d)"), in_len, out_len);
 		  break;
 		default:
-		  lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("zlib error, ret=%d"),
-			      z_ret);
+		  lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("zlib error, ret=%d"), z_ret);
 		  break;
 		}
 /*
@@ -271,33 +247,25 @@ lw6msg_z_decode (const char *msg)
 */
 	      if (strlen (msg) < _MSG_LEN_DUMP_MAX)
 		{
-		  lw6sys_log (LW6SYS_LOG_INFO,
-			      _x_ ("z-decode %d bytes msg was \"%s\""),
-			      (int) strlen (msg), msg);
+		  lw6sys_log (sys_context, LW6SYS_LOG_INFO, _x_ ("z-decode %d bytes msg was \"%s\""), (int) strlen (msg), msg);
 		}
 	      if (in_len < _IN_LEN_DUMP_MAX)
 		{
 		  char *in_hexa_str = NULL;
 
-		  in_hexa_str = lw6sys_hexa_buf_to_str (in_buf, in_len);
+		  in_hexa_str = lw6sys_hexa_buf_to_str (sys_context, in_buf, in_len);
 		  if (in_hexa_str)
 		    {
-		      lw6sys_log (LW6SYS_LOG_INFO,
-				  _x_
-				  ("z-decode %d bytes in_hexa_str was \"%s\""),
-				  in_len, in_hexa_str);
-		      LW6SYS_FREE (in_hexa_str);
+		      lw6sys_log (sys_context, LW6SYS_LOG_INFO, _x_ ("z-decode %d bytes in_hexa_str was \"%s\""), in_len, in_hexa_str);
+		      LW6SYS_FREE (sys_context, in_hexa_str);
 		    }
 		}
 	    }
-	  LW6SYS_FREE (in_buf);
+	  LW6SYS_FREE (sys_context, in_buf);
 	}
       else
 	{
-	  lw6sys_log (LW6SYS_LOG_INFO,
-		      _x_
-		      ("unable to decode \"%s\" as base64 prefixed by \"%s\""),
-		      msg, LW6MSG_Z_PREFIX);
+	  lw6sys_log (sys_context, LW6SYS_LOG_INFO, _x_ ("unable to decode \"%s\" as base64 prefixed by \"%s\""), msg, LW6MSG_Z_PREFIX);
 	}
     }
   else
@@ -305,7 +273,7 @@ lw6msg_z_decode (const char *msg)
       /*
        * We consider it wasn't z-encoded, keep it the same
        */
-      ret = lw6sys_str_copy (msg);
+      ret = lw6sys_str_copy (sys_context, msg);
     }
 
   return ret;
