@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -32,14 +32,12 @@
  * See also: http://www.uclibc.org/[...]/libc/inet/addr.c
  */
 char *
-_lw6net_inet_ntoa (struct in_addr in)
+_lw6net_inet_ntoa (lw6sys_context_t * sys_context, struct in_addr in)
 {
   char *ret = NULL;
   in_addr_t addr = ntohl (in.s_addr);
 
-  ret =
-    lw6sys_new_sprintf ("%d.%d.%d.%d", (addr >> 24) & 0xff,
-			(addr >> 16) & 0xff, (addr >> 8) & 0xff, addr & 0xff);
+  ret = lw6sys_new_sprintf (sys_context, "%d.%d.%d.%d", (addr >> 24) & 0xff, (addr >> 16) & 0xff, (addr >> 8) & 0xff, addr & 0xff);
 
   return ret;
 }
@@ -48,7 +46,7 @@ _lw6net_inet_ntoa (struct in_addr in)
  * inet_aton on UNIX and inet_addr on MS-Windows
  */
 int
-_lw6net_inet_aton (struct in_addr *in, const char *ip)
+_lw6net_inet_aton (lw6sys_context_t * sys_context, struct in_addr *in, const char *ip)
 {
   int ret = 0;
 
@@ -75,20 +73,17 @@ _lw6net_inet_aton (struct in_addr *in, const char *ip)
       else
 	{
 #ifdef LW6_MS_WINDOWS
-	  lw6sys_log (LW6SYS_LOG_WARNING,
-		      _x_ ("inet_addr() failed, ip=\"%s\""), ip);
-	  lw6net_last_error ();
+	  lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("inet_addr() failed, ip=\"%s\""), ip);
+	  lw6net_last_error (sys_context);
 #else
-	  lw6sys_log (LW6SYS_LOG_WARNING,
-		      _x_ ("inet_aton() failed, ip=\"%s\""), ip);
-	  lw6net_last_error ();
+	  lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("inet_aton() failed, ip=\"%s\""), ip);
+	  lw6net_last_error (sys_context);
 #endif
 	}
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_DEBUG,
-		  _x_ ("address \"%s\" identified as \"ANY\""), ip);
+      lw6sys_log (sys_context, LW6SYS_LOG_DEBUG, _x_ ("address \"%s\" identified as \"ANY\""), ip);
       ret = 1;
     }
 
