@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -28,32 +28,28 @@
 #include "net-internal.h"
 
 int
-_lw6net_connectable_init (_lw6net_connectable_t * connectable,
-			  int connectable_cache_hash_size,
+_lw6net_connectable_init (lw6sys_context_t * sys_context, _lw6net_connectable_t * connectable, int connectable_cache_hash_size,
 			  int connectable_cache_delay_sec)
 {
   int ret = 0;
 
-  connectable->connectable_cache_mutex = lw6sys_mutex_create ();
-  connectable->connectable_cache =
-    lw6sys_cache_new (NULL, connectable_cache_hash_size,
-		      connectable_cache_delay_sec * LW6SYS_TICKS_PER_SEC);
-  ret = (connectable->connectable_cache_mutex != NULL
-	 && connectable->connectable_cache != NULL);
+  connectable->connectable_cache_mutex = LW6SYS_MUTEX_CREATE (sys_context);
+  connectable->connectable_cache = lw6sys_cache_new (sys_context, NULL, connectable_cache_hash_size, connectable_cache_delay_sec * LW6SYS_TICKS_PER_SEC);
+  ret = (connectable->connectable_cache_mutex != NULL && connectable->connectable_cache != NULL);
 
   return ret;
 }
 
 void
-_lw6net_connectable_quit (_lw6net_connectable_t * connectable)
+_lw6net_connectable_quit (lw6sys_context_t * sys_context, _lw6net_connectable_t * connectable)
 {
   if (connectable->connectable_cache)
     {
-      lw6sys_cache_free (connectable->connectable_cache);
+      lw6sys_cache_free (sys_context, connectable->connectable_cache);
     }
   if (connectable->connectable_cache_mutex)
     {
-      lw6sys_mutex_destroy (connectable->connectable_cache_mutex);
+      LW6SYS_MUTEX_DESTROY (sys_context, connectable->connectable_cache_mutex);
     }
   memset (connectable, 0, sizeof (_lw6net_connectable_t));
 }
@@ -61,6 +57,7 @@ _lw6net_connectable_quit (_lw6net_connectable_t * connectable)
 /**
  * lw6net_is_connectable
  *
+ * @sys_context: global system context
  * @ip: IP address
  * @port: IP port
  *
@@ -73,37 +70,35 @@ _lw6net_connectable_quit (_lw6net_connectable_t * connectable)
  * Return value: 1 if connectable, 0 if not.
  */
 int
-lw6net_is_connectable (const char *ip, int port)
+lw6net_is_connectable (lw6sys_context_t * sys_context, const char *ip, int port)
 {
   int ret = 1;			// by default, connectable
   char *key = NULL;
   _lw6net_connectable_t *connectable = &(_lw6net_global_context->connectable);
 
-  key = lw6sys_new_sprintf ("%s:%d", ip, port);
+  key = lw6sys_new_sprintf (sys_context, "%s:%d", ip, port);
   if (key)
     {
-      if (lw6sys_mutex_lock (connectable->connectable_cache_mutex))
+      if (LW6SYS_MUTEX_LOCK (sys_context, connectable->connectable_cache_mutex))
 	{
 	  /*
 	   * Yes, test is inverted, if there's no key it means we
 	   * can connect as we store probable impossibilities
 	   * in the cache, and not positive connects.
 	   */
-	  if (!lw6sys_cache_has_key (connectable->connectable_cache, key))
+	  if (!lw6sys_cache_has_key (sys_context, connectable->connectable_cache, key))
 	    {
-	      lw6sys_log (LW6SYS_LOG_INFO,
-			  _x_ ("destination %s:%d marked as connectable"),
-			  ip, port);
+	      lw6sys_log (sys_context, LW6SYS_LOG_INFO, _x_ ("destination %s:%d marked as connectable"), ip, port);
 	      ret = 1;
 	    }
 	  else
 	    {
 	      ret = 0;
 	    }
-	  lw6sys_mutex_unlock (connectable->connectable_cache_mutex);
+	  LW6SYS_MUTEX_UNLOCK (sys_context, connectable->connectable_cache_mutex);
 	}
 
-      LW6SYS_FREE (key);
+      LW6SYS_FREE (sys_context, key);
     }
 
   return ret;
@@ -112,6 +107,7 @@ lw6net_is_connectable (const char *ip, int port)
 /**
  * lw6net_set_connectable
  *
+ * @sys_context: global system context
  * @ip: IP address
  * @port: IP port
  * @status: status, set to 1 if connectable, 0 if not
@@ -127,16 +123,16 @@ lw6net_is_connectable (const char *ip, int port)
  * Return value: none.
  */
 void
-lw6net_set_connectable (const char *ip, int port, int status)
+lw6net_set_connectable (lw6sys_context_t * sys_context, const char *ip, int port, int status)
 {
   char *key = NULL;
   _lw6net_connectable_t *connectable = &(_lw6net_global_context->connectable);
 
 
-  key = lw6sys_new_sprintf ("%s:%d", ip, port);
+  key = lw6sys_new_sprintf (sys_context, "%s:%d", ip, port);
   if (key)
     {
-      if (lw6sys_mutex_lock (connectable->connectable_cache_mutex))
+      if (LW6SYS_MUTEX_LOCK (sys_context, connectable->connectable_cache_mutex))
 	{
 	  if (status)
 	    {
@@ -146,22 +142,17 @@ lw6net_set_connectable (const char *ip, int port, int status)
 	       * the information to "yes you could connect" one just
 	       * needs to remove the entry.
 	       */
-	      lw6sys_cache_unset (connectable->connectable_cache, key);
-	      lw6sys_log (LW6SYS_LOG_INFO,
-			  _x_ ("destination %s:%d marked as connectable"), ip,
-			  port);
+	      lw6sys_cache_unset (sys_context, connectable->connectable_cache, key);
+	      lw6sys_log (sys_context, LW6SYS_LOG_INFO, _x_ ("destination %s:%d marked as connectable"), ip, port);
 	    }
 	  else
 	    {
-	      lw6sys_cache_set (connectable->connectable_cache, key, NULL);
-	      lw6sys_log (LW6SYS_LOG_INFO,
-			  _x_
-			  ("destination %s:%d marked as not connectable"),
-			  ip, port);
+	      lw6sys_cache_set (sys_context, connectable->connectable_cache, key, NULL);
+	      lw6sys_log (sys_context, LW6SYS_LOG_INFO, _x_ ("destination %s:%d marked as not connectable"), ip, port);
 	    }
 
-	  lw6sys_mutex_unlock (connectable->connectable_cache_mutex);
+	  LW6SYS_MUTEX_UNLOCK (sys_context, connectable->connectable_cache_mutex);
 	}
-      LW6SYS_FREE (key);
+      LW6SYS_FREE (sys_context, key);
     }
 }
