@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -28,36 +28,32 @@
 #include "net-internal.h"
 
 int
-_lw6net_dns_init (_lw6net_dns_t * dns, int dns_cache_hash_size,
-		  int dns_cache_delay_sec)
+_lw6net_dns_init (lw6sys_context_t * sys_context, _lw6net_dns_t * dns, int dns_cache_hash_size, int dns_cache_delay_sec)
 {
   int ret = 0;
 
-  dns->dns_gethostbyname_mutex = lw6sys_mutex_create ();
-  dns->dns_cache_mutex = lw6sys_mutex_create ();
-  dns->dns_cache =
-    lw6sys_cache_new (lw6sys_free_callback, dns_cache_hash_size,
-		      dns_cache_delay_sec * LW6SYS_TICKS_PER_SEC);
-  ret = (dns->dns_gethostbyname_mutex != NULL && dns->dns_cache_mutex != NULL
-	 && dns->dns_cache != NULL);
+  dns->dns_gethostbyname_mutex = LW6SYS_MUTEX_CREATE (sys_context);
+  dns->dns_cache_mutex = LW6SYS_MUTEX_CREATE (sys_context);
+  dns->dns_cache = lw6sys_cache_new (sys_context, lw6sys_free_callback, dns_cache_hash_size, dns_cache_delay_sec * LW6SYS_TICKS_PER_SEC);
+  ret = (dns->dns_gethostbyname_mutex != NULL && dns->dns_cache_mutex != NULL && dns->dns_cache != NULL);
 
   return ret;
 }
 
 void
-_lw6net_dns_quit (_lw6net_dns_t * dns)
+_lw6net_dns_quit (lw6sys_context_t * sys_context, _lw6net_dns_t * dns)
 {
   if (dns->dns_cache)
     {
-      lw6sys_cache_free (dns->dns_cache);
+      lw6sys_cache_free (sys_context, dns->dns_cache);
     }
   if (dns->dns_cache_mutex)
     {
-      lw6sys_mutex_destroy (dns->dns_cache_mutex);
+      LW6SYS_MUTEX_DESTROY (sys_context, dns->dns_cache_mutex);
     }
   if (dns->dns_gethostbyname_mutex)
     {
-      lw6sys_mutex_destroy (dns->dns_gethostbyname_mutex);
+      LW6SYS_MUTEX_DESTROY (sys_context, dns->dns_gethostbyname_mutex);
     }
   memset (dns, 0, sizeof (_lw6net_dns_t));
 }
@@ -80,7 +76,7 @@ _is_digit (char c)
  * Return value: 1 if it's an IP, O if not.
  */
 int
-lw6net_dns_is_ip (const char *ip)
+lw6net_dns_is_ip (lw6sys_context_t * sys_context, const char *ip)
 {
   int ret = 1;
   const char *pos = ip;
@@ -124,7 +120,7 @@ lw6net_dns_is_ip (const char *ip)
  * Return value: an IP if success, NULL on error.
  */
 char *
-lw6net_dns_gethostbyname (const char *name)
+lw6net_dns_gethostbyname (lw6sys_context_t * sys_context, const char *name)
 {
   char *ret = NULL;
   struct hostent *h;
@@ -134,7 +130,7 @@ lw6net_dns_gethostbyname (const char *name)
   char *to_put_in_cache = NULL;
   _lw6net_dns_t *dns = &(_lw6net_global_context->dns);
 
-  if (lw6net_dns_is_ip (name))
+  if (lw6net_dns_is_ip (sys_context, name))
     {
       /*
        * Yes, gethostbyname would do the job and *not* convert
@@ -145,21 +141,19 @@ lw6net_dns_gethostbyname (const char *name)
        * conditions. Ideal implementation would use
        * gethostbyname_r when available.
        */
-      ret = lw6sys_str_copy (name);
+      ret = lw6sys_str_copy (sys_context, name);
     }
   else
     {
-      if (lw6sys_mutex_lock (dns->dns_cache_mutex))
+      if (LW6SYS_MUTEX_LOCK (sys_context, dns->dns_cache_mutex))
 	{
-	  cached_ret = lw6sys_cache_get (dns->dns_cache, name);
+	  cached_ret = lw6sys_cache_get (sys_context, dns->dns_cache, name);
 	  if (cached_ret)
 	    {
-	      lw6sys_log (LW6SYS_LOG_DEBUG,
-			  _x_ ("cached DNS \"%s\" -> \"%s\""), name,
-			  cached_ret);
-	      ret = lw6sys_str_copy (cached_ret);
+	      lw6sys_log (sys_context, LW6SYS_LOG_DEBUG, _x_ ("cached DNS \"%s\" -> \"%s\""), name, cached_ret);
+	      ret = lw6sys_str_copy (sys_context, cached_ret);
 	    }
-	  lw6sys_mutex_unlock (dns->dns_cache_mutex);
+	  LW6SYS_MUTEX_UNLOCK (sys_context, dns->dns_cache_mutex);
 	}
       /*
        * At this stage cached_ret is NOT NULL if something is in the cache
@@ -169,38 +163,33 @@ lw6net_dns_gethostbyname (const char *name)
        */
       if (!ret)
 	{
-	  if (lw6net_dns_lock ())
+	  if (lw6net_dns_lock (sys_context))
 	    {
 	      h = gethostbyname (name);
-	      if (h && h->h_addrtype == AF_INET && h->h_length >= 4
-		  && h->h_addr_list[0])
+	      if (h && h->h_addrtype == AF_INET && h->h_length >= 4 && h->h_addr_list[0])
 		{
 		  addr.s_addr = *((u_long *) (h->h_addr_list[0]));
 		  ntoa_ret = inet_ntoa (addr);
 		  if (ntoa_ret)
 		    {
-		      lw6sys_log (LW6SYS_LOG_INFO,
-				  _x_ ("DNS request \"%s\" -> \"%s\""), name,
-				  ntoa_ret);
-		      to_put_in_cache = lw6sys_str_copy (ntoa_ret);
+		      lw6sys_log (sys_context, LW6SYS_LOG_INFO, _x_ ("DNS request \"%s\" -> \"%s\""), name, ntoa_ret);
+		      to_put_in_cache = lw6sys_str_copy (sys_context, ntoa_ret);
 
-		      ret = lw6sys_str_copy (ntoa_ret);
+		      ret = lw6sys_str_copy (sys_context, ntoa_ret);
 		    }
 		}
-	      lw6net_dns_unlock ();
+	      lw6net_dns_unlock (sys_context);
 	    }
 	}
     }
 
   if (to_put_in_cache)
     {
-      if (lw6sys_mutex_lock (dns->dns_cache_mutex))
+      if (LW6SYS_MUTEX_LOCK (sys_context, dns->dns_cache_mutex))
 	{
-	  lw6sys_log (LW6SYS_LOG_DEBUG,
-		      _x_ ("put in DNS cache \"%s\" -> \"%s\""), name,
-		      to_put_in_cache);
-	  lw6sys_cache_set (dns->dns_cache, name, to_put_in_cache);
-	  lw6sys_mutex_unlock (dns->dns_cache_mutex);
+	  lw6sys_log (sys_context, LW6SYS_LOG_DEBUG, _x_ ("put in DNS cache \"%s\" -> \"%s\""), name, to_put_in_cache);
+	  lw6sys_cache_set (sys_context, dns->dns_cache, name, to_put_in_cache);
+	  LW6SYS_MUTEX_UNLOCK (sys_context, dns->dns_cache_mutex);
 	}
     }
 
@@ -210,6 +199,8 @@ lw6net_dns_gethostbyname (const char *name)
 /**
  * lw6net_dns_lock
  *
+ * @sys_context: global system context
+ *
  * Locks access to dns function @lw6net_dns_gethostbyname.
  * This is because @gethostbyname isn't reentrant plus, even
  * if we didn't use it but its multithreadable equivalent
@@ -221,24 +212,26 @@ lw6net_dns_gethostbyname (const char *name)
  * Return value: an IP if success, 0 on error.
  */
 int
-lw6net_dns_lock ()
+lw6net_dns_lock (lw6sys_context_t * sys_context)
 {
   _lw6net_dns_t *dns = &(_lw6net_global_context->dns);
 
-  return lw6sys_mutex_lock (dns->dns_gethostbyname_mutex);
+  return LW6SYS_MUTEX_LOCK (sys_context, dns->dns_gethostbyname_mutex);
 }
 
 /**
  * lw6net_dns_unlock
  *
+ * @sys_context: global system context
+ *
  * Unlocks access to dns function @lw6net_dns_gethostbyname.
  *
  * Return value: an IP if success, 0 on error.
  */
 int
-lw6net_dns_unlock ()
+lw6net_dns_unlock (lw6sys_context_t * sys_context)
 {
   _lw6net_dns_t *dns = &(_lw6net_global_context->dns);
 
-  return lw6sys_mutex_unlock (dns->dns_gethostbyname_mutex);
+  return LW6SYS_MUTEX_UNLOCK (sys_context, dns->dns_gethostbyname_mutex);
 }
