@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -34,6 +34,8 @@
 /**
  * lw6net_if_guess_local
  *
+ * @sys_context: global system context
+ *
  * Guess the local IP address. This is not fool-proof,
  * and it probably cannot be as we can't handle all
  * user-specific configs involving multiple IP addresses,
@@ -46,7 +48,7 @@
  * Return value: the IP as a string, dynamically allocated
  */
 char *
-lw6net_if_guess_local ()
+lw6net_if_guess_local (lw6sys_context_t * sys_context)
 {
   char *ret = NULL;
 
@@ -60,50 +62,41 @@ lw6net_if_guess_local ()
   DWORD dwRetVal = 0;
   ULONG ulOutBufLen = sizeof (IP_ADAPTER_INFO);
 
-  pAdapterInfo = (IP_ADAPTER_INFO *) LW6SYS_CALLOC (sizeof (IP_ADAPTER_INFO));
+  pAdapterInfo = (IP_ADAPTER_INFO *) LW6SYS_CALLOC (sys_context, sizeof (IP_ADAPTER_INFO));
   if (pAdapterInfo)
     {
       // Make an initial call to GetAdaptersInfo to get
       // the necessary size into the ulOutBufLen variable
-      if (GetAdaptersInfo (pAdapterInfo, &ulOutBufLen) ==
-	  ERROR_BUFFER_OVERFLOW)
+      if (GetAdaptersInfo (pAdapterInfo, &ulOutBufLen) == ERROR_BUFFER_OVERFLOW)
 	{
-	  LW6SYS_FREE (pAdapterInfo);
-	  pAdapterInfo = (IP_ADAPTER_INFO *) LW6SYS_CALLOC (ulOutBufLen);
+	  LW6SYS_FREE (sys_context, pAdapterInfo);
+	  pAdapterInfo = (IP_ADAPTER_INFO *) LW6SYS_CALLOC (sys_context, ulOutBufLen);
 	}
       if (pAdapterInfo)
 	{
-	  if ((dwRetVal =
-	       GetAdaptersInfo (pAdapterInfo, &ulOutBufLen)) == NO_ERROR)
+	  if ((dwRetVal = GetAdaptersInfo (pAdapterInfo, &ulOutBufLen)) == NO_ERROR)
 	    {
 	      pAdapter = pAdapterInfo;
 	      while (pAdapter && !ret)
 		{
 		  if (pAdapter->IpAddressList.IpAddress.String &&
-		      strlen (pAdapter->IpAddressList.IpAddress.String) >
-		      0
-		      && strcmp (pAdapter->IpAddressList.IpAddress.String,
-				 LW6NET_ADDRESS_LOOPBACK) != 0)
+		      strlen (pAdapter->IpAddressList.IpAddress.String) > 0 && strcmp (pAdapter->IpAddressList.IpAddress.String, LW6NET_ADDRESS_LOOPBACK) != 0)
 		    {
-		      ret =
-			lw6sys_str_copy (pAdapter->IpAddressList.
-					 IpAddress.String);
+		      ret = lw6sys_str_copy (sys_context, pAdapter->IpAddressList.IpAddress.String);
 		    }
 		  pAdapter = pAdapter->Next;
 		}
 	    }
 	  else
 	    {
-	      lw6sys_log (LW6SYS_LOG_WARNING,
-			  _x_ ("GetAdaptersInfo failed with error %d"),
-			  (int) dwRetVal);
+	      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("GetAdaptersInfo failed with error %d"), (int) dwRetVal);
 	    }
 	}
     }
 
   if (pAdapterInfo)
     {
-      LW6SYS_FREE (pAdapterInfo);
+      LW6SYS_FREE (sys_context, pAdapterInfo);
     }
 
 #else
@@ -124,21 +117,16 @@ lw6net_if_guess_local ()
 	  // https://savannah.gnu.org/bugs/?41184
 	  if (ifa->ifa_addr != NULL && ifa->ifa_addr->sa_family == AF_INET)
 	    {
-	      if (!(s = getnameinfo (ifa->ifa_addr,
-				     sizeof (struct sockaddr_in),
-				     host, NI_MAXHOST, NULL, 0,
-				     NI_NUMERICHOST)))
+	      if (!(s = getnameinfo (ifa->ifa_addr, sizeof (struct sockaddr_in), host, NI_MAXHOST, NULL, 0, NI_NUMERICHOST)))
 		{
 		  if (strcmp (host, LW6NET_ADDRESS_LOOPBACK))
 		    {
-		      ret = lw6sys_str_copy (host);
+		      ret = lw6sys_str_copy (sys_context, host);
 		    }
 		}
 	      else
 		{
-		  lw6sys_log (LW6SYS_LOG_WARNING,
-			      _x_ ("getnameinfo() failed \"%s\""),
-			      gai_strerror (s));
+		  lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("getnameinfo() failed \"%s\""), gai_strerror (s));
 		}
 	    }
 	}
@@ -146,7 +134,7 @@ lw6net_if_guess_local ()
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("getifaddrs failed"));
+      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("getifaddrs failed"));
     }
 
 #endif
@@ -157,6 +145,7 @@ lw6net_if_guess_local ()
 /**
  * lw6net_if_guess_public_url
  *
+ * @sys_context: global system context
  * @bind_ip: the IP address used to bind on
  * @bind_port: the IP port used to bind on
  *
@@ -171,30 +160,28 @@ lw6net_if_guess_local ()
  * Return value: the IP as a string, dynamically allocated
  */
 char *
-lw6net_if_guess_public_url (const char *bind_ip, int bind_port)
+lw6net_if_guess_public_url (lw6sys_context_t * sys_context, const char *bind_ip, int bind_port)
 {
   char *ret = NULL;
   char *ip = NULL;
 
   if (!strcmp (bind_ip, LW6NET_ADDRESS_ANY))
     {
-      ip = lw6net_if_guess_local ();
+      ip = lw6net_if_guess_local (sys_context);
       if (!ip)
 	{
-	  lw6sys_log (LW6SYS_LOG_INFO,
-		      _x_
-		      ("can't find local network interface, using loopback"));
-	  ip = lw6sys_str_copy (LW6NET_ADDRESS_LOOPBACK);
+	  lw6sys_log (sys_context, LW6SYS_LOG_INFO, _x_ ("can't find local network interface, using loopback"));
+	  ip = lw6sys_str_copy (sys_context, LW6NET_ADDRESS_LOOPBACK);
 	}
     }
   else
     {
-      ip = lw6sys_str_copy (bind_ip);
+      ip = lw6sys_str_copy (sys_context, bind_ip);
     }
   if (ip)
     {
-      ret = lw6sys_url_http_from_ip_port (ip, bind_port);
-      LW6SYS_FREE (ip);
+      ret = lw6sys_url_http_from_ip_port (sys_context, ip, bind_port);
+      LW6SYS_FREE (sys_context, ip);
     }
 
   return ret;
