@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -49,6 +49,7 @@ static char trail[TRAIL_SIZE + 1] = { CHAR_LF, CHAR_0, CHAR_0 };
 /**
  * lw6net_recv_line_tcp:
  *
+ * @sys_context: global system context
  * @sock: the socket descriptor
  *
  * Receives a line terminated by LF ("\n", chr(10)) or
@@ -63,7 +64,7 @@ static char trail[TRAIL_SIZE + 1] = { CHAR_LF, CHAR_0, CHAR_0 };
  *   content received. The tailing (CR)/LF is stripped.
  */
 char *
-lw6net_recv_line_tcp (int *sock)
+lw6net_recv_line_tcp (lw6sys_context_t * sys_context, int *sock)
 {
   char *ret = NULL;
   int line_size = 0;
@@ -74,31 +75,28 @@ lw6net_recv_line_tcp (int *sock)
   char *pos_lf;
   char line_buf[LW6NET_MAX_LINE_SIZE + TRAIL_SIZE + 1];
 
-  if (lw6net_socket_is_valid (*sock))
+  if (lw6net_socket_is_valid (sys_context, *sock))
     {
       line_size = _lw6net_global_context->const_data.line_size;
       line_delay = _lw6net_global_context->const_data.line_delay_msec;
       memset (line_buf, 0, line_size + TRAIL_SIZE + 1);
-      available_size =
-	lw6net_tcp_peek (sock, line_buf, line_size + TRAIL_SIZE, 0.0f);
+      available_size = lw6net_tcp_peek (sys_context, sock, line_buf, line_size + TRAIL_SIZE, 0.0f);
       if (available_size > 0)
 	{
 	  pos_lf = strchr (line_buf, CHAR_LF);
 	  if (pos_lf)
 	    {
-	      trail_size = (pos_lf > line_buf
-			    && pos_lf[-1] ==
-			    CHAR_CR) ? TRAIL_SIZE : TRAIL_SIZE - 1;
+	      trail_size = (pos_lf > line_buf && pos_lf[-1] == CHAR_CR) ? TRAIL_SIZE : TRAIL_SIZE - 1;
 	      wanted_size = (pos_lf + 1 - line_buf);
 	      pos_lf[1 - trail_size] = CHAR_0;
-	      ret = lw6sys_str_copy (line_buf);
+	      ret = lw6sys_str_copy (sys_context, line_buf);
 	      if (ret)
 		{
-		  lw6sys_str_cleanup (ret);
+		  lw6sys_str_cleanup (sys_context, ret);
 		}
 
 	      // remove data from queue
-	      lw6net_tcp_recv (sock, line_buf, wanted_size, line_delay, 0);
+	      lw6net_tcp_recv (sys_context, sock, line_buf, wanted_size, line_delay, 0);
 	    }
 	}
     }
@@ -109,6 +107,7 @@ lw6net_recv_line_tcp (int *sock)
 /**
  * lw6net_send_line_tcp:
  *
+ * @sys_context: global system context
  * @sock: the socket descriptor
  * @line: the line to be sent, without the "\n" at the end
  *
@@ -120,7 +119,7 @@ lw6net_recv_line_tcp (int *sock)
  * Return value: non-zero if success
  */
 int
-lw6net_send_line_tcp (int *sock, const char *line)
+lw6net_send_line_tcp (lw6sys_context_t * sys_context, int *sock, const char *line)
 {
   int ret = 0;
   int line_size = 0;
@@ -128,16 +127,16 @@ lw6net_send_line_tcp (int *sock, const char *line)
   int wanted_size = 0;
   char *trailed_line = NULL;
 
-  if (lw6net_socket_is_valid (*sock) && line)
+  if (lw6net_socket_is_valid (sys_context, *sock) && line)
     {
       /*
        * If sock is not reported as alive, we don't even waste
        * the time to try and send data, this could really slow
        * down things on polling loops.
        */
-      if (lw6net_tcp_is_alive (sock))
+      if (lw6net_tcp_is_alive (sys_context, sock))
 	{
-	  trailed_line = lw6sys_str_concat (line, trail);
+	  trailed_line = lw6sys_str_concat (sys_context, line, trail);
 	  if (trailed_line)
 	    {
 	      line_size = _lw6net_global_context->const_data.line_size;
@@ -145,17 +144,12 @@ lw6net_send_line_tcp (int *sock, const char *line)
 	      wanted_size = strlen (trailed_line);
 	      if (wanted_size > line_size)
 		{
-		  lw6sys_log (LW6SYS_LOG_WARNING,
-			      _x_
-			      ("stripping line \"%s\" of size %d, limit is %d"),
-			      line, wanted_size, line_size);
+		  lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("stripping line \"%s\" of size %d, limit is %d"), line, wanted_size, line_size);
 		  wanted_size = line_size;
 		}
 
-	      ret =
-		lw6net_tcp_send (sock, trailed_line, wanted_size, line_delay,
-				 0);
-	      LW6SYS_FREE (trailed_line);
+	      ret = lw6net_tcp_send (sys_context, sock, trailed_line, wanted_size, line_delay, 0);
+	      LW6SYS_FREE (sys_context, trailed_line);
 	    }
 	}
     }
@@ -166,6 +160,7 @@ lw6net_send_line_tcp (int *sock, const char *line)
 /**
  * lw6net_recv_line_udp:
  *
+ * @sys_context: global system context
  * @sock: the socket descriptor
  * @incoming_ip: the IP address of the sender (returned)
  * @incoming_port: the IP port of the sender (returned)
@@ -183,7 +178,7 @@ lw6net_send_line_tcp (int *sock, const char *line)
  *   content received. The tailing (CR)/LF is stripped.
  */
 char *
-lw6net_recv_line_udp (int sock, char **incoming_ip, int *incoming_port)
+lw6net_recv_line_udp (lw6sys_context_t * sys_context, int sock, char **incoming_ip, int *incoming_port)
 {
   char *ret = NULL;
   int line_size = 0;
@@ -198,37 +193,30 @@ lw6net_recv_line_udp (int sock, char **incoming_ip, int *incoming_port)
    */
   char line_buf[LW6NET_MAX_LINE_SIZE + TRAIL_SIZE + 1];
 
-  if (lw6net_socket_is_valid (sock))
+  if (lw6net_socket_is_valid (sys_context, sock))
     {
-      line_size =
-	lw6sys_imin (_lw6net_global_context->const_data.line_size,
-		     LW6NET_PPPOE_MTU - TRAIL_SIZE);
+      line_size = lw6sys_imin (_lw6net_global_context->const_data.line_size, LW6NET_PPPOE_MTU - TRAIL_SIZE);
       memset (line_buf, 0, line_size + TRAIL_SIZE + 1);
-      available_size =
-	lw6net_udp_peek (sock, line_buf, line_size + TRAIL_SIZE,
-			 incoming_ip, incoming_port);
+      available_size = lw6net_udp_peek (sys_context, sock, line_buf, line_size + TRAIL_SIZE, incoming_ip, incoming_port);
       if (incoming_ip && (*incoming_ip))
 	{
-	  LW6SYS_FREE (*incoming_ip);
+	  LW6SYS_FREE (sys_context, *incoming_ip);
 	}
       if (available_size > 0)
 	{
 	  pos_lf = strchr (line_buf, CHAR_LF);
 	  if (pos_lf)
 	    {
-	      trail_size = (pos_lf > line_buf
-			    && pos_lf[-1] ==
-			    CHAR_CR) ? TRAIL_SIZE : TRAIL_SIZE - 1;
+	      trail_size = (pos_lf > line_buf && pos_lf[-1] == CHAR_CR) ? TRAIL_SIZE : TRAIL_SIZE - 1;
 	      pos_lf[1 - trail_size] = CHAR_0;
-	      ret = lw6sys_str_copy (line_buf);
+	      ret = lw6sys_str_copy (sys_context, line_buf);
 	      if (ret)
 		{
-		  lw6sys_str_cleanup (ret);
+		  lw6sys_str_cleanup (sys_context, ret);
 		}
 	    }
 	  // remove data from queue
-	  lw6net_udp_recv (sock, line_buf, available_size,
-			   incoming_ip, incoming_port);
+	  lw6net_udp_recv (sys_context, sock, line_buf, available_size, incoming_ip, incoming_port);
 	}
     }
 
@@ -238,6 +226,7 @@ lw6net_recv_line_udp (int sock, char **incoming_ip, int *incoming_port)
 /**
  * lw6net_recv_lines_udp:
  *
+ * @sys_context: global system context
  * @sock: the socket descriptor
  * @incoming_ip: the IP address of the sender (returned)
  * @incoming_port: the IP port of the sender (returned)
@@ -257,7 +246,7 @@ lw6net_recv_line_udp (int sock, char **incoming_ip, int *incoming_port)
  *   The tailing (CR)/LF is stripped from strings.
  */
 lw6sys_list_t *
-lw6net_recv_lines_udp (int sock, char **incoming_ip, int *incoming_port)
+lw6net_recv_lines_udp (lw6sys_context_t * sys_context, int sock, char **incoming_ip, int *incoming_port)
 {
   lw6sys_list_t *ret = NULL;
   char *line = NULL;
@@ -269,21 +258,17 @@ lw6net_recv_lines_udp (int sock, char **incoming_ip, int *incoming_port)
   char *seek = NULL;
   int no_lf_at_very_end = 0;
 
-  if (lw6net_socket_is_valid (sock))
+  if (lw6net_socket_is_valid (sys_context, sock))
     {
-      ret = lw6sys_list_new (lw6sys_free_callback);
+      ret = lw6sys_list_new (sys_context, lw6sys_free_callback);
       if (ret)
 	{
-	  line_size =
-	    lw6sys_imin (_lw6net_global_context->const_data.line_size,
-			 LW6NET_PPPOE_MTU - TRAIL_SIZE);
+	  line_size = lw6sys_imin (_lw6net_global_context->const_data.line_size, LW6NET_PPPOE_MTU - TRAIL_SIZE);
 	  memset (line_buf, 0, line_size + TRAIL_SIZE + 1);
-	  available_size =
-	    lw6net_udp_peek (sock, line_buf, line_size + TRAIL_SIZE,
-			     incoming_ip, incoming_port);
+	  available_size = lw6net_udp_peek (sys_context, sock, line_buf, line_size + TRAIL_SIZE, incoming_ip, incoming_port);
 	  if (incoming_ip && (*incoming_ip))
 	    {
-	      LW6SYS_FREE (*incoming_ip);
+	      LW6SYS_FREE (sys_context, *incoming_ip);
 	    }
 	  if (available_size > 0)
 	    {
@@ -293,17 +278,15 @@ lw6net_recv_lines_udp (int sock, char **incoming_ip, int *incoming_port)
 		  pos_lf = strchr (seek, CHAR_LF);
 		  if (pos_lf)
 		    {
-		      trail_size = (pos_lf > seek
-				    && pos_lf[-1] ==
-				    CHAR_CR) ? TRAIL_SIZE : TRAIL_SIZE - 1;
+		      trail_size = (pos_lf > seek && pos_lf[-1] == CHAR_CR) ? TRAIL_SIZE : TRAIL_SIZE - 1;
 		      pos_lf[1 - trail_size] = CHAR_0;
-		      line = lw6sys_str_copy (seek);
+		      line = lw6sys_str_copy (sys_context, seek);
 		      if (line)
 			{
-			  lw6sys_str_cleanup (line);
+			  lw6sys_str_cleanup (sys_context, line);
 			  if (ret)
 			    {
-			      lw6sys_list_push_back (&ret, line);
+			      lw6sys_list_push_back (sys_context, &ret, line);
 			    }
 			}
 		      seek = pos_lf + 1;
@@ -315,15 +298,14 @@ lw6net_recv_lines_udp (int sock, char **incoming_ip, int *incoming_port)
 		    }
 		}
 	      // remove data from queue
-	      lw6net_udp_recv (sock, line_buf, available_size,
-			       incoming_ip, incoming_port);
+	      lw6net_udp_recv (sys_context, sock, line_buf, available_size, incoming_ip, incoming_port);
 	    }
 	}
     }
 
-  if (ret && lw6sys_list_is_empty (ret))
+  if (ret && lw6sys_list_is_empty (sys_context, ret))
     {
-      lw6sys_list_free (ret);
+      lw6sys_list_free (sys_context, ret);
       ret = NULL;
     }
 
@@ -331,10 +313,8 @@ lw6net_recv_lines_udp (int sock, char **incoming_ip, int *incoming_port)
     {
       if (ret)
 	{
-	  lw6sys_log (LW6SYS_LOG_DEBUG,
-		      _x_
-		      ("no lf at the very end of the sequence of lines, message was probably truncated"));
-	  lw6sys_list_free (ret);
+	  lw6sys_log (sys_context, LW6SYS_LOG_DEBUG, _x_ ("no lf at the very end of the sequence of lines, message was probably truncated"));
+	  lw6sys_list_free (sys_context, ret);
 	  ret = NULL;
 	}
     }
@@ -343,7 +323,7 @@ lw6net_recv_lines_udp (int sock, char **incoming_ip, int *incoming_port)
     {
       if (incoming_ip && (*incoming_ip))
 	{
-	  LW6SYS_FREE (*incoming_ip);
+	  LW6SYS_FREE (sys_context, *incoming_ip);
 	  (*incoming_ip) = NULL;
 	}
     }
@@ -354,6 +334,7 @@ lw6net_recv_lines_udp (int sock, char **incoming_ip, int *incoming_port)
 /**
  * lw6net_send_line_udp:
  *
+ * @sys_context: global system context
  * @sock: the socket descriptor
  * @line: the line to be sent, without the "\n" at the end
  * @ip: the IP address of the target
@@ -366,7 +347,7 @@ lw6net_recv_lines_udp (int sock, char **incoming_ip, int *incoming_port)
  * Return value: the number of bytes sent, 0 if failure
  */
 int
-lw6net_send_line_udp (int sock, const char *line, const char *ip, int port)
+lw6net_send_line_udp (lw6sys_context_t * sys_context, int sock, const char *line, const char *ip, int port)
 {
   int ret = 0;
   int line_size = 0;
@@ -374,32 +355,25 @@ lw6net_send_line_udp (int sock, const char *line, const char *ip, int port)
   char *copied_line;
   char *trailed_line;
 
-  if (lw6net_socket_is_valid (sock) && line)
+  if (lw6net_socket_is_valid (sys_context, sock) && line)
     {
-      line_size =
-	lw6sys_imin (_lw6net_global_context->const_data.line_size,
-		     LW6NET_PPPOE_MTU - TRAIL_SIZE);
-      copied_line = lw6sys_str_copy (line);
+      line_size = lw6sys_imin (_lw6net_global_context->const_data.line_size, LW6NET_PPPOE_MTU - TRAIL_SIZE);
+      copied_line = lw6sys_str_copy (sys_context, line);
       if (copied_line)
 	{
 	  wanted_size = strlen (copied_line);
 	  if (wanted_size > line_size)
 	    {
-	      lw6sys_log (LW6SYS_LOG_WARNING,
-			  _x_
-			  ("stripping line \"%s\" of size %d, limit is %d"),
-			  copied_line, wanted_size, line_size);
-	      lw6sys_str_truncate (copied_line, line_size);
+	      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("stripping line \"%s\" of size %d, limit is %d"), copied_line, wanted_size, line_size);
+	      lw6sys_str_truncate (sys_context, copied_line, line_size);
 	    }
-	  trailed_line = lw6sys_str_concat (copied_line, trail);
+	  trailed_line = lw6sys_str_concat (sys_context, copied_line, trail);
 	  if (trailed_line)
 	    {
-	      ret =
-		lw6net_udp_send (sock, trailed_line,
-				 strlen (trailed_line), ip, port);
-	      LW6SYS_FREE (trailed_line);
+	      ret = lw6net_udp_send (sys_context, sock, trailed_line, strlen (trailed_line), ip, port);
+	      LW6SYS_FREE (sys_context, trailed_line);
 	    }
-	  LW6SYS_FREE (copied_line);
+	  LW6SYS_FREE (sys_context, copied_line);
 	}
     }
 
