@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -34,6 +34,7 @@ _lw6net_context_t *_lw6net_global_context = NULL;
 /**
  * lw6net_init
  *
+ * @sys_context: global system context
  * @argc: argc as passed to @main
  * @argv: argv as passed to @main
  * @net_log: 1 if you want to enable net log, 0 if not
@@ -45,14 +46,13 @@ _lw6net_context_t *_lw6net_global_context = NULL;
  * Return value: non-zero if success
  */
 int
-lw6net_init (int argc, const char *argv[], int net_log)
+lw6net_init (lw6sys_context_t * sys_context, int argc, const char *argv[], int net_log)
 {
   int ok = 0;
 
-  lw6sys_log (LW6SYS_LOG_INFO, _x_ ("net init"));
+  lw6sys_log (sys_context, LW6SYS_LOG_INFO, _x_ ("net init"));
 
-  _lw6net_global_context =
-    (_lw6net_context_t *) LW6SYS_CALLOC (sizeof (_lw6net_context_t));
+  _lw6net_global_context = (_lw6net_context_t *) LW6SYS_CALLOC (sys_context, sizeof (_lw6net_context_t));
   if (_lw6net_global_context)
     {
 #ifdef LW6_MS_WINDOWS
@@ -65,14 +65,12 @@ lw6net_init (int argc, const char *argv[], int net_log)
       err = WSAStartup (version_requested, &wsa_data);
       if (err == 0)
 	{
-	  lw6sys_log (LW6SYS_LOG_INFO, _x_ ("WSAStartup() OK, returned 0"));
+	  lw6sys_log (sys_context, LW6SYS_LOG_INFO, _x_ ("WSAStartup() OK, returned 0"));
 	  ok = 1;
 	}
       else
 	{
-	  lw6sys_log (LW6SYS_LOG_WARNING,
-		      _x_ ("WSAStartup() failed with code %d \"%s\""), err,
-		      _lw6net_wsa_str (err));
+	  lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("WSAStartup() failed with code %d \"%s\""), err, _lw6net_wsa_str (sys_context, err));
 	}
 #else
       /*
@@ -97,31 +95,20 @@ lw6net_init (int argc, const char *argv[], int net_log)
 	}
       else
 	{
-	  lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("signal() failed"));
+	  lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("signal() failed"));
 	}
 #endif
 
+      ok = ok && _lw6net_const_init (sys_context, argc, argv, &(_lw6net_global_context->const_data));
+      ok = ok && _lw6net_counters_init (sys_context, argc, argv, &(_lw6net_global_context->counters));
+      ok = ok && _lw6net_log_init (sys_context, argc, argv, &(_lw6net_global_context->log), net_log);
       ok = ok
-	&& _lw6net_const_init (argc, argv,
-			       &(_lw6net_global_context->const_data));
+	&& _lw6net_dns_init (sys_context, &(_lw6net_global_context->dns),
+			     _lw6net_global_context->const_data.dns_cache_hash_size, _lw6net_global_context->const_data.dns_cache_delay_sec);
       ok = ok
-	&& _lw6net_counters_init (argc, argv,
-				  &(_lw6net_global_context->counters));
-      ok = ok
-	&& _lw6net_log_init (argc, argv, &(_lw6net_global_context->log),
-			     net_log);
-      ok = ok
-	&& _lw6net_dns_init (&(_lw6net_global_context->dns),
-			     _lw6net_global_context->
-			     const_data.dns_cache_hash_size,
-			     _lw6net_global_context->
-			     const_data.dns_cache_delay_sec);
-      ok = ok
-	&& _lw6net_connectable_init (&(_lw6net_global_context->connectable),
-				     _lw6net_global_context->
-				     const_data.connectable_cache_hash_size,
-				     _lw6net_global_context->
-				     const_data.connectable_cache_delay_sec);
+	&& _lw6net_connectable_init (sys_context, &(_lw6net_global_context->connectable),
+				     _lw6net_global_context->const_data.connectable_cache_hash_size,
+				     _lw6net_global_context->const_data.connectable_cache_delay_sec);
     }
 
   if (!ok)
@@ -133,7 +120,7 @@ lw6net_init (int argc, const char *argv[], int net_log)
        */
       if (_lw6net_global_context)
 	{
-	  LW6SYS_FREE (_lw6net_global_context);
+	  LW6SYS_FREE (sys_context, _lw6net_global_context);
 	  _lw6net_global_context = NULL;
 	}
     }
@@ -144,15 +131,17 @@ lw6net_init (int argc, const char *argv[], int net_log)
 /**
  * lw6net_quit:
  *
+ * @sys_context: global system context
+ *
  * Frees memory, joins active threads, and releases everything
  * set up by network code.
  *
  * Return value: void
  */
 void
-lw6net_quit ()
+lw6net_quit (lw6sys_context_t * sys_context)
 {
-  lw6sys_log (LW6SYS_LOG_INFO, _x_ ("net quit"));
+  lw6sys_log (sys_context, LW6SYS_LOG_INFO, _x_ ("net quit"));
 
 #ifdef LW6_MS_WINDOWS
   WSACleanup ();
@@ -160,12 +149,12 @@ lw6net_quit ()
 
   if (_lw6net_global_context)
     {
-      _lw6net_connectable_quit (&(_lw6net_global_context->connectable));
-      _lw6net_dns_quit (&(_lw6net_global_context->dns));
-      _lw6net_log_quit (&(_lw6net_global_context->log));
-      _lw6net_counters_quit (&(_lw6net_global_context->counters));
-      _lw6net_const_quit (&(_lw6net_global_context->const_data));
-      LW6SYS_FREE (_lw6net_global_context);
+      _lw6net_connectable_quit (sys_context, &(_lw6net_global_context->connectable));
+      _lw6net_dns_quit (sys_context, &(_lw6net_global_context->dns));
+      _lw6net_log_quit (sys_context, &(_lw6net_global_context->log));
+      _lw6net_counters_quit (sys_context, &(_lw6net_global_context->counters));
+      _lw6net_const_quit (sys_context, &(_lw6net_global_context->const_data));
+      LW6SYS_FREE (sys_context, _lw6net_global_context);
     }
 
   _lw6net_global_context = NULL;
