@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -33,7 +33,7 @@
 #include "net-internal.h"
 
 void
-_lw6net_delay_msec_to_timeval (struct timeval *tv, int delay_msec)
+_lw6net_delay_msec_to_timeval (lw6sys_context_t * sys_context, struct timeval *tv, int delay_msec)
 {
   memset (tv, 0, sizeof (struct timeval));
 
@@ -44,6 +44,7 @@ _lw6net_delay_msec_to_timeval (struct timeval *tv, int delay_msec)
 /**
  * lw6net_tcp_listen
  *
+ * @sys_context: global system context
  * @ip: IP address to bind to
  * @port: IP port to listen on
  *
@@ -52,23 +53,23 @@ _lw6net_delay_msec_to_timeval (struct timeval *tv, int delay_msec)
  * Return value: >=0 on success, -1 on failure.
  */
 int
-lw6net_tcp_listen (const char *ip, int port)
+lw6net_tcp_listen (lw6sys_context_t * sys_context, const char *ip, int port)
 {
   int backlog;
   int sock = LW6NET_SOCKET_INVALID;
 
   backlog = _lw6net_global_context->const_data.listen_backlog;
 
-  sock = _lw6net_socket_bind (ip, port, SOCK_STREAM);
+  sock = _lw6net_socket_bind (sys_context, ip, port, SOCK_STREAM);
 
-  if (lw6net_socket_is_valid (sock))
+  if (lw6net_socket_is_valid (sys_context, sock))
     {
       if (listen (sock, backlog) < 0)
 	{
-	  lw6net_last_error ();
-	  lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("listen() failed"));
+	  lw6net_last_error (sys_context);
+	  lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("listen() failed"));
 
-	  lw6net_socket_close (&sock);
+	  lw6net_socket_close (sys_context, &sock);
 	}
     }
 
@@ -78,6 +79,7 @@ lw6net_tcp_listen (const char *ip, int port)
 /**
  * lw6net_tcp_accept
  *
+ * @sys_context: global system context
  * @incoming_ip: address of remote peer (out param, dynamically allocated)
  * @incoming_port: port of remote peer (out param)
  * @listening_sock: socket to listen on
@@ -88,8 +90,7 @@ lw6net_tcp_listen (const char *ip, int port)
  * Return value: the new socket (>=0) if accepted, else -1
  */
 int
-lw6net_tcp_accept (char **incoming_ip,
-		   int *incoming_port, int listening_sock, int delay_msec)
+lw6net_tcp_accept (lw6sys_context_t * sys_context, char **incoming_ip, int *incoming_port, int listening_sock, int delay_msec)
 {
   int new_sock = LW6NET_SOCKET_INVALID;
   int accepted = 0;
@@ -117,63 +118,52 @@ lw6net_tcp_accept (char **incoming_ip,
     {
       FD_ZERO (&read);
       FD_SET (listening_sock, &read);
-      _lw6net_delay_msec_to_timeval (&tv, delay_msec);
+      _lw6net_delay_msec_to_timeval (sys_context, &tv, delay_msec);
 
       res = select (listening_sock + 1, &read, NULL, NULL, &tv);
       if (res >= 1)
 	{
-	  new_sock =
-	    accept (listening_sock, (struct sockaddr *) &name, &namelen);
+	  new_sock = accept (listening_sock, (struct sockaddr *) &name, &namelen);
 	  if (new_sock >= 0)
 	    {
 	      li.l_onoff = 0;
 	      li.l_linger = 0;
 
-	      if (setsockopt (new_sock, SOL_SOCKET, SO_KEEPALIVE,
-			      (char *) &enable, sizeof (int)))
+	      if (setsockopt (new_sock, SOL_SOCKET, SO_KEEPALIVE, (char *) &enable, sizeof (int)))
 		{
-		  lw6net_last_error ();
-		  lw6sys_log (LW6SYS_LOG_WARNING,
-			      _x_ ("setsockopt(SO_KEEPALIVE) failed"));
+		  lw6net_last_error (sys_context);
+		  lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("setsockopt(SO_KEEPALIVE) failed"));
 		}
 	      /*
 	       * SO_NOSIGPIPE not defined on GNU/Linux, in that case
 	       * we use MSG_NOSIGNAL on send calls
 	       */
 #ifdef SO_NOSIGPIPE
-	      if (setsockopt (new_sock, SOL_SOCKET, SO_NOSIGPIPE,
-			      (char *) &enable, sizeof (int)))
+	      if (setsockopt (new_sock, SOL_SOCKET, SO_NOSIGPIPE, (char *) &enable, sizeof (int)))
 		{
-		  lw6net_last_error ();
-		  lw6sys_log (LW6SYS_LOG_WARNING,
-			      _x_ ("setsockopt(SO_NOSIGPIPE) failed"));
+		  lw6net_last_error (sys_context);
+		  lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("setsockopt(SO_NOSIGPIPE) failed"));
 		}
 #endif // SO_NOSIGPIPE
-	      if (setsockopt (new_sock, SOL_SOCKET, SO_OOBINLINE,
-			      (char *) &disable, sizeof (int)))
+	      if (setsockopt (new_sock, SOL_SOCKET, SO_OOBINLINE, (char *) &disable, sizeof (int)))
 		{
-		  lw6net_last_error ();
-		  lw6sys_log (LW6SYS_LOG_WARNING,
-			      _x_ ("setsockopt(SO_OOBINLINE) failed"));
+		  lw6net_last_error (sys_context);
+		  lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("setsockopt(SO_OOBINLINE) failed"));
 		}
-	      if (setsockopt (new_sock, SOL_SOCKET, SO_LINGER,
-			      (char *) &li, sizeof (struct linger)))
+	      if (setsockopt (new_sock, SOL_SOCKET, SO_LINGER, (char *) &li, sizeof (struct linger)))
 		{
-		  lw6net_last_error ();
-		  lw6sys_log (LW6SYS_LOG_WARNING,
-			      _x_ ("setsockopt(SO_LINGER) failed"));
+		  lw6net_last_error (sys_context);
+		  lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("setsockopt(SO_LINGER) failed"));
 		}
 
 	      //fcntl (new_sock, F_SETFL, O_NONBLOCK, 0);
 
 	      if (incoming_ip)
 		{
-		  (*incoming_ip) = _lw6net_inet_ntoa (name.sin_addr);
+		  (*incoming_ip) = _lw6net_inet_ntoa (sys_context, name.sin_addr);
 		  if (*incoming_ip)
 		    {
-		      _lw6net_counters_register_socket (&
-							(_lw6net_global_context->
-							 counters));
+		      _lw6net_counters_register_socket (sys_context, &(_lw6net_global_context->counters));
 		      accepted = 1;
 		    }
 		}
@@ -182,18 +172,15 @@ lw6net_tcp_accept (char **incoming_ip,
 		  (*incoming_port) = (int) ntohs (name.sin_port);
 		}
 
-	      if (incoming_ip && incoming_port && *incoming_ip
-		  && (*incoming_port) >= 0)
+	      if (incoming_ip && incoming_port && *incoming_ip && (*incoming_port) >= 0)
 		{
-		  lw6sys_log (LW6SYS_LOG_INFO,
-			      _x_ ("socket %d accepted from %s:%d"), new_sock,
-			      *incoming_ip, *incoming_port);
+		  lw6sys_log (sys_context, LW6SYS_LOG_INFO, _x_ ("socket %d accepted from %s:%d"), new_sock, *incoming_ip, *incoming_port);
 		}
 	    }
 	  else
 	    {
-	      lw6net_last_error ();
-	      lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("accept() failed"));
+	      lw6net_last_error (sys_context);
+	      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("accept() failed"));
 	    }
 
 	}
@@ -205,7 +192,7 @@ lw6net_tcp_accept (char **incoming_ip,
 	{
 	  if (*incoming_ip)
 	    {
-	      LW6SYS_FREE (*incoming_ip);
+	      LW6SYS_FREE (sys_context, *incoming_ip);
 	    }
 	  (*incoming_ip) = NULL;
 	}
@@ -219,8 +206,8 @@ lw6net_tcp_accept (char **incoming_ip,
       if (close (new_sock))
 #endif
 	{
-	  lw6net_last_error ();
-	  lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("close() failed"));
+	  lw6net_last_error (sys_context);
+	  lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("close() failed"));
 	}
       new_sock = LW6NET_SOCKET_INVALID;
     }
@@ -231,6 +218,7 @@ lw6net_tcp_accept (char **incoming_ip,
 /**
  * lw6net_tcp_connect
  *
+ * @sys_context: global system context
  * @ip: address to connect to
  * @port: port to connect to
  * @delay_msec: delay before we consider it's too late
@@ -240,7 +228,7 @@ lw6net_tcp_accept (char **incoming_ip,
  * Return value: socket (>=0) on success, else -1
  */
 int
-lw6net_tcp_connect (const char *ip, int port, int delay_msec)
+lw6net_tcp_connect (lw6sys_context_t * sys_context, const char *ip, int port, int delay_msec)
 {
   int sock = LW6NET_SOCKET_INVALID;
   int connect_ret = 0;
@@ -262,12 +250,12 @@ lw6net_tcp_connect (const char *ip, int port, int delay_msec)
   socklen_t getpeername_address_len = sizeof (struct sockaddr);
 #endif
 
-  if (lw6net_is_connectable (ip, port))
+  if (lw6net_is_connectable (sys_context, ip, port))
     {
       sock = socket (AF_INET, SOCK_STREAM, 0);
       if (sock >= 0)
 	{
-	  if (lw6net_socket_set_blocking_mode (sock, 0))
+	  if (lw6net_socket_set_blocking_mode (sys_context, sock, 0))
 	    {
 	      name.sin_family = AF_INET;
 	      name.sin_addr.s_addr = INADDR_ANY;
@@ -275,15 +263,13 @@ lw6net_tcp_connect (const char *ip, int port, int delay_msec)
 	      if (bind (sock, (struct sockaddr *) &name, sizeof (name)) >= 0)
 		{
 		  name.sin_family = AF_INET;
-		  if (_lw6net_inet_aton (&name.sin_addr, ip))
+		  if (_lw6net_inet_aton (sys_context, &name.sin_addr, ip))
 		    {
 		      name.sin_port = htons (port);
-		      connect_ret =
-			connect (sock, (struct sockaddr *) &name,
-				 sizeof (name));
+		      connect_ret = connect (sock, (struct sockaddr *) &name, sizeof (name));
 		      if (connect_ret >= 0)
 			{
-			  lw6sys_log (LW6SYS_LOG_WARNING,
+			  lw6sys_log (sys_context, LW6SYS_LOG_WARNING,
 				      _x_
 				      ("connect on \"%s:%d\" returned with a successfull code %d, this is very strange since we should be in non-blocking mode"),
 				      ip, port, connect_ret);
@@ -310,17 +296,12 @@ lw6net_tcp_connect (const char *ip, int port, int delay_msec)
 			       */
 			    case WSAEHOSTUNREACH:
 			    case WSAEHOSTDOWN:
-			      lw6sys_log (LW6SYS_LOG_INFO,
-					  _x_
-					  ("can't connect on \"%s:%d\", host unreachable or down"),
-					  ip, port);
+			      lw6sys_log (sys_context, LW6SYS_LOG_INFO, _x_ ("can't connect on \"%s:%d\", host unreachable or down"), ip, port);
 			      break;
 			    default:
-			      lw6net_last_error ();
-			      lw6sys_log (LW6SYS_LOG_WARNING,
-					  _x_
-					  ("connect on \"%s:%d\" failed, did not return WSAEINPROGRESS or WSAEWOULDBLOCK (code=%d)"),
-					  ip, port, winerr);
+			      lw6net_last_error (sys_context);
+			      lw6sys_log (sys_context, LW6SYS_LOG_WARNING,
+					  _x_ ("connect on \"%s:%d\" failed, did not return WSAEINPROGRESS or WSAEWOULDBLOCK (code=%d)"), ip, port, winerr);
 			    }
 #else
 			  switch (errno)
@@ -346,33 +327,24 @@ lw6net_tcp_connect (const char *ip, int port, int delay_msec)
 			       */
 			    case EHOSTUNREACH:
 			    case EHOSTDOWN:
-			      lw6sys_log (LW6SYS_LOG_INFO,
-					  _x_
-					  ("can't connect on \"%s:%d\", host unreachable or down"),
-					  ip, port);
+			      lw6sys_log (sys_context, LW6SYS_LOG_INFO, _x_ ("can't connect on \"%s:%d\", host unreachable or down"), ip, port);
 			      break;
 			    default:
-			      lw6net_last_error ();
-			      lw6sys_log (LW6SYS_LOG_WARNING,
-					  _x_
-					  ("connect on \"%s:%d\" failed, did not return EINPROGRESS or EWOULDBLOCK (code=%d)"),
-					  ip, port, errno);
+			      lw6net_last_error (sys_context);
+			      lw6sys_log (sys_context, LW6SYS_LOG_WARNING,
+					  _x_ ("connect on \"%s:%d\" failed, did not return EINPROGRESS or EWOULDBLOCK (code=%d)"), ip, port, errno);
 			    }
 #endif
 			  if (connect_async)
 			    {
 			      FD_ZERO (&write);
 			      FD_SET (sock, &write);
-			      _lw6net_delay_msec_to_timeval (&tv, delay_msec);
+			      _lw6net_delay_msec_to_timeval (sys_context, &tv, delay_msec);
 
-			      origin = lw6sys_get_timestamp ();
-			      while (!connected && !refused
-				     && (lw6sys_get_timestamp () <
-					 (origin + delay_msec)))
+			      origin = lw6sys_get_timestamp (sys_context);
+			      while (!connected && !refused && (lw6sys_get_timestamp (sys_context) < (origin + delay_msec)))
 				{
-				  select_ret =
-				    select (sock + 1, NULL, &write, NULL,
-					    &tv);
+				  select_ret = select (sock + 1, NULL, &write, NULL, &tv);
 
 				  if (select_ret > 0)
 				    {
@@ -391,28 +363,18 @@ lw6net_tcp_connect (const char *ip, int port, int delay_msec)
 					   * (at least on GNU/Linux) tell
 					   * something is wrong.
 					   */
-					  memset (&getpeername_address, 0,
-						  getpeername_address_len);
-					  if (!getpeername
-					      (sock, &getpeername_address,
-					       &getpeername_address_len))
+					  memset (&getpeername_address, 0, getpeername_address_len);
+					  if (!getpeername (sock, &getpeername_address, &getpeername_address_len))
 					    {
 					      /*
 					       * SO_NOSIGPIPE not defined on GNU/Linux, in that case
 					       * we use MSG_NOSIGNAL on send calls
 					       */
 #ifdef SO_NOSIGPIPE
-					      if (setsockopt
-						  (sock, SOL_SOCKET,
-						   SO_NOSIGPIPE,
-						   (char *) &enable,
-						   sizeof (int)))
+					      if (setsockopt (sock, SOL_SOCKET, SO_NOSIGPIPE, (char *) &enable, sizeof (int)))
 						{
-						  lw6net_last_error ();
-						  lw6sys_log
-						    (LW6SYS_LOG_WARNING,
-						     _x_
-						     ("setsockopt(SO_NOSIGPIPE) failed"));
+						  lw6net_last_error (sys_context);
+						  lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("setsockopt(SO_NOSIGPIPE) failed"));
 						}
 #endif // SO_NOSIGPIPE
 
@@ -420,20 +382,16 @@ lw6net_tcp_connect (const char *ip, int port, int delay_msec)
 					    }
 					  else
 					    {
-					      lw6sys_log (LW6SYS_LOG_INFO,
-							  _x_
-							  ("async connect on \"%s:%d\" failed, getpeername didn't return 0 as expected"),
-							  ip, port);
+					      lw6sys_log (sys_context,
+							  LW6SYS_LOG_INFO,
+							  _x_ ("async connect on \"%s:%d\" failed, getpeername didn't return 0 as expected"), ip, port);
 					      refused = 1;
 					    }
 #endif
 					}
 				      else
 					{
-					  lw6sys_log (LW6SYS_LOG_INFO,
-						      _x_
-						      ("async connect on \"%s:%d\" failed, FD_ISSET returned 0"),
-						      ip, port);
+					  lw6sys_log (sys_context, LW6SYS_LOG_INFO, _x_ ("async connect on \"%s:%d\" failed, FD_ISSET returned 0"), ip, port);
 					  refused = 1;
 					}
 				    }
@@ -444,19 +402,16 @@ lw6net_tcp_connect (const char *ip, int port, int delay_msec)
 		}
 	      else
 		{
-		  lw6net_last_error ();
-		  lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("bind() failed"));
+		  lw6net_last_error (sys_context);
+		  lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("bind() failed"));
 		}
 	    }
 	}
       if (connected)
 	{
-	  lw6sys_log (LW6SYS_LOG_INFO,
-		      _x_ ("socket %d connected on %s:%d"), sock, ip, port);
+	  lw6sys_log (sys_context, LW6SYS_LOG_INFO, _x_ ("socket %d connected on %s:%d"), sock, ip, port);
 
-	  _lw6net_counters_register_socket (&
-					    (_lw6net_global_context->
-					     counters));
+	  _lw6net_counters_register_socket (sys_context, &(_lw6net_global_context->counters));
 	}
       else
 	{
@@ -466,23 +421,20 @@ lw6net_tcp_connect (const char *ip, int port, int delay_msec)
 	   * often, we certainly don't want this to fill our
 	   * log...
 	   */
-	  lw6net_set_connectable (ip, port, 0);
+	  lw6net_set_connectable (sys_context, ip, port, 0);
 	}
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_INFO,
-		  _x_
-		  ("destination %s:%d already marked as not connectable, not even trying to connect to it"),
-		  ip, port);
+      lw6sys_log (sys_context, LW6SYS_LOG_INFO, _x_ ("destination %s:%d already marked as not connectable, not even trying to connect to it"), ip, port);
     }
 
-  if (lw6net_socket_is_valid (sock) && !connected)
+  if (lw6net_socket_is_valid (sys_context, sock) && !connected)
     {
       if (close (sock))
 	{
-	  lw6net_last_error ();
-	  lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("close() failed"));
+	  lw6net_last_error (sys_context);
+	  lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("close() failed"));
 	}
       sock = LW6NET_SOCKET_INVALID;
     }
@@ -493,6 +445,7 @@ lw6net_tcp_connect (const char *ip, int port, int delay_msec)
 /**
  * lw6net_tcp_send
  *
+ * @sys_context: global system context
  * @sock: socket to use
  * @buf: data buffer
  * @len: data buffer length
@@ -506,8 +459,7 @@ lw6net_tcp_connect (const char *ip, int port, int delay_msec)
  * Return value: 1 on success, 0 on failure.
  */
 int
-lw6net_tcp_send (int *sock, const char *buf, int len, int delay_msec,
-		 int loop)
+lw6net_tcp_send (lw6sys_context_t * sys_context, int *sock, const char *buf, int len, int delay_msec, int loop)
 {
   int ret = 0;
   fd_set write;
@@ -535,7 +487,7 @@ lw6net_tcp_send (int *sock, const char *buf, int len, int delay_msec,
   int try_again = 0;
   int64_t limit_timestamp = 0LL;
 
-  if (lw6net_socket_is_valid (*sock))
+  if (lw6net_socket_is_valid (sys_context, *sock))
     {
       ret = 1;
 
@@ -547,7 +499,7 @@ lw6net_tcp_send (int *sock, const char *buf, int len, int delay_msec,
 
 	  FD_ZERO (&write);
 	  FD_SET (*sock, &write);
-	  _lw6net_delay_msec_to_timeval (&tv, delay_msec);
+	  _lw6net_delay_msec_to_timeval (sys_context, &tv, delay_msec);
 
 	  select_ret = select ((*sock) + 1, NULL, &write, NULL, &tv);
 
@@ -557,23 +509,17 @@ lw6net_tcp_send (int *sock, const char *buf, int len, int delay_msec,
 	      winerr = WSAGetLastError ();
 	      if (winerr != WSAEINTR && winerr != WSAENOBUFS)
 		{
-		  lw6net_last_error ();
-		  lw6sys_log (LW6SYS_LOG_INFO,
-			      _x_
-			      ("error sending data on socket %d select() failed, code=%d"),
-			      *sock, winerr);
-		  lw6net_socket_close (sock);
+		  lw6net_last_error (sys_context);
+		  lw6sys_log (sys_context, LW6SYS_LOG_INFO, _x_ ("error sending data on socket %d select() failed, code=%d"), *sock, winerr);
+		  lw6net_socket_close (sys_context, sock);
 		  ret = 0;
 		}
 #else
 	      if (errno != EINTR && errno != ENOBUFS)
 		{
-		  lw6net_last_error ();
-		  lw6sys_log (LW6SYS_LOG_INFO,
-			      _x_
-			      ("error sending data on socket %d select() failed"),
-			      *sock);
-		  lw6net_socket_close (sock);
+		  lw6net_last_error (sys_context);
+		  lw6sys_log (sys_context, LW6SYS_LOG_INFO, _x_ ("error sending data on socket %d select() failed"), *sock);
+		  lw6net_socket_close (sys_context, sock);
 		  ret = 0;
 		}
 #endif
@@ -590,15 +536,10 @@ lw6net_tcp_send (int *sock, const char *buf, int len, int delay_msec,
 	    {
 	      if (FD_ISSET (*sock, &write))
 		{
-		  sent = send (*sock,
-			       buf + total_sent,
-			       lw6sys_imin (len - total_sent, chunk_size),
-			       flags);
+		  sent = send (*sock, buf + total_sent, lw6sys_imin (len - total_sent, chunk_size), flags);
 		  if (sent > 0 && sent <= len - total_sent)
 		    {
-		      lw6sys_log (LW6SYS_LOG_DEBUG,
-				  _x_ ("%d bytes sent on TCP socket %d"),
-				  sent, *sock);
+		      lw6sys_log (sys_context, LW6SYS_LOG_DEBUG, _x_ ("%d bytes sent on TCP socket %d"), sent, *sock);
 		      total_sent += sent;
 		    }
 		  else
@@ -607,27 +548,19 @@ lw6net_tcp_send (int *sock, const char *buf, int len, int delay_msec,
 			{
 #ifdef LW6_MS_WINDOWS
 			  winerr = WSAGetLastError ();
-			  if (winerr != WSAEINTR && winerr != WSAENOBUFS
-			      && winerr != WSAEWOULDBLOCK)
+			  if (winerr != WSAEINTR && winerr != WSAENOBUFS && winerr != WSAEWOULDBLOCK)
 			    {
-			      lw6net_last_error ();
-			      lw6sys_log (LW6SYS_LOG_INFO,
-					  _x_
-					  ("can't send data on socket %d send() failed, code=%d"),
-					  *sock, winerr);
-			      lw6net_socket_close (sock);
+			      lw6net_last_error (sys_context);
+			      lw6sys_log (sys_context, LW6SYS_LOG_INFO, _x_ ("can't send data on socket %d send() failed, code=%d"), *sock, winerr);
+			      lw6net_socket_close (sys_context, sock);
 			      ret = 0;
 			    }
 #else
-			  if (errno != EINTR && errno != ENOBUFS
-			      && errno != EAGAIN && errno != EWOULDBLOCK)
+			  if (errno != EINTR && errno != ENOBUFS && errno != EAGAIN && errno != EWOULDBLOCK)
 			    {
-			      lw6net_last_error ();
-			      lw6sys_log (LW6SYS_LOG_INFO,
-					  _x_
-					  ("can't send data on socket %d send() failed"),
-					  *sock);
-			      lw6net_socket_close (sock);
+			      lw6net_last_error (sys_context);
+			      lw6sys_log (sys_context, LW6SYS_LOG_INFO, _x_ ("can't send data on socket %d send() failed"), *sock);
+			      lw6net_socket_close (sys_context, sock);
 			      ret = 0;
 			    }
 #endif
@@ -645,18 +578,13 @@ lw6net_tcp_send (int *sock, const char *buf, int len, int delay_msec,
 		}
 	      else
 		{
-		  lw6sys_log (LW6SYS_LOG_DEBUG,
-			      _x_
-			      ("socket %d is not writeable, it's very likely that TCP system buffer is full"),
-			      *sock);
+		  lw6sys_log (sys_context, LW6SYS_LOG_DEBUG, _x_ ("socket %d is not writeable, it's very likely that TCP system buffer is full"), *sock);
 		}
 	    }
 
 	  if ((!loop) && (!try_again) && (total_sent != len))
 	    {
-	      lw6sys_log (LW6SYS_LOG_DEBUG,
-			  _x_ ("can't send data on socket %d (%d/%d)"), *sock,
-			  total_sent, len);
+	      lw6sys_log (sys_context, LW6SYS_LOG_DEBUG, _x_ ("can't send data on socket %d (%d/%d)"), *sock, total_sent, len);
 	      ret = 0;
 	    }
 
@@ -672,16 +600,14 @@ lw6net_tcp_send (int *sock, const char *buf, int len, int delay_msec,
 	    {
 	      if (limit_timestamp == 0LL)
 		{
-		  limit_timestamp = lw6sys_get_timestamp () + delay_msec;
+		  limit_timestamp = lw6sys_get_timestamp (sys_context) + delay_msec;
 		}
 	      else
 		{
-		  if (lw6sys_get_timestamp () > limit_timestamp)
+		  if (lw6sys_get_timestamp (sys_context) > limit_timestamp)
 		    {
-		      lw6sys_log (LW6SYS_LOG_INFO,
-				  _x_
-				  ("timeout on socket %d, could only send %d bytes out of %d in %d msec"),
-				  *sock, total_sent, len, delay_msec);
+		      lw6sys_log (sys_context, LW6SYS_LOG_INFO,
+				  _x_ ("timeout on socket %d, could only send %d bytes out of %d in %d msec"), *sock, total_sent, len, delay_msec);
 		      ret = 0;
 		    }
 		}
@@ -690,11 +616,8 @@ lw6net_tcp_send (int *sock, const char *buf, int len, int delay_msec,
 
       if (total_sent > 0)
 	{
-	  _lw6net_counters_register_send (&
-					  (_lw6net_global_context->counters),
-					  total_sent);
-	  _lw6net_log_tcp_send (&(_lw6net_global_context->log),
-				buf, total_sent);
+	  _lw6net_counters_register_send (sys_context, &(_lw6net_global_context->counters), total_sent);
+	  _lw6net_log_tcp_send (sys_context, &(_lw6net_global_context->log), buf, total_sent);
 	}
     }
 
@@ -704,6 +627,7 @@ lw6net_tcp_send (int *sock, const char *buf, int len, int delay_msec,
 /**
  * lw6net_tcp_peek
  *
+ * @sys_context: global system context
  * @sock: socket to use
  * @buf: data buffer
  * @len: data buffer length
@@ -717,7 +641,7 @@ lw6net_tcp_send (int *sock, const char *buf, int len, int delay_msec,
  * Return value: number of bytes available, 0 when nothing
  */
 int
-lw6net_tcp_peek (int *sock, char *buf, int len, int delay_msec)
+lw6net_tcp_peek (lw6sys_context_t * sys_context, int *sock, char *buf, int len, int delay_msec)
 {
   fd_set read;
   struct timeval tv;
@@ -749,13 +673,13 @@ lw6net_tcp_peek (int *sock, char *buf, int len, int delay_msec)
 	}
       else
 	{
-	  buf2 = (char *) LW6SYS_MALLOC (len);
+	  buf2 = (char *) LW6SYS_MALLOC (sys_context, len);
 	}
       if (buf2)
 	{
 	  FD_ZERO (&read);
 	  FD_SET (*sock, &read);
-	  _lw6net_delay_msec_to_timeval (&tv, delay_msec);
+	  _lw6net_delay_msec_to_timeval (sys_context, &tv, delay_msec);
 
 	  select_ret = select ((*sock) + 1, &read, NULL, NULL, &tv);
 
@@ -765,20 +689,14 @@ lw6net_tcp_peek (int *sock, char *buf, int len, int delay_msec)
 	      winerr = WSAGetLastError ();
 	      if (winerr != WSAEINTR)
 		{
-		  lw6net_last_error ();
-		  lw6sys_log (LW6SYS_LOG_INFO,
-			      _x_
-			      ("error peeking data on socket %d select() failed, code=%d"),
-			      *sock, winerr);
+		  lw6net_last_error (sys_context);
+		  lw6sys_log (sys_context, LW6SYS_LOG_INFO, _x_ ("error peeking data on socket %d select() failed, code=%d"), *sock, winerr);
 		}
 #else
 	      if (errno != EINTR)
 		{
-		  lw6net_last_error ();
-		  lw6sys_log (LW6SYS_LOG_INFO,
-			      _x_
-			      ("error peeking data on socket %d select() failed"),
-			      *sock);
+		  lw6net_last_error (sys_context);
+		  lw6sys_log (sys_context, LW6SYS_LOG_INFO, _x_ ("error peeking data on socket %d select() failed"), *sock);
 		}
 #endif
 	    }
@@ -789,9 +707,7 @@ lw6net_tcp_peek (int *sock, char *buf, int len, int delay_msec)
 		  available = recv (*sock, buf2, len, flags);
 		  if (available >= 0)
 		    {
-		      lw6sys_log (LW6SYS_LOG_DEBUG,
-				  _x_ ("%d bytes available on TCP socket %d"),
-				  available, *sock);
+		      lw6sys_log (sys_context, LW6SYS_LOG_DEBUG, _x_ ("%d bytes available on TCP socket %d"), available, *sock);
 		    }
 		  else
 		    {
@@ -801,23 +717,16 @@ lw6net_tcp_peek (int *sock, char *buf, int len, int delay_msec)
 			  winerr = WSAGetLastError ();
 			  if (winerr != WSAEINTR && winerr != WSAEWOULDBLOCK)
 			    {
-			      lw6net_last_error ();
-			      lw6sys_log (LW6SYS_LOG_INFO,
-					  _x_
-					  ("can't peek data on socket %d, code=%d"),
-					  *sock, winerr);
-			      lw6net_socket_close (sock);
+			      lw6net_last_error (sys_context);
+			      lw6sys_log (sys_context, LW6SYS_LOG_INFO, _x_ ("can't peek data on socket %d, code=%d"), *sock, winerr);
+			      lw6net_socket_close (sys_context, sock);
 			    }
 #else
-			  if (errno != EINTR
-			      && errno != EAGAIN && errno != EWOULDBLOCK)
+			  if (errno != EINTR && errno != EAGAIN && errno != EWOULDBLOCK)
 			    {
-			      lw6net_last_error ();
-			      lw6sys_log (LW6SYS_LOG_INFO,
-					  _x_
-					  ("can't peek data on socket %d"),
-					  *sock);
-			      lw6net_socket_close (sock);
+			      lw6net_last_error (sys_context);
+			      lw6sys_log (sys_context, LW6SYS_LOG_INFO, _x_ ("can't peek data on socket %d"), *sock);
+			      lw6net_socket_close (sys_context, sock);
 			    }
 #endif
 			}
@@ -827,7 +736,7 @@ lw6net_tcp_peek (int *sock, char *buf, int len, int delay_msec)
 
 	  if (!buf)
 	    {
-	      LW6SYS_FREE (buf2);
+	      LW6SYS_FREE (sys_context, buf2);
 	    }
 	}
     }
@@ -843,6 +752,7 @@ lw6net_tcp_peek (int *sock, char *buf, int len, int delay_msec)
 /**
  * lw6net_tcp_recv
  *
+ * @sys_context: global system context
  * @sock: socket to use
  * @buf: data buffer
  * @len: data buffer length
@@ -857,7 +767,7 @@ lw6net_tcp_peek (int *sock, char *buf, int len, int delay_msec)
  * Return value: number of bytes received, 0 when nothing
  */
 int
-lw6net_tcp_recv (int *sock, char *buf, int len, int delay_msec, int loop)
+lw6net_tcp_recv (lw6sys_context_t * sys_context, int *sock, char *buf, int len, int delay_msec, int loop)
 {
   int ret = 0;
   fd_set read;
@@ -883,7 +793,7 @@ lw6net_tcp_recv (int *sock, char *buf, int len, int delay_msec, int loop)
   int flags = 0;
 #endif
 
-  if (lw6net_socket_is_valid (*sock))
+  if (lw6net_socket_is_valid (sys_context, *sock))
     {
       ret = 1;
       chunk_size = _lw6net_global_context->const_data.chunk_size;
@@ -893,7 +803,7 @@ lw6net_tcp_recv (int *sock, char *buf, int len, int delay_msec, int loop)
 	{
 	  FD_ZERO (&read);
 	  FD_SET (*sock, &read);
-	  _lw6net_delay_msec_to_timeval (&tv, delay_msec);
+	  _lw6net_delay_msec_to_timeval (sys_context, &tv, delay_msec);
 
 	  select_ret = select ((*sock) + 1, &read, NULL, NULL, &tv);
 
@@ -903,21 +813,15 @@ lw6net_tcp_recv (int *sock, char *buf, int len, int delay_msec, int loop)
 	      winerr = WSAGetLastError ();
 	      if (winerr != WSAEINTR)
 		{
-		  lw6net_last_error ();
-		  lw6sys_log (LW6SYS_LOG_INFO,
-			      _x_
-			      ("error receiving data on socket %d select() failed, code=%d"),
-			      *sock, winerr);
+		  lw6net_last_error (sys_context);
+		  lw6sys_log (sys_context, LW6SYS_LOG_INFO, _x_ ("error receiving data on socket %d select() failed, code=%d"), *sock, winerr);
 		  ret = 0;
 		}
 #else
 	      if (errno != EINTR)
 		{
-		  lw6net_last_error ();
-		  lw6sys_log (LW6SYS_LOG_INFO,
-			      _x_
-			      ("error receiving data on socket %d select() failed"),
-			      *sock);
+		  lw6net_last_error (sys_context);
+		  lw6sys_log (sys_context, LW6SYS_LOG_INFO, _x_ ("error receiving data on socket %d select() failed"), *sock);
 		  ret = 0;
 		}
 #endif
@@ -926,15 +830,10 @@ lw6net_tcp_recv (int *sock, char *buf, int len, int delay_msec, int loop)
 	    {
 	      if (FD_ISSET (*sock, &read))
 		{
-		  received = recv (*sock,
-				   buf + total_received,
-				   lw6sys_imin (len - total_received,
-						chunk_size), flags);
+		  received = recv (*sock, buf + total_received, lw6sys_imin (len - total_received, chunk_size), flags);
 		  if (received > 0 && received <= len - total_received)
 		    {
-		      lw6sys_log (LW6SYS_LOG_DEBUG,
-				  _x_ ("%d bytes received on TCP socket %d"),
-				  received, *sock);
+		      lw6sys_log (sys_context, LW6SYS_LOG_DEBUG, _x_ ("%d bytes received on TCP socket %d"), received, *sock);
 		      total_received += received;
 		    }
 		  else
@@ -945,24 +844,17 @@ lw6net_tcp_recv (int *sock, char *buf, int len, int delay_msec, int loop)
 			  winerr = WSAGetLastError ();
 			  if (winerr != WSAEINTR && winerr != WSAEWOULDBLOCK)
 			    {
-			      lw6net_last_error ();
-			      lw6sys_log (LW6SYS_LOG_INFO,
-					  _x_
-					  ("can't recv data on socket %d, code=%d"),
-					  *sock, winerr);
-			      lw6net_socket_close (sock);
+			      lw6net_last_error (sys_context);
+			      lw6sys_log (sys_context, LW6SYS_LOG_INFO, _x_ ("can't recv data on socket %d, code=%d"), *sock, winerr);
+			      lw6net_socket_close (sys_context, sock);
 			      ret = 0;
 			    }
 #else
-			  if (errno != EINTR
-			      && errno != EAGAIN && errno != EWOULDBLOCK)
+			  if (errno != EINTR && errno != EAGAIN && errno != EWOULDBLOCK)
 			    {
-			      lw6net_last_error ();
-			      lw6sys_log (LW6SYS_LOG_INFO,
-					  _x_
-					  ("can't recv data on socket %d"),
-					  *sock);
-			      lw6net_socket_close (sock);
+			      lw6net_last_error (sys_context);
+			      lw6sys_log (sys_context, LW6SYS_LOG_INFO, _x_ ("can't recv data on socket %d"), *sock);
+			      lw6net_socket_close (sys_context, sock);
 			      ret = 0;
 			    }
 #endif
@@ -974,20 +866,15 @@ lw6net_tcp_recv (int *sock, char *buf, int len, int delay_msec, int loop)
 
 	  if ((!loop) && (total_received != len))
 	    {
-	      lw6sys_log (LW6SYS_LOG_INFO,
-			  _x_ ("can't recv data on socket %d (%d/%d)"), *sock,
-			  total_received, len);
+	      lw6sys_log (sys_context, LW6SYS_LOG_INFO, _x_ ("can't recv data on socket %d (%d/%d)"), *sock, total_received, len);
 	      ret = 0;
 	    }
 	}
 
       if (total_received > 0)
 	{
-	  _lw6net_counters_register_recv (&
-					  (_lw6net_global_context->counters),
-					  total_received);
-	  _lw6net_log_tcp_recv (&(_lw6net_global_context->log),
-				buf, total_received);
+	  _lw6net_counters_register_recv (sys_context, &(_lw6net_global_context->counters), total_received);
+	  _lw6net_log_tcp_recv (sys_context, &(_lw6net_global_context->log), buf, total_received);
 	}
     }
 
@@ -997,6 +884,7 @@ lw6net_tcp_recv (int *sock, char *buf, int len, int delay_msec, int loop)
 /**
  * lw6net_tcp_is_alive
  *
+ * @sys_context: global system context
  * @sock: socket to test
  *
  * Tells wether a socket is alive and able to send data. This function
@@ -1006,7 +894,7 @@ lw6net_tcp_recv (int *sock, char *buf, int len, int delay_msec, int loop)
  * Return value: 1 if alive, 0 if not.
  */
 int
-lw6net_tcp_is_alive (int *sock)
+lw6net_tcp_is_alive (lw6sys_context_t * sys_context, int *sock)
 {
   int ret = 0;
   fd_set write;
@@ -1016,7 +904,7 @@ lw6net_tcp_is_alive (int *sock)
   int winerr = 0;
 #endif
 
-  if (lw6net_socket_is_valid (*sock))
+  if (lw6net_socket_is_valid (sys_context, *sock))
     {
       ret = 1;
 
@@ -1037,11 +925,9 @@ lw6net_tcp_is_alive (int *sock)
 #endif
 	    {
 	      // socket is closed...
-	      lw6net_last_error ();
-	      lw6sys_log (LW6SYS_LOG_INFO,
-			  _x_ ("closing socket %d because select failed"),
-			  *sock);
-	      lw6net_socket_close (sock);
+	      lw6net_last_error (sys_context);
+	      lw6sys_log (sys_context, LW6SYS_LOG_INFO, _x_ ("closing socket %d because select failed"), *sock);
+	      lw6net_socket_close (sys_context, sock);
 	      ret = 0;
 	    }
 	}
@@ -1053,11 +939,8 @@ lw6net_tcp_is_alive (int *sock)
 	    }
 	  else
 	    {
-	      lw6net_last_error ();
-	      lw6sys_log (LW6SYS_LOG_DEBUG,
-			  _x_
-			  ("socket %d is not writeable, it's very likely that TCP system buffer is full"),
-			  *sock);
+	      lw6net_last_error (sys_context);
+	      lw6sys_log (sys_context, LW6SYS_LOG_DEBUG, _x_ ("socket %d is not writeable, it's very likely that TCP system buffer is full"), *sock);
 	      /*
 	       * Here, we don't mark the "alive" flag (ret) as
 	       * not alive, as a filled buffer is not a good enough
