@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -35,55 +35,53 @@
 /**
  * lw6net_udp_client
  *
+ * @sys_context: global system context
+ *
  * Creates an UDP client socket, that is, creates it and does
  * not bind it to any address.
  *
  * Return value: socket (>=0) on success, else -1
  */
 int
-lw6net_udp_client ()
+lw6net_udp_client (lw6sys_context_t * sys_context)
 {
   int sock = -1;
   int enable = 1;
 
   sock = socket (AF_INET, SOCK_DGRAM, 0);
 
-  sock = (lw6net_socket_is_valid (sock)) ? sock : LW6NET_SOCKET_INVALID;
+  sock = (lw6net_socket_is_valid (sys_context, sock)) ? sock : LW6NET_SOCKET_INVALID;
 
-  if (lw6net_socket_is_valid (sock))
+  if (lw6net_socket_is_valid (sys_context, sock))
     {
-      lw6sys_log (LW6SYS_LOG_INFO, _x_ ("new UDP socket %d"), sock);
+      lw6sys_log (sys_context, LW6SYS_LOG_INFO, _x_ ("new UDP socket %d"), sock);
 
-      _lw6net_counters_register_socket (&(_lw6net_global_context->counters));
+      _lw6net_counters_register_socket (sys_context, &(_lw6net_global_context->counters));
 
-      if (setsockopt (sock, SOL_SOCKET, SO_BROADCAST,
-		      (char *) &enable, sizeof (int)))
+      if (setsockopt (sock, SOL_SOCKET, SO_BROADCAST, (char *) &enable, sizeof (int)))
 	{
-	  lw6sys_log (LW6SYS_LOG_WARNING,
-		      _x_ ("setsockopt(SO_BROADCAST) failed"));
-	  lw6net_last_error ();
+	  lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("setsockopt(SO_BROADCAST) failed"));
+	  lw6net_last_error (sys_context);
 	}
       /*
        * SO_NOSIGPIPE not defined on GNU/Linux, in that case
        * we use MSG_NOSIGNAL on send calls
        */
 #ifdef SO_NOSIGPIPE
-      if (setsockopt (sock, SOL_SOCKET, SO_NOSIGPIPE,
-		      (char *) &enable, sizeof (int)))
+      if (setsockopt (sock, SOL_SOCKET, SO_NOSIGPIPE, (char *) &enable, sizeof (int)))
 	{
-	  lw6net_last_error ();
-	  lw6sys_log (LW6SYS_LOG_WARNING,
-		      _x_ ("setsockopt(SO_NOSIGPIPE) failed"));
+	  lw6net_last_error (sys_context);
+	  lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("setsockopt(SO_NOSIGPIPE) failed"));
 	}
 #endif // SO_NOSIGPIPE
 
-      if (lw6net_socket_set_blocking_mode (sock, 0))
+      if (lw6net_socket_set_blocking_mode (sys_context, sock, 0))
 	{
 	  //ok
 	}
       else
 	{
-	  lw6net_socket_close (&sock);
+	  lw6net_socket_close (sys_context, &sock);
 	}
     }
 
@@ -93,6 +91,7 @@ lw6net_udp_client ()
 /**
  * lw6net_udp_server
  *
+ * @sys_context: global system context
  * @ip: IP address to bind to
  * @port: IP port to listen on
  *
@@ -102,29 +101,27 @@ lw6net_udp_client ()
  * Return value: socket (>=0) on success, else -1
  */
 int
-lw6net_udp_server (const char *ip, int port)
+lw6net_udp_server (lw6sys_context_t * sys_context, const char *ip, int port)
 {
   int sock = -1;
   int enable = 1;
 
-  sock = _lw6net_socket_bind (ip, port, SOCK_DGRAM);
-  if (lw6net_socket_is_valid (sock))
+  sock = _lw6net_socket_bind (sys_context, ip, port, SOCK_DGRAM);
+  if (lw6net_socket_is_valid (sys_context, sock))
     {
-      if (setsockopt (sock, SOL_SOCKET, SO_BROADCAST,
-		      (char *) &enable, sizeof (int)))
+      if (setsockopt (sock, SOL_SOCKET, SO_BROADCAST, (char *) &enable, sizeof (int)))
 	{
-	  lw6sys_log (LW6SYS_LOG_WARNING,
-		      _x_ ("setsockopt(SO_BROADCAST) failed"));
-	  lw6net_last_error ();
+	  lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("setsockopt(SO_BROADCAST) failed"));
+	  lw6net_last_error (sys_context);
 	}
 
-      if (lw6net_socket_set_blocking_mode (sock, 0))
+      if (lw6net_socket_set_blocking_mode (sys_context, sock, 0))
 	{
 	  //ok
 	}
       else
 	{
-	  lw6net_socket_close (&sock);
+	  lw6net_socket_close (sys_context, &sock);
 	}
     }
 
@@ -134,6 +131,7 @@ lw6net_udp_server (const char *ip, int port)
 /**
  * lw6net_udp_send
  *
+ * @sys_context: global system context
  * @sock: socket to use
  * @buf: data buffer
  * @len: data buffer length
@@ -148,34 +146,27 @@ lw6net_udp_server (const char *ip, int port)
  * Return value: number of bytes sent
  */
 int
-lw6net_udp_send (int sock, const char *buf, int len, const char *ip, int port)
+lw6net_udp_send (lw6sys_context_t * sys_context, int sock, const char *buf, int len, const char *ip, int port)
 {
   int send_size = 0;
   struct sockaddr_in name;
   int res;
 
   name.sin_family = AF_INET;
-  if (_lw6net_inet_aton (&name.sin_addr, ip))
+  if (_lw6net_inet_aton (sys_context, &name.sin_addr, ip))
     {
       name.sin_port = htons (port);
-      res =
-	sendto (sock, buf, len, 0, (struct sockaddr *) &name, sizeof (name));
+      res = sendto (sock, buf, len, 0, (struct sockaddr *) &name, sizeof (name));
       if (res >= 0)
 	{
 	  send_size = res;
-	  lw6sys_log (LW6SYS_LOG_DEBUG,
-		      _x_ ("%d bytes sent on UDP socket %d"), send_size,
-		      sock);
-	  _lw6net_counters_register_send (&(_lw6net_global_context->counters),
-					  send_size);
-	  _lw6net_log_udp_send (&(_lw6net_global_context->log), buf,
-				send_size);
+	  lw6sys_log (sys_context, LW6SYS_LOG_DEBUG, _x_ ("%d bytes sent on UDP socket %d"), send_size, sock);
+	  _lw6net_counters_register_send (sys_context, &(_lw6net_global_context->counters), send_size);
+	  _lw6net_log_udp_send (sys_context, &(_lw6net_global_context->log), buf, send_size);
 	}
       else
 	{
-	  lw6sys_log (LW6SYS_LOG_DEBUG,
-		      _x_ ("unable to send %d bytes on UDP socket %d"), len,
-		      sock);
+	  lw6sys_log (sys_context, LW6SYS_LOG_DEBUG, _x_ ("unable to send %d bytes on UDP socket %d"), len, sock);
 	}
     }
 
@@ -183,8 +174,7 @@ lw6net_udp_send (int sock, const char *buf, int len, const char *ip, int port)
 }
 
 static int
-udp_recv (int sock, char *buf,
-	  int len, char **incoming_ip, int *incoming_port, int flag)
+_udp_recv (lw6sys_context_t * sys_context, int sock, char *buf, int len, char **incoming_ip, int *incoming_port, int flag)
 {
   int recv_size = 0;
   struct sockaddr_in name;
@@ -197,19 +187,15 @@ udp_recv (int sock, char *buf,
   if (res >= 0)
     {
       recv_size = res;
-      lw6sys_log (LW6SYS_LOG_DEBUG,
-		  _x_ ("%d bytes received on UDP socket %d"), recv_size,
-		  sock);
+      lw6sys_log (sys_context, LW6SYS_LOG_DEBUG, _x_ ("%d bytes received on UDP socket %d"), recv_size, sock);
       if (flag != MSG_PEEK)
 	{
-	  _lw6net_counters_register_recv (&(_lw6net_global_context->counters),
-					  recv_size);
-	  _lw6net_log_udp_recv (&(_lw6net_global_context->log), buf,
-				recv_size);
+	  _lw6net_counters_register_recv (sys_context, &(_lw6net_global_context->counters), recv_size);
+	  _lw6net_log_udp_recv (sys_context, &(_lw6net_global_context->log), buf, recv_size);
 	}
       if (incoming_ip)
 	{
-	  (*incoming_ip) = _lw6net_inet_ntoa (name.sin_addr);
+	  (*incoming_ip) = _lw6net_inet_ntoa (sys_context, name.sin_addr);
 	}
       if (incoming_port)
 	{
@@ -234,6 +220,7 @@ udp_recv (int sock, char *buf,
 /**
  * lw6net_udp_peek
  *
+ * @sys_context: global system context
  * @sock: socket to use
  * @buf: data buffer
  * @len: data buffer length
@@ -245,15 +232,15 @@ udp_recv (int sock, char *buf,
  * Return value: number of bytes received
  */
 int
-lw6net_udp_peek (int sock, char *buf, int len,
-		 char **incoming_ip, int *incoming_port)
+lw6net_udp_peek (lw6sys_context_t * sys_context, int sock, char *buf, int len, char **incoming_ip, int *incoming_port)
 {
-  return udp_recv (sock, buf, len, incoming_ip, incoming_port, MSG_PEEK);
+  return _udp_recv (sys_context, sock, buf, len, incoming_ip, incoming_port, MSG_PEEK);
 }
 
 /**
  * lw6net_udp_recv
  *
+ * @sys_context: global system context
  * @sock: socket to use
  * @buf: data buffer
  * @len: data buffer length
@@ -265,8 +252,7 @@ lw6net_udp_peek (int sock, char *buf, int len,
  * Return value: number of bytes received
  */
 int
-lw6net_udp_recv (int sock, char *buf,
-		 int len, char **incoming_ip, int *incoming_port)
+lw6net_udp_recv (lw6sys_context_t * sys_context, int sock, char *buf, int len, char **incoming_ip, int *incoming_port)
 {
-  return udp_recv (sock, buf, len, incoming_ip, incoming_port, 0);
+  return _udp_recv (sys_context, sock, buf, len, incoming_ip, incoming_port, 0);
 }
