@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -30,6 +30,7 @@
 /**
  * lw6nod_info_new
  *
+ * @sys_context: global system context
  * @program: the program (normally it's liquidwar6)
  * @version: the version
  * @codename: the codename
@@ -52,40 +53,35 @@
  * Return value: newly allocated object, NULL on error.
  */
 lw6nod_info_t *
-lw6nod_info_new (const char *program,
+lw6nod_info_new (lw6sys_context_t * sys_context, const char *program,
 		 const char *version,
 		 const char *codename,
 		 int stamp, u_int64_t id, const char *url, const char *title,
-		 const char *description, const char *password, int bench,
-		 int open_relay, int uptime, int idle_screenshot_size,
-		 void *idle_screenshot_data)
+		 const char *description, const char *password, int bench, int open_relay, int uptime, int idle_screenshot_size, void *idle_screenshot_data)
 {
   lw6nod_info_t *info = NULL;
   int const_init_ret = 0;
 
-  info = (lw6nod_info_t *) LW6SYS_CALLOC (sizeof (lw6nod_info_t));
+  info = (lw6nod_info_t *) LW6SYS_CALLOC (sys_context, sizeof (lw6nod_info_t));
   if (info)
     {
-      info->mutex = lw6sys_mutex_create ();
+      info->mutex = LW6SYS_MUTEX_CREATE (sys_context);
 
       const_init_ret =
-	_lw6nod_const_info_init (&(info->const_info), program, version,
+	_lw6nod_const_info_init (sys_context, &(info->const_info), program, version,
 				 codename, stamp, id, url, title, description,
-				 password, bench, open_relay, uptime,
-				 idle_screenshot_size, idle_screenshot_data);
-      lw6nod_info_idle (info);
-      info->discovered_nodes = lw6nod_info_new_discovered_nodes ();
-      info->verified_nodes = lw6nod_info_new_verified_nodes ();
-      if (info->mutex && const_init_ret && info->discovered_nodes
-	  && info->verified_nodes)
+				 password, bench, open_relay, uptime, idle_screenshot_size, idle_screenshot_data);
+      lw6nod_info_idle (sys_context, info);
+      info->discovered_nodes = lw6nod_info_new_discovered_nodes (sys_context);
+      info->verified_nodes = lw6nod_info_new_verified_nodes (sys_context);
+      if (info->mutex && const_init_ret && info->discovered_nodes && info->verified_nodes)
 	{
 	  // ok
 	}
       else
 	{
-	  lw6sys_log (LW6SYS_LOG_WARNING,
-		      _x_ ("unable to create nod_info object"));
-	  lw6nod_info_free (info);
+	  lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("unable to create nod_info object"));
+	  lw6nod_info_free (sys_context, info);
 	  info = NULL;
 	}
     }
@@ -96,6 +92,7 @@ lw6nod_info_new (const char *program,
 /**
  * lw6nod_info_free
  *
+ * @sys_context: global system context
  * @info: the node info to free
  *
  * Frees a node info object.
@@ -103,27 +100,27 @@ lw6nod_info_new (const char *program,
  * Return value: none
  */
 void
-lw6nod_info_free (lw6nod_info_t * info)
+lw6nod_info_free (lw6sys_context_t * sys_context, lw6nod_info_t * info)
 {
-  lw6nod_info_idle (info);
+  lw6nod_info_idle (sys_context, info);
   if (info->dyn_info.level)
     {
-      LW6SYS_FREE (info->dyn_info.level);
+      LW6SYS_FREE (sys_context, info->dyn_info.level);
     }
   if (info->mutex)
     {
-      lw6sys_mutex_destroy (info->mutex);
+      LW6SYS_MUTEX_DESTROY (sys_context, info->mutex);
     }
-  _lw6nod_const_info_reset (&(info->const_info));
+  _lw6nod_const_info_reset (sys_context, &(info->const_info));
   if (info->discovered_nodes)
     {
-      lw6sys_hash_free (info->discovered_nodes);
+      lw6sys_hash_free (sys_context, info->discovered_nodes);
     }
   if (info->verified_nodes)
     {
-      lw6sys_list_free (info->verified_nodes);
+      lw6sys_list_free (sys_context, info->verified_nodes);
     }
-  LW6SYS_FREE (info);
+  LW6SYS_FREE (sys_context, info);
 }
 
 /**
@@ -139,11 +136,11 @@ lw6nod_info_free (lw6nod_info_t * info)
  * Return value: 1 if ok, 0 if not.
  */
 int
-lw6nod_info_lock (lw6nod_info_t * info)
+lw6nod_info_lock (lw6sys_context_t * sys_context, lw6nod_info_t * info)
 {
   int ret = 0;
 
-  ret = lw6sys_mutex_lock (info->mutex);
+  ret = LW6SYS_MUTEX_LOCK (sys_context, info->mutex);
 
   return ret;
 }
@@ -151,6 +148,7 @@ lw6nod_info_lock (lw6nod_info_t * info)
 /**
  * lw6nod_info_unlock
  *
+ * @sys_context: global system context
  * @info: the node info to unlock
  *
  * Unlocks a node info object, this is the compation of
@@ -159,11 +157,11 @@ lw6nod_info_lock (lw6nod_info_t * info)
  * Return value: 1 if ok, 0 if not.
  */
 int
-lw6nod_info_unlock (lw6nod_info_t * info)
+lw6nod_info_unlock (lw6sys_context_t * sys_context, lw6nod_info_t * info)
 {
   int ret = 0;
 
-  ret = lw6sys_mutex_unlock (info->mutex);
+  ret = LW6SYS_MUTEX_UNLOCK (sys_context, info->mutex);
 
   return ret;
 }
@@ -171,6 +169,7 @@ lw6nod_info_unlock (lw6nod_info_t * info)
 /**
  * lw6nod_info_idle
  *
+ * @sys_context: global system context
  * @info: the node info to modify
  *
  * Clears a node info object and sets all its variable attributes
@@ -180,7 +179,7 @@ lw6nod_info_unlock (lw6nod_info_t * info)
  * Return value: none.
  */
 void
-lw6nod_info_idle (lw6nod_info_t * info)
+lw6nod_info_idle (lw6sys_context_t * sys_context, lw6nod_info_t * info)
 {
   int locked = 0;
 
@@ -190,20 +189,21 @@ lw6nod_info_idle (lw6nod_info_t * info)
    */
   if (info->mutex)
     {
-      locked = lw6nod_info_lock (info);
+      locked = lw6nod_info_lock (sys_context, info);
     }
 
-  _lw6nod_dyn_info_reset (&(info->dyn_info));
+  _lw6nod_dyn_info_reset (sys_context, &(info->dyn_info));
 
   if (info->mutex && locked)
     {
-      lw6nod_info_unlock (info);
+      lw6nod_info_unlock (sys_context, info);
     }
 }
 
 /**
  * lw6nod_info_update
  *
+ * @sys_context: global system context
  * @info: the node info to update
  * @community_id: the id of the community the node belongs to
  * @round: the current round (can have an offset with real round number)
@@ -227,23 +227,20 @@ lw6nod_info_idle (lw6nod_info_t * info)
  * Return value: 1 if OK, 0 if error.
  */
 int
-lw6nod_info_update (lw6nod_info_t * info, u_int64_t community_id, int round,
+lw6nod_info_update (lw6sys_context_t * sys_context, lw6nod_info_t * info, u_int64_t community_id, int round,
 		    const char *level, int required_bench, int nb_colors,
 		    int max_nb_colors, int nb_cursors, int max_nb_cursors,
-		    int nb_nodes, int max_nb_nodes, const char *peer_id_list,
-		    int game_screenshot_size, void *game_screenshot_data)
+		    int nb_nodes, int max_nb_nodes, const char *peer_id_list, int game_screenshot_size, void *game_screenshot_data)
 {
   int ret = 0;
 
-  if (lw6nod_info_lock (info))
+  if (lw6nod_info_lock (sys_context, info))
     {
       ret =
-	_lw6nod_dyn_info_update (&(info->dyn_info), community_id, round,
+	_lw6nod_dyn_info_update (sys_context, &(info->dyn_info), community_id, round,
 				 level, required_bench, nb_colors,
-				 max_nb_colors, nb_cursors, max_nb_cursors,
-				 nb_nodes, max_nb_nodes,
-				 game_screenshot_size, game_screenshot_data);
-      lw6nod_info_unlock (info);
+				 max_nb_colors, nb_cursors, max_nb_cursors, nb_nodes, max_nb_nodes, game_screenshot_size, game_screenshot_data);
+      lw6nod_info_unlock (sys_context, info);
     }
 
   return ret;
@@ -252,6 +249,7 @@ lw6nod_info_update (lw6nod_info_t * info, u_int64_t community_id, int round,
 /**
  * lw6nod_info_dup_dyn
  *
+ * @sys_context: global system context
  * @info: the node info containing the dyn info to duplicate
  *
  * Extracts the dynamic part of an info struct and duplicates
@@ -261,42 +259,37 @@ lw6nod_info_update (lw6nod_info_t * info, u_int64_t community_id, int round,
  * Return value: newly allocated object, must be freed.
  */
 lw6nod_dyn_info_t *
-lw6nod_info_dup_dyn (lw6nod_info_t * info)
+lw6nod_info_dup_dyn (lw6sys_context_t * sys_context, lw6nod_info_t * info)
 {
   lw6nod_dyn_info_t *dyn_info = NULL;
   int ok = 1;
   int i = 0;
 
-  dyn_info = (lw6nod_dyn_info_t *) LW6SYS_CALLOC (sizeof (lw6nod_dyn_info_t));
+  dyn_info = (lw6nod_dyn_info_t *) LW6SYS_CALLOC (sys_context, sizeof (lw6nod_dyn_info_t));
 
   if (dyn_info)
     {
-      if (lw6nod_info_lock (info))
+      if (lw6nod_info_lock (sys_context, info))
 	{
 	  ok = _lw6nod_dyn_info_update
-	    (dyn_info, info->dyn_info.community_id_int,
+	    (sys_context, dyn_info, info->dyn_info.community_id_int,
 	     info->dyn_info.round, info->dyn_info.level,
 	     info->dyn_info.required_bench, info->dyn_info.nb_colors,
 	     info->dyn_info.max_nb_colors, info->dyn_info.nb_cursors,
 	     info->dyn_info.max_nb_cursors, info->dyn_info.nb_nodes,
-	     info->dyn_info.max_nb_nodes,
-	     info->dyn_info.game_screenshot_size,
-	     info->dyn_info.game_screenshot_data) && ok;
+	     info->dyn_info.max_nb_nodes, info->dyn_info.game_screenshot_size, info->dyn_info.game_screenshot_data) && ok;
 	  for (i = 0; i < LW6NOD_MAX_NB_PEERS; ++i)
 	    {
 	      ok =
-		_lw6nod_ref_info_update (&(dyn_info->community_peers[i]),
-					 info->dyn_info.
-					 community_peers[i].id_int,
-					 info->dyn_info.
-					 community_peers[i].url) && ok;
+		_lw6nod_ref_info_update (sys_context, &(dyn_info->community_peers[i]),
+					 info->dyn_info.community_peers[i].id_int, info->dyn_info.community_peers[i].url) && ok;
 	    }
 	  if (!ok)
 	    {
-	      lw6nod_dyn_info_free (dyn_info);
+	      lw6nod_dyn_info_free (sys_context, dyn_info);
 	      dyn_info = NULL;
 	    }
-	  lw6nod_info_unlock (info);
+	  lw6nod_info_unlock (sys_context, info);
 	}
     }
 
@@ -306,6 +299,8 @@ lw6nod_info_dup_dyn (lw6nod_info_t * info)
 /**
  * lw6nod_info_new_discovered_nodes
  *
+ * @sys_context: global system context
+ *
  * Creates a new hash, to be used as a discovered nodes list.
  * Using this function has the
  * advantage of setting the hash options to their defaults.
@@ -315,11 +310,11 @@ lw6nod_info_dup_dyn (lw6nod_info_t * info)
  * Return value: an empty hash
  */
 lw6sys_hash_t *
-lw6nod_info_new_discovered_nodes ()
+lw6nod_info_new_discovered_nodes (lw6sys_context_t * sys_context)
 {
   lw6sys_hash_t *ret;
 
-  ret = lw6sys_hash_new (NULL, _LW6NOD_HASH_SIZE);
+  ret = lw6sys_hash_new (sys_context, NULL, _LW6NOD_HASH_SIZE);
 
   return ret;
 }
@@ -327,6 +322,7 @@ lw6nod_info_new_discovered_nodes ()
 /**
  * lw6nod_info_add_discovered_node
  *
+ * @sys_context: global system context
  * @info: the node info to update
  * @public_url: the address of the discovered node
  *
@@ -339,35 +335,32 @@ lw6nod_info_new_discovered_nodes ()
  * Return value: 1 if OK, O if error.
  */
 int
-lw6nod_info_add_discovered_node (lw6nod_info_t * info, const char *public_url)
+lw6nod_info_add_discovered_node (lw6sys_context_t * sys_context, lw6nod_info_t * info, const char *public_url)
 {
   int ret = 0;
   char *canonized_url;
 
   if (strlen (public_url) > 0)
     {
-      if (lw6nod_info_lock (info))
+      if (lw6nod_info_lock (sys_context, info))
 	{
 	  if (!info->discovered_nodes)
 	    {
 	      // could be NULL if popping too hard
-	      info->discovered_nodes = lw6nod_info_new_discovered_nodes ();
+	      info->discovered_nodes = lw6nod_info_new_discovered_nodes (sys_context);
 	    }
 	  if (info->discovered_nodes)
 	    {
-	      canonized_url = lw6sys_url_canonize (public_url);
+	      canonized_url = lw6sys_url_canonize (sys_context, public_url);
 	      if (canonized_url)
 		{
-		  lw6sys_log (LW6SYS_LOG_DEBUG,
-			      _x_ ("adding \"%s\" as a possible node"),
-			      canonized_url);
-		  lw6sys_hash_set (info->discovered_nodes, canonized_url,
-				   NULL);
-		  LW6SYS_FREE (canonized_url);
+		  lw6sys_log (sys_context, LW6SYS_LOG_DEBUG, _x_ ("adding \"%s\" as a possible node"), canonized_url);
+		  lw6sys_hash_set (sys_context, info->discovered_nodes, canonized_url, NULL);
+		  LW6SYS_FREE (sys_context, canonized_url);
 		}
 	    }
 	  ret = ((info->discovered_nodes) != NULL);
-	  lw6nod_info_unlock (info);
+	  lw6nod_info_unlock (sys_context, info);
 	}
     }
 
@@ -377,6 +370,7 @@ lw6nod_info_add_discovered_node (lw6nod_info_t * info, const char *public_url)
 /**
  * lw6nod_info_pop_discovered_nodes
  *
+ * @sys_context: global system context
  * @info: the node info to query
  *
  * Returns a list of all discovered nodes (their public URL)
@@ -385,23 +379,23 @@ lw6nod_info_add_discovered_node (lw6nod_info_t * info, const char *public_url)
  * Return value: a list of dynamically allocated strings.
  */
 lw6sys_list_t *
-lw6nod_info_pop_discovered_nodes (lw6nod_info_t * info)
+lw6nod_info_pop_discovered_nodes (lw6sys_context_t * sys_context, lw6nod_info_t * info)
 {
   lw6sys_list_t *ret = NULL;
 
-  if (lw6nod_info_lock (info))
+  if (lw6nod_info_lock (sys_context, info))
     {
       if (info->discovered_nodes)
 	{
-	  ret = lw6sys_hash_keys (info->discovered_nodes);
-	  lw6sys_hash_free (info->discovered_nodes);
+	  ret = lw6sys_hash_keys (sys_context, info->discovered_nodes);
+	  lw6sys_hash_free (sys_context, info->discovered_nodes);
 	}
       else
 	{
-	  ret = lw6sys_list_new (lw6sys_free_callback);
+	  ret = lw6sys_list_new (sys_context, lw6sys_free_callback);
 	}
-      info->discovered_nodes = lw6nod_info_new_discovered_nodes ();
-      lw6nod_info_unlock (info);
+      info->discovered_nodes = lw6nod_info_new_discovered_nodes (sys_context);
+      lw6nod_info_unlock (sys_context, info);
     }
 
   return ret;
@@ -410,6 +404,8 @@ lw6nod_info_pop_discovered_nodes (lw6nod_info_t * info)
 /**
  * lw6nod_info_new_verified_nodes
  *
+ * @sys_context: global system context
+ *
  * Creates a new list, to be filled with nodes and typically passed
  * to @lw6nod_info_set_verified_nodes. Using this function has the
  * advantage of setting the listh options to their defaults.
@@ -417,25 +413,24 @@ lw6nod_info_pop_discovered_nodes (lw6nod_info_t * info)
  * Return value: an empty list
  */
 lw6sys_list_t *
-lw6nod_info_new_verified_nodes ()
+lw6nod_info_new_verified_nodes (lw6sys_context_t * sys_context)
 {
   lw6sys_list_t *ret;
 
-  ret = lw6sys_list_new ((lw6sys_free_func_t) lw6nod_info_free);
+  ret = lw6sys_list_new (sys_context, (lw6sys_free_func_t) lw6nod_info_free);
 
   return ret;
 }
 
 static int
-_verified_sort_callback (const lw6sys_list_t ** list_a,
-			 const lw6sys_list_t ** list_b)
+_verified_sort_callback (lw6sys_context_t * sys_context, void *func_data, const void *ptr_a, const void *ptr_b)
 {
   int ret = 0;
   const lw6nod_info_t *a;
   const lw6nod_info_t *b;
 
-  a = (const lw6nod_info_t *) ((*list_a)->data);
-  b = (const lw6nod_info_t *) ((*list_b)->data);
+  a = (const lw6nod_info_t *) ptr_a;
+  b = (const lw6nod_info_t *) ptr_b;
 
   if (a->const_info.title && b->const_info.title)
     {
@@ -452,6 +447,7 @@ _verified_sort_callback (const lw6sys_list_t ** list_a,
 /**
  * lw6nod_info_set_verified_nodes
  *
+ * @sys_context: global system context
  * @info: the node info to modify
  * @list: the list of verified nodes, will be freed by this function
  *
@@ -466,22 +462,22 @@ _verified_sort_callback (const lw6sys_list_t ** list_a,
  * Return value: 1 if OK, 0 on error.
  */
 int
-lw6nod_info_set_verified_nodes (lw6nod_info_t * info, lw6sys_list_t * list)
+lw6nod_info_set_verified_nodes (lw6sys_context_t * sys_context, lw6nod_info_t * info, lw6sys_list_t * list)
 {
   int ret = 0;
 
-  lw6sys_sort (&list, _verified_sort_callback);
+  lw6sys_sort (sys_context, &list, _verified_sort_callback, NULL);
 
   if (list)
     {
-      if (lw6nod_info_lock (info))
+      if (lw6nod_info_lock (sys_context, info))
 	{
 	  if (info->verified_nodes)
 	    {
-	      lw6sys_list_free (info->verified_nodes);
+	      lw6sys_list_free (sys_context, info->verified_nodes);
 	    }
 	  info->verified_nodes = list;
-	  lw6nod_info_unlock (info);
+	  lw6nod_info_unlock (sys_context, info);
 	}
     }
 
@@ -491,6 +487,7 @@ lw6nod_info_set_verified_nodes (lw6nod_info_t * info, lw6sys_list_t * list)
 /**
  * lw6nod_info_map_verified_nodes
  *
+ * @sys_context: global system context
  * @info: the node info concerned
  * @func: the function to apply
  * @func_data: arbitrary pointer holding data to pass to function
@@ -503,16 +500,14 @@ lw6nod_info_set_verified_nodes (lw6nod_info_t * info, lw6sys_list_t * list)
  * Return value: none.
  */
 void
-lw6nod_info_map_verified_nodes (lw6nod_info_t * info,
-				lw6sys_list_callback_func_t func,
-				void *func_data)
+lw6nod_info_map_verified_nodes (lw6sys_context_t * sys_context, lw6nod_info_t * info, lw6sys_list_callback_func_t func, void *func_data)
 {
-  if (lw6nod_info_lock (info))
+  if (lw6nod_info_lock (sys_context, info))
     {
       if (info->verified_nodes)
 	{
-	  lw6sys_list_map (info->verified_nodes, func, func_data);
+	  lw6sys_list_map (sys_context, info->verified_nodes, func, func_data);
 	}
-      lw6nod_info_unlock (info);
+      lw6nod_info_unlock (sys_context, info);
     }
 }
