@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -28,23 +28,22 @@
 #include "nod-internal.h"
 
 void
-_lw6nod_ref_info_reset (lw6nod_ref_info_t * ref_info)
+_lw6nod_ref_info_reset (lw6sys_context_t * sys_context, lw6nod_ref_info_t * ref_info)
 {
   if (ref_info->id_str)
     {
-      LW6SYS_FREE (ref_info->id_str);
+      LW6SYS_FREE (sys_context, ref_info->id_str);
     }
   if (ref_info->url)
     {
-      LW6SYS_FREE (ref_info->url);
+      LW6SYS_FREE (sys_context, ref_info->url);
     }
 
   memset (ref_info, 0, sizeof (lw6nod_ref_info_t));
 }
 
 int
-_lw6nod_ref_info_update (lw6nod_ref_info_t * ref_info, u_int64_t id,
-			 const char *url)
+_lw6nod_ref_info_update (lw6sys_context_t * sys_context, lw6nod_ref_info_t * ref_info, u_int64_t id, const char *url)
 {
   int ret = 1;
 
@@ -53,10 +52,10 @@ _lw6nod_ref_info_update (lw6nod_ref_info_t * ref_info, u_int64_t id,
       ref_info->id_int = id;
       if (ref_info->id_str)
 	{
-	  LW6SYS_FREE (ref_info->id_str);
+	  LW6SYS_FREE (sys_context, ref_info->id_str);
 	  ref_info->id_str = NULL;
 	}
-      ref_info->id_str = lw6sys_id_ltoa (id);
+      ref_info->id_str = lw6sys_id_ltoa (sys_context, id);
     }
 
   /*
@@ -68,12 +67,12 @@ _lw6nod_ref_info_update (lw6nod_ref_info_t * ref_info, u_int64_t id,
     {
       if (ref_info->url)
 	{
-	  LW6SYS_FREE (ref_info->url);
+	  LW6SYS_FREE (sys_context, ref_info->url);
 	  ref_info->url = NULL;
 	}
       if (url)
 	{
-	  ref_info->url = lw6sys_url_canonize (url);
+	  ref_info->url = lw6sys_url_canonize (sys_context, url);
 	}
       else
 	{
