@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -30,6 +30,7 @@
 /**
  * lw6p2p_entry_new
  *
+ * @sys_context: global system context
  * @creation_timestamp: when it has been created, UNIX timestamp
  * @version: version of the node
  * @codename: codename of the node
@@ -64,18 +65,17 @@
  * Return value: newly allocated object
  */
 lw6p2p_entry_t *
-lw6p2p_entry_new (int creation_timestamp, char *version, char *codename,
+lw6p2p_entry_new (lw6sys_context_t * sys_context, int creation_timestamp, char *version, char *codename,
 		  int stamp, char *id, char *url, char *title,
 		  char *description, int has_password, int bench,
 		  int open_relay, char *community_id, int round, char *level,
 		  int required_bench, int nb_colors, int max_nb_colors,
 		  int nb_cursors, int max_nb_cursors, int nb_nodes,
-		  int max_nb_nodes, char *ip, int port,
-		  int last_ping_timestamp, int ping_delay_msec, int available)
+		  int max_nb_nodes, char *ip, int port, int last_ping_timestamp, int ping_delay_msec, int available)
 {
   lw6p2p_entry_t *entry = NULL;
 
-  entry = (lw6p2p_entry_t *) LW6SYS_CALLOC (sizeof (lw6p2p_entry_t));
+  entry = (lw6p2p_entry_t *) LW6SYS_CALLOC (sys_context, sizeof (lw6p2p_entry_t));
   if (entry)
     {
       entry->creation_timestamp = creation_timestamp;
@@ -110,8 +110,7 @@ lw6p2p_entry_new (int creation_timestamp, char *version, char *codename,
       // variable data
       if (community_id)
 	{
-	  strncpy (entry->community_id, community_id,
-		   LW6P2P_COMMUNITY_ID_SIZE);
+	  strncpy (entry->community_id, community_id, LW6P2P_COMMUNITY_ID_SIZE);
 	}
       entry->round = round;
       if (level)
@@ -141,6 +140,7 @@ lw6p2p_entry_new (int creation_timestamp, char *version, char *codename,
 /**
  * lw6p2p_entry_free
  *
+ * @sys_context: global system context
  * @entry: entry to free
  *
  * Frees a p2p entry.
@@ -148,14 +148,15 @@ lw6p2p_entry_new (int creation_timestamp, char *version, char *codename,
  * Return value: none.
  */
 void
-lw6p2p_entry_free (lw6p2p_entry_t * entry)
+lw6p2p_entry_free (lw6sys_context_t * sys_context, lw6p2p_entry_t * entry)
 {
-  LW6SYS_FREE (entry);
+  LW6SYS_FREE (sys_context, entry);
 }
 
 /**
  * lw6p2p_entry_repr
  *
+ * @sys_context: global system context
  * @entry: entry to represent
  *
  * Gives a human-readable representation of the entry
@@ -163,13 +164,11 @@ lw6p2p_entry_free (lw6p2p_entry_t * entry)
  * Return value: dynamically allocated string
  */
 char *
-lw6p2p_entry_repr (const lw6p2p_entry_t * entry)
+lw6p2p_entry_repr (lw6sys_context_t * sys_context, const lw6p2p_entry_t * entry)
 {
   char *repr = NULL;
 
-  repr =
-    lw6sys_new_sprintf ("%s url=%s (%s:%d) available=%d", entry->title,
-			entry->url, entry->ip, entry->port, entry->available);
+  repr = lw6sys_new_sprintf (sys_context, "%s url=%s (%s:%d) available=%d", entry->title, entry->url, entry->ip, entry->port, entry->available);
 
   return repr;
 }
