@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -41,7 +41,7 @@ is_spc (char c)
 }
 
 static void
-command_normalize (char *command_text)
+_command_normalize (lw6sys_context_t * sys_context, char *command_text)
 {
   char *pos_src = NULL;
   char *pos_dst = NULL;
@@ -71,7 +71,7 @@ command_normalize (char *command_text)
 }
 
 static int
-command_add_parse (lw6pil_command_t * command, char *command_args)
+_command_add_parse (lw6sys_context_t * sys_context, lw6pil_command_t * command, char *command_args)
 {
   int ret = 0;
   char *pos;
@@ -87,20 +87,17 @@ command_add_parse (lw6pil_command_t * command, char *command_args)
     {
       (*seek) = '\0';
       seek++;
-      command->args.add.cursor_id = lw6sys_id_atol (pos);
+      command->args.add.cursor_id = lw6sys_id_atol (sys_context, pos);
       pos = seek;
-      if (lw6sys_check_id_16 (command->args.add.cursor_id))
+      if (lw6sys_check_id_16 (sys_context, command->args.add.cursor_id))
 	{
-	  command->args.add.team_color = lw6map_team_color_key_to_index (pos);
-	  if (command->args.add.team_color >= 0
-	      && command->args.add.team_color < LW6MAP_MAX_NB_TEAMS)
+	  command->args.add.team_color = lw6map_team_color_key_to_index (sys_context, pos);
+	  if (command->args.add.team_color >= 0 && command->args.add.team_color < LW6MAP_MAX_NB_TEAMS)
 	    {
-	      lw6sys_log (LW6SYS_LOG_DEBUG,
+	      lw6sys_log (sys_context, LW6SYS_LOG_DEBUG,
 			  _x_
 			  ("%s command parsed cursor_id=%x, team_color=%d (%s)"),
-			  LW6PIL_COMMAND_TEXT_ADD,
-			  (int) command->args.set.cursor_id,
-			  command->args.add.team_color, pos);
+			  LW6PIL_COMMAND_TEXT_ADD, (int) command->args.set.cursor_id, command->args.add.team_color, pos);
 	      ret = 1;
 	    }
 	}
@@ -110,16 +107,14 @@ command_add_parse (lw6pil_command_t * command, char *command_args)
 }
 
 static int
-command_remove_parse (lw6pil_command_t * command, char *command_args)
+_command_remove_parse (lw6sys_context_t * sys_context, lw6pil_command_t * command, char *command_args)
 {
   int ret = 0;
 
-  command->args.remove.cursor_id = lw6sys_id_atol (command_args);
-  if (lw6sys_check_id_16 (command->args.remove.cursor_id))
+  command->args.remove.cursor_id = lw6sys_id_atol (sys_context, command_args);
+  if (lw6sys_check_id_16 (sys_context, command->args.remove.cursor_id))
     {
-      lw6sys_log (LW6SYS_LOG_DEBUG, _x_ ("%s command parsed cursor_id=%x"),
-		  LW6PIL_COMMAND_TEXT_REMOVE,
-		  (int) command->args.set.cursor_id);
+      lw6sys_log (sys_context, LW6SYS_LOG_DEBUG, _x_ ("%s command parsed cursor_id=%x"), LW6PIL_COMMAND_TEXT_REMOVE, (int) command->args.set.cursor_id);
       ret = 1;
     }
 
@@ -127,7 +122,7 @@ command_remove_parse (lw6pil_command_t * command, char *command_args)
 }
 
 static int
-command_set_parse (lw6pil_command_t * command, char *command_args)
+_command_set_parse (lw6sys_context_t * sys_context, lw6pil_command_t * command, char *command_args)
 {
   int ret = 0;
   char *pos;
@@ -143,9 +138,9 @@ command_set_parse (lw6pil_command_t * command, char *command_args)
     {
       (*seek) = '\0';
       seek++;
-      command->args.set.cursor_id = lw6sys_id_atol (pos);
+      command->args.set.cursor_id = lw6sys_id_atol (sys_context, pos);
       pos = seek;
-      if (lw6sys_check_id_16 (command->args.set.cursor_id))
+      if (lw6sys_check_id_16 (sys_context, command->args.set.cursor_id))
 	{
 	  while (!is_spc (*seek))
 	    {
@@ -155,7 +150,7 @@ command_set_parse (lw6pil_command_t * command, char *command_args)
 	    {
 	      (*seek) = '\0';
 	      seek++;
-	      command->args.set.x = lw6sys_atoi (pos);
+	      command->args.set.x = lw6sys_atoi (sys_context, pos);
 	      pos = seek;
 	      while (!is_spc (*seek))
 		{
@@ -164,7 +159,7 @@ command_set_parse (lw6pil_command_t * command, char *command_args)
 	      if (*seek)
 		{
 		  (*seek) = '\0';
-		  command->args.set.y = lw6sys_atoi (pos);
+		  command->args.set.y = lw6sys_atoi (sys_context, pos);
 		  seek++;
 		  pos = seek;
 		  while (!is_spc (*seek))
@@ -174,25 +169,20 @@ command_set_parse (lw6pil_command_t * command, char *command_args)
 		  if (*seek)
 		    {
 		      (*seek) = '\0';
-		      command->args.set.fire = lw6sys_atoi (pos);
-		      if (command->args.set.fire == 0
-			  || command->args.set.fire == 1)
+		      command->args.set.fire = lw6sys_atoi (sys_context, pos);
+		      if (command->args.set.fire == 0 || command->args.set.fire == 1)
 			{
 			  seek++;
 			  pos = seek;
-			  command->args.set.fire2 = lw6sys_atoi (pos);
-			  if (command->args.set.fire2 == 0
-			      || command->args.set.fire2 == 1)
+			  command->args.set.fire2 = lw6sys_atoi (sys_context, pos);
+			  if (command->args.set.fire2 == 0 || command->args.set.fire2 == 1)
 			    {
-			      lw6sys_log (LW6SYS_LOG_DEBUG,
+			      lw6sys_log (sys_context, LW6SYS_LOG_DEBUG,
 					  _x_
 					  ("%s command parsed cursor_id=%x, x=%d, y=%d, fire=%d, fire2=%d"),
 					  LW6PIL_COMMAND_TEXT_SET,
 					  (int) command->args.set.cursor_id,
-					  command->args.set.x,
-					  command->args.set.y,
-					  command->args.set.fire,
-					  command->args.set.fire2);
+					  command->args.set.x, command->args.set.y, command->args.set.fire, command->args.set.fire2);
 			      ret = 1;
 			    }
 			}
@@ -206,7 +196,7 @@ command_set_parse (lw6pil_command_t * command, char *command_args)
 }
 
 static int
-command_dump_parse (lw6pil_command_t * command, char *command_args)
+_command_dump_parse (lw6sys_context_t * sys_context, lw6pil_command_t * command, char *command_args)
 {
   int ret = 0;
   char *pos;
@@ -222,7 +212,7 @@ command_dump_parse (lw6pil_command_t * command, char *command_args)
     {
       (*seek) = '\0';
       seek++;
-      command->args.dump.level_hexa = lw6sys_str_copy (pos);
+      command->args.dump.level_hexa = lw6sys_str_copy (sys_context, pos);
       pos = seek;
 
       if (command->args.dump.level_hexa)
@@ -236,18 +226,15 @@ command_dump_parse (lw6pil_command_t * command, char *command_args)
 	    {
 	      (*seek) = '\0';
 	      seek++;
-	      command->args.dump.game_struct_hexa = lw6sys_str_copy (pos);
+	      command->args.dump.game_struct_hexa = lw6sys_str_copy (sys_context, pos);
 	      pos = seek;
 
 	      if (command->args.dump.game_struct_hexa)
 		{
-		  command->args.dump.game_state_hexa = lw6sys_str_copy (pos);
+		  command->args.dump.game_state_hexa = lw6sys_str_copy (sys_context, pos);
 		  if (command->args.dump.game_state_hexa)
 		    {
-		      lw6sys_log (LW6SYS_LOG_DEBUG,
-				  _x_
-				  ("%s command parsed"),
-				  LW6PIL_COMMAND_TEXT_DUMP);
+		      lw6sys_log (sys_context, LW6SYS_LOG_DEBUG, _x_ ("%s command parsed"), LW6PIL_COMMAND_TEXT_DUMP);
 		      ret = 1;
 		    }
 		}
@@ -259,19 +246,18 @@ command_dump_parse (lw6pil_command_t * command, char *command_args)
 }
 
 static int
-command_parse (lw6pil_command_t * command, const char *command_text,
-	       int64_t seq_0, int round_0)
+_command_parse (lw6sys_context_t * sys_context, lw6pil_command_t * command, const char *command_text, int64_t seq_0, int round_0)
 {
   int ret = 0;
   char *pos;
   char *seek;
   char *tmp;
 
-  tmp = lw6sys_str_copy (command_text);
+  tmp = lw6sys_str_copy (sys_context, command_text);
   if (tmp)
     {
-      command_normalize (tmp);
-      command->text = lw6sys_str_copy (tmp);
+      _command_normalize (sys_context, tmp);
+      command->text = lw6sys_str_copy (sys_context, tmp);
       if (command->text)
 	{
 	  seek = tmp;
@@ -284,7 +270,7 @@ command_parse (lw6pil_command_t * command, const char *command_text,
 	    {
 	      (*seek) = '\0';
 	      seek++;
-	      command->seq = lw6sys_atoll (pos);
+	      command->seq = lw6sys_atoll (sys_context, pos);
 	      if (command->seq >= _LW6PIL_MIN_SEQ_0 && command->seq >= seq_0)
 		{
 		  command->round = command->seq - seq_0 + round_0;
@@ -297,8 +283,8 @@ command_parse (lw6pil_command_t * command, const char *command_text,
 		    {
 		      (*seek) = '\0';
 		      seek++;
-		      command->node_id = lw6sys_id_atol (pos);
-		      if (lw6sys_check_id_64 (command->node_id))
+		      command->node_id = lw6sys_id_atol (sys_context, pos);
+		      if (lw6sys_check_id_64 (sys_context, command->node_id))
 			{
 			  pos = seek;
 			  while (!is_spc (*seek))
@@ -309,98 +295,80 @@ command_parse (lw6pil_command_t * command, const char *command_text,
 			    {
 			      (*seek) = '\0';
 			      seek++;
-			      if (!strcmp (pos, LW6PIL_COMMAND_TEXT_ADD))
+			      if (lw6sys_str_is_same (sys_context, pos, LW6PIL_COMMAND_TEXT_ADD))
 				{
 				  command->code = LW6PIL_COMMAND_CODE_ADD;
-				  ret = command_add_parse (command, seek);
+				  ret = _command_add_parse (sys_context, command, seek);
 				}
-			      else
-				if (!strcmp (pos, LW6PIL_COMMAND_TEXT_REMOVE))
+			      else if (lw6sys_str_is_same (sys_context, pos, LW6PIL_COMMAND_TEXT_REMOVE))
 				{
 				  command->code = LW6PIL_COMMAND_CODE_REMOVE;
-				  ret = command_remove_parse (command, seek);
+				  ret = _command_remove_parse (sys_context, command, seek);
 				}
-			      else if (!strcmp (pos, LW6PIL_COMMAND_TEXT_SET))
+			      else if (lw6sys_str_is_same (sys_context, pos, LW6PIL_COMMAND_TEXT_SET))
 				{
 				  command->code = LW6PIL_COMMAND_CODE_SET;
-				  ret = command_set_parse (command, seek);
+				  ret = _command_set_parse (sys_context, command, seek);
 				}
-			      else
-				if (!strcmp (pos, LW6PIL_COMMAND_TEXT_DUMP))
+			      else if (lw6sys_str_is_same (sys_context, pos, LW6PIL_COMMAND_TEXT_DUMP))
 				{
 				  command->code = LW6PIL_COMMAND_CODE_DUMP;
-				  ret = command_dump_parse (command, seek);
+				  ret = _command_dump_parse (sys_context, command, seek);
 				}
 			      else
 				{
-				  lw6sys_log (LW6SYS_LOG_WARNING,
-					      _x_ ("bad command text \"%s\""),
-					      pos);
+				  lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("bad command text \"%s\""), pos);
 				}
 			    }
 			  else
 			    {
-			      if (!strcmp (pos, LW6PIL_COMMAND_TEXT_NOP))
+			      if (lw6sys_str_is_same (sys_context, pos, LW6PIL_COMMAND_TEXT_NOP))
 				{
 				  command->code = LW6PIL_COMMAND_CODE_NOP;
 				  ret = 1;
 				}
-			      else
-				if (!strcmp
-				    (pos, LW6PIL_COMMAND_TEXT_REGISTER))
+			      else if (lw6sys_str_is_same (sys_context, pos, LW6PIL_COMMAND_TEXT_REGISTER))
 				{
-				  command->code =
-				    LW6PIL_COMMAND_CODE_REGISTER;
+				  command->code = LW6PIL_COMMAND_CODE_REGISTER;
 				  ret = 1;
 				}
-			      else
-				if (!strcmp
-				    (pos, LW6PIL_COMMAND_TEXT_UNREGISTER))
+			      else if (lw6sys_str_is_same (sys_context, pos, LW6PIL_COMMAND_TEXT_UNREGISTER))
 				{
-				  command->code =
-				    LW6PIL_COMMAND_CODE_UNREGISTER;
+				  command->code = LW6PIL_COMMAND_CODE_UNREGISTER;
 				  ret = 1;
 				}
-			      else
-				if (!strcmp (pos, LW6PIL_COMMAND_TEXT_SEED))
+			      else if (lw6sys_str_is_same (sys_context, pos, LW6PIL_COMMAND_TEXT_SEED))
 				{
 				  command->code = LW6PIL_COMMAND_CODE_SEED;
 				  ret = 1;
 				}
 			      else
 				{
-				  lw6sys_log (LW6SYS_LOG_WARNING,
-					      _x_ ("bad command text \"%s\""),
-					      pos);
+				  lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("bad command text \"%s\""), pos);
 				}
 			    }
 			}
 		      else
 			{
-			  lw6sys_log (LW6SYS_LOG_WARNING,
-				      _x_ ("bad id in command \"%s\""),
-				      command_text);
+			  lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("bad id in command \"%s\""), command_text);
 			}
 		    }
 		}
 	      else
 		{
-		  lw6sys_log (LW6SYS_LOG_WARNING,
-			      _x_ ("bad seq in command \"%s\""),
-			      command_text);
+		  lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("bad seq in command \"%s\""), command_text);
 		}
 	    }
 	}
-      LW6SYS_FREE (tmp);
+      LW6SYS_FREE (sys_context, tmp);
     }
 
   if (!ret)
     {
       if (command->text)
 	{
-	  lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("invalid command \"%s\""),
-		      command->text);
-	  LW6SYS_FREE (command->text);
+	  lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("invalid command \"%s\""), command->text);
+	  LW6SYS_FREE (sys_context, command->text);
 	}
       memset (command, 0, sizeof (lw6pil_command_t));
     }
@@ -411,6 +379,7 @@ command_parse (lw6pil_command_t * command, const char *command_text,
 /**
  * lw6pil_command_new
  *
+ * @sys_context: global system context
  * @command_text: readable text of the command
  * @seq_0: sequence offset reference (to calculate difference between sequence and rounds)
  * @round_0: round offset reference (to calculate difference between sequence and rounds)
@@ -420,16 +389,16 @@ command_parse (lw6pil_command_t * command, const char *command_text,
  * Return value: newly allocated object
  */
 lw6pil_command_t *
-lw6pil_command_new (const char *command_text, int64_t seq_0, int round_0)
+lw6pil_command_new (lw6sys_context_t * sys_context, const char *command_text, int64_t seq_0, int round_0)
 {
   lw6pil_command_t *ret = NULL;
 
-  ret = (lw6pil_command_t *) LW6SYS_CALLOC (sizeof (lw6pil_command_t));
+  ret = (lw6pil_command_t *) LW6SYS_CALLOC (sys_context, sizeof (lw6pil_command_t));
   if (ret)
     {
-      if (!command_parse (ret, command_text, seq_0, round_0))
+      if (!_command_parse (sys_context, ret, command_text, seq_0, round_0))
 	{
-	  LW6SYS_FREE (ret);
+	  LW6SYS_FREE (sys_context, ret);
 	  ret = NULL;
 	}
     }
@@ -440,6 +409,7 @@ lw6pil_command_new (const char *command_text, int64_t seq_0, int round_0)
 /**
  * lw6pil_command_dup
  *
+ * @sys_context: global system context
  * @command: object to duplicate
  *
  * Creates a copy of a command struct.
@@ -447,33 +417,28 @@ lw6pil_command_new (const char *command_text, int64_t seq_0, int round_0)
  * Return value: newly allocated object.
  */
 lw6pil_command_t *
-lw6pil_command_dup (lw6pil_command_t * command)
+lw6pil_command_dup (lw6sys_context_t * sys_context, lw6pil_command_t * command)
 {
   lw6pil_command_t *ret = NULL;
 
-  ret = (lw6pil_command_t *) LW6SYS_CALLOC (sizeof (lw6pil_command_t));
+  ret = (lw6pil_command_t *) LW6SYS_CALLOC (sys_context, sizeof (lw6pil_command_t));
   if (ret)
     {
       memcpy (ret, command, sizeof (lw6pil_command_t));
-      ret->text = lw6sys_str_copy (command->text);
+      ret->text = lw6sys_str_copy (sys_context, command->text);
       if (!ret->text)
 	{
-	  LW6SYS_FREE (ret);
+	  LW6SYS_FREE (sys_context, ret);
 	  ret = NULL;
 	}
       if (ret && ret->code == LW6PIL_COMMAND_CODE_DUMP)
 	{
-	  ret->args.dump.level_hexa =
-	    lw6sys_str_copy (command->args.dump.level_hexa);
-	  ret->args.dump.game_struct_hexa =
-	    lw6sys_str_copy (command->args.dump.game_struct_hexa);
-	  ret->args.dump.game_state_hexa =
-	    lw6sys_str_copy (command->args.dump.game_state_hexa);
-	  if ((!ret->args.dump.level_hexa)
-	      || (!ret->args.dump.game_struct_hexa)
-	      || (!ret->args.dump.game_state_hexa))
+	  ret->args.dump.level_hexa = lw6sys_str_copy (sys_context, command->args.dump.level_hexa);
+	  ret->args.dump.game_struct_hexa = lw6sys_str_copy (sys_context, command->args.dump.game_struct_hexa);
+	  ret->args.dump.game_state_hexa = lw6sys_str_copy (sys_context, command->args.dump.game_state_hexa);
+	  if ((!ret->args.dump.level_hexa) || (!ret->args.dump.game_struct_hexa) || (!ret->args.dump.game_state_hexa))
 	    {
-	      lw6pil_command_free (ret);
+	      lw6pil_command_free (sys_context, ret);
 	      ret = NULL;
 	    }
 	}
@@ -485,6 +450,7 @@ lw6pil_command_dup (lw6pil_command_t * command)
 /**
  * lw6pil_command_free
  *
+ * @sys_context: global system context
  * @command: command to free
  *
  * Frees a command struct, with all its members.
@@ -492,46 +458,43 @@ lw6pil_command_dup (lw6pil_command_t * command)
  * Return value: none.
  */
 void
-lw6pil_command_free (lw6pil_command_t * command)
+lw6pil_command_free (lw6sys_context_t * sys_context, lw6pil_command_t * command)
 {
   if (command)
     {
       if (command->text)
 	{
-	  LW6SYS_FREE (command->text);
+	  LW6SYS_FREE (sys_context, command->text);
 	}
       if (command->code == LW6PIL_COMMAND_CODE_DUMP)
 	{
 	  if (command->args.dump.level_hexa)
 	    {
-	      LW6SYS_FREE (command->args.dump.level_hexa);
+	      LW6SYS_FREE (sys_context, command->args.dump.level_hexa);
 	    }
 	  if (command->args.dump.game_struct_hexa)
 	    {
-	      LW6SYS_FREE (command->args.dump.game_struct_hexa);
+	      LW6SYS_FREE (sys_context, command->args.dump.game_struct_hexa);
 	    }
 	  if (command->args.dump.game_state_hexa)
 	    {
-	      LW6SYS_FREE (command->args.dump.game_state_hexa);
+	      LW6SYS_FREE (sys_context, command->args.dump.game_state_hexa);
 	    }
 	}
-      LW6SYS_FREE (command);
+      LW6SYS_FREE (sys_context, command);
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("trying to free NULL command"));
+      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("trying to free NULL command"));
     }
 }
 
 int
-_lw6pil_command_sort_callback (const lw6sys_list_t ** list_a,
-			       const lw6sys_list_t ** list_b)
+_lw6pil_command_sort_callback (lw6sys_context_t * sys_context, void *func_data, const void *ptr_a, const void *ptr_b)
 {
   int ret = 0;
-  const lw6pil_command_t *command_a =
-    (const lw6pil_command_t *) ((*list_a)->data);
-  const lw6pil_command_t *command_b =
-    (const lw6pil_command_t *) ((*list_b)->data);
+  const lw6pil_command_t *command_a = (const lw6pil_command_t *) ptr_a;
+  const lw6pil_command_t *command_b = (const lw6pil_command_t *) ptr_b;
 
   if (command_a->seq < command_b->seq)
     {
@@ -568,6 +531,7 @@ _lw6pil_command_sort_callback (const lw6sys_list_t ** list_a,
 /**
  * lw6pil_command_repr
  *
+ * @sys_context: global system context
  * @command: command to represent
  *
  * Gives a readable representation of a command.
@@ -575,7 +539,7 @@ _lw6pil_command_sort_callback (const lw6sys_list_t ** list_a,
  * Return value: dynamically allocated string.
  */
 char *
-lw6pil_command_repr (const lw6pil_command_t * command)
+lw6pil_command_repr (lw6sys_context_t * sys_context, const lw6pil_command_t * command)
 {
   char *ret = NULL;
 
@@ -583,75 +547,65 @@ lw6pil_command_repr (const lw6pil_command_t * command)
     {
     case LW6PIL_COMMAND_CODE_NOP:
       ret =
-	lw6sys_new_sprintf ("%" LW6SYS_PRINTF_LL "d %" LW6SYS_PRINTF_LL
-			    "x %s", (long long) command->seq,
-			    (long long) command->node_id,
-			    LW6PIL_COMMAND_TEXT_NOP);
+	lw6sys_new_sprintf (sys_context,
+			    "%" LW6SYS_PRINTF_LL "d %" LW6SYS_PRINTF_LL
+			    "x %s", (long long) command->seq, (long long) command->node_id, LW6PIL_COMMAND_TEXT_NOP);
       break;
     case LW6PIL_COMMAND_CODE_REGISTER:
       ret =
-	lw6sys_new_sprintf ("%" LW6SYS_PRINTF_LL "d %" LW6SYS_PRINTF_LL
-			    "x %s", (long long) command->seq,
-			    (long long) command->node_id,
-			    LW6PIL_COMMAND_TEXT_REGISTER);
+	lw6sys_new_sprintf (sys_context,
+			    "%" LW6SYS_PRINTF_LL "d %" LW6SYS_PRINTF_LL
+			    "x %s", (long long) command->seq, (long long) command->node_id, LW6PIL_COMMAND_TEXT_REGISTER);
       break;
     case LW6PIL_COMMAND_CODE_ADD:
       ret =
-	lw6sys_new_sprintf ("%" LW6SYS_PRINTF_LL "d %" LW6SYS_PRINTF_LL
+	lw6sys_new_sprintf (sys_context,
+			    "%" LW6SYS_PRINTF_LL "d %" LW6SYS_PRINTF_LL
 			    "x %s %x %s", (long long) command->seq,
 			    (long long) command->node_id,
 			    LW6PIL_COMMAND_TEXT_ADD,
-			    (int) command->args.add.cursor_id,
-			    lw6map_team_color_index_to_key (command->args.
-							    add.team_color));
+			    (int) command->args.add.cursor_id, lw6map_team_color_index_to_key (sys_context, command->args.add.team_color));
       break;
     case LW6PIL_COMMAND_CODE_SET:
       ret =
-	lw6sys_new_sprintf ("%" LW6SYS_PRINTF_LL "d %" LW6SYS_PRINTF_LL
+	lw6sys_new_sprintf (sys_context,
+			    "%" LW6SYS_PRINTF_LL "d %" LW6SYS_PRINTF_LL
 			    "x %s %x %d %d %d %d", (long long) command->seq,
 			    (long long) command->node_id,
 			    LW6PIL_COMMAND_TEXT_SET,
-			    (int) command->args.set.cursor_id,
-			    command->args.set.x, command->args.set.y,
-			    command->args.set.fire, command->args.set.fire2);
+			    (int) command->args.set.cursor_id, command->args.set.x, command->args.set.y, command->args.set.fire, command->args.set.fire2);
       break;
     case LW6PIL_COMMAND_CODE_REMOVE:
       ret =
-	lw6sys_new_sprintf ("%" LW6SYS_PRINTF_LL "d %" LW6SYS_PRINTF_LL
+	lw6sys_new_sprintf (sys_context,
+			    "%" LW6SYS_PRINTF_LL "d %" LW6SYS_PRINTF_LL
 			    "x %s %x", (long long) command->seq,
-			    (long long) command->node_id,
-			    LW6PIL_COMMAND_TEXT_REMOVE,
-			    (int) command->args.remove.cursor_id);
+			    (long long) command->node_id, LW6PIL_COMMAND_TEXT_REMOVE, (int) command->args.remove.cursor_id);
       break;
     case LW6PIL_COMMAND_CODE_UNREGISTER:
       ret =
-	lw6sys_new_sprintf ("%" LW6SYS_PRINTF_LL "d %" LW6SYS_PRINTF_LL
-			    "x %s", (long long) command->seq,
-			    (long long) command->node_id,
-			    LW6PIL_COMMAND_TEXT_UNREGISTER);
+	lw6sys_new_sprintf (sys_context,
+			    "%" LW6SYS_PRINTF_LL "d %" LW6SYS_PRINTF_LL
+			    "x %s", (long long) command->seq, (long long) command->node_id, LW6PIL_COMMAND_TEXT_UNREGISTER);
       break;
     case LW6PIL_COMMAND_CODE_SEED:
       ret =
-	lw6sys_new_sprintf ("%" LW6SYS_PRINTF_LL "d %" LW6SYS_PRINTF_LL
-			    "x %s", (long long) command->seq,
-			    (long long) command->node_id,
-			    LW6PIL_COMMAND_TEXT_SEED);
+	lw6sys_new_sprintf (sys_context,
+			    "%" LW6SYS_PRINTF_LL "d %" LW6SYS_PRINTF_LL
+			    "x %s", (long long) command->seq, (long long) command->node_id, LW6PIL_COMMAND_TEXT_SEED);
       break;
     case LW6PIL_COMMAND_CODE_DUMP:
       ret =
-	lw6sys_new_sprintf ("%" LW6SYS_PRINTF_LL "d %" LW6SYS_PRINTF_LL
+	lw6sys_new_sprintf (sys_context,
+			    "%" LW6SYS_PRINTF_LL "d %" LW6SYS_PRINTF_LL
 			    "x %s %d %d %d", (long long) command->seq,
 			    (long long) command->node_id,
 			    LW6PIL_COMMAND_TEXT_DUMP,
 			    (int) strlen (command->args.dump.game_state_hexa),
-			    (int) strlen (command->args.
-					  dump.game_struct_hexa),
-			    (int) strlen (command->args.dump.level_hexa));
+			    (int) strlen (command->args.dump.game_struct_hexa), (int) strlen (command->args.dump.level_hexa));
       break;
     default:
-      ret =
-	lw6sys_new_sprintf ("%s %s", LW6PIL_COMMAND_TEXT_INVALID,
-			    command->text);
+      ret = lw6sys_new_sprintf (sys_context, "%s %s", LW6PIL_COMMAND_TEXT_INVALID, command->text);
       break;
     }
 
@@ -661,6 +615,7 @@ lw6pil_command_repr (const lw6pil_command_t * command)
 /**
  * lw6pil_command_execute
  *
+ * @sys_context: global system context
  * @dump: pointer on dump structure (out param, can be NULL)
  * @timestamp: current timestamp (can be 0 if dump is NULL)
  * @game_state: game state to work on, can be NULL (usefull for DUMP)
@@ -674,15 +629,12 @@ lw6pil_command_repr (const lw6pil_command_t * command)
  * Return value: 1 if ok, 0 if failed.
  */
 int
-lw6pil_command_execute (lw6pil_dump_t * dump, int64_t timestamp,
-			lw6ker_game_state_t * game_state,
-			lw6pil_command_t * command)
+lw6pil_command_execute (lw6sys_context_t * sys_context, lw6pil_dump_t * dump, int64_t timestamp, lw6ker_game_state_t * game_state, lw6pil_command_t * command)
 {
   int ret = 0;
   lw6ker_cursor_t cursor;
 
-  lw6sys_log (LW6SYS_LOG_DEBUG, _x_ ("execute command \"%s\""),
-	      command->text);
+  lw6sys_log (sys_context, LW6SYS_LOG_DEBUG, _x_ ("execute command \"%s\""), command->text);
 
   switch (command->code)
     {
@@ -693,45 +645,38 @@ lw6pil_command_execute (lw6pil_dump_t * dump, int64_t timestamp,
     case LW6PIL_COMMAND_CODE_REGISTER:
       if (game_state)
 	{
-	  ret =
-	    lw6ker_game_state_register_node (game_state, command->node_id);
+	  ret = lw6ker_game_state_register_node (sys_context, game_state, command->node_id);
 	}
       break;
     case LW6PIL_COMMAND_CODE_ADD:
       if (game_state)
 	{
-	  ret =
-	    lw6ker_game_state_add_cursor (game_state, command->node_id,
-					  command->args.add.cursor_id,
-					  command->args.add.team_color);
+	  ret = lw6ker_game_state_add_cursor (sys_context, game_state, command->node_id, command->args.add.cursor_id, command->args.add.team_color);
 	}
       break;
     case LW6PIL_COMMAND_CODE_SET:
       if (game_state)
 	{
-	  lw6ker_cursor_reset (&cursor);
+	  lw6ker_cursor_reset (sys_context, &cursor);
 	  cursor.node_id = command->node_id;
 	  cursor.cursor_id = command->args.set.cursor_id;
 	  cursor.pos.x = command->args.set.x;
 	  cursor.pos.y = command->args.set.y;
 	  cursor.fire = command->args.set.fire;
 	  cursor.fire2 = command->args.set.fire2;
-	  ret = lw6ker_game_state_set_cursor (game_state, &cursor);
+	  ret = lw6ker_game_state_set_cursor (sys_context, game_state, &cursor);
 	}
       break;
     case LW6PIL_COMMAND_CODE_REMOVE:
       if (game_state)
 	{
-	  ret =
-	    lw6ker_game_state_remove_cursor (game_state, command->node_id,
-					     command->args.remove.cursor_id);
+	  ret = lw6ker_game_state_remove_cursor (sys_context, game_state, command->node_id, command->args.remove.cursor_id);
 	}
       break;
     case LW6PIL_COMMAND_CODE_UNREGISTER:
       if (game_state)
 	{
-	  ret =
-	    lw6ker_game_state_unregister_node (game_state, command->node_id);
+	  ret = lw6ker_game_state_unregister_node (sys_context, game_state, command->node_id);
 	}
       break;
     case LW6PIL_COMMAND_CODE_DUMP:
@@ -742,7 +687,7 @@ lw6pil_command_execute (lw6pil_dump_t * dump, int64_t timestamp,
        * Note that DUMP can arrive both in the case game_state is not NULL
        * and in the case it is NULL.
        */
-      ret = lw6pil_dump_command_execute (dump, timestamp, command, NULL);
+      ret = lw6pil_dump_command_execute (sys_context, dump, timestamp, command, NULL);
       break;
     case LW6PIL_COMMAND_CODE_SEED:
       /*
@@ -753,8 +698,7 @@ lw6pil_command_execute (lw6pil_dump_t * dump, int64_t timestamp,
       ret = 1;
       break;
     default:
-      lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("incorrect command \"%s\""),
-		  command->text);
+      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("incorrect command \"%s\""), command->text);
       break;
     }
 
@@ -764,6 +708,7 @@ lw6pil_command_execute (lw6pil_dump_t * dump, int64_t timestamp,
 /**
  * lw6pil_command_execute_text
  *
+ * @sys_context: global system context
  * @dump: pointer on dump structure (out param, can be NULL)
  * @timestamp: current timestamp (can be 0 if dump is NULL)
  * @game_state: game state to work on, can be NULL (typically for DUMP)
@@ -778,19 +723,17 @@ lw6pil_command_execute (lw6pil_dump_t * dump, int64_t timestamp,
  * Return value: 1 if ok, 0 if failed.
  */
 int
-lw6pil_command_execute_text (lw6pil_dump_t * dump,
-			     int64_t timestamp,
-			     lw6ker_game_state_t * game_state,
+lw6pil_command_execute_text (lw6sys_context_t * sys_context, lw6pil_dump_t * dump, int64_t timestamp, lw6ker_game_state_t * game_state,
 			     const char *command_text, int64_t seq_0)
 {
   int ret = 0;
   lw6pil_command_t *command = NULL;
 
-  command = lw6pil_command_new (command_text, seq_0, _LW6PIL_MIN_ROUND_0);
+  command = lw6pil_command_new (sys_context, command_text, seq_0, _LW6PIL_MIN_ROUND_0);
   if (command)
     {
-      ret = lw6pil_command_execute (dump, timestamp, game_state, command);
-      lw6pil_command_free (command);
+      ret = lw6pil_command_execute (sys_context, dump, timestamp, game_state, command);
+      lw6pil_command_free (sys_context, command);
     }
 
   return ret;
@@ -799,6 +742,7 @@ lw6pil_command_execute_text (lw6pil_dump_t * dump,
 /**
  * lw6pil_command_execute_local
  *
+ * @sys_context: global system context
  * @local_cursors: local cursors information
  * @command: command to execute
  *
@@ -808,13 +752,11 @@ lw6pil_command_execute_text (lw6pil_dump_t * dump,
  * Return value: 1 if success, 0 if failure.
  */
 int
-lw6pil_command_execute_local (lw6pil_local_cursors_t * local_cursors,
-			      lw6pil_command_t * command)
+lw6pil_command_execute_local (lw6sys_context_t * sys_context, lw6pil_local_cursors_t * local_cursors, lw6pil_command_t * command)
 {
   int ret = 0;
 
-  lw6sys_log (LW6SYS_LOG_DEBUG, _x_ ("execute command \"%s\""),
-	      command->text);
+  lw6sys_log (sys_context, LW6SYS_LOG_DEBUG, _x_ ("execute command \"%s\""), command->text);
   switch (command->code)
     {
     case LW6PIL_COMMAND_CODE_NOP:
@@ -827,15 +769,10 @@ lw6pil_command_execute_local (lw6pil_local_cursors_t * local_cursors,
       ret = 1;
       break;
     case LW6PIL_COMMAND_CODE_SET:
-      ret =
-	lw6pil_local_cursors_set_xy (local_cursors,
-				     command->args.set.cursor_id,
-				     command->args.set.x,
-				     command->args.set.y);
+      ret = lw6pil_local_cursors_set_xy (sys_context, local_cursors, command->args.set.cursor_id, command->args.set.x, command->args.set.y);
       break;
     default:
-      lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("incorrect command \"%s\""),
-		  command->text);
+      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("incorrect command \"%s\""), command->text);
       break;
     }
 
@@ -845,6 +782,7 @@ lw6pil_command_execute_local (lw6pil_local_cursors_t * local_cursors,
 /**
  * lw6pil_command_execute_local_text
  *
+ * @sys_context: global system context
  * @local_cursors: local cursors information
  * @command_text: command text to execute
  *
@@ -854,18 +792,16 @@ lw6pil_command_execute_local (lw6pil_local_cursors_t * local_cursors,
  * Return value: 1 if success, 0 if failure.
  */
 int
-lw6pil_command_execute_local_text (lw6pil_local_cursors_t * local_cursors,
-				   const char *command_text)
+lw6pil_command_execute_local_text (lw6sys_context_t * sys_context, lw6pil_local_cursors_t * local_cursors, const char *command_text)
 {
   int ret = 0;
   lw6pil_command_t *command = NULL;
 
-  command =
-    lw6pil_command_new (command_text, _LW6PIL_MIN_SEQ_0, _LW6PIL_MIN_ROUND_0);
+  command = lw6pil_command_new (sys_context, command_text, _LW6PIL_MIN_SEQ_0, _LW6PIL_MIN_ROUND_0);
   if (command)
     {
-      ret = lw6pil_command_execute_local (local_cursors, command);
-      lw6pil_command_free (command);
+      ret = lw6pil_command_execute_local (sys_context, local_cursors, command);
+      lw6pil_command_free (sys_context, command);
     }
 
   return ret;
