@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -27,8 +27,7 @@
 #include "pil.h"
 
 static lw6pil_local_cursor_t *
-_get_cursor (lw6pil_local_cursors_t * local_cursors, u_int16_t cursor_id,
-	     int create)
+_get_cursor (lw6pil_local_cursors_t * local_cursors, u_int16_t cursor_id, int create)
 {
   lw6pil_local_cursor_t *ret = NULL;
   int i;
@@ -41,8 +40,7 @@ _get_cursor (lw6pil_local_cursors_t * local_cursors, u_int16_t cursor_id,
 	  break;
 	}
     }
-  if (create && (!ret) && (i < LW6MAP_MAX_NB_CURSORS)
-      && (local_cursors->nb_cursors < LW6MAP_MAX_NB_CURSORS))
+  if (create && (!ret) && (i < LW6MAP_MAX_NB_CURSORS) && (local_cursors->nb_cursors < LW6MAP_MAX_NB_CURSORS))
     {
       ret = &(local_cursors->cursors[i]);
       ret->cursor_id = cursor_id;
@@ -58,7 +56,8 @@ _get_cursor (lw6pil_local_cursors_t * local_cursors, u_int16_t cursor_id,
 /**
  * lw6pil_local_cursors_reset
  *
- * @lw6pil_local_cursors_t: the structure to reset
+ * @sys_context: global system context
+ * @local_cursors: the structure to reset
  *
  * Resets a local cursors struct. Note that this need not be called very often,
  * in fact the local cursors can cope with "dead" cursors easily. In practise,
@@ -67,7 +66,7 @@ _get_cursor (lw6pil_local_cursors_t * local_cursors, u_int16_t cursor_id,
  * Return value: none.
  */
 void
-lw6pil_local_cursors_reset (lw6pil_local_cursors_t * local_cursors)
+lw6pil_local_cursors_reset (lw6sys_context_t * sys_context, lw6pil_local_cursors_t * local_cursors)
 {
   memset (local_cursors, 0, sizeof (lw6pil_local_cursors_t));
 }
@@ -75,7 +74,8 @@ lw6pil_local_cursors_reset (lw6pil_local_cursors_t * local_cursors)
 /**
  * lw6pil_local_cursors_get_cursor
  *
- * @lw6pil_local_cursors_t: the structure to query
+ * @sys_context: global system context
+ * @local_cursors: the structure to query
  * @cursor_id: the id of the cursor to query
  *
  * Returns a pointer on the cursor with the given id.
@@ -84,8 +84,7 @@ lw6pil_local_cursors_reset (lw6pil_local_cursors_t * local_cursors)
  * does not exist.
  */
 lw6pil_local_cursor_t *
-lw6pil_local_cursors_get_cursor (lw6pil_local_cursors_t *
-				 local_cursors, u_int16_t cursor_id)
+lw6pil_local_cursors_get_cursor (lw6sys_context_t * sys_context, lw6pil_local_cursors_t * local_cursors, u_int16_t cursor_id)
 {
   return _get_cursor (local_cursors, cursor_id, 0);
 }
@@ -93,7 +92,7 @@ lw6pil_local_cursors_get_cursor (lw6pil_local_cursors_t *
 /**
  * lw6pil_local_cursors_get_info
  *
- * @lw6pil_local_cursors_t: the structure to query
+ * @local_cursors: the structure to query
  * @x: a pointer to the x position, may be NULL
  * @y: a pointer to the y position, may be NULL
  * @mouse_controlled: a pointer to the mouse_controlled flag, may be NULL
@@ -104,8 +103,7 @@ lw6pil_local_cursors_get_cursor (lw6pil_local_cursors_t *
  * Return value: 1 on success (cursor exists), 0 on failure (no such cursor).
  */
 int
-lw6pil_local_cursors_get_info (lw6pil_local_cursors_t * local_cursors, int *x,
-			       int *y, int *mouse_controlled,
+lw6pil_local_cursors_get_info (lw6sys_context_t * sys_context, lw6pil_local_cursors_t * local_cursors, int *x, int *y, int *mouse_controlled,
 			       u_int16_t cursor_id)
 {
   int ret = 0;
@@ -135,7 +133,8 @@ lw6pil_local_cursors_get_info (lw6pil_local_cursors_t * local_cursors, int *x,
 /**
  * lw6pil_local_cursors_set_xy
  *
- * @lw6pil_local_cursors_t: the structure to modify
+ * @sys_context: global system context
+ * @local_cursors: the structure to modify
  * @cursor_id: the id of the cursor to modify
  * @x: the x position
  * @y: the y position
@@ -146,8 +145,7 @@ lw6pil_local_cursors_get_info (lw6pil_local_cursors_t * local_cursors, int *x,
  * Return value: 1 on success (cursor exists), 0 on failure (no such cursor).
  */
 int
-lw6pil_local_cursors_set_xy (lw6pil_local_cursors_t * local_cursors,
-			     u_int16_t cursor_id, int x, int y)
+lw6pil_local_cursors_set_xy (lw6sys_context_t * sys_context, lw6pil_local_cursors_t * local_cursors, u_int16_t cursor_id, int x, int y)
 {
   int ret = 0;
   lw6pil_local_cursor_t *cursor;
@@ -155,8 +153,7 @@ lw6pil_local_cursors_set_xy (lw6pil_local_cursors_t * local_cursors,
   cursor = _get_cursor (local_cursors, cursor_id, 1);
   if (cursor)
     {
-      lw6sys_log (LW6SYS_LOG_DEBUG, _x_ ("set local cursor %x to %d,%d"),
-		  cursor_id, x, y);
+      lw6sys_log (sys_context, LW6SYS_LOG_DEBUG, _x_ ("set local cursor %x to %d,%d"), cursor_id, x, y);
       cursor->x = x;
       cursor->y = y;
       ret = 1;
@@ -168,7 +165,8 @@ lw6pil_local_cursors_set_xy (lw6pil_local_cursors_t * local_cursors,
 /**
  * lw6pil_local_cursors_set_mouse_controlled
  *
- * @lw6pil_local_cursors_t: the structure to modify
+ * @sys_context: global system context
+ * @local_cursors: the structure to modify
  * @cursor_id: the id of the cursor to modify
  * @mouse_controlled: the mouse_controlled attribute
  *
@@ -179,9 +177,7 @@ lw6pil_local_cursors_set_xy (lw6pil_local_cursors_t * local_cursors,
  * Return value: 1 on success (cursor exists), 0 on failure (no such cursor).
  */
 int
-lw6pil_local_cursors_set_mouse_controlled (lw6pil_local_cursors_t *
-					   local_cursors, u_int16_t cursor_id,
-					   int mouse_controlled)
+lw6pil_local_cursors_set_mouse_controlled (lw6sys_context_t * sys_context, lw6pil_local_cursors_t * local_cursors, u_int16_t cursor_id, int mouse_controlled)
 {
   int ret = 0;
   int i;
@@ -208,7 +204,8 @@ lw6pil_local_cursors_set_mouse_controlled (lw6pil_local_cursors_t *
 /**
  * lw6pil_local_cursors_get_main_info
  *
- * @lw6pil_local_cursors_t: the structure to query
+ * @sys_context: global system context
+ * @local_cursors: the structure to query
  * @cursor_id: the id of the main cursor, may be NULL
  * @x: a pointer to the x position, may be NULL
  * @y: a pointer to the y position, may be NULL
@@ -219,15 +216,13 @@ lw6pil_local_cursors_set_mouse_controlled (lw6pil_local_cursors_t *
  * Return value: 1 on success (cursor exists), 0 on failure (no such cursor).
  */
 int
-lw6pil_local_cursors_get_main_info (lw6pil_local_cursors_t *
-				    local_cursors, u_int16_t * cursor_id,
-				    int *x, int *y, int *mouse_controlled)
+lw6pil_local_cursors_get_main_info (lw6sys_context_t * sys_context, lw6pil_local_cursors_t * local_cursors, u_int16_t * cursor_id, int *x, int *y,
+				    int *mouse_controlled)
 {
   int ret = 0;
   int i = local_cursors->main_i;
 
-  if (lw6sys_check_id_16 (local_cursors->main_cursor_id)
-      && local_cursors->cursors[i].is_main)
+  if (lw6sys_check_id_16 (sys_context, local_cursors->main_cursor_id) && local_cursors->cursors[i].is_main)
     {
       if (cursor_id)
 	{
@@ -254,7 +249,8 @@ lw6pil_local_cursors_get_main_info (lw6pil_local_cursors_t *
 /**
  * lw6pil_local_cursors_set_main
  *
- * @lw6pil_local_cursors_t: the structure to modify
+ * @sys_context: global system context
+ * @local_cursors: the structure to modify
  * @cursor_id: the id of the cursor to be labelled as main cursor
  *
  * Sets the main cursor attribute, the main cursor is later used,
@@ -264,8 +260,7 @@ lw6pil_local_cursors_get_main_info (lw6pil_local_cursors_t *
  * Return value: 1 on success (cursor exists), 0 on failure (no such cursor).
  */
 int
-lw6pil_local_cursors_set_main (lw6pil_local_cursors_t *
-			       local_cursors, u_int16_t cursor_id)
+lw6pil_local_cursors_set_main (lw6sys_context_t * sys_context, lw6pil_local_cursors_t * local_cursors, u_int16_t cursor_id)
 {
   int ret = 0;
   int i;
