@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -30,6 +30,7 @@
 /**
  * lw6pil_nopilot_poll_dump
  *
+ * @sys_context: global system context
  * @dump: will contain the dump information if needed, can be NULL
  * @command_text: the command received from the network.
  * @timestamp: timestamp, used to initialize the pilot
@@ -43,8 +44,7 @@
  * Return value: 1 on success, 0 on failure.
  */
 int
-lw6pil_nopilot_poll_dump (lw6pil_dump_t * dump, const char *command_text,
-			  int64_t timestamp)
+lw6pil_nopilot_poll_dump (lw6sys_context_t * sys_context, lw6pil_dump_t * dump, const char *command_text, int64_t timestamp)
 {
   int ret = 0;
 
@@ -52,11 +52,9 @@ lw6pil_nopilot_poll_dump (lw6pil_dump_t * dump, const char *command_text,
    * Yes, we need to set dump to zero, else we might return
    * false positives...
    */
-  lw6pil_dump_zero (dump);
+  lw6pil_dump_zero (sys_context, dump);
 
-  ret = lw6pil_command_execute_text (dump,
-				     timestamp, NULL, command_text,
-				     _LW6PIL_MIN_SEQ_0);
+  ret = lw6pil_command_execute_text (sys_context, dump, timestamp, NULL, command_text, _LW6PIL_MIN_SEQ_0);
 
   return ret;
 }
