@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -28,26 +28,22 @@
 #include "pil-internal.h"
 
 char *
-_lw6pil_seed_command_generate (_lw6pil_pilot_t * pilot, u_int64_t server_id,
-			       int64_t seq)
+_lw6pil_seed_command_generate (lw6sys_context_t * sys_context, _lw6pil_pilot_t * pilot, u_int64_t server_id, int64_t seq)
 {
   char *ret = NULL;
 
-  if (seq > _lw6pil_pilot_get_last_commit_seq (pilot))
+  if (seq > _lw6pil_pilot_get_last_commit_seq (sys_context, pilot))
     {
       ret =
-	lw6sys_new_sprintf ("%" LW6SYS_PRINTF_LL "d %" LW6SYS_PRINTF_LL
-			    "x %s", (long long) seq,
-			    (long long) server_id, LW6PIL_COMMAND_TEXT_SEED);
+	lw6sys_new_sprintf (sys_context, "%" LW6SYS_PRINTF_LL "d %" LW6SYS_PRINTF_LL "x %s", (long long) seq, (long long) server_id, LW6PIL_COMMAND_TEXT_SEED);
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING,
+      lw6sys_log (sys_context, LW6SYS_LOG_WARNING,
 		  _x_ ("calling seed with inconsistent seqs, seq=%"
 		       LW6SYS_PRINTF_LL
-		       "d is too low because last_commit_seq=%"
-		       LW6SYS_PRINTF_LL "d"), (long long) seq,
-		  (long long) _lw6pil_pilot_get_last_commit_seq (pilot));
+		       "d is too low because last_commit_seq=%" LW6SYS_PRINTF_LL "d"), (long long) seq,
+		  (long long) _lw6pil_pilot_get_last_commit_seq (sys_context, pilot));
     }
 
   return ret;
@@ -56,6 +52,7 @@ _lw6pil_seed_command_generate (_lw6pil_pilot_t * pilot, u_int64_t server_id,
 /**
  * lw6pil_seed_command_generate
  *
+ * @sys_context: global system context
  * @pilot: the pilot to transform as a SEED.
  * @server_id: ID of server issuing the command
  * @seq: seq at which the dump should be generated
@@ -67,9 +64,7 @@ _lw6pil_seed_command_generate (_lw6pil_pilot_t * pilot, u_int64_t server_id,
  * Return value: newly allocated string
  */
 char *
-lw6pil_seed_command_generate (lw6pil_pilot_t * pilot, u_int64_t server_id,
-			      int64_t seq)
+lw6pil_seed_command_generate (lw6sys_context_t * sys_context, lw6pil_pilot_t * pilot, u_int64_t server_id, int64_t seq)
 {
-  return _lw6pil_seed_command_generate ((_lw6pil_pilot_t *) pilot, server_id,
-					seq);
+  return _lw6pil_seed_command_generate (sys_context, (_lw6pil_pilot_t *) pilot, server_id, seq);
 }
