@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -30,6 +30,8 @@
 /**
  * lw6pil_seq_random_0
  *
+ * @sys_context: global system context
+ *
  * Gets a pseudo-random start seq, why do we use this? Just to make
  * sure even in non-network situations, seq are always very high and
  * random, this way this is one less bug to check in networked context.
@@ -37,11 +39,11 @@
  * Return value: random integer value, always greater than INT_MAX
  */
 int64_t
-lw6pil_seq_random_0 ()
+lw6pil_seq_random_0 (lw6sys_context_t * sys_context)
 {
   int64_t ret = 0L;
 
-  ret = _LW6PIL_MIN_SEQ_0 + lw6sys_random (_LW6PIL_RANGE_SEQ_0);
+  ret = _LW6PIL_MIN_SEQ_0 + lw6sys_random (sys_context, _LW6PIL_RANGE_SEQ_0);
 
   return ret;
 }
