@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -62,9 +62,7 @@
  * LW6MAP_RULES_DEFAULT_MOVES_PER_ROUND)
  * which is something like 900 * 50 * 2 = 90000.
  */
-static const char
-  *_commands[LW6PIL_SUITE_NB_NODES][LW6PIL_SUITE_NB_STAGES]
-  [_MAX_MESSAGES_PER_NODE_AND_STAGE] = {
+static const char *_commands[LW6PIL_SUITE_NB_NODES][LW6PIL_SUITE_NB_STAGES][_MAX_MESSAGES_PER_NODE_AND_STAGE] = {
   /*
    * NODE_A messages
    */
@@ -222,6 +220,7 @@ static const char
 /**
  * lw6pil_suite_init
  *
+ * @sys_context: global system context
  * @dump: dump to use as a base to init the suite (out param)
  * @timestamp: timestamp used for pilot creation (should be "now")
  *
@@ -232,23 +231,22 @@ static const char
  * Return value: 1 on success, 0 on failure.
  */
 int
-lw6pil_suite_init (lw6pil_dump_t * dump, int64_t timestamp)
+lw6pil_suite_init (lw6sys_context_t * sys_context, lw6pil_dump_t * dump, int64_t timestamp)
 {
   int ret = 0;
 
-  lw6pil_dump_zero (dump);
+  lw6pil_dump_zero (sys_context, dump);
 
-  dump->level = lw6map_builtin_scale (_INIT_SCALE_PERCENT);
+  dump->level = lw6map_builtin_scale (sys_context, _INIT_SCALE_PERCENT);
   if (dump->level)
     {
-      dump->game_struct = lw6ker_game_struct_new (dump->level, NULL);
+      dump->game_struct = lw6ker_game_struct_new (sys_context, dump->level, NULL);
       if (dump->game_struct)
 	{
-	  dump->game_state = lw6ker_game_state_new (dump->game_struct, NULL);
+	  dump->game_state = lw6ker_game_state_new (sys_context, dump->game_struct, NULL);
 	  if (dump->game_state)
 	    {
-	      dump->pilot =
-		lw6pil_pilot_new (dump->game_state, _SEQ_0, timestamp, NULL);
+	      dump->pilot = lw6pil_pilot_new (sys_context, dump->game_state, _SEQ_0, timestamp, NULL);
 	      if (dump->pilot)
 		{
 		  ret = 1;
@@ -259,7 +257,7 @@ lw6pil_suite_init (lw6pil_dump_t * dump, int64_t timestamp)
 
   if (!ret)
     {
-      lw6pil_dump_clear (dump);
+      lw6pil_dump_clear (sys_context, dump);
     }
   return ret;
 }
@@ -267,12 +265,14 @@ lw6pil_suite_init (lw6pil_dump_t * dump, int64_t timestamp)
 /**
  * lw6pil_suite_get_seq_0
  *
+ * @sys_context: global system context
+ *
  * Get the base seq_0 for the reference test suite.
  *
  * Return value: 64-bit integer.
  */
 int64_t
-lw6pil_suite_get_seq_0 ()
+lw6pil_suite_get_seq_0 (lw6sys_context_t * sys_context)
 {
   return _SEQ_0;
 }
@@ -280,6 +280,7 @@ lw6pil_suite_get_seq_0 ()
 /**
  * lw6pil_suite_get_node_id
  *
+ * @sys_context: global system context
  * @node_index: index of the node we want informations about
  *
  * Get the node_id associated to an index, typically a 64-bit
@@ -289,7 +290,7 @@ lw6pil_suite_get_seq_0 ()
  * Return value: the node id, as an unsigned 64-bit integer
  */
 u_int64_t
-lw6pil_suite_get_node_id (int node_index)
+lw6pil_suite_get_node_id (lw6sys_context_t * sys_context, int node_index)
 {
   u_int64_t ret = 0LL;
 
@@ -305,8 +306,7 @@ lw6pil_suite_get_node_id (int node_index)
       ret = _NODE_C_ID;
       break;
     default:
-      lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("invalid node_index %d"),
-		  node_index);
+      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("invalid node_index %d"), node_index);
     }
 
   return ret;
@@ -315,6 +315,7 @@ lw6pil_suite_get_node_id (int node_index)
 /**
  * lw6pil_suite_get_command_by_node_index
  *
+ * @sys_context: global system context
  * @node_index: index of the node (not its id)
  * @stage: major stage of the test suite
  * @step: minor step of the test suite
@@ -324,14 +325,13 @@ lw6pil_suite_get_node_id (int node_index)
  * Return value: static string, must not be freed.
  */
 const char *
-lw6pil_suite_get_command_by_node_index (int node_index, int stage, int step)
+lw6pil_suite_get_command_by_node_index (lw6sys_context_t * sys_context, int node_index, int stage, int step)
 {
   const char *ret = NULL;
   const char **commands = NULL;
   int i = 0;
 
-  if (node_index >= 0 && node_index < LW6PIL_SUITE_NB_NODES && stage >= 0
-      && stage < LW6PIL_SUITE_NB_STAGES)
+  if (node_index >= 0 && node_index < LW6PIL_SUITE_NB_NODES && stage >= 0 && stage < LW6PIL_SUITE_NB_STAGES)
     {
       commands = _commands[node_index][stage];
       while (i <= step && commands[i])
@@ -348,7 +348,7 @@ lw6pil_suite_get_command_by_node_index (int node_index, int stage, int step)
   return ret;
 }
 
-int
+static int
 _command_sort (const void *arg_a, const void *arg_b)
 {
   int ret = 0;
@@ -363,6 +363,7 @@ _command_sort (const void *arg_a, const void *arg_b)
 /**
  * lw6pil_suite_get_command_by_stage
  *
+ * @sys_context: global system context
  * @stage: major stage of the test suite
  * @step: minor step of the test suite
  *
@@ -372,7 +373,7 @@ _command_sort (const void *arg_a, const void *arg_b)
  * Return value: static string, must not be freed.
  */
 const char *
-lw6pil_suite_get_command_by_stage (int stage, int step)
+lw6pil_suite_get_command_by_stage (lw6sys_context_t * sys_context, int stage, int step)
 {
   const char *ret = NULL;
   const char **commands = NULL;
@@ -395,14 +396,11 @@ lw6pil_suite_get_command_by_stage (int stage, int step)
 	}
       if (step < nb_commands)
 	{
-	  sorted_commands =
-	    (const char **) LW6SYS_MALLOC ((nb_commands + 1) *
-					   sizeof (char *));
+	  sorted_commands = (const char **) LW6SYS_MALLOC (sys_context, (nb_commands + 1) * sizeof (char *));
 	  if (sorted_commands)
 	    {
 	      j = 0;
-	      for (node_index = 0; node_index < LW6PIL_SUITE_NB_NODES;
-		   ++node_index)
+	      for (node_index = 0; node_index < LW6PIL_SUITE_NB_NODES; ++node_index)
 		{
 		  i = 0;
 		  commands = _commands[node_index][stage];
@@ -421,11 +419,10 @@ lw6pil_suite_get_command_by_stage (int stage, int step)
 		   * function. But it's not a real problem, this is just for
 		   * testing, never used within real games.
 		   */
-		  qsort (sorted_commands, nb_commands, sizeof (char *),
-			 _command_sort);
+		  qsort (sorted_commands, nb_commands, sizeof (char *), _command_sort);
 		}
 	      ret = sorted_commands[step];
-	      LW6SYS_FREE (sorted_commands);
+	      LW6SYS_FREE (sys_context, sorted_commands);
 	    }
 	}
     }
@@ -436,6 +433,7 @@ lw6pil_suite_get_command_by_stage (int stage, int step)
 /**
  * lw6pil_suite_get_command_by_step
  *
+ * @sys_context: global system context
  * @step: minor step of the test suite
  *
  * Get the reference test suite message by step.
@@ -444,7 +442,7 @@ lw6pil_suite_get_command_by_stage (int stage, int step)
  * Return value: static string, must not be freed.
  */
 const char *
-lw6pil_suite_get_command_by_step (int step)
+lw6pil_suite_get_command_by_step (lw6sys_context_t * sys_context, int step)
 {
   const char *ret = NULL;
   const char **commands = NULL;
@@ -469,13 +467,11 @@ lw6pil_suite_get_command_by_step (int step)
     }
   if (step < nb_commands)
     {
-      sorted_commands =
-	(const char **) LW6SYS_MALLOC ((nb_commands + 1) * sizeof (char *));
+      sorted_commands = (const char **) LW6SYS_MALLOC (sys_context, (nb_commands + 1) * sizeof (char *));
       if (sorted_commands)
 	{
 	  j = 0;
-	  for (node_index = 0; node_index < LW6PIL_SUITE_NB_NODES;
-	       ++node_index)
+	  for (node_index = 0; node_index < LW6PIL_SUITE_NB_NODES; ++node_index)
 	    {
 	      for (stage = 0; stage < LW6PIL_SUITE_NB_STAGES; ++stage)
 		{
@@ -497,11 +493,10 @@ lw6pil_suite_get_command_by_step (int step)
 	       * function. But it's not a real problem, this is just for
 	       * testing, never used within real games.
 	       */
-	      qsort (sorted_commands, nb_commands, sizeof (char *),
-		     _command_sort);
+	      qsort (sorted_commands, nb_commands, sizeof (char *), _command_sort);
 	    }
 	  ret = sorted_commands[step];
-	  LW6SYS_FREE (sorted_commands);
+	  LW6SYS_FREE (sys_context, sorted_commands);
 	}
     }
 
@@ -511,6 +506,7 @@ lw6pil_suite_get_command_by_step (int step)
 /**
  * lw6pil_suite_get_checkpoint
  *
+ * @sys_context: global system context
  * @game_state_checksum: expected checksum for the given checkpoint (out param)
  * @seq: expected seq for the given checkpoint (out param)
  * @round: expected round for the given checkpoint (out param)
@@ -523,8 +519,7 @@ lw6pil_suite_get_command_by_step (int step)
  * Return value: none, everything in out params
  */
 void
-lw6pil_suite_get_checkpoint (u_int32_t * game_state_checksum, int64_t * seq,
-			     int *round, int stage)
+lw6pil_suite_get_checkpoint (lw6sys_context_t * sys_context, u_int32_t * game_state_checksum, int64_t * seq, int *round, int stage)
 {
   switch (stage)
     {
@@ -559,7 +554,7 @@ lw6pil_suite_get_checkpoint (u_int32_t * game_state_checksum, int64_t * seq,
       (*round) = _STAGE_6_ROUND;
       break;
     default:
-      lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("invalid stage %d"), stage);
+      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("invalid stage %d"), stage);
       (*game_state_checksum) = 0;
       (*seq) = 0LL;
       (*round) = 0;
