@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -36,6 +36,7 @@ typedef struct _coverage_check_s
 /**
  * lw6scm_coverage_new
  *
+ * @sys_context: global system context
  * @funcs: list of functions, used as an input to size the hash correctly
  *
  * Creates a new coverage hash, this is a simple hash containing pointers
@@ -46,18 +47,16 @@ typedef struct _coverage_check_s
  * Return value: newly allocated hash
  */
 lw6sys_hash_t *
-lw6scm_coverage_new (lw6sys_list_t * funcs)
+lw6scm_coverage_new (lw6sys_context_t * sys_context, lw6sys_list_t * funcs)
 {
   lw6sys_hash_t *ret = NULL;
   int funcs_size = 0;
   int ret_size = 0;
 
-  funcs_size = lw6sys_list_length (funcs);
+  funcs_size = lw6sys_list_length (sys_context, funcs);
   ret_size = (funcs_size) / 2 + 1;
-  lw6sys_log (LW6SYS_LOG_DEBUG,
-	      _x_ ("init coverage hash with %d slots for a max of %d funcs"),
-	      ret_size, funcs_size);
-  ret = lw6sys_hash_new (lw6sys_free_callback, ret_size);
+  lw6sys_log (sys_context, LW6SYS_LOG_DEBUG, _x_ ("init coverage hash with %d slots for a max of %d funcs"), ret_size, funcs_size);
+  ret = lw6sys_hash_new (sys_context, lw6sys_free_callback, ret_size);
 
   return ret;
 }
@@ -67,64 +66,57 @@ lw6scm_coverage_new (lw6sys_list_t * funcs)
  *
  * Registers a call on a given function.
  *
+ * @sys_context: global system context
  * @coverage: the hash to use to store the update
  * @func: the name of the function (its callable scheme name)
  *
  * Return value: none.
  */
 void
-lw6scm_coverage_call (lw6sys_hash_t * coverage, const char *func)
+lw6scm_coverage_call (lw6sys_context_t * sys_context, lw6sys_hash_t * coverage, const char *func)
 {
   void *value = NULL;
   int *calls;
 
   if (coverage)
     {
-      value = lw6sys_hash_get (coverage, func);
+      value = lw6sys_hash_get (sys_context, coverage, func);
       if (value)
 	{
 	  calls = (int *) value;
 	  ++(*calls);
-	  lw6sys_log (LW6SYS_LOG_DEBUG,
-		      _x_ ("calling scm function \"%s\", #%d"), func,
-		      (*calls));
+	  lw6sys_log (sys_context, LW6SYS_LOG_DEBUG, _x_ ("calling scm function \"%s\", #%d"), func, (*calls));
 	}
       else
 	{
-	  calls = (int *) LW6SYS_MALLOC (sizeof (int));
+	  calls = (int *) LW6SYS_MALLOC (sys_context, sizeof (int));
 	  if (calls)
 	    {
 	      (*calls) = 1;
-	      lw6sys_hash_set (coverage, func, calls);
-	      lw6sys_log (LW6SYS_LOG_INFO,
-			  _x_ ("calling scm function \"%s\", 1st call"),
-			  func);
+	      lw6sys_hash_set (sys_context, coverage, func, calls);
+	      lw6sys_log (sys_context, LW6SYS_LOG_INFO, _x_ ("calling scm function \"%s\", 1st call"), func);
 	    }
 	}
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING,
-		  _x_ ("trying to register function call on NULL coverage"));
+      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("trying to register function call on NULL coverage"));
     }
 }
 
 static void
-_coverage_log_callback (void *func_data, const char *key, void *value)
+_coverage_log_callback (lw6sys_context_t * sys_context, void *func_data, const char *key, void *value)
 {
   int calls = 0;
 
   if (value)
     {
       calls = *((int *) value);
-      lw6sys_log (LW6SYS_LOG_INFO,
-		  _x_ ("script function \"%s\" called %d times"), key, calls);
+      lw6sys_log (sys_context, LW6SYS_LOG_INFO, _x_ ("script function \"%s\" called %d times"), key, calls);
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING,
-		  _x_ ("script function \"%s\" has NULL coverage entry"),
-		  key);
+      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("script function \"%s\" has NULL coverage entry"), key);
     }
 }
 
@@ -134,50 +126,52 @@ _coverage_log_callback (void *func_data, const char *key, void *value)
  * Logs the information about which function has been called, and how many times.
  * This is only about scheme functions.
  *
+ * @sys_context: global system context
  * @coverage: the hash containing the call data
  *
  * Return value: none
  */
 void
-lw6scm_coverage_log (lw6sys_hash_t * coverage)
+lw6scm_coverage_log (lw6sys_context_t * sys_context, lw6sys_hash_t * coverage)
 {
   if (coverage)
     {
-      lw6sys_hash_map (coverage, _coverage_log_callback, NULL);
+      lw6sys_hash_map (sys_context, coverage, _coverage_log_callback, NULL);
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("trying to log NULL coverage"));
+      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("trying to log NULL coverage"));
     }
 }
 
 static void
-_coverage_check_callback (void *func_data, void *value)
+_coverage_check_callback (lw6sys_context_t * sys_context, void *func_data, void *value)
 {
   const char *key = (const char *) value;
   _coverage_check_t *cc = (_coverage_check_t *) func_data;
   char *c_name = NULL;
 
-  lw6sys_log (LW6SYS_LOG_INFO, _x_ ("checking script function \"%s\""), key);
-  c_name = lw6scm_funcname_scm2c (key);
+  lw6sys_log (sys_context, LW6SYS_LOG_INFO, _x_ ("checking script function \"%s\""), key);
+  c_name = lw6scm_funcname_scm2c (sys_context, key);
   if (c_name)
     {
-      if (lw6sys_hash_has_key (cc->coverage, c_name))
+      if (lw6sys_hash_has_key (sys_context, cc->coverage, c_name))
 	{
 	  ++(cc->n);
 	}
       else
 	{
-	  lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("no call to \"%s\""), key);
+	  lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("no call to \"%s\""), key);
 	  *(cc->ret) = 0;
 	}
-      LW6SYS_FREE (c_name);
+      LW6SYS_FREE (sys_context, c_name);
     }
 }
 
 /**
  * lw6scm_coverage_check
  *
+ * @sys_context: global system context
  * @percent: if not NULL, will contain the percentage of coverage
  * @coverage: object to query, containing coverage information
  * @funcs: list of functions to check
@@ -192,8 +186,7 @@ _coverage_check_callback (void *func_data, void *value)
  * Return value: 1 if OK, 0 if KO.
  */
 int
-lw6scm_coverage_check (int *percent, lw6sys_hash_t * coverage,
-		       lw6sys_list_t * funcs)
+lw6scm_coverage_check (lw6sys_context_t * sys_context, int *percent, lw6sys_hash_t * coverage, lw6sys_list_t * funcs)
 {
   int ret = 0;
   int funcs_size = 0;
@@ -203,11 +196,11 @@ lw6scm_coverage_check (int *percent, lw6sys_hash_t * coverage,
     {
       ret = 1;
       memset (&cc, 0, sizeof (_coverage_check_t));
-      funcs_size = lw6sys_list_length (funcs);
+      funcs_size = lw6sys_list_length (sys_context, funcs);
       cc.ret = &ret;
       cc.coverage = coverage;
 
-      lw6sys_list_map (funcs, _coverage_check_callback, (void *) &cc);
+      lw6sys_list_map (sys_context, funcs, _coverage_check_callback, (void *) &cc);
       if (percent != NULL && funcs_size > 0)
 	{
 	  (*percent) = (100 * cc.n) / funcs_size;
@@ -215,7 +208,7 @@ lw6scm_coverage_check (int *percent, lw6sys_hash_t * coverage,
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("trying to check NULL coverage"));
+      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("trying to check NULL coverage"));
     }
 
   return ret;
