@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -37,6 +37,7 @@
 /**
  * lw6scm_funcname_scm2c
  *
+ * @sys_context: global system context
  * @funcname: function name to change
  *
  * Transforms a function name of the form c-my-func to
@@ -45,15 +46,14 @@
  * Return value: new allocated string.
  */
 char *
-lw6scm_funcname_scm2c (const char *funcname)
+lw6scm_funcname_scm2c (lw6sys_context_t * sys_context, const char *funcname)
 {
   char *ret = NULL;
   char *ptr = NULL;
 
   if (strlen (funcname) > _SCM_PREFIX_LEN)
     {
-      ret =
-	lw6sys_new_sprintf ("%s%s", _C_PREFIX, funcname + _SCM_PREFIX_LEN);
+      ret = lw6sys_new_sprintf (sys_context, "%s%s", _C_PREFIX, funcname + _SCM_PREFIX_LEN);
       if (ret)
 	{
 	  for (ptr = ret; *ptr; ++ptr)
@@ -72,6 +72,7 @@ lw6scm_funcname_scm2c (const char *funcname)
 /**
  * lw6scm_funcname_scm2c
  *
+ * @sys_context: global system context
  * @funcname: function name to change
  *
  * Transforms a function name of the form _scm_my_func to
@@ -80,15 +81,14 @@ lw6scm_funcname_scm2c (const char *funcname)
  * Return value: new allocated string.
  */
 char *
-lw6scm_funcname_c2scm (const char *funcname)
+lw6scm_funcname_c2scm (lw6sys_context_t * sys_context, const char *funcname)
 {
   char *ret = NULL;
   char *ptr = NULL;
 
   if (strlen (funcname) > _C_PREFIX_LEN)
     {
-      ret =
-	lw6sys_new_sprintf ("%s%s", _SCM_PREFIX, funcname + _C_PREFIX_LEN);
+      ret = lw6sys_new_sprintf (sys_context, "%s%s", _SCM_PREFIX, funcname + _C_PREFIX_LEN);
       if (ret)
 	{
 	  for (ptr = ret; *ptr; ++ptr)
