@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -29,6 +29,7 @@
 /**
  * lw6scm_utils_to_0str
  *
+ * @sys_context: global system context
  * @string: SCM object to convert
  *
  * Helper function, creates a 0 terminated string
@@ -39,7 +40,7 @@
  * Return value: newly allocated string, pointer must be freed.
  */
 char *
-lw6scm_utils_to_0str (SCM string)
+lw6scm_utils_to_0str (lw6sys_context_t * sys_context, SCM string)
 {
   char *c_string = NULL;
   int length = 0;
@@ -62,7 +63,7 @@ lw6scm_utils_to_0str (SCM string)
    * string handling is awfull enough...
    */
   c_length = length * 2 * sizeof (char);
-  c_string = (char *) LW6SYS_CALLOC (c_length + 3);
+  c_string = (char *) LW6SYS_CALLOC (sys_context, c_length + 3);
   if (c_string)
     {
       if (length > 0)
@@ -72,9 +73,7 @@ lw6scm_utils_to_0str (SCM string)
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING,
-		  _x_
-		  ("unable to convert a guile SCM string to a standard C \"'\\0' terminated\" string"));
+      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("unable to convert a guile SCM string to a standard C \"'\\0' terminated\" string"));
     }
 
   return c_string;
@@ -83,6 +82,7 @@ lw6scm_utils_to_0str (SCM string)
 /**
  * lw6scm_utils_to_scm_str_list
  *
+ * @sys_context: global system context
  * @c_list: list object to convert
  *
  * Transform a C list containing strings to a Guile list containing
@@ -91,17 +91,16 @@ lw6scm_utils_to_0str (SCM string)
  * Return value: Guile object, a list of strings
  */
 SCM
-lw6scm_utils_to_scm_str_list (lw6sys_list_t * c_list)
+lw6scm_utils_to_scm_str_list (lw6sys_context_t * sys_context, lw6sys_list_t * c_list)
 {
   SCM ret = SCM_EOL;
   lw6sys_list_t *c_item = NULL;
 
-  for (c_item = c_list; c_item; c_item = lw6sys_list_next (c_item))
+  for (c_item = c_list; c_item; c_item = lw6sys_list_next (sys_context, c_item))
     {
       if (c_item->data)
 	{
-	  ret =
-	    scm_cons (scm_from_locale_string ((char *) c_item->data), ret);
+	  ret = scm_cons (scm_from_locale_string ((char *) c_item->data), ret);
 	}
     }
 
@@ -111,23 +110,21 @@ lw6scm_utils_to_scm_str_list (lw6sys_list_t * c_list)
 }
 
 static void
-_to_scm_str_assoc_callback (void *func_data, const char *key, void *value)
+_to_scm_str_assoc_callback (lw6sys_context_t * sys_context, void *func_data, const char *key, void *value)
 {
   SCM *ret_p = (SCM *) func_data;
   char *value_str = (char *) value;
 
   if (value_str && (SCM_CONSP (*ret_p) || (*ret_p) == SCM_EOL))
     {
-      (*ret_p) =
-	scm_cons (scm_cons
-		  (scm_from_locale_string (key),
-		   scm_from_locale_string (value_str)), *ret_p);
+      (*ret_p) = scm_cons (scm_cons (scm_from_locale_string (key), scm_from_locale_string (value_str)), *ret_p);
     }
 }
 
 /**
  * lw6scm_utils_to_scm_str_assoc
  *
+ * @sys_context: global system context
  * @c_assoc: assoc object to convert
  *
  * Transform a C assoc containing strings to a Guile assoc containing
@@ -136,11 +133,11 @@ _to_scm_str_assoc_callback (void *func_data, const char *key, void *value)
  * Return value: Guile object, an assoc of strings
  */
 SCM
-lw6scm_utils_to_scm_str_assoc (lw6sys_assoc_t * c_assoc)
+lw6scm_utils_to_scm_str_assoc (lw6sys_context_t * sys_context, lw6sys_assoc_t * c_assoc)
 {
   SCM ret = SCM_EOL;
 
-  lw6sys_assoc_map (c_assoc, _to_scm_str_assoc_callback, &ret);
+  lw6sys_assoc_map (sys_context, c_assoc, _to_scm_str_assoc_callback, &ret);
   if (SCM_CONSP (ret) || ret == SCM_EOL)
     {
       ret = scm_reverse (ret);
@@ -152,6 +149,7 @@ lw6scm_utils_to_scm_str_assoc (lw6sys_assoc_t * c_assoc)
 /**
  * lw6scm_utils_to_sys_str_list
  *
+ * @sys_context: global system context
  * @list: SCM object to convert
  *
  * Creates a C list from an SCM list containing strings.
@@ -161,11 +159,11 @@ lw6scm_utils_to_scm_str_assoc (lw6sys_assoc_t * c_assoc)
  * Return value: new C list object
  */
 lw6sys_list_t *
-lw6scm_utils_to_sys_str_list (SCM list)
+lw6scm_utils_to_sys_str_list (lw6sys_context_t * sys_context, SCM list)
 {
   lw6sys_list_t *c_list = NULL;
 
-  c_list = lw6sys_list_new (lw6sys_free_callback);
+  c_list = lw6sys_list_new (sys_context, lw6sys_free_callback);
   if (c_list)
     {
       if (SCM_CONSP (list))
@@ -178,10 +176,10 @@ lw6scm_utils_to_sys_str_list (SCM list)
 	  for (i = n - 1; i >= 0; --i)
 	    {
 	      item = scm_list_ref (list, scm_from_int (i));
-	      c_item = lw6scm_utils_to_0str (item);
+	      c_item = lw6scm_utils_to_0str (sys_context, item);
 	      if (c_item)
 		{
-		  lw6sys_list_push_front (&c_list, c_item);
+		  lw6sys_list_push_front (sys_context, &c_list, c_item);
 		  // do not free c_item, list will do it
 		}
 	    }
@@ -194,6 +192,7 @@ lw6scm_utils_to_sys_str_list (SCM list)
 /**
  * lw6scm_utils_to_sys_str_assoc
  *
+ * @sys_context: global system context
  * @assoc: SCM object to convert
  *
  * Creates a C assoc from an SCM assoc containing strings.
@@ -203,11 +202,11 @@ lw6scm_utils_to_sys_str_list (SCM list)
  * Return value: new C assoc object
  */
 lw6sys_assoc_t *
-lw6scm_utils_to_sys_str_assoc (SCM assoc)
+lw6scm_utils_to_sys_str_assoc (lw6sys_context_t * sys_context, SCM assoc)
 {
   lw6sys_assoc_t *c_assoc = NULL;
 
-  c_assoc = lw6sys_assoc_new (lw6sys_free_callback);
+  c_assoc = lw6sys_assoc_new (sys_context, lw6sys_free_callback);
   if (c_assoc)
     {
       if (SCM_CONSP (assoc))
@@ -222,12 +221,12 @@ lw6scm_utils_to_sys_str_assoc (SCM assoc)
 	      item = scm_list_ref (assoc, scm_from_int (i));
 	      if (SCM_CONSP (item))
 		{
-		  key = lw6scm_utils_to_0str (scm_car (item));
-		  value = lw6scm_utils_to_0str (scm_cdr (item));
+		  key = lw6scm_utils_to_0str (sys_context, scm_car (item));
+		  value = lw6scm_utils_to_0str (sys_context, scm_cdr (item));
 		  if (key && value)
 		    {
-		      lw6sys_assoc_set (&c_assoc, key, (void *) value);
-		      LW6SYS_FREE (key);
+		      lw6sys_assoc_set (sys_context, &c_assoc, key, (void *) value);
+		      LW6SYS_FREE (sys_context, key);
 		      // value must not be freed now
 		    }
 		}
