@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -30,7 +30,7 @@
 #define _LW6SIM_SIMULATION_TIME 60
 
 /* sim-mask */
-extern int _lw6sim_mask_get_max (int nb_teams);
-extern int _lw6sim_mask_is_valid (int mask);
+extern int _lw6sim_mask_get_max (lw6sys_context_t * sys_context, int nb_teams);
+extern int _lw6sim_mask_is_valid (lw6sys_context_t * sys_context, int mask);
 
 #endif
