@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -30,6 +30,7 @@
 /**
  * lw6sim_results_zero
  *
+ * @sys_context: global system context
  * @results: out param, will be cleared
  *
  * Fills the struct with zeroes.
@@ -37,7 +38,7 @@
  * Return value: none.
  */
 void
-lw6sim_results_zero (lw6sim_results_t * results)
+lw6sim_results_zero (lw6sys_context_t * sys_context, lw6sim_results_t * results)
 {
   memset (results, 0, sizeof (lw6sim_results_t));
 }
@@ -45,6 +46,7 @@ lw6sim_results_zero (lw6sim_results_t * results)
 /**
  * lw6sim_results_update_percents
  *
+ * @sys_context: global system context
  * @results: results set to work on (in/out param)
  *
  * Updates the structure so that the percent members
@@ -53,7 +55,7 @@ lw6sim_results_zero (lw6sim_results_t * results)
  * Return value: 1 on success, 0 on failure.
  */
 int
-lw6sim_results_update_percents (lw6sim_results_t * results)
+lw6sim_results_update_percents (lw6sys_context_t * sys_context, lw6sim_results_t * results)
 {
   int ret = 0;
   int i;
@@ -67,9 +69,7 @@ lw6sim_results_update_percents (lw6sim_results_t * results)
     {
       for (i = 0; i < LW6MAP_MAX_NB_TEAMS; ++i)
 	{
-	  results->percent[i] =
-	    (((float) results->absolute[i]) * 100.0f) /
-	    ((float) absolute_total);
+	  results->percent[i] = (((float) results->absolute[i]) * 100.0f) / ((float) absolute_total);
 	}
       ret = 1;
     }
