@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -28,8 +28,8 @@
 #include "sim-internal.h"
 
 static int
-_simulate (int argc, const char *argv[], lw6sim_results_t * results,
-	   lw6ker_game_struct_t * game_struct, int mask, char *bot_backend)
+_simulate (lw6sys_context_t * sys_context, int argc, const char *argv[], lw6sim_results_t * results, lw6ker_game_struct_t * game_struct, int mask,
+	   char *bot_backend)
 {
   int ret = 0;
   lw6ker_game_state_t *game_state = NULL;
@@ -52,11 +52,10 @@ _simulate (int argc, const char *argv[], lw6sim_results_t * results,
   memset (&cursor, 0, sizeof (lw6ker_cursor_t));
   memset (&seed, 0, sizeof (lw6bot_seed_t));
 
-  node_id = lw6sys_generate_id_64 ();
-  nb_rounds =
-    game_struct->rules.rounds_per_sec * game_struct->rules.total_time;
+  node_id = lw6sys_generate_id_64 (sys_context);
+  nb_rounds = game_struct->rules.rounds_per_sec * game_struct->rules.total_time;
 
-  game_state = lw6ker_game_state_new (game_struct, NULL);
+  game_state = lw6ker_game_state_new (sys_context, game_struct, NULL);
   if (game_state)
     {
       seed.game_state = game_state;
@@ -67,21 +66,19 @@ _simulate (int argc, const char *argv[], lw6sim_results_t * results,
 
       ret = 1;
 
-      lw6ker_game_state_register_node (game_state, node_id);
+      lw6ker_game_state_register_node (sys_context, game_state, node_id);
       for (i = 0; i < LW6MAP_MAX_NB_TEAMS; ++i)
 	{
-	  if (lw6ker_team_mask_is_concerned (i, mask))
+	  if (lw6ker_team_mask_is_concerned (sys_context, i, mask))
 	    {
 	      cursors_colors[nb_cursors] = i;
-	      cursors_ids[nb_cursors] = lw6sys_generate_id_16 ();
-	      lw6ker_game_state_add_cursor (game_state, node_id,
-					    cursors_ids[nb_cursors], i);
-	      cursors_bots[nb_cursors] =
-		lw6bot_create_backend (argc, argv, bot_backend);
+	      cursors_ids[nb_cursors] = lw6sys_generate_id_16 (sys_context);
+	      lw6ker_game_state_add_cursor (sys_context, game_state, node_id, cursors_ids[nb_cursors], i);
+	      cursors_bots[nb_cursors] = lw6bot_create_backend (sys_context, argc, argv, bot_backend);
 	      if (cursors_bots[nb_cursors])
 		{
 		  seed.param.cursor_id = cursors_ids[nb_cursors];
-		  ret = ret && lw6bot_init (cursors_bots[nb_cursors], &seed);
+		  ret = ret && lw6bot_init (sys_context, cursors_bots[nb_cursors], &seed);
 		}
 	      nb_cursors++;
 	    }
@@ -95,21 +92,21 @@ _simulate (int argc, const char *argv[], lw6sim_results_t * results,
 		{
 		  if (cursors_bots[i])
 		    {
-		      lw6bot_next_move (cursors_bots[i], &x, &y);
-		      lw6ker_cursor_reset (&cursor);
+		      lw6bot_next_move (sys_context, cursors_bots[i], &x, &y);
+		      lw6ker_cursor_reset (sys_context, &cursor);
 		      cursor.pos.x = x;
 		      cursor.pos.y = y;
 		      cursor.node_id = node_id;
 		      cursor.cursor_id = cursors_ids[i];
-		      lw6ker_game_state_set_cursor (game_state, &cursor);
+		      lw6ker_game_state_set_cursor (sys_context, game_state, &cursor);
 		    }
 		}
 	    }
 
-	  lw6ker_game_state_do_round (game_state);
+	  lw6ker_game_state_do_round (sys_context, game_state);
 	}
 
-      lw6ker_score_array_update (&score_array, game_state);
+      lw6ker_score_array_update (sys_context, &score_array, game_state);
       for (i = 0; i < score_array.nb_scores; ++i)
 	{
 	  j = score_array.scores[i].team_color;
@@ -117,9 +114,7 @@ _simulate (int argc, const char *argv[], lw6sim_results_t * results,
 	    {
 	      bonus = score_array.scores[i].consolidated_percent;
 	      results->absolute[j] += bonus;
-	      lw6sys_log (LW6SYS_LOG_INFO,
-			  _x_ ("bonus for team %d is %d, new absolute is %d"),
-			  j, bonus, results->absolute[j]);
+	      lw6sys_log (sys_context, LW6SYS_LOG_INFO, _x_ ("bonus for team %d is %d, new absolute is %d"), j, bonus, results->absolute[j]);
 	    }
 	}
 
@@ -127,12 +122,12 @@ _simulate (int argc, const char *argv[], lw6sim_results_t * results,
 	{
 	  if (cursors_bots[i])
 	    {
-	      lw6bot_quit (cursors_bots[i]);
-	      lw6bot_destroy_backend (cursors_bots[i]);
+	      lw6bot_quit (sys_context, cursors_bots[i]);
+	      lw6bot_destroy_backend (sys_context, cursors_bots[i]);
 	    }
 	}
 
-      lw6ker_game_state_free (game_state);
+      lw6ker_game_state_free (sys_context, game_state);
     }
 
   return ret;
@@ -141,6 +136,7 @@ _simulate (int argc, const char *argv[], lw6sim_results_t * results,
 /**
  * lw6sim_simulate
  *
+ * @sys_context: global system context
  * @argc: argc as passed to @main
  * @argv: argv as passed to @main
  * @results: out param, results of the simulation
@@ -155,8 +151,7 @@ _simulate (int argc, const char *argv[], lw6sim_results_t * results,
  * Return value: 1 on success, 0 on failure.
  */
 int
-lw6sim_simulate (int argc, const char *argv[], lw6sim_results_t * results,
-		 int nb_teams, char *bot_backend)
+lw6sim_simulate (lw6sys_context_t * sys_context, int argc, const char *argv[], lw6sim_results_t * results, int nb_teams, char *bot_backend)
 {
   int ret = 0;
   int max_mask;
@@ -164,43 +159,38 @@ lw6sim_simulate (int argc, const char *argv[], lw6sim_results_t * results,
   lw6map_level_t *level = NULL;
   lw6ker_game_struct_t *game_struct = NULL;
 
-  level = lw6map_builtin_defaults ();
+  level = lw6map_builtin_defaults (sys_context);
   level->param.rules.total_time = _LW6SIM_SIMULATION_TIME;
   if (level)
     {
-      game_struct = lw6ker_game_struct_new (level, NULL);
+      game_struct = lw6ker_game_struct_new (sys_context, level, NULL);
       if (game_struct)
 	{
-	  max_mask = _lw6sim_mask_get_max (nb_teams);
-	  lw6sim_results_zero (results);
+	  max_mask = _lw6sim_mask_get_max (sys_context, nb_teams);
+	  lw6sim_results_zero (sys_context, results);
 	  results->nb_teams = nb_teams;
 	  ret = 1;
 	  for (i = 0; i < max_mask; ++i)
 	    {
-	      if (_lw6sim_mask_is_valid (i))
+	      if (_lw6sim_mask_is_valid (sys_context, i))
 		{
 		  if (ret)
 		    {
-		      lw6sys_log (LW6SYS_LOG_INFO, _x_ ("simulating %d/%d"),
-				  i, max_mask);
-		      ret =
-			_simulate (argc, argv, results, game_struct, i,
-				   bot_backend);
+		      lw6sys_log (sys_context, LW6SYS_LOG_INFO, _x_ ("simulating %d/%d"), i, max_mask);
+		      ret = _simulate (sys_context, argc, argv, results, game_struct, i, bot_backend);
 		    }
 		}
 	      else
 		{
-		  lw6sys_log (LW6SYS_LOG_INFO,
-			      _x_ ("skipping simulation %d/%d, unvalid mask"),
-			      i, max_mask);
+		  lw6sys_log (sys_context, LW6SYS_LOG_INFO, _x_ ("skipping simulation %d/%d, unvalid mask"), i, max_mask);
 		}
 	    }
-	  lw6ker_game_struct_free (game_struct);
+	  lw6ker_game_struct_free (sys_context, game_struct);
 	}
-      lw6map_free (level);
+      lw6map_free (sys_context, level);
     }
 
-  ret = lw6sim_results_update_percents (results) && ret;
+  ret = lw6sim_results_update_percents (sys_context, results) && ret;
 
   return ret;
 }
@@ -208,6 +198,7 @@ lw6sim_simulate (int argc, const char *argv[], lw6sim_results_t * results,
 /**
  * lw6sim_simulate_basic
  *
+ * @sys_context: global system context
  * @argc: argc as passed to @main
  * @argv: argv as passed to @main
  * @results: out param, results of the simulation
@@ -219,16 +210,15 @@ lw6sim_simulate (int argc, const char *argv[], lw6sim_results_t * results,
  * Return value: 1 on success, 0 on failure.
  */
 int
-lw6sim_simulate_basic (int argc, const char *argv[],
-		       lw6sim_results_t * results)
+lw6sim_simulate_basic (lw6sys_context_t * sys_context, int argc, const char *argv[], lw6sim_results_t * results)
 {
-  return lw6sim_simulate (argc, argv, results, LW6SIM_SIMULATE_BASIC_NB_TEAMS,
-			  LW6SIM_SIMULATE_BASIC_BOT_BACKEND);
+  return lw6sim_simulate (sys_context, argc, argv, results, LW6SIM_SIMULATE_BASIC_NB_TEAMS, LW6SIM_SIMULATE_BASIC_BOT_BACKEND);
 }
 
 /**
  * lw6sim_simulate_full
  *
+ * @sys_context: global system context
  * @argc: argc as passed to @main
  * @argv: argv as passed to @main
  * @results: out param, results of the simulation
@@ -240,9 +230,7 @@ lw6sim_simulate_basic (int argc, const char *argv[],
  * Return value: 1 on success, 0 on failure.
  */
 int
-lw6sim_simulate_full (int argc, const char *argv[],
-		      lw6sim_results_t * results)
+lw6sim_simulate_full (lw6sys_context_t * sys_context, int argc, const char *argv[], lw6sim_results_t * results)
 {
-  return lw6sim_simulate (argc, argv, results, LW6SIM_SIMULATE_FULL_NB_TEAMS,
-			  LW6SIM_SIMULATE_FULL_BOT_BACKEND);
+  return lw6sim_simulate (sys_context, argc, argv, results, LW6SIM_SIMULATE_FULL_NB_TEAMS, LW6SIM_SIMULATE_FULL_BOT_BACKEND);
 }
