@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -28,7 +28,7 @@
 #include "mod-csound-internal.h"
 
 extern int
-_mod_csound_play_fx (_mod_csound_context_t * csound_context, int fx_id)
+_mod_csound_play_fx (lw6sys_context_t * sys_context, _mod_csound_context_t * csound_context, int fx_id)
 {
   int ret = 0;
 
