@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -28,8 +28,7 @@
 #include "mod-csound-internal.h"
 
 int
-_mod_csound_is_music_file (_mod_csound_context_t *
-			   csound_context, char *music_file)
+_mod_csound_is_music_file (lw6sys_context_t * sys_context, _mod_csound_context_t * csound_context, char *music_file)
 {
   int ret = 0;
 
@@ -40,8 +39,7 @@ _mod_csound_is_music_file (_mod_csound_context_t *
 }
 
 int
-_mod_csound_play_music_file (_mod_csound_context_t * snd_context,
-			     char *music_file)
+_mod_csound_play_music_file (lw6sys_context_t * sys_context, _mod_csound_context_t * snd_context, char *music_file)
 {
   int ret = 0;
 
@@ -52,8 +50,7 @@ _mod_csound_play_music_file (_mod_csound_context_t * snd_context,
 }
 
 int
-_mod_csound_play_music_random (_mod_csound_context_t * csound_context,
-			       char *music_path, char *music_filter,
+_mod_csound_play_music_random (lw6sys_context_t * sys_context, _mod_csound_context_t * csound_context, char *music_path, char *music_filter,
 			       char *music_exclude)
 {
   int ret = 0;
@@ -65,7 +62,7 @@ _mod_csound_play_music_random (_mod_csound_context_t * csound_context,
 }
 
 void
-_mod_csound_stop_music (_mod_csound_context_t * csound_context)
+_mod_csound_stop_music (lw6sys_context_t * sys_context, _mod_csound_context_t * csound_context)
 {
   // todo...
 }
