@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -28,11 +28,11 @@
 #include "mod-csound-internal.h"
 
 char *
-_mod_csound_repr (_mod_csound_context_t * csound_context, u_int32_t id)
+_mod_csound_repr (lw6sys_context_t * sys_context, _mod_csound_context_t * csound_context, u_int32_t id)
 {
   char *ret = NULL;
 
-  ret = lw6sys_new_sprintf (_x_ ("%u csound"), id);
+  ret = lw6sys_new_sprintf (sys_context, _x_ ("%u csound"), id);
 
   return ret;
 }
