@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -28,8 +28,7 @@
 #include "mod-csound-internal.h"
 
 extern void
-_mod_csound_set_fx_volume (_mod_csound_context_t * csound_context,
-			   float volume)
+_mod_csound_set_fx_volume (lw6sys_context_t * sys_context, _mod_csound_context_t * csound_context, float volume)
 {
   csound_context->volume.fx = volume;
 
@@ -37,8 +36,7 @@ _mod_csound_set_fx_volume (_mod_csound_context_t * csound_context,
 }
 
 extern void
-_mod_csound_set_water_volume (_mod_csound_context_t * csound_context,
-			      float volume)
+_mod_csound_set_water_volume (lw6sys_context_t * sys_context, _mod_csound_context_t * csound_context, float volume)
 {
   csound_context->volume.water = volume;
 
@@ -46,8 +44,7 @@ _mod_csound_set_water_volume (_mod_csound_context_t * csound_context,
 }
 
 extern void
-_mod_csound_set_music_volume (_mod_csound_context_t * csound_context,
-			      float volume)
+_mod_csound_set_music_volume (lw6sys_context_t * sys_context, _mod_csound_context_t * csound_context, float volume)
 {
   csound_context->volume.music = volume;
 
