@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -30,28 +30,27 @@
 #define SUB "snd/ogg"
 
 int
-_mod_ogg_path_init (_mod_ogg_context_t * ogg_context, int argc,
-		    const char *argv[])
+_mod_ogg_path_init (lw6sys_context_t * sys_context, _mod_ogg_context_t * ogg_context, int argc, const char *argv[])
 {
   char *data_root_dir = NULL;
   int ret = 0;
 
-  data_root_dir = lw6sys_get_data_dir (argc, argv);
+  data_root_dir = lw6sys_get_data_dir (sys_context, argc, argv);
   if (data_root_dir)
     {
-      ogg_context->path.data_dir = lw6sys_path_concat (data_root_dir, SUB);
+      ogg_context->path.data_dir = lw6sys_path_concat (sys_context, data_root_dir, SUB);
       ret = 1;
-      LW6SYS_FREE (data_root_dir);
+      LW6SYS_FREE (sys_context, data_root_dir);
     }
 
   return ret;
 }
 
 void
-_mod_ogg_path_quit (_mod_ogg_context_t * ogg_context)
+_mod_ogg_path_quit (lw6sys_context_t * sys_context, _mod_ogg_context_t * ogg_context)
 {
   if (ogg_context->path.data_dir)
     {
-      LW6SYS_FREE (ogg_context->path.data_dir);
+      LW6SYS_FREE (sys_context, ogg_context->path.data_dir);
     }
 }
