@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -28,7 +28,7 @@
 #include "mod-ogg-internal.h"
 
 char *
-_mod_ogg_repr (_mod_ogg_context_t * ogg_context, u_int32_t id)
+_mod_ogg_repr (lw6sys_context_t * sys_context, _mod_ogg_context_t * ogg_context, u_int32_t id)
 {
   char *ret = NULL;
   SDL_version version;
@@ -36,11 +36,9 @@ _mod_ogg_repr (_mod_ogg_context_t * ogg_context, u_int32_t id)
   memset (&version, 0, sizeof (SDL_version));
   version = *SDL_Linked_Version ();
   ret =
-    lw6sys_new_sprintf (_x_
+    lw6sys_new_sprintf (sys_context, _x_
 			("%u ogg SDL version %u.%u.%u volume %0.1f-%0.1f-%0.1f"),
-			id, version.major, version.minor, version.patch,
-			ogg_context->volume.fx, ogg_context->volume.water,
-			ogg_context->volume.music);
+			id, version.major, version.minor, version.patch, ogg_context->volume.fx, ogg_context->volume.water, ogg_context->volume.music);
 
   return ret;
 }
