@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -28,7 +28,7 @@
 #include "mod-ogg-internal.h"
 
 extern void
-_mod_ogg_set_fx_volume (_mod_ogg_context_t * ogg_context, float volume)
+_mod_ogg_set_fx_volume (lw6sys_context_t * sys_context, _mod_ogg_context_t * ogg_context, float volume)
 {
   int i = 0;
 
@@ -41,7 +41,7 @@ _mod_ogg_set_fx_volume (_mod_ogg_context_t * ogg_context, float volume)
 }
 
 extern void
-_mod_ogg_set_water_volume (_mod_ogg_context_t * ogg_context, float volume)
+_mod_ogg_set_water_volume (lw6sys_context_t * sys_context, _mod_ogg_context_t * ogg_context, float volume)
 {
   ogg_context->volume.water = volume;
 
@@ -52,14 +52,12 @@ _mod_ogg_set_water_volume (_mod_ogg_context_t * ogg_context, float volume)
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING,
-		  _x_ ("not even channels (%d) to handle water"),
-		  ogg_context->mixer.nb_channels);
+      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("not even channels (%d) to handle water"), ogg_context->mixer.nb_channels);
     }
 }
 
 extern void
-_mod_ogg_set_music_volume (_mod_ogg_context_t * ogg_context, float volume)
+_mod_ogg_set_music_volume (lw6sys_context_t * sys_context, _mod_ogg_context_t * ogg_context, float volume)
 {
   ogg_context->volume.music = volume;
 
