@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -28,7 +28,7 @@
 #include "mod-httpd-internal.h"
 
 _mod_httpd_response_t *
-_mod_httpd_http_error (_mod_httpd_context_t * httpd_context, int status)
+_mod_httpd_http_error (lw6sys_context_t * sys_context, _mod_httpd_context_t * httpd_context, int status)
 {
   _mod_httpd_response_t *response = NULL;
   char *content = NULL;
@@ -62,30 +62,24 @@ _mod_httpd_http_error (_mod_httpd_context_t * httpd_context, int status)
 
   if (status_text)
     {
-      date_str = lw6sys_date_rfc1123 (0);
+      date_str = lw6sys_date_rfc1123 (sys_context, 0);
       if (date_str)
 	{
 	  content =
-	    lw6sys_new_sprintf (httpd_context->data.htdocs.error_html, status,
+	    lw6sys_new_sprintf (sys_context,
+				httpd_context->data.htdocs.error_html, status,
 				status_text, lw6sys_build_get_package_name (),
 				httpd_context->data.consts.header_description,
 				httpd_context->data.consts.header_keywords,
 				lw6sys_build_get_copyright (),
-				lw6sys_build_get_package_tarname (), status,
-				status_text,
-				lw6sys_build_get_package_name (), date_str);
+				lw6sys_build_get_package_tarname (sys_context), status, status_text, lw6sys_build_get_package_name (sys_context), date_str);
 	  if (content)
 	    {
-	      response =
-		_mod_httpd_response_from_str (httpd_context, status, 1, 0,
-					      NULL,
-					      httpd_context->data.
-					      consts.content_type_html,
-					      content);
-	      LW6SYS_FREE (content);
+	      response = _mod_httpd_response_from_str (sys_context, httpd_context, status, 1, 0, NULL, httpd_context->data.consts.content_type_html, content);
+	      LW6SYS_FREE (sys_context, content);
 	      content = NULL;
 	    }
-	  LW6SYS_FREE (date_str);
+	  LW6SYS_FREE (sys_context, date_str);
 	}
     }
 
