@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -28,34 +28,29 @@
 #include "mod-httpd-internal.h"
 
 int
-_mod_httpd_log (_mod_httpd_context_t * httpd_context,
-		_mod_httpd_request_t * request,
-		_mod_httpd_response_t * response)
+_mod_httpd_log (lw6sys_context_t * sys_context, _mod_httpd_context_t * httpd_context, _mod_httpd_request_t * request, _mod_httpd_response_t * response)
 {
   int ret = 0;
   FILE *f = NULL;
   char *date_str = NULL;
 
-  date_str = lw6sys_date_clf ();
+  date_str = lw6sys_date_clf (sys_context);
   if (date_str)
     {
-      if (lw6sys_mutex_lock (httpd_context->access_log_mutex))
+      if (LW6SYS_MUTEX_LOCK (sys_context, httpd_context->access_log_mutex))
 	{
 	  f = fopen (httpd_context->access_log_file, "ab");
 	  if (f)
 	    {
-	      if (fprintf
-		  (f, "%s - - [%s] \"%s\" %d %d\n", request->client_ip,
-		   date_str, request->first_line, response->status,
-		   response->content_size) > 0)
+	      if (fprintf (f, "%s - - [%s] \"%s\" %d %d\n", request->client_ip, date_str, request->first_line, response->status, response->content_size) > 0)
 		{
 		  ret = 1;
 		}
 	      fclose (f);
 	    }
-	  lw6sys_mutex_unlock (httpd_context->access_log_mutex);
+	  LW6SYS_MUTEX_UNLOCK (sys_context, httpd_context->access_log_mutex);
 	}
-      LW6SYS_FREE (date_str);
+      LW6SYS_FREE (sys_context, date_str);
     }
 
   return ret;
