@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -60,84 +60,72 @@ mod_tcpd_is_dlclose_safe ()
 }
 
 static void *
-_init (int argc, const char *argv[], lw6cnx_properties_t * properties,
-       lw6srv_listener_t * listener)
+_init (lw6sys_context_t * sys_context, int argc, const char *argv[], lw6cnx_properties_t * properties, lw6srv_listener_t * listener)
 {
-  _mod_tcpd_context_t *tcpd_context =
-    _mod_tcpd_init (argc, argv, properties, listener);
+  _mod_tcpd_context_t *tcpd_context = _mod_tcpd_init (sys_context, argc, argv, properties, listener);
 
   return (void *) tcpd_context;
 }
 
 static void
-_quit (void *srv_context)
+_quit (lw6sys_context_t * sys_context, void *srv_context)
 {
   _mod_tcpd_context_t *tcpd_context = (_mod_tcpd_context_t *) srv_context;
 
   if (tcpd_context)
     {
-      _mod_tcpd_quit (tcpd_context);
+      _mod_tcpd_quit (sys_context, tcpd_context);
     }
 }
 
 static int
-_analyse_tcp (void *srv_context, lw6srv_tcp_accepter_t * tcp_accepter,
-	      lw6nod_info_t * node_info,
-	      u_int64_t * remote_id, char **remote_url)
+_analyse_tcp (lw6sys_context_t * sys_context, void *srv_context, lw6srv_tcp_accepter_t * tcp_accepter, lw6nod_info_t * node_info, u_int64_t * remote_id,
+	      char **remote_url)
 {
   _mod_tcpd_context_t *tcpd_context = (_mod_tcpd_context_t *) srv_context;
   int ret = 0;
 
   if (tcpd_context)
     {
-      ret =
-	_mod_tcpd_analyse_tcp (tcpd_context, tcp_accepter, node_info,
-			       remote_id, remote_url);
+      ret = _mod_tcpd_analyse_tcp (sys_context, tcpd_context, tcp_accepter, node_info, remote_id, remote_url);
     }
 
   return ret;
 }
 
 static int
-_analyse_udp (void *srv_context, lw6srv_udp_buffer_t * udp_buffer,
-	      lw6nod_info_t * node_info,
-	      u_int64_t * remote_id, char **remote_url)
+_analyse_udp (lw6sys_context_t * sys_context, void *srv_context, lw6srv_udp_buffer_t * udp_buffer, lw6nod_info_t * node_info, u_int64_t * remote_id,
+	      char **remote_url)
 {
   _mod_tcpd_context_t *tcpd_context = (_mod_tcpd_context_t *) srv_context;
   int ret = 0;
 
   if (tcpd_context)
     {
-      ret =
-	_mod_tcpd_analyse_udp (tcpd_context, udp_buffer, node_info, remote_id,
-			       remote_url);
+      ret = _mod_tcpd_analyse_udp (sys_context, tcpd_context, udp_buffer, node_info, remote_id, remote_url);
     }
 
   return ret;
 }
 
 static int
-_process_oob (void *srv_context, lw6nod_info_t * node_info,
-	      lw6srv_oob_data_t * oob_data)
+_process_oob (lw6sys_context_t * sys_context, void *srv_context, lw6nod_info_t * node_info, lw6srv_oob_data_t * oob_data)
 {
   _mod_tcpd_context_t *tcpd_context = (_mod_tcpd_context_t *) srv_context;
   int ret = 0;
 
   if (tcpd_context)
     {
-      ret = _mod_tcpd_process_oob (tcpd_context, node_info, oob_data);
+      ret = _mod_tcpd_process_oob (sys_context, tcpd_context, node_info, oob_data);
     }
 
   return ret;
 }
 
 static lw6cnx_connection_t *
-_open (void *srv_context, lw6srv_listener_t * listener, const char *local_url,
+_open (lw6sys_context_t * sys_context, void *srv_context, lw6srv_listener_t * listener, const char *local_url,
        const char *remote_url, const char *remote_ip,
-       int remote_port, const char *password,
-       u_int64_t local_id, u_int64_t remote_id, int dns_ok,
-       int network_reliability, lw6cnx_recv_callback_t recv_callback_func,
-       void *recv_callback_data)
+       int remote_port, const char *password, u_int64_t local_id, u_int64_t remote_id, int dns_ok, int network_reliability)
 {
   _mod_tcpd_context_t *tcpd_context = (_mod_tcpd_context_t *) srv_context;
   lw6cnx_connection_t *ret = NULL;
@@ -145,132 +133,129 @@ _open (void *srv_context, lw6srv_listener_t * listener, const char *local_url,
   if (tcpd_context)
     {
       ret =
-	_mod_tcpd_open (tcpd_context, listener, local_url, remote_url,
-			remote_ip, remote_port, password, local_id, remote_id,
-			dns_ok, network_reliability, recv_callback_func,
-			recv_callback_data);
+	_mod_tcpd_open (sys_context, tcpd_context, listener, local_url, remote_url,
+			remote_ip, remote_port, password, local_id, remote_id, dns_ok, network_reliability);
     }
 
   return ret;
 }
 
 static int
-_feed_with_tcp (void *srv_context, lw6cnx_connection_t * connection,
-		lw6srv_tcp_accepter_t * tcp_accepter)
+_feed_with_tcp (lw6sys_context_t * sys_context, void *srv_context, lw6cnx_connection_t * connection, lw6srv_tcp_accepter_t * tcp_accepter)
 {
   _mod_tcpd_context_t *tcpd_context = (_mod_tcpd_context_t *) srv_context;
   int ret = 0;
 
   if (connection)
     {
-      ret = _mod_tcpd_feed_with_tcp (tcpd_context, connection, tcp_accepter);
+      ret = _mod_tcpd_feed_with_tcp (sys_context, tcpd_context, connection, tcp_accepter);
     }
 
   return ret;
 }
 
 static int
-_feed_with_udp (void *srv_context, lw6cnx_connection_t * connection,
-		lw6srv_udp_buffer_t * udp_buffer)
+_feed_with_udp (lw6sys_context_t * sys_context, void *srv_context, lw6cnx_connection_t * connection, lw6srv_udp_buffer_t * udp_buffer)
 {
   _mod_tcpd_context_t *tcpd_context = (_mod_tcpd_context_t *) srv_context;
   int ret = 0;
 
   if (connection)
     {
-      ret = _mod_tcpd_feed_with_udp (tcpd_context, connection, udp_buffer);
+      ret = _mod_tcpd_feed_with_udp (sys_context, tcpd_context, connection, udp_buffer);
     }
 
   return ret;
 }
 
 static void
-_close (void *srv_context, lw6cnx_connection_t * connection)
+_close (lw6sys_context_t * sys_context, void *srv_context, lw6cnx_connection_t * connection)
 {
   _mod_tcpd_context_t *tcpd_context = (_mod_tcpd_context_t *) srv_context;
   if (tcpd_context)
     {
-      _mod_tcpd_close (tcpd_context, connection);
+      _mod_tcpd_close (sys_context, tcpd_context, connection);
     }
 }
 
 static int
-_send (void *srv_context, lw6cnx_connection_t * connection, int64_t now,
-       u_int32_t physical_ticket_sig, u_int32_t logical_ticket_sig,
-       u_int64_t logical_from_id, u_int64_t logical_to_id,
-       const char *message)
+_send (lw6sys_context_t * sys_context, void *srv_context, lw6cnx_connection_t * connection, int64_t now,
+       u_int32_t physical_ticket_sig, u_int32_t logical_ticket_sig, u_int64_t logical_from_id, u_int64_t logical_to_id, const char *message)
 {
   _mod_tcpd_context_t *tcpd_context = (_mod_tcpd_context_t *) srv_context;
   int ret = 0;
 
   if (tcpd_context)
     {
-      ret =
-	_mod_tcpd_send (tcpd_context, connection, now, physical_ticket_sig,
-			logical_ticket_sig, logical_from_id, logical_to_id,
-			message);
+      ret = _mod_tcpd_send (sys_context, tcpd_context, connection, now, physical_ticket_sig, logical_ticket_sig, logical_from_id, logical_to_id, message);
     }
 
   return ret;
 }
 
 static int
-_can_send (void *srv_context, lw6cnx_connection_t * connection)
+_can_send (lw6sys_context_t * sys_context, void *srv_context, lw6cnx_connection_t * connection)
 {
   _mod_tcpd_context_t *tcpd_context = (_mod_tcpd_context_t *) srv_context;
   int ret = 0;
 
   if (tcpd_context)
     {
-      ret = _mod_tcpd_can_send (tcpd_context, connection);
+      ret = _mod_tcpd_can_send (sys_context, tcpd_context, connection);
     }
 
   return ret;
 }
 
 static void
-_poll (void *srv_context, lw6cnx_connection_t * connection)
+_poll (lw6sys_context_t * sys_context, void *srv_context, lw6cnx_connection_t * connection)
 {
   _mod_tcpd_context_t *tcpd_context = (_mod_tcpd_context_t *) srv_context;
 
   if (tcpd_context)
     {
-      _mod_tcpd_poll (tcpd_context, connection);
+      _mod_tcpd_poll (sys_context, tcpd_context, connection);
     }
 }
 
 static char *
-_repr (void *srv_context, lw6cnx_connection_t * connection)
+_repr (lw6sys_context_t * sys_context, void *srv_context, lw6cnx_connection_t * connection)
 {
   _mod_tcpd_context_t *tcpd_context = (_mod_tcpd_context_t *) srv_context;
   char *ret = NULL;
 
   if (tcpd_context)
     {
-      ret = _mod_tcpd_repr (tcpd_context, connection);
+      ret = _mod_tcpd_repr (sys_context, tcpd_context, connection);
     }
 
   return ret;
 }
 
+/**
+ * mod_tcpd_get_pedigree
+ *
+ * @sys_context: global system context
+ *
+ * Returns the pedigree for mod-tcpd, giving details about the module,
+ * including name, description, licence, date/time of compilation.
+ *
+ * Return value: dynamically allocated object.
+ */
 lw6sys_module_pedigree_t *
-mod_tcpd_get_pedigree ()
+mod_tcpd_get_pedigree (lw6sys_context_t * sys_context)
 {
   lw6sys_module_pedigree_t *module_pedigree = NULL;
 
-  module_pedigree =
-    (lw6sys_module_pedigree_t *)
-    LW6SYS_CALLOC (sizeof (lw6sys_module_pedigree_t));
+  module_pedigree = (lw6sys_module_pedigree_t *) LW6SYS_CALLOC (sys_context, sizeof (lw6sys_module_pedigree_t));
   if (module_pedigree)
     {
       module_pedigree->id = MOD_TCPD_BACKEND_ID;
       module_pedigree->category = "srv";
       module_pedigree->name = _("TCPD");
-      module_pedigree->readme =
-	_x_ ("Basic TCP/IP server, the most reliable way to communicate.");
+      module_pedigree->readme = _x_ ("Basic TCP/IP server, the most reliable way to communicate.");
       module_pedigree->version = VERSION;
-      module_pedigree->copyright =
-	"Copyright (C)  2014  Christian Mauduit <ufoot@ufoot.org>";
+      module_pedigree->copyright = "Copyright (C)  2015  Christian Mauduit <ufoot@ufoot.org>";
       module_pedigree->license = "GPLv3+ (GNU GPL version 3 or later)";
       module_pedigree->date = __DATE__;
       module_pedigree->time = __TIME__;
@@ -279,12 +264,21 @@ mod_tcpd_get_pedigree ()
   return module_pedigree;
 }
 
+/**
+ * mod_tcpd_create_backend
+ *
+ * @sys_context: global system context
+ *
+ * Creates a mod-tcpd backend.
+ *
+ * Return value: backend pointer.
+ */
 lw6srv_backend_t *
-mod_tcpd_create_backend ()
+mod_tcpd_create_backend (lw6sys_context_t * sys_context)
 {
   lw6srv_backend_t *backend;
 
-  backend = LW6SYS_MALLOC (sizeof (lw6srv_backend_t));
+  backend = LW6SYS_MALLOC (sys_context, sizeof (lw6srv_backend_t));
   if (backend)
     {
       memset (backend, 0, sizeof (lw6srv_backend_t));
