@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -31,8 +31,7 @@
 #define _CONSTS_FILE "tcpd-const.xml"
 
 static void
-_read_callback (void *callback_data, const char *element, const char *key,
-		const char *value)
+_read_callback (lw6sys_context_t * sys_context, void *callback_data, const char *element, const char *key, const char *value)
 {
   _mod_tcpd_consts_t *consts;
 
@@ -40,53 +39,48 @@ _read_callback (void *callback_data, const char *element, const char *key,
 
   if (!strcmp (element, "int"))
     {
-      lw6cfg_read_xml_int (key, value, "error-timeout",
-			   &(consts->error_timeout));
-      lw6cfg_read_xml_int (key, value, "ping-alter-base",
-			   &(consts->ping_alter_base));
-      lw6cfg_read_xml_int (key, value, "ping-alter-percent",
-			   &(consts->ping_alter_percent));
+      lw6cfg_read_xml_int (sys_context, key, value, "error-timeout", &(consts->error_timeout));
+      lw6cfg_read_xml_int (sys_context, key, value, "ping-alter-base", &(consts->ping_alter_base));
+      lw6cfg_read_xml_int (sys_context, key, value, "ping-alter-percent", &(consts->ping_alter_percent));
     }
 }
 
 static int
-_load_consts (_mod_tcpd_consts_t * consts, const char *consts_file)
+_load_consts (lw6sys_context_t * sys_context, _mod_tcpd_consts_t * consts, const char *consts_file)
 {
   int ret = 0;
 
-  lw6sys_log (LW6SYS_LOG_INFO, _x_ ("reading \"%s\""), consts_file);
+  lw6sys_log (sys_context, LW6SYS_LOG_INFO, _x_ ("reading \"%s\""), consts_file);
 
-  ret =
-    lw6cfg_read_key_value_xml_file (consts_file, _read_callback,
-				    (void *) consts);
+  ret = lw6cfg_read_key_value_xml_file (sys_context, consts_file, _read_callback, (void *) consts);
 
   return ret;
 }
 
 int
-_mod_tcpd_load_data (_mod_tcpd_data_t * tcpd_data, const char *data_dir)
+_mod_tcpd_load_data (lw6sys_context_t * sys_context, _mod_tcpd_data_t * tcpd_data, const char *data_dir)
 {
   int ret = 0;
   char *tcpd_subdir = NULL;
   char *consts_file = NULL;
 
-  tcpd_subdir = lw6sys_path_concat (data_dir, _TCPD_SUBDIR);
+  tcpd_subdir = lw6sys_path_concat (sys_context, data_dir, _TCPD_SUBDIR);
   if (tcpd_subdir)
     {
-      consts_file = lw6sys_path_concat (tcpd_subdir, _CONSTS_FILE);
+      consts_file = lw6sys_path_concat (sys_context, tcpd_subdir, _CONSTS_FILE);
       if (consts_file)
 	{
-	  ret = _load_consts (&(tcpd_data->consts), consts_file);
-	  LW6SYS_FREE (consts_file);
+	  ret = _load_consts (sys_context, &(tcpd_data->consts), consts_file);
+	  LW6SYS_FREE (sys_context, consts_file);
 	}
-      LW6SYS_FREE (tcpd_subdir);
+      LW6SYS_FREE (sys_context, tcpd_subdir);
     }
 
   return ret;
 }
 
 static int
-_unload_consts (_mod_tcpd_consts_t * consts)
+_unload_consts (lw6sys_context_t * sys_context, _mod_tcpd_consts_t * consts)
 {
   int ret = 1;
 
@@ -96,7 +90,7 @@ _unload_consts (_mod_tcpd_consts_t * consts)
 }
 
 void
-_mod_tcpd_unload_data (_mod_tcpd_data_t * tcpd_data)
+_mod_tcpd_unload_data (lw6sys_context_t * sys_context, _mod_tcpd_data_t * tcpd_data)
 {
-  _unload_consts (&(tcpd_data->consts));
+  _unload_consts (sys_context, &(tcpd_data->consts));
 }
