@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -28,18 +28,15 @@
 #include "mod-tcpd-internal.h"
 
 int
-_mod_tcpd_analyse_tcp (_mod_tcpd_context_t * tcpd_context,
-		       lw6srv_tcp_accepter_t * tcp_accepter,
-		       lw6nod_info_t * node_info,
-		       u_int64_t * remote_id, char **remote_url)
+_mod_tcpd_analyse_tcp (lw6sys_context_t * sys_context, _mod_tcpd_context_t * tcpd_context,
+		       lw6srv_tcp_accepter_t * tcp_accepter, lw6nod_info_t * node_info, u_int64_t * remote_id, char **remote_url)
 {
   int ret = 0;
   char *line = NULL;
   char *msg = NULL;
 
   line = tcp_accepter->first_line;
-  lw6sys_log (LW6SYS_LOG_DEBUG,
-	      _x_ ("trying to recognize tcpd protocol in \"%s\""), line);
+  lw6sys_log (sys_context, LW6SYS_LOG_DEBUG, _x_ ("trying to recognize tcpd protocol in \"%s\""), line);
 
   if (remote_id)
     {
@@ -50,53 +47,45 @@ _mod_tcpd_analyse_tcp (_mod_tcpd_context_t * tcpd_context,
       (*remote_url) = NULL;
     }
 
-  if (lw6net_tcp_is_alive (&(tcp_accepter->sock)))
+  if (lw6net_tcp_is_alive (sys_context, &(tcp_accepter->sock)))
     {
       if (lw6sys_chr_is_eol (line[0])
-	  || lw6sys_str_starts_with_no_case (line,
+	  || lw6sys_str_starts_with_no_case (sys_context, line,
 					     LW6MSG_OOB_PING)
-	  || lw6sys_str_starts_with_no_case (line,
-					     LW6MSG_OOB_INFO)
-	  || lw6sys_str_starts_with_no_case (line, LW6MSG_OOB_LIST))
+	  || lw6sys_str_starts_with_no_case (sys_context, line, LW6MSG_OOB_INFO) || lw6sys_str_starts_with_no_case (sys_context, line, LW6MSG_OOB_LIST))
 	{
-	  lw6sys_log (LW6SYS_LOG_DEBUG,
-		      _x_ ("recognized tcpd protocol (OOB)"));
+	  lw6sys_log (sys_context, LW6SYS_LOG_DEBUG, _x_ ("recognized tcpd protocol (OOB)"));
 	  ret |= (LW6SRV_ANALYSE_UNDERSTANDABLE | LW6SRV_ANALYSE_OOB);
 	}
 
-      if (lw6sys_str_starts_with_no_case
-	  (line, _MOD_TCPD_PROTOCOL_LW6_STRING))
+      if (lw6sys_str_starts_with_no_case (sys_context, line, _MOD_TCPD_PROTOCOL_LW6_STRING))
 	{
-	  lw6sys_log (LW6SYS_LOG_DEBUG, _x_ ("recognized tcpd protocol"));
+	  lw6sys_log (sys_context, LW6SYS_LOG_DEBUG, _x_ ("recognized tcpd protocol"));
 	  if (lw6msg_envelope_analyse
-	      (line, LW6MSG_ENVELOPE_MODE_TELNET,
+	      (sys_context, line, LW6MSG_ENVELOPE_MODE_TELNET,
 	       node_info->const_info.ref_info.url,
-	       node_info->const_info.password, 0,
-	       node_info->const_info.ref_info.id_int, &msg, NULL, NULL,
-	       remote_id, NULL, NULL, NULL, remote_url))
+	       node_info->const_info.password, 0, node_info->const_info.ref_info.id_int, &msg, NULL, NULL, remote_id, NULL, NULL, NULL, remote_url))
 	    {
 	      ret |= LW6SRV_ANALYSE_UNDERSTANDABLE;
-	      lw6sys_log (LW6SYS_LOG_DEBUG, _x_ ("tcpd message \"%s\" OK"),
-			  line);
+	      lw6sys_log (sys_context, LW6SYS_LOG_DEBUG, _x_ ("tcpd message \"%s\" OK"), line);
 	      if (msg)
 		{
 		  /*
 		   * We need to pass msg else remote_url isn't processed
 		   */
-		  LW6SYS_FREE (msg);
+		  LW6SYS_FREE (sys_context, msg);
 		}
 	    }
 	  else
 	    {
 	      if (strchr (line, '\n'))
 		{
-		  lw6sys_log (LW6SYS_LOG_DEBUG,
-			      _x_ ("unable to analyse message \"%s\""), line);
+		  lw6sys_log (sys_context, LW6SYS_LOG_DEBUG, _x_ ("unable to analyse message \"%s\""), line);
 		  ret |= LW6SRV_ANALYSE_DEAD;
 		}
 	      else
 		{
-		  lw6sys_log (LW6SYS_LOG_DEBUG,
+		  lw6sys_log (sys_context, LW6SYS_LOG_DEBUG,
 			      _x_
 			      ("unable to analyse message \"%s\" but line does not seem complete, assuming some data is still missing, giving it another chance"),
 			      line);
@@ -113,10 +102,8 @@ _mod_tcpd_analyse_tcp (_mod_tcpd_context_t * tcpd_context,
 }
 
 int
-_mod_tcpd_analyse_udp (_mod_tcpd_context_t * tcpd_context,
-		       lw6srv_udp_buffer_t * udp_buffer,
-		       lw6nod_info_t * node_info,
-		       u_int64_t * remote_id, char **remote_url)
+_mod_tcpd_analyse_udp (lw6sys_context_t * sys_context, _mod_tcpd_context_t * tcpd_context,
+		       lw6srv_udp_buffer_t * udp_buffer, lw6nod_info_t * node_info, u_int64_t * remote_id, char **remote_url)
 {
   int ret = 0;
 
@@ -137,41 +124,38 @@ _mod_tcpd_analyse_udp (_mod_tcpd_context_t * tcpd_context,
 }
 
 int
-_mod_tcpd_feed_with_tcp (_mod_tcpd_context_t * tcpd_context,
-			 lw6cnx_connection_t * connection,
+_mod_tcpd_feed_with_tcp (lw6sys_context_t * sys_context, _mod_tcpd_context_t * tcpd_context, lw6cnx_connection_t * connection,
 			 lw6srv_tcp_accepter_t * tcp_accepter)
 {
   int ret = 0;
-  _mod_tcpd_specific_data_t *specific_data =
-    (_mod_tcpd_specific_data_t *) connection->backend_specific_data;;
+  _mod_tcpd_specific_data_t *specific_data = (_mod_tcpd_specific_data_t *) connection->backend_specific_data;;
   int tmp_sock = LW6NET_SOCKET_INVALID;
 
   if (specific_data)
     {
       tmp_sock = tcp_accepter->sock;
-      if (lw6net_socket_is_valid (specific_data->sock))
+      if (lw6net_socket_is_valid (sys_context, specific_data->sock))
 	{
-	  if (!lw6net_tcp_is_alive (&(specific_data->sock)))
+	  if (!lw6net_tcp_is_alive (sys_context, &(specific_data->sock)))
 	    {
 	      /*
 	       * Close our old socket, use the new one
 	       */
+	      lw6sys_log (sys_context, LW6SYS_LOG_DEBUG, _x_ ("old connection dead, replacing with new connection, using sock %d"), tmp_sock);
 	      tcp_accepter->sock = LW6NET_SOCKET_INVALID;
 	      specific_data->sock = tmp_sock;
 	      ret = 1;
 	    }
 	  else
 	    {
-	      lw6sys_log (LW6SYS_LOG_WARNING,
-			  _x_
-			  ("double connection from \"%s\" (%s:%d), ignoring"),
-			  connection->remote_url, connection->remote_ip,
-			  connection->remote_port);
-	      lw6net_socket_close (&(tcp_accepter->sock));
+	      lw6sys_log (sys_context, LW6SYS_LOG_WARNING,
+			  _x_ ("double connection from \"%s\" (%s:%d), ignoring"), connection->remote_url, connection->remote_ip, connection->remote_port);
+	      lw6net_socket_close (sys_context, &(tcp_accepter->sock));
 	    }
 	}
       else
 	{
+	  lw6sys_log (sys_context, LW6SYS_LOG_DEBUG, _x_ ("new connection, using sock %d"), tmp_sock);
 	  tcp_accepter->sock = LW6NET_SOCKET_INVALID;
 	  specific_data->sock = tmp_sock;
 	  ret = 1;
@@ -188,13 +172,14 @@ _mod_tcpd_feed_with_tcp (_mod_tcpd_context_t * tcpd_context,
 }
 
 int
-_mod_tcpd_feed_with_udp (_mod_tcpd_context_t * tcpd_context,
-			 lw6cnx_connection_t * connection,
+_mod_tcpd_feed_with_udp (lw6sys_context_t * sys_context, _mod_tcpd_context_t * tcpd_context, lw6cnx_connection_t * connection,
 			 lw6srv_udp_buffer_t * udp_buffer)
 {
   int ret = 0;
 
-  // todo
+  /*
+   * UDP is never handled by mod_tcpd, return always false
+   */
 
   return ret;
 }
