@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -28,38 +28,28 @@
 #include "mod-tcpd-internal.h"
 
 lw6cnx_connection_t *
-_mod_tcpd_open (_mod_tcpd_context_t * tcpd_context,
+_mod_tcpd_open (lw6sys_context_t * sys_context, _mod_tcpd_context_t * tcpd_context,
 		lw6srv_listener_t * listener, const char *local_url,
 		const char *remote_url, const char *remote_ip,
-		int remote_port, const char *password, u_int64_t local_id,
-		u_int64_t remote_id, int dns_ok, int network_reliability,
-		lw6cnx_recv_callback_t recv_callback_func,
-		void *recv_callback_data)
+		int remote_port, const char *password, u_int64_t local_id, u_int64_t remote_id, int dns_ok, int network_reliability)
 {
   lw6cnx_connection_t *ret = NULL;
   _mod_tcpd_specific_data_t *specific_data = NULL;
 
-  lw6sys_log (LW6SYS_LOG_DEBUG, _x_ ("_mod_tcpd_open \"%s\""), remote_url);
-  ret =
-    lw6cnx_connection_new (local_url, remote_url, remote_ip, remote_port,
-			   password, local_id, remote_id, dns_ok,
-			   network_reliability, recv_callback_func,
-			   recv_callback_data);
+  lw6sys_log (sys_context, LW6SYS_LOG_DEBUG, _x_ ("_mod_tcpd_open \"%s\""), remote_url);
+  ret = lw6cnx_connection_new (sys_context, local_url, remote_url, remote_ip, remote_port, password, local_id, remote_id, dns_ok, network_reliability);
   if (ret)
     {
-      ret->backend_specific_data =
-	LW6SYS_CALLOC (sizeof (_mod_tcpd_specific_data_t));
-      specific_data =
-	(_mod_tcpd_specific_data_t *) ret->backend_specific_data;
+      ret->backend_specific_data = LW6SYS_CALLOC (sys_context, sizeof (_mod_tcpd_specific_data_t));
+      specific_data = (_mod_tcpd_specific_data_t *) ret->backend_specific_data;
       if (specific_data)
 	{
-	  lw6sys_log (LW6SYS_LOG_DEBUG,
-		      _x_ ("open tcpd connection with \"%s\""), remote_url);
+	  lw6sys_log (sys_context, LW6SYS_LOG_DEBUG, _x_ ("open tcpd connection with \"%s\""), remote_url);
 	  specific_data->sock = LW6NET_SOCKET_INVALID;
 	}
       else
 	{
-	  _mod_tcpd_close (tcpd_context, ret);
+	  _mod_tcpd_close (sys_context, tcpd_context, ret);
 	  ret = NULL;
 	}
     }
@@ -68,23 +58,20 @@ _mod_tcpd_open (_mod_tcpd_context_t * tcpd_context,
 }
 
 void
-_mod_tcpd_close (_mod_tcpd_context_t * tcpd_context,
-		 lw6cnx_connection_t * connection)
+_mod_tcpd_close (lw6sys_context_t * sys_context, _mod_tcpd_context_t * tcpd_context, lw6cnx_connection_t * connection)
 {
-  _mod_tcpd_specific_data_t *specific_data =
-    (_mod_tcpd_specific_data_t *) connection->backend_specific_data;;
+  _mod_tcpd_specific_data_t *specific_data = (_mod_tcpd_specific_data_t *) connection->backend_specific_data;;
 
   if (specific_data)
     {
-      lw6net_socket_close (&(specific_data->sock));
-      LW6SYS_FREE (specific_data);
+      lw6net_socket_close (sys_context, &(specific_data->sock));
+      LW6SYS_FREE (sys_context, specific_data);
     }
-  lw6cnx_connection_free (connection);
+  lw6cnx_connection_free (sys_context, connection);
 }
 
 int
-_mod_tcpd_timeout_ok (_mod_tcpd_context_t * tcpd_context,
-		      int64_t origin_timestamp)
+_mod_tcpd_timeout_ok (lw6sys_context_t * sys_context, _mod_tcpd_context_t * tcpd_context, int64_t origin_timestamp)
 {
   int ret = 0;
   int d = 0;
@@ -96,7 +83,7 @@ _mod_tcpd_timeout_ok (_mod_tcpd_context_t * tcpd_context,
    * some time assumed to be reasonnable (depends on settings)
    * it will be over.
    */
-  d = abs (lw6sys_get_timestamp () - origin_timestamp);
+  d = abs (lw6sys_get_timestamp (sys_context) - origin_timestamp);
   ret = (d < (tcpd_context->data.consts.error_timeout * 1000));
 
   return ret;
