@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -27,15 +27,15 @@
 #include "srv.h"
 
 static void
-_warning (const char *func_name)
+_warning (lw6sys_context_t * sys_context, const char *func_name)
 {
-  lw6sys_log (LW6SYS_LOG_WARNING,
-	      _x_ ("srv backend function \"%s\" is not defined"), func_name);
+  lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("srv backend function \"%s\" is not defined"), func_name);
 }
 
 /**
  * lw6srv_init
  *
+ * @sys_context: global system context
  * @backend: backend to use
  * @listener: listener object to use when constructing the backend.
  *
@@ -44,20 +44,18 @@ _warning (const char *func_name)
  * Return value: 1 on success, 0 on failure
  */
 int
-lw6srv_init (lw6srv_backend_t * backend, lw6srv_listener_t * listener)
+lw6srv_init (lw6sys_context_t * sys_context, lw6srv_backend_t * backend, lw6srv_listener_t * listener)
 {
   LW6SYS_BACKEND_FUNCTION_BEGIN;
 
   backend->srv_context = NULL;
   if (backend->init)
     {
-      backend->srv_context =
-	backend->init (backend->argc, backend->argv, &(backend->properties),
-		       listener);
+      backend->srv_context = backend->init (sys_context, backend->argc, backend->argv, &(backend->properties), listener);
     }
   else
     {
-      _warning (__FUNCTION__);
+      _warning (sys_context, __FUNCTION__);
     }
 
   LW6SYS_BACKEND_FUNCTION_END;
@@ -68,12 +66,13 @@ lw6srv_init (lw6srv_backend_t * backend, lw6srv_listener_t * listener)
 /**
  * lw6srv_quit
  *
+ * @sys_context: global system context
  * @backend: unitialize a srv backend
  *
  * Closes a srv, but does not free all ressources.
  */
 void
-lw6srv_quit (lw6srv_backend_t * backend)
+lw6srv_quit (lw6sys_context_t * sys_context, lw6srv_backend_t * backend)
 {
   LW6SYS_BACKEND_FUNCTION_BEGIN;
 
@@ -85,13 +84,13 @@ lw6srv_quit (lw6srv_backend_t * backend)
        */
       if (backend->srv_context)
 	{
-	  backend->quit (backend->srv_context);
+	  backend->quit (sys_context, backend->srv_context);
 	  backend->srv_context = NULL;
 	}
     }
   else
     {
-      _warning (__FUNCTION__);
+      _warning (sys_context, __FUNCTION__);
     }
   LW6SYS_BACKEND_FUNCTION_END;
 }
@@ -99,6 +98,7 @@ lw6srv_quit (lw6srv_backend_t * backend)
 /**
  * lw6srv_analyse_tcp
  *
+ * @sys_context: global system context
  * @backend: server backend to use
  * @tcp_accepter: TCP mode accepter
  * @node_info: this node information
@@ -114,9 +114,7 @@ lw6srv_quit (lw6srv_backend_t * backend)
  * Return value: bitwise flag.
  */
 int
-lw6srv_analyse_tcp (lw6srv_backend_t * backend,
-		    lw6srv_tcp_accepter_t * tcp_accepter,
-		    lw6nod_info_t * node_info,
+lw6srv_analyse_tcp (lw6sys_context_t * sys_context, lw6srv_backend_t * backend, lw6srv_tcp_accepter_t * tcp_accepter, lw6nod_info_t * node_info,
 		    u_int64_t * remote_id, char **remote_url)
 {
   int ret = 0;
@@ -125,13 +123,11 @@ lw6srv_analyse_tcp (lw6srv_backend_t * backend,
 
   if (backend->analyse_tcp)
     {
-      ret =
-	backend->analyse_tcp (backend->srv_context, tcp_accepter, node_info,
-			      remote_id, remote_url);
+      ret = backend->analyse_tcp (sys_context, backend->srv_context, tcp_accepter, node_info, remote_id, remote_url);
     }
   else
     {
-      _warning (__FUNCTION__);
+      _warning (sys_context, __FUNCTION__);
     }
 
   LW6SYS_BACKEND_FUNCTION_END;
@@ -142,6 +138,7 @@ lw6srv_analyse_tcp (lw6srv_backend_t * backend,
 /**
  * lw6srv_analyse_tcp
  *
+ * @sys_context: global system context
  * @backend: server backend to use
  * @udp_buffer: UDP buffer
  * @node_info: this node information
@@ -157,10 +154,8 @@ lw6srv_analyse_tcp (lw6srv_backend_t * backend,
  * Return value: bitwise flag.
  */
 int
-lw6srv_analyse_udp (lw6srv_backend_t * backend,
-		    lw6srv_udp_buffer_t * udp_buffer,
-		    lw6nod_info_t * node_info, u_int64_t * remote_id,
-		    char **remote_url)
+lw6srv_analyse_udp (lw6sys_context_t * sys_context, lw6srv_backend_t * backend, lw6srv_udp_buffer_t * udp_buffer, lw6nod_info_t * node_info,
+		    u_int64_t * remote_id, char **remote_url)
 {
   int ret = 0;
 
@@ -168,13 +163,11 @@ lw6srv_analyse_udp (lw6srv_backend_t * backend,
 
   if (backend->analyse_udp)
     {
-      ret =
-	backend->analyse_udp (backend->srv_context, udp_buffer, node_info,
-			      remote_id, remote_url);
+      ret = backend->analyse_udp (sys_context, backend->srv_context, udp_buffer, node_info, remote_id, remote_url);
     }
   else
     {
-      _warning (__FUNCTION__);
+      _warning (sys_context, __FUNCTION__);
     }
 
   LW6SYS_BACKEND_FUNCTION_END;
@@ -185,6 +178,7 @@ lw6srv_analyse_udp (lw6srv_backend_t * backend,
 /**
  * lw6srv_process_oob
  *
+ * @sys_context: global system context
  * @backend: server backend to use
  * @node_info: this node information
  * @oob_data: OOB data received
@@ -194,8 +188,7 @@ lw6srv_analyse_udp (lw6srv_backend_t * backend,
  * Return value: 1 if OK, 0 if not.
  */
 int
-lw6srv_process_oob (lw6srv_backend_t * backend, lw6nod_info_t * node_info,
-		    lw6srv_oob_data_t * oob_data)
+lw6srv_process_oob (lw6sys_context_t * sys_context, lw6srv_backend_t * backend, lw6nod_info_t * node_info, lw6srv_oob_data_t * oob_data)
 {
   int ret = 0;
 
@@ -203,11 +196,11 @@ lw6srv_process_oob (lw6srv_backend_t * backend, lw6nod_info_t * node_info,
 
   if (backend->process_oob)
     {
-      ret = backend->process_oob (backend->srv_context, node_info, oob_data);
+      ret = backend->process_oob (sys_context, backend->srv_context, node_info, oob_data);
     }
   else
     {
-      _warning (__FUNCTION__);
+      _warning (sys_context, __FUNCTION__);
     }
 
   LW6SYS_BACKEND_FUNCTION_END;
@@ -218,6 +211,7 @@ lw6srv_process_oob (lw6srv_backend_t * backend, lw6nod_info_t * node_info,
 /**
  * lw6srv_open
  *
+ * @sys_context: global system context
  * @backend: server backend to use
  * @lw6srv_listener: listener object
  * @local_url: local url to use (to send to peer)
@@ -229,8 +223,6 @@ lw6srv_process_oob (lw6srv_backend_t * backend, lw6nod_info_t * node_info,
  * @remote_id: the remove 64-bit id
  * @dns_ok: 1 if no DNS mismatch, 0 if situation is unclear
  * @network_reliability: the greater, the more reliable it is
- * @recv_callback_func: callback fired when receiving data
- * @recv_callback_data: additionnal data passed to callback
  *
  * Opens a server connection. One might wonder, clients open
  * connections, but servers? To some extent, this is the equivalent
@@ -243,13 +235,9 @@ lw6srv_process_oob (lw6srv_backend_t * backend, lw6nod_info_t * node_info,
  * Return value: new connection object.
  */
 lw6cnx_connection_t *
-lw6srv_open (lw6srv_backend_t * backend, lw6srv_listener_t * listener,
+lw6srv_open (lw6sys_context_t * sys_context, lw6srv_backend_t * backend, lw6srv_listener_t * listener,
 	     const char *local_url, const char *remote_url,
-	     const char *remote_ip, int remote_port, const char *password,
-	     u_int64_t local_id, u_int64_t remote_id, int dns_ok,
-	     int network_reliability,
-	     lw6cnx_recv_callback_t recv_callback_func,
-	     void *recv_callback_data)
+	     const char *remote_ip, int remote_port, const char *password, u_int64_t local_id, u_int64_t remote_id, int dns_ok, int network_reliability)
 {
   lw6cnx_connection_t *ret = NULL;
 
@@ -258,10 +246,8 @@ lw6srv_open (lw6srv_backend_t * backend, lw6srv_listener_t * listener,
   if (backend->open)
     {
       ret =
-	backend->open (backend->srv_context, listener, local_url, remote_url,
-		       remote_ip, remote_port, password, local_id, remote_id,
-		       dns_ok, network_reliability, recv_callback_func,
-		       recv_callback_data);
+	backend->open (sys_context, backend->srv_context, listener, local_url, remote_url,
+		       remote_ip, remote_port, password, local_id, remote_id, dns_ok, network_reliability);
       if (ret)
 	{
 	  ret->properties = backend->properties;
@@ -269,7 +255,7 @@ lw6srv_open (lw6srv_backend_t * backend, lw6srv_listener_t * listener,
     }
   else
     {
-      _warning (__FUNCTION__);
+      _warning (sys_context, __FUNCTION__);
     }
 
   LW6SYS_BACKEND_FUNCTION_END;
@@ -280,7 +266,8 @@ lw6srv_open (lw6srv_backend_t * backend, lw6srv_listener_t * listener,
 /**
  * lw6srv_feed_with_tcp
  *
- * @beckend: server backend to use
+ * @sys_context: global system context
+ * @backend: server backend to use
  * @connection: connection to use
  * @tcp_accepter: TCP accepter holding data
  *
@@ -291,9 +278,7 @@ lw6srv_open (lw6srv_backend_t * backend, lw6srv_listener_t * listener,
  * Return value: 1 some data processed, else 0
  */
 int
-lw6srv_feed_with_tcp (lw6srv_backend_t * backend,
-		      lw6cnx_connection_t * connection,
-		      lw6srv_tcp_accepter_t * tcp_accepter)
+lw6srv_feed_with_tcp (lw6sys_context_t * sys_context, lw6srv_backend_t * backend, lw6cnx_connection_t * connection, lw6srv_tcp_accepter_t * tcp_accepter)
 {
   int ret = 0;
 
@@ -301,13 +286,11 @@ lw6srv_feed_with_tcp (lw6srv_backend_t * backend,
 
   if (backend->feed_with_tcp)
     {
-      ret =
-	backend->feed_with_tcp (backend->srv_context, connection,
-				tcp_accepter);
+      ret = backend->feed_with_tcp (sys_context, backend->srv_context, connection, tcp_accepter);
     }
   else
     {
-      _warning (__FUNCTION__);
+      _warning (sys_context, __FUNCTION__);
     }
 
   LW6SYS_BACKEND_FUNCTION_END;
@@ -318,7 +301,8 @@ lw6srv_feed_with_tcp (lw6srv_backend_t * backend,
 /**
  * lw6srv_feed_with_udp
  *
- * @beckend: server backend to use
+ * @sys_context: global system context
+ * @backend: server backend to use
  * @connection: connection to use
  * @tcp_accepter: TCP accepter holding data
  *
@@ -329,9 +313,7 @@ lw6srv_feed_with_tcp (lw6srv_backend_t * backend,
  * Return value: 1 some data processed, else 0
  */
 int
-lw6srv_feed_with_udp (lw6srv_backend_t * backend,
-		      lw6cnx_connection_t * connection,
-		      lw6srv_udp_buffer_t * udp_buffer)
+lw6srv_feed_with_udp (lw6sys_context_t * sys_context, lw6srv_backend_t * backend, lw6cnx_connection_t * connection, lw6srv_udp_buffer_t * udp_buffer)
 {
   int ret = 0;
 
@@ -339,12 +321,11 @@ lw6srv_feed_with_udp (lw6srv_backend_t * backend,
 
   if (backend->feed_with_udp)
     {
-      ret =
-	backend->feed_with_udp (backend->srv_context, connection, udp_buffer);
+      ret = backend->feed_with_udp (sys_context, backend->srv_context, connection, udp_buffer);
     }
   else
     {
-      _warning (__FUNCTION__);
+      _warning (sys_context, __FUNCTION__);
     }
 
   LW6SYS_BACKEND_FUNCTION_END;
@@ -355,6 +336,7 @@ lw6srv_feed_with_udp (lw6srv_backend_t * backend,
 /**
  * lw6srv_close
  *
+ * @sys_context: global system context
  * @backend: server backend to use
  * @connection: connection to close
  *
@@ -363,17 +345,17 @@ lw6srv_feed_with_udp (lw6srv_backend_t * backend,
  * Return value: none.
  */
 void
-lw6srv_close (lw6srv_backend_t * backend, lw6cnx_connection_t * connection)
+lw6srv_close (lw6sys_context_t * sys_context, lw6srv_backend_t * backend, lw6cnx_connection_t * connection)
 {
   LW6SYS_BACKEND_FUNCTION_BEGIN;
 
   if (backend->close)
     {
-      backend->close (backend->srv_context, connection);
+      backend->close (sys_context, backend->srv_context, connection);
     }
   else
     {
-      _warning (__FUNCTION__);
+      _warning (sys_context, __FUNCTION__);
     }
 
   LW6SYS_BACKEND_FUNCTION_END;
@@ -382,6 +364,7 @@ lw6srv_close (lw6srv_backend_t * backend, lw6cnx_connection_t * connection)
 /**
  * lw6srv_send
  *
+ * @sys_context: global system context
  * @backend: server backend to use
  * @connection: connection to use
  * @now: current timestamp
@@ -397,11 +380,8 @@ lw6srv_close (lw6srv_backend_t * backend, lw6cnx_connection_t * connection)
  * Return value: 1 on success, 0 if not
  */
 int
-lw6srv_send (lw6srv_backend_t * backend, lw6cnx_connection_t * connection,
-	     int64_t now,
-	     u_int32_t physical_ticket_sig, u_int32_t logical_ticket_sig,
-	     u_int64_t logical_from_id,
-	     u_int64_t logical_to_id, const char *message)
+lw6srv_send (lw6sys_context_t * sys_context, lw6srv_backend_t * backend, lw6cnx_connection_t * connection,
+	     int64_t now, u_int32_t physical_ticket_sig, u_int32_t logical_ticket_sig, u_int64_t logical_from_id, u_int64_t logical_to_id, const char *message)
 {
   int ret = 0;
 
@@ -409,12 +389,11 @@ lw6srv_send (lw6srv_backend_t * backend, lw6cnx_connection_t * connection,
 
   if (backend->send)
     {
-      if (lw6cnx_connection_reliability_filter (connection))
+      if (lw6cnx_connection_reliability_filter (sys_context, connection))
 	{
 	  ret =
-	    backend->send (backend->srv_context, connection, now,
-			   physical_ticket_sig, logical_ticket_sig,
-			   logical_from_id, logical_to_id, message);
+	    backend->send (sys_context, backend->srv_context, connection, now, physical_ticket_sig, logical_ticket_sig, logical_from_id, logical_to_id,
+			   message);
 	}
       else
 	{
@@ -430,7 +409,7 @@ lw6srv_send (lw6srv_backend_t * backend, lw6cnx_connection_t * connection,
     }
   else
     {
-      _warning (__FUNCTION__);
+      _warning (sys_context, __FUNCTION__);
     }
 
   LW6SYS_BACKEND_FUNCTION_END;
@@ -441,6 +420,7 @@ lw6srv_send (lw6srv_backend_t * backend, lw6cnx_connection_t * connection,
 /**
  * lw6srv_can_send
  *
+ * @sys_context: global system context
  * @backend: server backend to use
  * @connection: connection to use
  *
@@ -451,7 +431,7 @@ lw6srv_send (lw6srv_backend_t * backend, lw6cnx_connection_t * connection,
  * Return value: 1 if it can be used to send messages, 0 if not ready.
  */
 int
-lw6srv_can_send (lw6srv_backend_t * backend, lw6cnx_connection_t * connection)
+lw6srv_can_send (lw6sys_context_t * sys_context, lw6srv_backend_t * backend, lw6cnx_connection_t * connection)
 {
   int ret = 0;
 
@@ -459,11 +439,11 @@ lw6srv_can_send (lw6srv_backend_t * backend, lw6cnx_connection_t * connection)
 
   if (backend->send)
     {
-      ret = backend->can_send (backend->srv_context, connection);
+      ret = backend->can_send (sys_context, backend->srv_context, connection);
     }
   else
     {
-      _warning (__FUNCTION__);
+      _warning (sys_context, __FUNCTION__);
     }
 
   LW6SYS_BACKEND_FUNCTION_END;
@@ -474,6 +454,7 @@ lw6srv_can_send (lw6srv_backend_t * backend, lw6cnx_connection_t * connection)
 /**
  * lw6srv_poll
  *
+ * @sys_context: global system context
  * @backend: server backend to use
  * @connection: connection to use
  *
@@ -482,17 +463,17 @@ lw6srv_can_send (lw6srv_backend_t * backend, lw6cnx_connection_t * connection)
  * Return value: none.
  */
 void
-lw6srv_poll (lw6srv_backend_t * backend, lw6cnx_connection_t * connection)
+lw6srv_poll (lw6sys_context_t * sys_context, lw6srv_backend_t * backend, lw6cnx_connection_t * connection)
 {
   LW6SYS_BACKEND_FUNCTION_BEGIN;
 
   if (backend->poll)
     {
-      backend->poll (backend->srv_context, connection);
+      backend->poll (sys_context, backend->srv_context, connection);
     }
   else
     {
-      _warning (__FUNCTION__);
+      _warning (sys_context, __FUNCTION__);
     }
 
   LW6SYS_BACKEND_FUNCTION_END;
@@ -501,6 +482,7 @@ lw6srv_poll (lw6srv_backend_t * backend, lw6cnx_connection_t * connection)
 /**
  * lw6srv_repr
  *
+ * @sys_context: global system context
  * @backend: backend to use
  * @connection: connection to represent
  *
@@ -509,8 +491,7 @@ lw6srv_poll (lw6srv_backend_t * backend, lw6cnx_connection_t * connection)
  * Return value: dynamically allocated string.
  */
 char *
-lw6srv_repr (const lw6srv_backend_t * backend,
-	     lw6cnx_connection_t * connection)
+lw6srv_repr (lw6sys_context_t * sys_context, const lw6srv_backend_t * backend, lw6cnx_connection_t * connection)
 {
   char *ret = NULL;
 
@@ -518,11 +499,11 @@ lw6srv_repr (const lw6srv_backend_t * backend,
 
   if (backend->repr)
     {
-      ret = backend->repr (backend->srv_context, connection);
+      ret = backend->repr (sys_context, backend->srv_context, connection);
     }
   else
     {
-      _warning (__FUNCTION__);
+      _warning (sys_context, __FUNCTION__);
     }
 
   LW6SYS_BACKEND_FUNCTION_END;
