@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -29,6 +29,7 @@
 /**
  * lw6srv_oob_new
  *
+ * @sys_context: global system context
  * @remote_ip: remote IP address
  * @remote_port: remote port
  * @sock: the socket handler (either TCP or UDP)
@@ -43,22 +44,21 @@
  * Return value: new object
  */
 lw6srv_oob_t *
-lw6srv_oob_new (const char *remote_ip, int remote_port, int sock,
-		const char *first_line)
+lw6srv_oob_new (lw6sys_context_t * sys_context, const char *remote_ip, int remote_port, int sock, const char *first_line)
 {
   lw6srv_oob_t *oob = NULL;
 
-  oob = (lw6srv_oob_t *) LW6SYS_CALLOC (sizeof (lw6srv_oob_t));
+  oob = (lw6srv_oob_t *) LW6SYS_CALLOC (sys_context, sizeof (lw6srv_oob_t));
   if (oob)
     {
-      oob->data.creation_timestamp = lw6sys_get_timestamp ();
+      oob->data.creation_timestamp = lw6sys_get_timestamp (sys_context);
       oob->data.do_not_finish = 0;
-      oob->data.remote_ip = lw6sys_str_copy (remote_ip);
+      oob->data.remote_ip = lw6sys_str_copy (sys_context, remote_ip);
       oob->data.remote_port = remote_port;
       oob->data.sock = sock;
       if (first_line)
 	{
-	  oob->data.first_line = lw6sys_str_copy (first_line);
+	  oob->data.first_line = lw6sys_str_copy (sys_context, first_line);
 	}
     }
 
@@ -66,7 +66,7 @@ lw6srv_oob_new (const char *remote_ip, int remote_port, int sock,
     {
       if (!oob->data.remote_ip)
 	{
-	  lw6srv_oob_free (oob);
+	  lw6srv_oob_free (sys_context, oob);
 	  oob = NULL;
 	}
     }
@@ -77,6 +77,7 @@ lw6srv_oob_new (const char *remote_ip, int remote_port, int sock,
 /**
  * lw6srv_oob_free
  *
+ * @sys_context: global system context
  * @oob: the object to free
  *
  * Frees an OOB structure.
@@ -84,7 +85,7 @@ lw6srv_oob_new (const char *remote_ip, int remote_port, int sock,
  * Return value: none
  */
 void
-lw6srv_oob_free (lw6srv_oob_t * oob)
+lw6srv_oob_free (lw6sys_context_t * sys_context, lw6srv_oob_t * oob)
 {
   if (oob)
     {
@@ -99,40 +100,36 @@ lw6srv_oob_free (lw6srv_oob_t * oob)
 	  oob->data.do_not_finish = 1;
 	  if (oob->data.remote_ip)
 	    {
-	      lw6sys_log (LW6SYS_LOG_INFO,
-			  _x_ ("joining srv OOB thread serving \"%s:%d\""),
-			  oob->data.remote_ip, oob->data.remote_port);
+	      lw6sys_log (sys_context, LW6SYS_LOG_INFO, _x_ ("joining srv OOB thread serving \"%s:%d\""), oob->data.remote_ip, oob->data.remote_port);
 	    }
 	  else
 	    {
-	      lw6sys_log (LW6SYS_LOG_INFO, _x_ ("joining srv OOB thread"));
+	      lw6sys_log (sys_context, LW6SYS_LOG_INFO, _x_ ("joining srv OOB thread"));
 	    }
-	  lw6sys_thread_join (oob->thread);
+	  lw6sys_thread_join (sys_context, oob->thread);
 	  if (oob->data.remote_ip)
 	    {
-	      lw6sys_log (LW6SYS_LOG_INFO,
-			  _x_ ("joined srv OOB thread serving \"%s:%d\""),
-			  oob->data.remote_ip, oob->data.remote_port);
+	      lw6sys_log (sys_context, LW6SYS_LOG_INFO, _x_ ("joined srv OOB thread serving \"%s:%d\""), oob->data.remote_ip, oob->data.remote_port);
 	    }
 	  else
 	    {
-	      lw6sys_log (LW6SYS_LOG_INFO, _x_ ("joined srv OOB thread"));
+	      lw6sys_log (sys_context, LW6SYS_LOG_INFO, _x_ ("joined srv OOB thread"));
 	    }
 	}
 
       if (oob->data.remote_ip)
 	{
-	  LW6SYS_FREE (oob->data.remote_ip);
+	  LW6SYS_FREE (sys_context, oob->data.remote_ip);
 	}
       if (oob->data.first_line)
 	{
-	  LW6SYS_FREE (oob->data.first_line);
+	  LW6SYS_FREE (sys_context, oob->data.first_line);
 	}
-      LW6SYS_FREE (oob);
-      lw6sys_log (LW6SYS_LOG_DEBUG, _x_ ("oob freed"));
+      LW6SYS_FREE (sys_context, oob);
+      lw6sys_log (sys_context, LW6SYS_LOG_DEBUG, _x_ ("oob freed"));
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("trying to free NULL oob"));
+      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("trying to free NULL oob"));
     }
 }
