@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -38,12 +38,14 @@
 /**
  * lw6srv_default_backends
  *
+ * @sys_context: global system context
+ *
  * Returns the list of the default srv backends.
  *
  * Return value: comma separated string, must not be freed.
  */
 char *
-lw6srv_default_backends ()
+lw6srv_default_backends (lw6sys_context_t * sys_context)
 {
   return _SRV_DEFAULT_BACKENDS;
 }
@@ -51,6 +53,7 @@ lw6srv_default_backends ()
 /**
  * lw6srv_get_backends
  *
+ * @sys_context: global system context
  * @argc: argc, as passed to @main
  * @argv: argv, as passed to @main
  *
@@ -64,41 +67,38 @@ lw6srv_default_backends ()
  * Return value: hash containing id/name pairs.
  */
 lw6sys_assoc_t *
-lw6srv_get_backends (int argc, const char *argv[])
+lw6srv_get_backends (lw6sys_context_t * sys_context, int argc, const char *argv[])
 {
   lw6sys_assoc_t *ret = NULL;
 
 #ifdef LW6_ALLINONE
   lw6sys_module_pedigree_t *module_pedigree = NULL;
 
-  ret = lw6sys_assoc_new (lw6sys_free_callback);
+  ret = lw6sys_assoc_new (sys_context, lw6sys_free_callback);
   if (ret)
     {
-      module_pedigree = mod_tcpd_get_pedigree ();
+      module_pedigree = mod_tcpd_get_pedigree (sys_context);
       if (module_pedigree)
 	{
-	  lw6sys_assoc_set (&ret, module_pedigree->id,
-			    lw6sys_str_copy (module_pedigree->name));
-	  LW6SYS_FREE (module_pedigree);
+	  lw6sys_assoc_set (sys_context, &ret, module_pedigree->id, lw6sys_str_copy (sys_context, module_pedigree->name));
+	  LW6SYS_FREE (sys_context, module_pedigree);
 	}
-      module_pedigree = mod_udpd_get_pedigree ();
+      module_pedigree = mod_udpd_get_pedigree (sys_context);
       if (module_pedigree)
 	{
-	  lw6sys_assoc_set (&ret, module_pedigree->id,
-			    lw6sys_str_copy (module_pedigree->name));
-	  LW6SYS_FREE (module_pedigree);
+	  lw6sys_assoc_set (sys_context, &ret, module_pedigree->id, lw6sys_str_copy (sys_context, module_pedigree->name));
+	  LW6SYS_FREE (sys_context, module_pedigree);
 	}
-      module_pedigree = mod_httpd_get_pedigree ();
+      module_pedigree = mod_httpd_get_pedigree (sys_context);
       if (module_pedigree)
 	{
-	  lw6sys_assoc_set (&ret, module_pedigree->id,
-			    lw6sys_str_copy (module_pedigree->name));
-	  LW6SYS_FREE (module_pedigree);
+	  lw6sys_assoc_set (sys_context, &ret, module_pedigree->id, lw6sys_str_copy (sys_context, module_pedigree->name));
+	  LW6SYS_FREE (sys_context, module_pedigree);
 	}
     }
-#else
-  ret = lw6dyn_list_backends (argc, argv, "srv");
-#endif
+#else // LW6_ALLINONE
+  ret = lw6dyn_list_backends (sys_context, argc, argv, "srv");
+#endif // LW6_ALLINONE
 
   return ret;
 }
@@ -106,6 +106,7 @@ lw6srv_get_backends (int argc, const char *argv[])
 /**
  * lw6srv_create_backend
  *
+ * @sys_context: global system context
  * @argc: argc, as passed to @main
  * @argv: argv, as passed to @main
  * @name: string containing srv key, typically got from @lw6srv_get_backends
@@ -117,21 +118,21 @@ lw6srv_get_backends (int argc, const char *argv[])
  * Return value: srv backend.
  */
 lw6srv_backend_t *
-lw6srv_create_backend (int argc, const char *argv[], const char *name)
+lw6srv_create_backend (lw6sys_context_t * sys_context, int argc, const char *argv[], const char *name)
 {
   lw6srv_backend_t *backend = NULL;
 #ifdef LW6_ALLINONE
   if (name && !strcmp (name, "tcpd"))
     {
-      backend = mod_tcpd_create_backend ();
+      backend = mod_tcpd_create_backend (sys_context);
     }
   if (name && !strcmp (name, "udpd"))
     {
-      backend = mod_udpd_create_backend ();
+      backend = mod_udpd_create_backend (sys_context);
     }
   if (name && !strcmp (name, "httpd"))
     {
-      backend = mod_httpd_create_backend ();
+      backend = mod_httpd_create_backend (sys_context);
     }
 
   if (backend)
@@ -141,37 +142,32 @@ lw6srv_create_backend (int argc, const char *argv[], const char *name)
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING,
-		  _x_ ("server backend \"%s\" does not exist"), name);
+      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("server backend \"%s\" does not exist"), name);
     }
-#else
+#else // LW6_ALLINONE
   lw6dyn_dl_handle_t *backend_handle = NULL;
 
-  backend_handle = lw6dyn_dlopen_backend (argc, argv, "srv", name);
+  backend_handle = lw6dyn_dlopen_backend (sys_context, argc, argv, "srv", name);
 
   if (backend_handle)
     {
       char *init_func_name;
-      lw6srv_backend_t *(*init_func) ();
+      lw6srv_backend_t *(*init_func) (lw6sys_context_t *);
 
-      init_func_name =
-	lw6sys_new_sprintf (LW6DYN_CREATE_BACKEND_FUNC_FORMAT, name);
+      init_func_name = lw6sys_new_sprintf (sys_context, LW6DYN_CREATE_BACKEND_FUNC_FORMAT, name);
       if (init_func_name)
 	{
-	  init_func = lw6dyn_dlsym (backend_handle, init_func_name);
+	  init_func = lw6dyn_dlsym (sys_context, backend_handle, init_func_name);
 	  if (init_func)
 	    {
-	      backend = init_func ();
+	      backend = init_func (sys_context);
 	    }
 	  else
 	    {
-	      lw6sys_log (LW6SYS_LOG_WARNING,
-			  _x_
-			  ("unable to find function \"%s\" in server backend \"%s\""),
-			  init_func_name, name);
+	      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("unable to find function \"%s\" in server backend \"%s\""), init_func_name, name);
 	    }
 
-	  LW6SYS_FREE (init_func_name);
+	  LW6SYS_FREE (sys_context, init_func_name);
 	}
     }
 
@@ -184,10 +180,9 @@ lw6srv_create_backend (int argc, const char *argv[], const char *name)
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING,
-		  _x_ ("unable to open server backend \"%s\""), name);
+      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("unable to open server backend \"%s\""), name);
     }
-#endif
+#endif // LW6_ALLINONE
 
   if (backend)
     {
@@ -199,10 +194,10 @@ lw6srv_create_backend (int argc, const char *argv[], const char *name)
 	  backend->id = ++seq_id;
 	}
 
-      backend->name = lw6sys_str_copy (name);
+      backend->name = lw6sys_str_copy (sys_context, name);
       if (!(backend->name))
 	{
-	  lw6srv_destroy_backend (backend);
+	  lw6srv_destroy_backend (sys_context, backend);
 	}
     }
 
@@ -212,6 +207,7 @@ lw6srv_create_backend (int argc, const char *argv[], const char *name)
 /**
  * lw6srv_destroy_backend
  *
+ * @sys_context: global system context
  * @backend: backend to destroy
  *
  * Destroys a srv backend.
@@ -219,15 +215,15 @@ lw6srv_create_backend (int argc, const char *argv[], const char *name)
  * Return value: none.
  */
 void
-lw6srv_destroy_backend (lw6srv_backend_t * backend)
+lw6srv_destroy_backend (lw6sys_context_t * sys_context, lw6srv_backend_t * backend)
 {
 #ifndef LW6_ALLINONE
-  lw6dyn_dlclose_backend (backend->dl_handle);
-#endif
+  lw6dyn_dlclose_backend (sys_context, backend->dl_handle);
+#endif // LW6_ALLINONE
   if (backend->name)
     {
-      LW6SYS_FREE (backend->name);
+      LW6SYS_FREE (sys_context, backend->name);
       backend->name = NULL;
     }
-  LW6SYS_FREE (backend);
+  LW6SYS_FREE (sys_context, backend);
 }
