@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -38,18 +38,17 @@
  * Return value: none
  */
 lw6srv_tcp_accepter_t *
-lw6srv_tcp_accepter_new (char *client_ip, int client_port, int sock)
+lw6srv_tcp_accepter_new (lw6sys_context_t * sys_context, char *client_ip, int client_port, int sock)
 {
   lw6srv_tcp_accepter_t *ret = NULL;
 
-  ret =
-    (lw6srv_tcp_accepter_t *) LW6SYS_CALLOC (sizeof (lw6srv_tcp_accepter_t));
+  ret = (lw6srv_tcp_accepter_t *) LW6SYS_CALLOC (sys_context, sizeof (lw6srv_tcp_accepter_t));
   if (ret)
     {
       ret->client_id.client_ip = client_ip;	// we'll destroy this ourselves
       ret->client_id.client_port = client_port;
       ret->sock = sock;
-      ret->creation_timestamp = lw6sys_get_timestamp ();
+      ret->creation_timestamp = lw6sys_get_timestamp (sys_context);
     }
 
   return ret;
@@ -65,7 +64,7 @@ lw6srv_tcp_accepter_new (char *client_ip, int client_port, int sock)
  * Return value: none
  */
 void
-lw6srv_tcp_accepter_free (lw6srv_tcp_accepter_t * tcp_accepter)
+lw6srv_tcp_accepter_free (lw6sys_context_t * sys_context, lw6srv_tcp_accepter_t * tcp_accepter)
 {
   /*
    * We don't close the socket for it might be used by
@@ -73,7 +72,7 @@ lw6srv_tcp_accepter_free (lw6srv_tcp_accepter_t * tcp_accepter)
    */
   if (tcp_accepter->client_id.client_ip)
     {
-      LW6SYS_FREE (tcp_accepter->client_id.client_ip);
+      LW6SYS_FREE (sys_context, tcp_accepter->client_id.client_ip);
     }
-  LW6SYS_FREE (tcp_accepter);
+  LW6SYS_FREE (sys_context, tcp_accepter);
 }
