@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -54,28 +54,29 @@
 typedef struct _lw6srv_test_data_s
 {
   int ret;
+  lw6sys_context_t *sys_context;
   lw6srv_backend_t *backend[_TEST_NB_BACKENDS];
   lw6srv_listener_t *listener;
 } _lw6srv_test_data_t;
 
-static _lw6srv_test_data_t _test_data = { 0, {NULL, NULL, NULL}, NULL };
+static _lw6srv_test_data_t _test_data = { 0, NULL, {NULL, NULL, NULL}, NULL };
 
 static void
 _test_oob ()
 {
   int ret = 1;
+  lw6sys_context_t *sys_context = _test_data.sys_context;
+
   LW6SYS_TEST_FUNCTION_BEGIN;
 
   {
     lw6srv_oob_t *oob;
 
-    oob =
-      lw6srv_oob_new (_TEST_OOB_REMOTE_IP, _TEST_OOB_REMOTE_PORT,
-		      _TEST_OOB_INVALID_SOCK, _TEST_LINE);
+    oob = lw6srv_oob_new (sys_context, _TEST_OOB_REMOTE_IP, _TEST_OOB_REMOTE_PORT, _TEST_OOB_INVALID_SOCK, _TEST_LINE);
     if (oob)
       {
-	lw6sys_log (LW6SYS_LOG_NOTICE, _x_ ("created oob object"));
-	lw6srv_oob_free (oob);
+	lw6sys_log (sys_context, LW6SYS_LOG_NOTICE, _x_ ("created oob object"));
+	lw6srv_oob_free (sys_context, oob);
       }
     else
       {
@@ -90,29 +91,27 @@ static void
 _test_tcp_accepter ()
 {
   int ret = 1;
+  lw6sys_context_t *sys_context = _test_data.sys_context;
+
   LW6SYS_TEST_FUNCTION_BEGIN;
 
   {
     lw6srv_tcp_accepter_t *tcp_accepter = NULL;
     char *ip = NULL;
 
-    ip = lw6sys_str_copy (LW6NET_ADDRESS_LOOPBACK);
+    ip = lw6sys_str_copy (sys_context, LW6NET_ADDRESS_LOOPBACK);
     if (ip)
       {
-	tcp_accepter =
-	  lw6srv_tcp_accepter_new (ip, _TEST_PORT, _TEST_FAKE_SOCK);
+	tcp_accepter = lw6srv_tcp_accepter_new (sys_context, ip, _TEST_PORT, _TEST_FAKE_SOCK);
 	if (tcp_accepter)
 	  {
-	    lw6sys_log (LW6SYS_LOG_NOTICE, _x_ ("tcp_accepter %s:%d"),
-			tcp_accepter->client_id.client_ip,
-			tcp_accepter->client_id.client_port);
-	    lw6srv_tcp_accepter_free (tcp_accepter);
+	    lw6sys_log (sys_context, LW6SYS_LOG_NOTICE, _x_ ("tcp_accepter %s:%d"), tcp_accepter->client_id.client_ip, tcp_accepter->client_id.client_port);
+	    lw6srv_tcp_accepter_free (sys_context, tcp_accepter);
 	  }
 	else
 	  {
-	    lw6sys_log (LW6SYS_LOG_WARNING,
-			_x_ ("unable to create tcp_accepter object"));
-	    LW6SYS_FREE (ip);
+	    lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("unable to create tcp_accepter object"));
+	    LW6SYS_FREE (sys_context, ip);
 	    ret = 0;
 	  }
       }
@@ -125,6 +124,8 @@ static void
 _test_udp_buffer ()
 {
   int ret = 1;
+  lw6sys_context_t *sys_context = _test_data.sys_context;
+
   LW6SYS_TEST_FUNCTION_BEGIN;
 
   {
@@ -132,32 +133,29 @@ _test_udp_buffer ()
     char *ip = NULL;
     char *line = NULL;
 
-    ip = lw6sys_str_copy (LW6NET_ADDRESS_LOOPBACK);
+    ip = lw6sys_str_copy (sys_context, LW6NET_ADDRESS_LOOPBACK);
     if (ip)
       {
-	line = lw6sys_str_copy (_TEST_LINE);
+	line = lw6sys_str_copy (sys_context, _TEST_LINE);
 	if (line)
 	  {
-	    udp_buffer = lw6srv_udp_buffer_new (ip, _TEST_PORT, line);
+	    udp_buffer = lw6srv_udp_buffer_new (sys_context, ip, _TEST_PORT, line);
 	    if (udp_buffer)
 	      {
-		lw6sys_log (LW6SYS_LOG_NOTICE, _x_ ("udp_buffer %s:%d"),
-			    udp_buffer->client_id.client_ip,
-			    udp_buffer->client_id.client_port);
-		lw6srv_udp_buffer_free (udp_buffer);
+		lw6sys_log (sys_context, LW6SYS_LOG_NOTICE, _x_ ("udp_buffer %s:%d"), udp_buffer->client_id.client_ip, udp_buffer->client_id.client_port);
+		lw6srv_udp_buffer_free (sys_context, udp_buffer);
 	      }
 	    else
 	      {
-		lw6sys_log (LW6SYS_LOG_WARNING,
-			    _x_ ("unable to create udp_buffer object"));
-		LW6SYS_FREE (line);
-		LW6SYS_FREE (ip);
+		lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("unable to create udp_buffer object"));
+		LW6SYS_FREE (sys_context, line);
+		LW6SYS_FREE (sys_context, ip);
 		ret = 0;
 	      }
 	  }
 	else
 	  {
-	    LW6SYS_FREE (ip);
+	    LW6SYS_FREE (sys_context, ip);
 	  }
       }
   }
@@ -172,10 +170,12 @@ static void
 _test_dummy ()
 {
   int ret = 1;
+  lw6sys_context_t *sys_context = _test_data.sys_context;
+
   LW6SYS_TEST_FUNCTION_BEGIN;
 
   {
-    lw6sys_log (LW6SYS_LOG_NOTICE, _x_ ("dummy test"));
+    lw6sys_log (sys_context, LW6SYS_LOG_NOTICE, _x_ ("dummy test"));
   }
 
   LW6SYS_TEST_FUNCTION_END;
@@ -184,7 +184,9 @@ _test_dummy ()
 static int
 _setup_init ()
 {
-  lw6sys_log (LW6SYS_LOG_NOTICE, _x_ ("init libsrv CUnit test suite"));
+  lw6sys_context_t *sys_context = _test_data.sys_context;
+
+  lw6sys_log (sys_context, LW6SYS_LOG_NOTICE, _x_ ("init libsrv CUnit test suite"));
 
   return CUE_SUCCESS;
 }
@@ -192,7 +194,9 @@ _setup_init ()
 static int
 _setup_quit ()
 {
-  lw6sys_log (LW6SYS_LOG_NOTICE, _x_ ("quit libsrv CUnit test suite"));
+  lw6sys_context_t *sys_context = _test_data.sys_context;
+
+  lw6sys_log (sys_context, LW6SYS_LOG_NOTICE, _x_ ("quit libsrv CUnit test suite"));
 
   return CUE_SUCCESS;
 }
@@ -201,45 +205,39 @@ static int
 _setup_init_listener ()
 {
   int ret = CUE_SINIT_FAILED;
+  lw6sys_context_t *sys_context = _test_data.sys_context;
   int argc = _TEST_ARGC;
   const char *argv[_TEST_ARGC] = { _TEST_ARGV0 };
   int i = 0;
   int ok = 1;
 
-  lw6sys_log (LW6SYS_LOG_NOTICE,
-	      _x_ ("init libsrv-listener CUnit test suite"));
+  lw6sys_log (sys_context, LW6SYS_LOG_NOTICE, _x_ ("init libsrv-listener CUnit test suite"));
 
-  if (lw6net_init (argc, argv, _TEST_NET_LOG))
+  if (lw6net_init (sys_context, argc, argv, _TEST_NET_LOG))
     {
-      _test_data.backend[0] = lw6srv_create_backend (argc, argv, "tcpd");
-      _test_data.backend[1] = lw6srv_create_backend (argc, argv, "udpd");
-      _test_data.backend[2] = lw6srv_create_backend (argc, argv, "httpd");
+      _test_data.backend[0] = lw6srv_create_backend (sys_context, argc, argv, "tcpd");
+      _test_data.backend[1] = lw6srv_create_backend (sys_context, argc, argv, "udpd");
+      _test_data.backend[2] = lw6srv_create_backend (sys_context, argc, argv, "httpd");
 
-      if (_test_data.backend[0] && _test_data.backend[1]
-	  && _test_data.backend[2])
+      if (_test_data.backend[0] && _test_data.backend[1] && _test_data.backend[2])
 	{
-	  _test_data.listener = lw6srv_start (LW6NET_ADDRESS_ANY, _TEST_PORT);
+	  _test_data.listener = lw6srv_start (sys_context, LW6NET_ADDRESS_ANY, _TEST_PORT);
 	  if (_test_data.listener)
 	    {
 	      for (i = 0; i < _TEST_NB_BACKENDS; ++i)
 		{
 		  if (ok)
 		    {
-		      if (lw6srv_init
-			  (_test_data.backend[i], _test_data.listener))
+		      if (lw6srv_init (sys_context, _test_data.backend[i], _test_data.listener))
 			{
-			  lw6sys_log (LW6SYS_LOG_NOTICE,
+			  lw6sys_log (sys_context, LW6SYS_LOG_NOTICE,
 				      _x_
 				      ("successfull init for backend \"%s\", hint_timeout=%d seconds"),
-				      _test_data.backend[i]->name,
-				      _test_data.backend[i]->
-				      properties.hint_timeout);
+				      _test_data.backend[i]->name, _test_data.backend[i]->properties.hint_timeout);
 			}
 		      else
 			{
-			  lw6sys_log (LW6SYS_LOG_WARNING,
-				      _x_ ("unable to init backend \"%s\""),
-				      _test_data.backend[i]->name);
+			  lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("unable to init backend \"%s\""), _test_data.backend[i]->name);
 			  ok = 0;
 			}
 		      if (ok)
@@ -259,35 +257,33 @@ static int
 _setup_quit_listener ()
 {
   int ret = CUE_SCLEAN_FAILED;
+  lw6sys_context_t *sys_context = _test_data.sys_context;
   int i = 0;
 
-  lw6sys_log (LW6SYS_LOG_NOTICE,
-	      _x_ ("quit libsrv-listener CUnit test suite"));
+  lw6sys_log (sys_context, LW6SYS_LOG_NOTICE, _x_ ("quit libsrv-listener CUnit test suite"));
 
   if (_test_data.listener)
     {
-      if (_test_data.backend[0] && _test_data.backend[1]
-	  && _test_data.backend[2])
+      if (_test_data.backend[0] && _test_data.backend[1] && _test_data.backend[2])
 	{
 	  for (i = 0; i < _TEST_NB_BACKENDS; ++i)
 	    {
-	      lw6srv_quit (_test_data.backend[i]);
+	      lw6srv_quit (sys_context, _test_data.backend[i]);
 	    }
 	  ret = CUE_SUCCESS;
 	}
-      lw6srv_stop (_test_data.listener);
+      lw6srv_stop (sys_context, _test_data.listener);
       _test_data.listener = NULL;
-      if (_test_data.backend[0] && _test_data.backend[1]
-	  && _test_data.backend[2])
+      if (_test_data.backend[0] && _test_data.backend[1] && _test_data.backend[2])
 	{
 	  for (i = 0; i < _TEST_NB_BACKENDS; ++i)
 	    {
-	      lw6srv_destroy_backend (_test_data.backend[i]);
+	      lw6srv_destroy_backend (sys_context, _test_data.backend[i]);
 	      _test_data.backend[i] = NULL;
 	    }
 	}
     }
-  lw6net_quit ();
+  lw6net_quit (sys_context);
 
   return ret;
 }
@@ -295,6 +291,7 @@ _setup_quit_listener ()
 /**
  * lw6srv_test_register
  *
+ * @sys_context: global system context
  * @mode: test mode (bitmask)
  *
  * Registers all tests for the libsrv module.
@@ -302,23 +299,25 @@ _setup_quit_listener ()
  * Return value: 1 if test is successfull, 0 on error.
  */
 int
-lw6srv_test_register (int mode)
+lw6srv_test_register (lw6sys_context_t * sys_context, int mode)
 {
   int ret = 1;
   CU_Suite *suite;
 
+  _test_data.sys_context = sys_context;
+
   if (lw6sys_false ())
     {
       /*
        * Just to make sure most functions are stuffed in the binary
        */
-      lw6sys_test_register (mode);
-      lw6glb_test_register (mode);
-      lw6cfg_test_register (mode);
-      lw6net_test_register (mode);
-      lw6nod_test_register (mode);
-      lw6cnx_test_register (mode);
-      lw6msg_test_register (mode);
+      lw6sys_test_register (sys_context, mode);
+      lw6glb_test_register (sys_context, mode);
+      lw6cfg_test_register (sys_context, mode);
+      lw6net_test_register (sys_context, mode);
+      lw6nod_test_register (sys_context, mode);
+      lw6cnx_test_register (sys_context, mode);
+      lw6msg_test_register (sys_context, mode);
 
       /*
        * No lw6dyn_test, see https://savannah.gnu.org/bugs/index.php?35017
@@ -336,24 +335,18 @@ lw6srv_test_register (int mode)
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING,
-		  _x_ ("unable to add CUnit test suite, error msg is \"%s\""),
-		  CU_get_error_msg ());
+      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("unable to add CUnit test suite, error msg is \"%s\""), CU_get_error_msg ());
       ret = 0;
     }
 
-  suite =
-    CU_add_suite ("lw6srv-listener", _setup_init_listener,
-		  _setup_quit_listener);
+  suite = CU_add_suite ("lw6srv-listener", _setup_init_listener, _setup_quit_listener);
   if (suite)
     {
       LW6SYS_CUNIT_ADD_TEST (suite, _test_dummy);
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING,
-		  _x_ ("unable to add CUnit test suite, error msg is \"%s\""),
-		  CU_get_error_msg ());
+      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("unable to add CUnit test suite, error msg is \"%s\""), CU_get_error_msg ());
       ret = 0;
     }
 
@@ -363,6 +356,7 @@ lw6srv_test_register (int mode)
 /**
  * lw6srv_test_run
  *
+ * @sys_context: global system context
  * @mode: test mode (bitmask)
  *
  * Runs the @srv module test suite, testing most (if not all...)
@@ -371,12 +365,14 @@ lw6srv_test_register (int mode)
  * Return value: 1 if test is successfull, 0 on error.
  */
 int
-lw6srv_test_run (int mode)
+lw6srv_test_run (lw6sys_context_t * sys_context, int mode)
 {
   int ret = 0;
 
   _test_data.ret = 1;
-  if (lw6sys_cunit_run_tests (mode))
+  _test_data.sys_context = sys_context;
+
+  if (lw6sys_cunit_run_tests (sys_context, mode))
     {
       ret = _test_data.ret;
     }
