@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -29,6 +29,7 @@
 /**
  * lw6srv_udp_buffer_new
  *
+ * @sys_context: global system context
  * @client_ip: the client ip, will be freed when object is freed, do not free it
  * @client_port: the client port
  * @line: the line received, will be freed when object is freed, do not free it
@@ -38,11 +39,11 @@
  * Return value: none
  */
 lw6srv_udp_buffer_t *
-lw6srv_udp_buffer_new (char *client_ip, int client_port, char *line)
+lw6srv_udp_buffer_new (lw6sys_context_t * sys_context, char *client_ip, int client_port, char *line)
 {
   lw6srv_udp_buffer_t *ret = NULL;
 
-  ret = (lw6srv_udp_buffer_t *) LW6SYS_CALLOC (sizeof (lw6srv_udp_buffer_t));
+  ret = (lw6srv_udp_buffer_t *) LW6SYS_CALLOC (sys_context, sizeof (lw6srv_udp_buffer_t));
   if (ret)
     {
       ret->client_id.client_ip = client_ip;	// we'll destroy this ourselves
@@ -56,6 +57,7 @@ lw6srv_udp_buffer_new (char *client_ip, int client_port, char *line)
 /**
  * lw6srv_udp_buffer_free
  *
+ * @sys_context: global system context
  * @udp_buffer: the object to free
  *
  * Frees a udp_buffer object.
@@ -63,15 +65,15 @@ lw6srv_udp_buffer_new (char *client_ip, int client_port, char *line)
  * Return value: none
  */
 void
-lw6srv_udp_buffer_free (lw6srv_udp_buffer_t * udp_buffer)
+lw6srv_udp_buffer_free (lw6sys_context_t * sys_context, lw6srv_udp_buffer_t * udp_buffer)
 {
   if (udp_buffer->client_id.client_ip)
     {
-      LW6SYS_FREE (udp_buffer->client_id.client_ip);
+      LW6SYS_FREE (sys_context, udp_buffer->client_id.client_ip);
     }
   if (udp_buffer->line)
     {
-      LW6SYS_FREE (udp_buffer->line);
+      LW6SYS_FREE (sys_context, udp_buffer->line);
     }
-  LW6SYS_FREE (udp_buffer);
+  LW6SYS_FREE (sys_context, udp_buffer);
 }
