@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -539,6 +539,7 @@ lw6sys_color_iabgr_to_8 (u_int32_t color_i)
 /**
  * lw6sys_color_a_to_8
  *
+ * @sys_context: global system context
  * @ascii: the color to convert
  *
  * Converts a color from a human readable string to
@@ -549,7 +550,7 @@ lw6sys_color_iabgr_to_8 (u_int32_t color_i)
  * Return value: the converted color (structure).
  */
 lw6sys_color_8_t
-lw6sys_color_a_to_8 (const char *ascii)
+lw6sys_color_a_to_8 (lw6sys_context_t * sys_context, const char *ascii)
 {
   lw6sys_color_8_t ret;
 
@@ -599,18 +600,13 @@ lw6sys_color_a_to_8 (const char *ascii)
 	  ret.b = strtol (buf, NULL, 16);
 	  break;
 	default:
-	  lw6sys_log (LW6SYS_LOG_WARNING,
-		      _x_
-		      ("invalid color value \"%s\", color format must be \"#RGB\", \"#RGBA\", \"#RRGGBB\" or \"#RRGGBBAA\""),
-		      ascii);
+	  lw6sys_log (sys_context, LW6SYS_LOG_WARNING,
+		      _x_ ("invalid color value \"%s\", color format must be \"#RGB\", \"#RGBA\", \"#RRGGBB\" or \"#RRGGBBAA\""), ascii);
 	}
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING,
-		  _x_
-		  ("invalid color value \"%s\", color value must start with \"#\""),
-		  ascii);
+      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("invalid color value \"%s\", color value must start with \"#\""), ascii);
     }
 
   return ret;
@@ -619,6 +615,7 @@ lw6sys_color_a_to_8 (const char *ascii)
 /**
  * lw6sys_color_a_to_f
  *
+ * @sys_context: global system context
  * @color_f: the converted color (pointer must point to writable memory)
  * @ascii: the color to convert
  *
@@ -630,17 +627,18 @@ lw6sys_color_a_to_8 (const char *ascii)
  * Return value: none.
  */
 void
-lw6sys_color_a_to_f (lw6sys_color_f_t * color_f, const char *ascii)
+lw6sys_color_a_to_f (lw6sys_context_t * sys_context, lw6sys_color_f_t * color_f, const char *ascii)
 {
   lw6sys_color_8_t color_8;
 
-  color_8 = lw6sys_color_a_to_8 (ascii);
+  color_8 = lw6sys_color_a_to_8 (sys_context, ascii);
   lw6sys_color_8_to_f (color_f, color_8);
 }
 
 /**
  * lw6sys_color_8_to_a
  *
+ * @sys_context: global system context
  * @color_8: the color to convert
  *
  * Converts a color from a "0 - 255" integer based structure
@@ -650,20 +648,17 @@ lw6sys_color_a_to_f (lw6sys_color_f_t * color_f, const char *ascii)
  * Return value: a newly allocated string.
  */
 char *
-lw6sys_color_8_to_a (lw6sys_color_8_t color_8)
+lw6sys_color_8_to_a (lw6sys_context_t * sys_context, lw6sys_color_8_t color_8)
 {
   char *ret = NULL;
 
   if (color_8.a == 0xFF)
     {
-      ret =
-	lw6sys_new_sprintf ("#%02x%02x%02x", color_8.r, color_8.g, color_8.b);
+      ret = lw6sys_new_sprintf (sys_context, "#%02x%02x%02x", color_8.r, color_8.g, color_8.b);
     }
   else
     {
-      ret =
-	lw6sys_new_sprintf ("#%02x%02x%02x%02x", color_8.r, color_8.g,
-			    color_8.b, color_8.a);
+      ret = lw6sys_new_sprintf (sys_context, "#%02x%02x%02x%02x", color_8.r, color_8.g, color_8.b, color_8.a);
     }
 
   return ret;
@@ -672,6 +667,7 @@ lw6sys_color_8_to_a (lw6sys_color_8_t color_8)
 /**
  * lw6sys_color_rgb_to_hsv
  *
+ * @sys_context: global system context
  * @color_hsv: the target color, in HSV format
  * @color_8: the source color, in RGB 256 format
  *
@@ -682,8 +678,7 @@ lw6sys_color_8_to_a (lw6sys_color_8_t color_8)
  * Return value: none.
  */
 void
-lw6sys_color_rgb_to_hsv (lw6sys_color_hsv_t * color_hsv,
-			 lw6sys_color_8_t color_8)
+lw6sys_color_rgb_to_hsv (lw6sys_context_t * sys_context, lw6sys_color_hsv_t * color_hsv, lw6sys_color_8_t color_8)
 {
   // inspired from Allegro src/color.c
   int delta;
@@ -698,8 +693,7 @@ lw6sys_color_rgb_to_hsv (lw6sys_color_hsv_t * color_hsv,
 	{
 	  /* b>r>g */
 	  delta = color_8.b - color_8.g;
-	  color_hsv->h =
-	    240.0f + ((color_8.r - color_8.g) * 60) / (float) delta;
+	  color_hsv->h = 240.0f + ((color_8.r - color_8.g) * 60) / (float) delta;
 	  color_hsv->s = (float) delta / (float) color_8.b;
 	  color_hsv->v = (float) color_8.b * (1.0f / 255.0f);
 	}
@@ -720,8 +714,7 @@ lw6sys_color_rgb_to_hsv (lw6sys_color_hsv_t * color_hsv,
 	{
 	  /* b>g>=r */
 	  delta = color_8.b - color_8.r;
-	  color_hsv->h =
-	    240.0f + ((color_8.r - color_8.g) * 60) / (float) delta;
+	  color_hsv->h = 240.0f + ((color_8.r - color_8.g) * 60) / (float) delta;
 	  color_hsv->s = (float) delta / (float) color_8.b;
 	  color_hsv->v = (float) color_8.b * (1.0f / 255.0f);
 	}
@@ -742,8 +735,7 @@ lw6sys_color_rgb_to_hsv (lw6sys_color_hsv_t * color_hsv,
 	    }
 	  else
 	    {
-	      color_hsv->h =
-		120.0f + ((color_8.b - color_8.r) * 60) / (float) delta;
+	      color_hsv->h = 120.0f + ((color_8.b - color_8.r) * 60) / (float) delta;
 	      color_hsv->s = (float) delta / (float) color_8.g;
 	      color_hsv->v = (float) color_8.g * (1.0f / 255.0f);
 	    }
@@ -756,6 +748,7 @@ lw6sys_color_rgb_to_hsv (lw6sys_color_hsv_t * color_hsv,
 /**
  * lw6sys_color_hsv_to_rgb
  *
+ * @sys_context: global system context
  * @color_hsv: the source color, in HSV format
  *
  * Converts from RGB to HSV. Usefull to make colors transformed in HSV
@@ -765,7 +758,7 @@ lw6sys_color_rgb_to_hsv (lw6sys_color_hsv_t * color_hsv,
  * Return value: the RGB color.
  */
 lw6sys_color_8_t
-lw6sys_color_hsv_to_rgb (const lw6sys_color_hsv_t * color_hsv)
+lw6sys_color_hsv_to_rgb (lw6sys_context_t * sys_context, const lw6sys_color_hsv_t * color_hsv)
 {
   // inspired from Allegro src/color.c
   lw6sys_color_8_t color_8 = LW6SYS_COLOR_8_BLACK;
@@ -849,6 +842,7 @@ lw6sys_color_hsv_to_rgb (const lw6sys_color_hsv_t * color_hsv)
 /**
  * lw6sys_color_hsv_invert
  *
+ * @sys_context: global system context
  * @color_hsv: the source color, in HSV format
  * @invert_h: wether to invert the hue
  * @invert_s: wether to invert the saturation
@@ -861,8 +855,7 @@ lw6sys_color_hsv_to_rgb (const lw6sys_color_hsv_t * color_hsv)
  * Return value: none.
  */
 void
-lw6sys_color_hsv_invert (lw6sys_color_hsv_t * color_hsv, int invert_h,
-			 int invert_s, int invert_v)
+lw6sys_color_hsv_invert (lw6sys_context_t * sys_context, lw6sys_color_hsv_t * color_hsv, int invert_h, int invert_s, int invert_v)
 {
   if (invert_h)
     {
@@ -905,6 +898,7 @@ lw6sys_color_is_grey (lw6sys_color_8_t color)
 /**
  * lw6sys_color_average
  *
+ * @sys_context: global system context
  * @size: number of the color array (number of items)
  * @colors: the colors to compute
  *
@@ -915,7 +909,7 @@ lw6sys_color_is_grey (lw6sys_color_8_t color)
  * Return value: the (inexact) average color.
  */
 lw6sys_color_8_t
-lw6sys_color_average (int size, const lw6sys_color_8_t * colors)
+lw6sys_color_average (lw6sys_context_t * sys_context, int size, const lw6sys_color_8_t * colors)
 {
   int i;
   int64_t sum_r = 0;
@@ -931,7 +925,7 @@ lw6sys_color_average (int size, const lw6sys_color_8_t * colors)
     {
       for (i = 0; i < size; ++i)
 	{
-	  lw6sys_color_rgb_to_hsv (&color_hsv, colors[i]);
+	  lw6sys_color_rgb_to_hsv (sys_context, &color_hsv, colors[i]);
 	  sum_s += color_hsv.s;
 	  sum_v += color_hsv.v;
 	  sum_r += colors[i].r;
@@ -943,10 +937,10 @@ lw6sys_color_average (int size, const lw6sys_color_8_t * colors)
       color_8.g = sum_g / size;
       color_8.b = sum_b / size;
       color_8.a = sum_a / size;
-      lw6sys_color_rgb_to_hsv (&color_hsv, color_8);	// set hue & alpha (h,a)
+      lw6sys_color_rgb_to_hsv (sys_context, &color_hsv, color_8);	// set hue & alpha (h,a)
       color_hsv.s = sum_s / size;
       color_hsv.v = sum_v / size;
-      color_8 = lw6sys_color_hsv_to_rgb (&color_hsv);
+      color_8 = lw6sys_color_hsv_to_rgb (sys_context, &color_hsv);
     }
 
   return color_8;
@@ -955,6 +949,7 @@ lw6sys_color_average (int size, const lw6sys_color_8_t * colors)
 /**
  * lw6sys_color_ponderate
  *
+ * @sys_context: global system context
  * @color1: first color
  * @color2: second color
  * @coeff: the ponderation coefficient
@@ -968,8 +963,7 @@ lw6sys_color_average (int size, const lw6sys_color_8_t * colors)
  * Return value: the (inexact) ponderated color.
  */
 lw6sys_color_8_t
-lw6sys_color_ponderate (lw6sys_color_8_t color1, lw6sys_color_8_t color2,
-			float coeff)
+lw6sys_color_ponderate (lw6sys_context_t * sys_context, lw6sys_color_8_t color1, lw6sys_color_8_t color2, float coeff)
 {
   lw6sys_color_8_t ret = LW6SYS_COLOR_8_BLACK;
   lw6sys_color_hsv_t color1_hsv;
@@ -997,8 +991,8 @@ lw6sys_color_ponderate (lw6sys_color_8_t color1, lw6sys_color_8_t color2,
 	}
       else
 	{
-	  lw6sys_color_rgb_to_hsv (&color1_hsv, color1);
-	  lw6sys_color_rgb_to_hsv (&color2_hsv, color2);
+	  lw6sys_color_rgb_to_hsv (sys_context, &color1_hsv, color1);
+	  lw6sys_color_rgb_to_hsv (sys_context, &color2_hsv, color2);
 	  if (color2_hsv.h - color1_hsv.h < 180.0f)
 	    {
 	      color2_hsv.h += 360.0f;
@@ -1011,7 +1005,7 @@ lw6sys_color_ponderate (lw6sys_color_8_t color1, lw6sys_color_8_t color2,
 	  ret_hsv.s = one_minus_coeff * color1_hsv.s + coeff * color2_hsv.s;
 	  ret_hsv.v = one_minus_coeff * color1_hsv.v + coeff * color2_hsv.v;
 	  ret_hsv.a = one_minus_coeff * color1_hsv.a + coeff * color2_hsv.a;
-	  ret = lw6sys_color_hsv_to_rgb (&ret_hsv);
+	  ret = lw6sys_color_hsv_to_rgb (sys_context, &ret_hsv);
 	}
     }
 
@@ -1019,8 +1013,7 @@ lw6sys_color_ponderate (lw6sys_color_8_t color1, lw6sys_color_8_t color2,
 }
 
 static void
-color_hsv_to_xyz (float *x, float *y, float *z,
-		  lw6sys_color_hsv_t * color_hsv)
+color_hsv_to_xyz (lw6sys_context_t * sys_context, float *x, float *y, float *z, lw6sys_color_hsv_t * color_hsv)
 {
   float angle;
 
@@ -1031,17 +1024,18 @@ color_hsv_to_xyz (float *x, float *y, float *z,
 }
 
 static void
-color_8_to_xyz (float *x, float *y, float *z, lw6sys_color_8_t color_8)
+color_8_to_xyz (lw6sys_context_t * sys_context, float *x, float *y, float *z, lw6sys_color_8_t color_8)
 {
   lw6sys_color_hsv_t color_hsv = LW6SYS_COLOR_HSV_BLACK;
 
-  lw6sys_color_rgb_to_hsv (&color_hsv, color_8);
-  color_hsv_to_xyz (x, y, z, &color_hsv);
+  lw6sys_color_rgb_to_hsv (sys_context, &color_hsv, color_8);
+  color_hsv_to_xyz (sys_context, x, y, z, &color_hsv);
 }
 
 /**
  * lw6sys_color_distance
  *
+ * @sys_context: global system context
  * @color1: first color
  * @color2: second color
  *
@@ -1053,7 +1047,7 @@ color_8_to_xyz (float *x, float *y, float *z, lw6sys_color_8_t color_8)
  * Return value: the distance.
  */
 float
-lw6sys_color_distance (lw6sys_color_8_t color1, lw6sys_color_8_t color2)
+lw6sys_color_distance (lw6sys_context_t * sys_context, lw6sys_color_8_t color1, lw6sys_color_8_t color2)
 {
   float x1 = 0.0f;
   float y1 = 0.0f;
@@ -1063,11 +1057,9 @@ lw6sys_color_distance (lw6sys_color_8_t color1, lw6sys_color_8_t color2)
   float z2 = 0.0f;
   float distance = 0.0f;
 
-  color_8_to_xyz (&x1, &y1, &z1, color1);
-  color_8_to_xyz (&x2, &y2, &z2, color2);
-  distance =
-    sqrt ((x2 - x1) * (x2 - x1) + (y2 - y1) * (y2 - y1) +
-	  (z2 - z1) * (z2 - z1));
+  color_8_to_xyz (sys_context, &x1, &y1, &z1, color1);
+  color_8_to_xyz (sys_context, &x2, &y2, &z2, color2);
+  distance = sqrt ((x2 - x1) * (x2 - x1) + (y2 - y1) * (y2 - y1) + (z2 - z1) * (z2 - z1));
 
   return distance;
 }
@@ -1075,6 +1067,7 @@ lw6sys_color_distance (lw6sys_color_8_t color1, lw6sys_color_8_t color2)
 /**
  * lw6sys_color_is_same
  *
+ * @sys_context: global system context
  * @color1: the first color to compare
  * @color2: the second color to compare
  *
@@ -1083,7 +1076,7 @@ lw6sys_color_distance (lw6sys_color_8_t color1, lw6sys_color_8_t color2)
  * Return value: 1 if they are the same, 0 if not.
  */
 int
-lw6sys_color_is_same (lw6sys_color_8_t color1, lw6sys_color_8_t color2)
+lw6sys_color_is_same (lw6sys_context_t * sys_context, lw6sys_color_8_t color1, lw6sys_color_8_t color2)
 {
   int ret = 0;
 
@@ -1095,7 +1088,7 @@ lw6sys_color_is_same (lw6sys_color_8_t color1, lw6sys_color_8_t color2)
 /**
  * lw6sys_color_8_solid
  *
- * color: the color to modify
+ * @color: the color to modify
  *
  * Make a color "solid" that is make it not transparent at all.
  *
@@ -1110,7 +1103,7 @@ lw6sys_color_8_solid (lw6sys_color_8_t * color)
 /**
  * lw6sys_color_f_solid
  *
- * color: the color to modify
+ * @color: the color to modify
  *
  * Make a color "solid" that is make it not transparent at all.
  *
