@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -47,6 +47,7 @@
 /**
  * lw6sys_escape_http_uri
  *
+ * @sys_context: global system context
  * @src: the string to escape
  *
  * Transforms a string so that it does not contain any non-valid
@@ -61,7 +62,7 @@
  * Return value: newly allocated string.
  */
 char *
-lw6sys_escape_http_uri (const char *src)
+lw6sys_escape_http_uri (lw6sys_context_t * sys_context, const char *src)
 {
   char *ret = NULL;
   int len = 0;
@@ -69,9 +70,9 @@ lw6sys_escape_http_uri (const char *src)
   unsigned char c;
   char *hexa;
 
-  src = lw6sys_str_empty_if_null (src);
+  src = lw6sys_str_empty_if_null (sys_context, src);
   len = lw6sys_imin (strlen (src), _ESCAPE_HTTP_URI_MAX_LEN);
-  ret = (char *) LW6SYS_CALLOC (_ESCAPE_HTTP_URI_LEN * len + 1);
+  ret = (char *) LW6SYS_CALLOC (sys_context, _ESCAPE_HTTP_URI_LEN * len + 1);
   if (ret)
     {
       for (i = 0, j = 0; i < len && j < _ESCAPE_HTTP_URI_MAX_LEN; ++i)
@@ -80,14 +81,13 @@ lw6sys_escape_http_uri (const char *src)
 	  if (c >= ' ')
 	    {
 	      if (c == '_' || c == '-' || c == '/' || c == '.' || c == ','
-		  || c == '#' || c == ':' || c == ';' || c == '?' || c == '&'
-		  || c == '%' || lw6sys_chr_is_alnum (c))
+		  || c == '#' || c == ':' || c == ';' || c == '?' || c == '&' || c == '%' || lw6sys_chr_is_alnum (c))
 		{
 		  ret[j++] = c;
 		}
 	      else
 		{
-		  hexa = lw6sys_new_sprintf (_ESCAPE_HTTP_URI_MASK, (int) c);
+		  hexa = lw6sys_new_sprintf (sys_context, _ESCAPE_HTTP_URI_MASK, (int) c);
 		  if (hexa)
 		    {
 		      ret[j++] = '%';
@@ -98,19 +98,15 @@ lw6sys_escape_http_uri (const char *src)
 			}
 		      else
 			{
-			  lw6sys_log (LW6SYS_LOG_WARNING,
-				      _x_
-				      ("incorrect hexa conversion for %d \"%s\""),
-				      (int) c, hexa);
+			  lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("incorrect hexa conversion for %d \"%s\""), (int) c, hexa);
 			}
-		      LW6SYS_FREE (hexa);
+		      LW6SYS_FREE (sys_context, hexa);
 		    }
 		}
 	    }
 	  else
 	    {
-	      lw6sys_log (LW6SYS_LOG_DEBUG,
-			  _x_ ("invalid character %d in uri"), (int) c);
+	      lw6sys_log (sys_context, LW6SYS_LOG_DEBUG, _x_ ("invalid character %d in uri"), (int) c);
 	    }
 	}
       if (j <= _ESCAPE_HTTP_URI_LEN * len)
@@ -119,9 +115,7 @@ lw6sys_escape_http_uri (const char *src)
 	}
       else
 	{
-	  lw6sys_log (LW6SYS_LOG_WARNING,
-		      _x_ ("http uri escape string too long %d for %d/%d"), j,
-		      _ESCAPE_HTTP_URI_LEN * len, len);
+	  lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("http uri escape string too long %d for %d/%d"), j, _ESCAPE_HTTP_URI_LEN * len, len);
 	}
     }
 
@@ -131,6 +125,7 @@ lw6sys_escape_http_uri (const char *src)
 /**
  * lw6sys_escape_html_attribute
  *
+ * @sys_context: global system context
  * @src: the string to escape
  *
  * Transforms a string so that it can fit in a html field,
@@ -140,7 +135,7 @@ lw6sys_escape_http_uri (const char *src)
  * Return value: newly allocated string.
  */
 char *
-lw6sys_escape_html_attribute (const char *src)
+lw6sys_escape_html_attribute (lw6sys_context_t * sys_context, const char *src)
 {
   char *ret = NULL;
   int len = 0;
@@ -148,9 +143,9 @@ lw6sys_escape_html_attribute (const char *src)
   unsigned char c;
   char *quot = NULL;
 
-  src = lw6sys_str_empty_if_null (src);
+  src = lw6sys_str_empty_if_null (sys_context, src);
   len = lw6sys_imin (strlen (src), _ESCAPE_HTML_ATTRIBUTE_MAX_LEN);
-  ret = (char *) LW6SYS_CALLOC (_ESCAPE_HTML_ATTRIBUTE_LEN * len + 1);
+  ret = (char *) LW6SYS_CALLOC (sys_context, _ESCAPE_HTML_ATTRIBUTE_LEN * len + 1);
   if (ret)
     {
       for (i = 0, j = 0; i < len && j < _ESCAPE_HTML_ATTRIBUTE_MAX_LEN; ++i)
@@ -158,9 +153,7 @@ lw6sys_escape_html_attribute (const char *src)
 	  c = src[i];
 	  c = lw6sys_imax (' ', c);
 	  if (c != _ESCAPE_HTML_ATTRIBUTE_QUOT_CHAR
-	      && c != _ESCAPE_HTML_ATTRIBUTE_LT_CHAR
-	      && c != _ESCAPE_HTML_ATTRIBUTE_GT_CHAR
-	      && c != _ESCAPE_HTML_ATTRIBUTE_AMP_CHAR)
+	      && c != _ESCAPE_HTML_ATTRIBUTE_LT_CHAR && c != _ESCAPE_HTML_ATTRIBUTE_GT_CHAR && c != _ESCAPE_HTML_ATTRIBUTE_AMP_CHAR)
 	    {
 	      ret[j++] = c;
 	    }
@@ -181,9 +174,7 @@ lw6sys_escape_html_attribute (const char *src)
 		  quot = _ESCAPE_HTML_ATTRIBUTE_AMP_STR;
 		  break;
 		default:
-		  lw6sys_log (LW6SYS_LOG_WARNING,
-			      _x_ ("unable to find a substitude for char %d"),
-			      (int) c);
+		  lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("unable to find a substitude for char %d"), (int) c);
 		  quot = "";
 		}
 	      for (k = 0; k < _ESCAPE_HTML_ATTRIBUTE_LEN && quot[k]; ++k)
@@ -198,10 +189,7 @@ lw6sys_escape_html_attribute (const char *src)
 	}
       else
 	{
-	  lw6sys_log (LW6SYS_LOG_WARNING,
-		      _x_
-		      ("html attribute escape string too long %d for %d/%d"),
-		      j, _ESCAPE_HTML_ATTRIBUTE_LEN * len, len);
+	  lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("html attribute escape string too long %d for %d/%d"), j, _ESCAPE_HTML_ATTRIBUTE_LEN * len, len);
 	}
     }
 
@@ -211,6 +199,7 @@ lw6sys_escape_html_attribute (const char *src)
 /**
  * lw6sys_escape_sql_value
  *
+ * @sys_context: global system context
  * @src: the string to escape
  *
  * Transforms a string so that it can fit as an SQL parameter,
@@ -221,7 +210,7 @@ lw6sys_escape_html_attribute (const char *src)
  * Return value: newly allocated string.
  */
 char *
-lw6sys_escape_sql_value (const char *src)
+lw6sys_escape_sql_value (lw6sys_context_t * sys_context, const char *src)
 {
   char *ret = NULL;
   int len = 0;
@@ -229,9 +218,9 @@ lw6sys_escape_sql_value (const char *src)
   unsigned char c;
   char *quot = NULL;
 
-  src = lw6sys_str_empty_if_null (src);
+  src = lw6sys_str_empty_if_null (sys_context, src);
   len = lw6sys_imin (strlen (src), _ESCAPE_SQL_VALUE_MAX_LEN);
-  ret = (char *) LW6SYS_CALLOC (_ESCAPE_SQL_VALUE_LEN * len + 1);
+  ret = (char *) LW6SYS_CALLOC (sys_context, _ESCAPE_SQL_VALUE_LEN * len + 1);
   if (ret)
     {
       for (i = 0, j = 0; i < len && j < _ESCAPE_SQL_VALUE_MAX_LEN; ++i)
@@ -257,9 +246,7 @@ lw6sys_escape_sql_value (const char *src)
 	}
       else
 	{
-	  lw6sys_log (LW6SYS_LOG_WARNING,
-		      _x_ ("sql value escape string too long %d for %d/%d"),
-		      j, _ESCAPE_SQL_VALUE_LEN * len, len);
+	  lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("sql value escape string too long %d for %d/%d"), j, _ESCAPE_SQL_VALUE_LEN * len, len);
 	}
     }
 
