@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -33,6 +33,7 @@
 /**
  * lw6sys_exec_find_myself
  *
+ * @sys_context: global system context
  * @argc: number of args as passed to main
  * @argv: array of args as passed to main
  *
@@ -42,22 +43,20 @@
  * Return value: the path (newly allocated string).
  */
 char *
-lw6sys_exec_find_myself (int argc, const char *argv[])
+lw6sys_exec_find_myself (lw6sys_context_t * sys_context, int argc, const char *argv[])
 {
   char *myself = NULL;
 
   if (argc >= 1)
     {
-      myself = lw6sys_str_copy (argv[0]);
-      if (lw6sys_file_exists (myself))
+      myself = lw6sys_str_copy (sys_context, argv[0]);
+      if (lw6sys_file_exists (sys_context, myself))
 	{
-	  lw6sys_log (LW6SYS_LOG_DEBUG, _x_ ("found myself in \"%s\""),
-		      myself);
+	  lw6sys_log (sys_context, LW6SYS_LOG_DEBUG, _x_ ("found myself in \"%s\""), myself);
 	}
       else
 	{
-	  lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("file \"%s\" does not exist"),
-		      myself);
+	  lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("file \"%s\" does not exist"), myself);
 	}
     }
 
@@ -67,6 +66,7 @@ lw6sys_exec_find_myself (int argc, const char *argv[])
 /**
  * lw6sys_is_executed_again
  *
+ * @sys_context: global system context
  * @argc: number of args as passed to main
  * @argv: array of args as passed to main
  *
@@ -76,12 +76,11 @@ lw6sys_exec_find_myself (int argc, const char *argv[])
  * Return value: 1 if executed again, 0 if not.
  */
 int
-lw6sys_is_executed_again (int argc, const char *argv[])
+lw6sys_is_executed_again (lw6sys_context_t * sys_context, int argc, const char *argv[])
 {
   int ret = 0;
 
-  ret = lw6sys_env_exists_prefixed (LW6DEF_EXECUTED_AGAIN)
-    || lw6sys_arg_exists (argc, argv, LW6DEF_EXECUTED_AGAIN);
+  ret = lw6sys_env_exists_prefixed (sys_context, LW6DEF_EXECUTED_AGAIN) || lw6sys_arg_exists (sys_context, argc, argv, LW6DEF_EXECUTED_AGAIN);
 
   return ret;
 }
@@ -89,6 +88,7 @@ lw6sys_is_executed_again (int argc, const char *argv[])
 /**
  * lw6sys_exec_again
  *
+ * @sys_context: global system context
  * @argc: number of args as passed to main
  * @argv: array of args as passed to main
  *
@@ -103,58 +103,53 @@ lw6sys_is_executed_again (int argc, const char *argv[])
  * Return value: 1 on success, 0 on failure (always fail)
  */
 int
-lw6sys_exec_again (int argc, const char *argv[])
+lw6sys_exec_again (lw6sys_context_t * sys_context, int argc, const char *argv[])
 {
   char *myself;
   char **new_argv;
   int i;
   int ret = 0;
 
-  if (!lw6sys_is_executed_again (argc, argv))
+  if (!lw6sys_is_executed_again (sys_context, argc, argv))
     {
       if (argc >= 1)
 	{
-	  myself = lw6sys_exec_find_myself (argc, argv);
+	  myself = lw6sys_exec_find_myself (sys_context, argc, argv);
 	  if (myself)
 	    {
-	      new_argv =
-		(char **) LW6SYS_CALLOC (sizeof (char *) * (argc + 2));
+	      new_argv = (char **) LW6SYS_CALLOC (sys_context, sizeof (char *) * (argc + 2));
 	      if (new_argv)
 		{
 		  for (i = 0; i < argc; ++i)
 		    {
-		      new_argv[i] = lw6sys_str_copy (argv[i]);
+		      new_argv[i] = lw6sys_str_copy (sys_context, argv[i]);
 		    }
-		  lw6sys_setenv_prefixed (LW6DEF_EXECUTED_AGAIN,
-					  _EXECUTED_AGAIN_TRUE);
+		  lw6sys_setenv_prefixed (sys_context, LW6DEF_EXECUTED_AGAIN, _EXECUTED_AGAIN_TRUE);
 		  new_argv[argc] = "--" LW6DEF_EXECUTED_AGAIN;
 		  new_argv[argc + 1] = NULL;
 		  execvp (myself, (void *) new_argv);
-		  lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("execvp(%s) failed"),
-			      myself);
+		  lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("execvp(%s) failed"), myself);
 		  for (i = 0; i < argc; ++i)
 		    {
 		      if (new_argv[i])
 			{
-			  LW6SYS_FREE (new_argv[i]);
+			  LW6SYS_FREE (sys_context, new_argv[i]);
 			}
 		    }
-		  LW6SYS_FREE (new_argv);
+		  LW6SYS_FREE (sys_context, new_argv);
 		}
-	      LW6SYS_FREE (myself);
+	      LW6SYS_FREE (sys_context, myself);
 	    }
 	  else
 	    {
-	      lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("unable to find myself"));
+	      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("unable to find myself"));
 	    }
-	  lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("can't run \"%s\" again"),
-		      argv[0]);
+	  lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("can't run \"%s\" again"), argv[0]);
 	}
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_INFO,
-		  _x_ ("executed again so no new process started"));
+      lw6sys_log (sys_context, LW6SYS_LOG_INFO, _x_ ("executed again so no new process started"));
       ret = 1;
     }
 
@@ -164,6 +159,7 @@ lw6sys_exec_again (int argc, const char *argv[])
 /**
  * lw6sys_exec_restart
  *
+ * @sys_context: global system context
  * @argc: number of args as passed to main
  * @argv: array of args as passed to main
  *
@@ -173,7 +169,7 @@ lw6sys_exec_again (int argc, const char *argv[])
  * Return value: 1 on success, 0 on failure (always fail)
  */
 int
-lw6sys_exec_restart (int argc, const char *argv[])
+lw6sys_exec_restart (lw6sys_context_t * sys_context, int argc, const char *argv[])
 {
   char *myself;
   char **new_argv;
@@ -182,36 +178,35 @@ lw6sys_exec_restart (int argc, const char *argv[])
 
   if (argc >= 1)
     {
-      myself = lw6sys_exec_find_myself (argc, argv);
+      myself = lw6sys_exec_find_myself (sys_context, argc, argv);
       if (myself)
 	{
-	  new_argv = (char **) LW6SYS_CALLOC (sizeof (char *) * (argc + 1));
+	  new_argv = (char **) LW6SYS_CALLOC (sys_context, sizeof (char *) * (argc + 1));
 	  if (new_argv)
 	    {
 	      for (i = 0; i < argc; ++i)
 		{
-		  new_argv[i] = lw6sys_str_copy (argv[i]);
+		  new_argv[i] = lw6sys_str_copy (sys_context, argv[i]);
 		}
 	      new_argv[argc] = NULL;
 	      execvp (myself, (void *) new_argv);
-	      lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("execvp(%s) failed"),
-			  myself);
+	      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("execvp(%s) failed"), myself);
 	      for (i = 0; i < argc; ++i)
 		{
 		  if (new_argv[i])
 		    {
-		      LW6SYS_FREE (new_argv[i]);
+		      LW6SYS_FREE (sys_context, new_argv[i]);
 		    }
 		}
-	      LW6SYS_FREE (new_argv);
+	      LW6SYS_FREE (sys_context, new_argv);
 	    }
-	  LW6SYS_FREE (myself);
+	  LW6SYS_FREE (sys_context, myself);
 	}
       else
 	{
-	  lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("unable to find myself"));
+	  lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("unable to find myself"));
 	}
-      lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("can't restart \"%s\""), argv[0]);
+      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("can't restart \"%s\""), argv[0]);
     }
 
   return ret;
