@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -29,6 +29,7 @@
 /**
  * lw6sys_clear_file
  *
+ * @sys_context: global system context
  * @filename: absolute or relative filename
  *
  * Clears a file, that is, make it a 0 byte file, empty, ready
@@ -39,20 +40,20 @@
  * Return value: 1 if success, 0 if failure.
  */
 int
-lw6sys_clear_file (const char *filename)
+lw6sys_clear_file (lw6sys_context_t * sys_context, const char *filename)
 {
   int ret = 0;
   FILE *f = NULL;
   char *dir = NULL;
 
-  dir = lw6sys_path_parent (filename);
+  dir = lw6sys_path_parent (sys_context, filename);
   if (dir)
     {
-      if (!lw6sys_dir_exists (dir))
+      if (!lw6sys_dir_exists (sys_context, dir))
 	{
-	  lw6sys_create_dir_silent (dir);
+	  lw6sys_create_dir_silent (sys_context, dir);
 	}
-      LW6SYS_FREE (dir);
+      LW6SYS_FREE (sys_context, dir);
     }
 
   f = fopen (filename, "wb");
@@ -70,7 +71,7 @@ lw6sys_clear_file (const char *filename)
 }
 
 static void *
-_read_bin (int *filesize, const char *filename)
+_read_bin (lw6sys_context_t * sys_context, int *filesize, const char *filename)
 {
   char *file_content = NULL;
   FILE *f;
@@ -85,15 +86,13 @@ _read_bin (int *filesize, const char *filename)
       if (size >= 0)
 	{
 	  fseek (f, 0, SEEK_SET);
-	  file_content = LW6SYS_CALLOC (size + 1);
+	  file_content = LW6SYS_CALLOC (sys_context, size + 1);
 	  if (file_content)
 	    {
 	      clearerr (f);
 	      while ((!feof (f)) && (!ferror (f)) && (read < size))
 		{
-		  read +=
-		    fread (file_content + read, sizeof (char), size - read,
-			   f);
+		  read += fread (file_content + read, sizeof (char), size - read, f);
 		}
 	      if (read < size)
 		{
@@ -102,18 +101,13 @@ _read_bin (int *filesize, const char *filename)
 		   * bigger, rounded value, greater than the real size.
 		   */
 #ifndef LW6_MS_WINDOWS
-		  lw6sys_log (LW6SYS_LOG_INFO,
-			      _x_
-			      ("couldn't read all of file \"%s\", size was supposed to be %d but only read %d"),
-			      filename, size, (int) read);
+		  lw6sys_log (sys_context, LW6SYS_LOG_INFO,
+			      _x_ ("couldn't read all of file \"%s\", size was supposed to be %d but only read %d"), filename, size, (int) read);
 #endif
 		}
 	      else if (read > size)
 		{
-		  lw6sys_log (LW6SYS_LOG_WARNING,
-			      _x_
-			      ("inconsistency in file \"%s\", size is %d but read %d"),
-			      filename, size, (int) read);
+		  lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("inconsistency in file \"%s\", size is %d but read %d"), filename, size, (int) read);
 		}
 	    }
 	}
@@ -121,8 +115,7 @@ _read_bin (int *filesize, const char *filename)
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING,
-		  _x_ ("can't open file \"%s\" for reading"), filename);
+      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("can't open file \"%s\" for reading"), filename);
     }
 
   if (filesize)
@@ -143,6 +136,7 @@ _read_bin (int *filesize, const char *filename)
 /**
  * lw6sys_read_file_content
  *
+ * @sys_context: global system context
  * @filename: absolute or relative filename
  *
  * Reads the content of a file, and returns it as a string.
@@ -154,11 +148,11 @@ _read_bin (int *filesize, const char *filename)
  * Return value: a newly allocated pointer, must be freed.
  */
 char *
-lw6sys_read_file_content (const char *filename)
+lw6sys_read_file_content (lw6sys_context_t * sys_context, const char *filename)
 {
   char *ret = NULL;
 
-  ret = (char *) _read_bin (NULL, filename);
+  ret = (char *) _read_bin (sys_context, NULL, filename);
 
   return ret;
 }
@@ -166,6 +160,7 @@ lw6sys_read_file_content (const char *filename)
 /**
  * lw6sys_read_file_content_bin
  *
+ * @sys_context: global system context
  * @filesize: will contain the file size, in bytes
  * @filename: absolute or relative filename
  *
@@ -183,11 +178,11 @@ lw6sys_read_file_content (const char *filename)
  * Return value: a newly allocated pointer, must be freed.
  */
 void *
-lw6sys_read_file_content_bin (int *filesize, const char *filename)
+lw6sys_read_file_content_bin (lw6sys_context_t * sys_context, int *filesize, const char *filename)
 {
   void *ret = NULL;
 
-  ret = _read_bin (filesize, filename);
+  ret = _read_bin (sys_context, filesize, filename);
 
   return ret;
 }
@@ -195,6 +190,7 @@ lw6sys_read_file_content_bin (int *filesize, const char *filename)
 /**
  * lw6sys_write_file_content
  *
+ * @sys_context: global system context
  * @filename: absolute or relative filename
  * @content: the content to be written.
  *
@@ -206,7 +202,7 @@ lw6sys_read_file_content_bin (int *filesize, const char *filename)
  * and opaque binary data usage is not recommended.
  */
 int
-lw6sys_write_file_content (const char *filename, const char *content)
+lw6sys_write_file_content (lw6sys_context_t * sys_context, const char *filename, const char *content)
 {
   FILE *f = NULL;
   int ret = 0;
@@ -220,16 +216,13 @@ lw6sys_write_file_content (const char *filename, const char *content)
 	}
       else
 	{
-	  lw6sys_log (LW6SYS_LOG_WARNING,
-		      _x_ ("unable to write %d bytes in file \"%s\""),
-		      (int) strlen (content), filename);
+	  lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("unable to write %d bytes in file \"%s\""), (int) strlen (content), filename);
 	}
       fclose (f);
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING,
-		  _x_ ("unable open file \"%s\" for reading"), filename);
+      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("unable open file \"%s\" for reading"), filename);
     }
 
   return ret;
