@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -36,6 +36,7 @@
 /**
  * lw6sys_locale_to_utf8
  *
+ * @sys_context: global system context
  * @string: the string to convert
  *
  * Used to force strings into UTF-8 mode, this is basically
@@ -49,7 +50,7 @@
  *   no matter what the locale is.
  */
 char *
-lw6sys_locale_to_utf8 (const char *string)
+lw6sys_locale_to_utf8 (lw6sys_context_t * sys_context, const char *string)
 {
   char *utf8 = NULL;
 
@@ -72,12 +73,12 @@ lw6sys_locale_to_utf8 (const char *string)
 
   if (codeset)
     {
-      if (lw6sys_str_is_same (codeset, _UTF8))
+      if (lw6sys_str_is_same (sys_context, codeset, _UTF8))
 	{
 	  /*
 	   * Note: we are in UTF-8 already, no need to change again...
 	   */
-	  utf8 = lw6sys_str_copy (string);
+	  utf8 = lw6sys_str_copy (sys_context, string);
 	}
       else
 	{
@@ -99,7 +100,7 @@ lw6sys_locale_to_utf8 (const char *string)
 	      ilen = strlen (string);
 	      max_olen = strlen (string) * 2;
 
-	      utf8 = LW6SYS_CALLOC (max_olen + 1);
+	      utf8 = LW6SYS_CALLOC (sys_context, max_olen + 1);
 	      if (utf8)
 		{
 		  /*
@@ -116,8 +117,7 @@ lw6sys_locale_to_utf8 (const char *string)
 		  optr = utf8;
 		  oleft = max_olen;
 
-		  if (iconv (cd, &iptr, &ileft, &optr, &oleft) ==
-		      (size_t) - 1)
+		  if (iconv (cd, &iptr, &ileft, &optr, &oleft) == (size_t) - 1)
 		    {
 		      /*
 		       * The message below is not translated, not
@@ -127,9 +127,8 @@ lw6sys_locale_to_utf8 (const char *string)
 		       * is not working, it makes to translate
 		       * anyway...
 		       */
-		      lw6sys_log (LW6SYS_LOG_WARNING,
-				  "iconv error \"%s\"", string);
-		      LW6SYS_FREE (utf8);
+		      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, "iconv error \"%s\"", string);
+		      LW6SYS_FREE (sys_context, utf8);
 		      utf8 = NULL;	// important to be sure it's handled later
 		    }
 		}
@@ -141,14 +140,14 @@ lw6sys_locale_to_utf8 (const char *string)
 	       * Message not translated, iconv doesn't work anyway
 	       * if we're here
 	       */
-	      lw6sys_log (LW6SYS_LOG_WARNING, "unable to open iconv");
+	      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, "unable to open iconv");
 	    }
 	}
     }
 
   if (utf8 == NULL)
     {
-      utf8 = lw6sys_str_copy (string);
+      utf8 = lw6sys_str_copy (sys_context, string);
     }
 
   if (utf8 == NULL)
@@ -157,7 +156,7 @@ lw6sys_locale_to_utf8 (const char *string)
        * Message not translated, iconv doesn't work anyway
        * if we're here
        */
-      lw6sys_log (LW6SYS_LOG_WARNING, "unable to translate string to utf8");
+      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, "unable to translate string to utf8");
     }
 
   return utf8;
