@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -37,6 +37,7 @@ typedef struct list_dup_callback_data_s
 /**
  * lw6sys_list_new
  *
+ * @sys_context: global system context
  * @free_func: a callback which will be called on data when freeing the list
  *
  * Creates an empty list. There's a difference between NULL and an
@@ -47,14 +48,13 @@ typedef struct list_dup_callback_data_s
  * Return value: a pointer to the created object, may be NULL.
  */
 lw6sys_list_t *
-lw6sys_list_new (lw6sys_free_func_t free_func)
+lw6sys_list_new (lw6sys_context_t * sys_context, lw6sys_free_func_t free_func)
 {
   lw6sys_list_t *ret = NULL;
 
-  ret = LW6SYS_MALLOC (sizeof (lw6sys_list_t));
+  ret = LW6SYS_CALLOC (sys_context, sizeof (lw6sys_list_t));
   if (ret)
     {
-      memset (ret, 0, sizeof (lw6sys_list_t));
       ret->free_func = free_func;
     }
 
@@ -64,6 +64,7 @@ lw6sys_list_new (lw6sys_free_func_t free_func)
 /**
  * lw6sys_list_free
  *
+ * @sys_context: global system context
  * @list: the list to delete.
  *
  * Delete a list, this will cascade delete all the following
@@ -72,7 +73,7 @@ lw6sys_list_new (lw6sys_free_func_t free_func)
  * Return value: none.
  */
 void
-lw6sys_list_free (lw6sys_list_t * list)
+lw6sys_list_free (lw6sys_context_t * sys_context, lw6sys_list_t * list)
 {
   if (list)
     {
@@ -90,10 +91,10 @@ lw6sys_list_free (lw6sys_list_t * list)
        */
       if (list->free_func && list->data)
 	{
-	  list->free_func (list->data);
+	  list->free_func (sys_context, list->data);
 	}
 
-      LW6SYS_FREE (list);
+      LW6SYS_FREE (sys_context, list);
 
       if (next_item)
 	{
@@ -104,18 +105,19 @@ lw6sys_list_free (lw6sys_list_t * list)
 	   * return addresses which are of no use. At least
 	   * the compiler *could* do it 8-) Recursion recursion...
 	   */
-	  lw6sys_list_free ((lw6sys_list_t *) next_item);
+	  lw6sys_list_free (sys_context, (lw6sys_list_t *) next_item);
 	}
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("trying to free NULL list"));
+      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("trying to free NULL list"));
     }
 }
 
 /**
  * lw6sys_list_next
  *
+ * @sys_context: global system context
  * @list: the current position in the list
  *
  * It's safer to call this rather than dig right into
@@ -124,7 +126,7 @@ lw6sys_list_free (lw6sys_list_t * list)
  * Return value: a new position in the list, may be NULL.
  */
 lw6sys_list_t *
-lw6sys_list_next (lw6sys_list_t * list)
+lw6sys_list_next (lw6sys_context_t * sys_context, lw6sys_list_t * list)
 {
   lw6sys_list_t *ret = NULL;
 
@@ -134,7 +136,7 @@ lw6sys_list_next (lw6sys_list_t * list)
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("calling next on NULL list"));
+      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("calling next on NULL list"));
     }
 
   return ret;
@@ -143,6 +145,7 @@ lw6sys_list_next (lw6sys_list_t * list)
 /**
  * lw6sys_list_is_empty
  *
+ * @sys_context: global system context
  * @list: the list we want informations about
  *
  * Checks wether the list is empty or not. Note that being empty
@@ -153,7 +156,7 @@ lw6sys_list_next (lw6sys_list_t * list)
  * Return value: 1 if empty, 0 if there is at list one item.
  */
 int
-lw6sys_list_is_empty (lw6sys_list_t * list)
+lw6sys_list_is_empty (lw6sys_context_t * sys_context, const lw6sys_list_t * list)
 {
   int empty = 1;
 
@@ -163,15 +166,16 @@ lw6sys_list_is_empty (lw6sys_list_t * list)
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("calling is_empty on NULL list"));
+      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("calling is_empty on NULL list"));
     }
 
   return empty;
 }
 
 /**
- * lw6sys_info_length
+ * lw6sys_list_length
  *
+ * @sys_context: global system context
  * @list: the list we want informations about
  *
  * Calculates the length of the list. This is a performance killer
@@ -180,7 +184,7 @@ lw6sys_list_is_empty (lw6sys_list_t * list)
  * Return value: the number of elements, 0 is none (empty list).
  */
 int
-lw6sys_list_length (lw6sys_list_t * list)
+lw6sys_list_length (lw6sys_context_t * sys_context, const lw6sys_list_t * list)
 {
   int ret = 0;
 
@@ -194,7 +198,7 @@ lw6sys_list_length (lw6sys_list_t * list)
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("calling length on NULL list"));
+      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("calling length on NULL list"));
     }
 
   return ret;
@@ -203,6 +207,7 @@ lw6sys_list_length (lw6sys_list_t * list)
 /**
  * lw6sys_list_map
  *
+ * @sys_context: global system context
  * @list: the list where elements will be taken
  * @func: the function which will be executed
  * @func_data: additionnal data to be passed to @func
@@ -220,8 +225,7 @@ lw6sys_list_length (lw6sys_list_t * list)
  * Return value: none.
  */
 void
-lw6sys_list_map (lw6sys_list_t * list,
-		 lw6sys_list_callback_func_t func, void *func_data)
+lw6sys_list_map (lw6sys_context_t * sys_context, lw6sys_list_t * list, lw6sys_list_callback_func_t func, void *func_data)
 {
   if (list)
     {
@@ -229,20 +233,21 @@ lw6sys_list_map (lw6sys_list_t * list,
 	{
 	  if (list->next_item)
 	    {
-	      func (func_data, list->data);
+	      func (sys_context, func_data, list->data);
 	    }
 	  list = list->next_item;
 	}
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("calling map on NULL list"));
+      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("calling map on NULL list"));
     }
 }
 
 /**
  * lw6sys_list_filter
  *
+ * @sys_context: global system context
  * @list: the list where elements will be taken
  * @func: the function which will be executed
  * @func_data: additionnal data to be passed to @func
@@ -257,8 +262,7 @@ lw6sys_list_map (lw6sys_list_t * list,
  * Return value: none.
  */
 void
-lw6sys_list_filter (lw6sys_list_t ** list,
-		    lw6sys_list_filter_func_t func, void *func_data)
+lw6sys_list_filter (lw6sys_context_t * sys_context, lw6sys_list_t ** list, lw6sys_list_filter_func_t func, void *func_data)
 {
   lw6sys_list_t *tmp_item = NULL;
   lw6sys_list_t *cur_item = NULL;
@@ -271,7 +275,7 @@ lw6sys_list_filter (lw6sys_list_t ** list,
 	{
 	  if (cur_item->next_item)
 	    {
-	      if (func (func_data, cur_item->data))
+	      if (func (sys_context, func_data, cur_item->data))
 		{
 		  prev_item = cur_item;
 		  cur_item = cur_item->next_item;
@@ -281,7 +285,7 @@ lw6sys_list_filter (lw6sys_list_t ** list,
 		  tmp_item = cur_item;
 		  if (cur_item->free_func && cur_item->data)
 		    {
-		      cur_item->free_func (cur_item->data);
+		      cur_item->free_func (sys_context, cur_item->data);
 		    }
 		  cur_item = cur_item->next_item;
 		  if (prev_item)
@@ -292,7 +296,7 @@ lw6sys_list_filter (lw6sys_list_t ** list,
 		    {
 		      (*list) = cur_item;
 		    }
-		  LW6SYS_FREE (tmp_item);
+		  LW6SYS_FREE (sys_context, tmp_item);
 		}
 	    }
 	  else
@@ -303,13 +307,14 @@ lw6sys_list_filter (lw6sys_list_t ** list,
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("calling filter on NULL list"));
+      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("calling filter on NULL list"));
     }
 }
 
 /**
  * lw6sys_list_push_front
  *
+ * @sys_context: global system context
  * @list: a pointer to the list (pointer on pointer, read/write value)
  * @data: the data to be pushed
  *
@@ -327,13 +332,13 @@ lw6sys_list_filter (lw6sys_list_t ** list,
  * Return value: none.
  */
 void
-lw6sys_list_push_front (lw6sys_list_t ** list, void *data)
+lw6sys_list_push_front (lw6sys_context_t * sys_context, lw6sys_list_t ** list, void *data)
 {
   lw6sys_list_t *new_list = NULL;
 
   if (list && *list)
     {
-      new_list = LW6SYS_MALLOC (sizeof (lw6sys_list_t));
+      new_list = LW6SYS_MALLOC (sys_context, sizeof (lw6sys_list_t));
       if (new_list)
 	{
 	  new_list->next_item = (*list);
@@ -344,14 +349,14 @@ lw6sys_list_push_front (lw6sys_list_t ** list, void *data)
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING,
-		  _x_ ("calling push_front on NULL list"));
+      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("calling push_front on NULL list"));
     }
 }
 
 /**
  * lw6sys_list_pop_front
  *
+ * @sys_context: global system context
  * @list: a pointer to the list (pointer on pointer, read/write value)
  *
  * Pops data from the list, the returned value is what
@@ -372,7 +377,7 @@ lw6sys_list_push_front (lw6sys_list_t ** list, void *data)
  * Return value: a pointer on the popped data, whatever you pushed.
  */
 void *
-lw6sys_list_pop_front (lw6sys_list_t ** list)
+lw6sys_list_pop_front (lw6sys_context_t * sys_context, lw6sys_list_t ** list)
 {
   void *data = NULL;
 
@@ -387,13 +392,13 @@ lw6sys_list_pop_front (lw6sys_list_t ** list)
        * value returned would be freed before it is even
        * returned to the caller!!!
        */
-      LW6SYS_FREE (*list);
+      LW6SYS_FREE (sys_context, *list);
 
       (*list) = new_list;
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("calling pop_front on NULL list"));
+      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("calling pop_front on NULL list"));
     }
 
   return data;
@@ -402,6 +407,7 @@ lw6sys_list_pop_front (lw6sys_list_t ** list)
 /**
  * lw6sys_list_push_back
  *
+ * @sys_context: global system context
  * @list: a pointer to the list (pointer on pointer, read/write value)
  * @data: the data to be pushed
  *
@@ -419,7 +425,7 @@ lw6sys_list_pop_front (lw6sys_list_t ** list)
  * Return value: none.
  */
 void
-lw6sys_list_push_back (lw6sys_list_t ** list, void *data)
+lw6sys_list_push_back (lw6sys_context_t * sys_context, lw6sys_list_t ** list, void *data)
 {
   lw6sys_list_t *end = NULL;
   lw6sys_list_t *new_list = NULL;
@@ -434,7 +440,7 @@ lw6sys_list_push_back (lw6sys_list_t ** list, void *data)
 
       if (end && !end->next_item)
 	{
-	  new_list = LW6SYS_CALLOC (sizeof (lw6sys_list_t));
+	  new_list = LW6SYS_CALLOC (sys_context, sizeof (lw6sys_list_t));
 	  if (new_list)
 	    {
 	      end->next_item = new_list;
@@ -444,18 +450,19 @@ lw6sys_list_push_back (lw6sys_list_t ** list, void *data)
 	}
       else
 	{
-	  lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("list push_back bug"));
+	  lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("list push_back bug"));
 	}
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("calling push_back on NULL list"));
+      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("calling push_back on NULL list"));
     }
 }
 
 /**
  * lw6sys_list_pop_back
  *
+ * @sys_context: global system context
  * @list: a pointer to the list (pointer on pointer, read/write value)
  *
  * Pops data from the list, the returned value is what
@@ -476,7 +483,7 @@ lw6sys_list_push_back (lw6sys_list_t ** list, void *data)
  * Return value: a pointer on the popped data, whatever you pushed.
  */
 void *
-lw6sys_list_pop_back (lw6sys_list_t ** list)
+lw6sys_list_pop_back (lw6sys_context_t * sys_context, lw6sys_list_t ** list)
 {
   void *data = NULL;
   lw6sys_list_t *end = NULL;
@@ -487,8 +494,7 @@ lw6sys_list_pop_back (lw6sys_list_t ** list)
     {
       end = (*list);
       before_end = end;
-      while (end && end->next_item
-	     && ((lw6sys_list_t *) (end->next_item))->next_item)
+      while (end && end->next_item && ((lw6sys_list_t *) (end->next_item))->next_item)
 	{
 	  before_end = end;
 	  end = end->next_item;
@@ -496,7 +502,7 @@ lw6sys_list_pop_back (lw6sys_list_t ** list)
       data = end->data;
       if (((*list)->next_item) == NULL)
 	{
-	  LW6SYS_FREE (*list);
+	  LW6SYS_FREE (sys_context, *list);
 	  (*list) = NULL;
 	}
       else
@@ -505,7 +511,7 @@ lw6sys_list_pop_back (lw6sys_list_t ** list)
 	    {
 	      tmp = (*list);
 	      (*list) = (*list)->next_item;
-	      LW6SYS_FREE (tmp);
+	      LW6SYS_FREE (sys_context, tmp);
 	    }
 	  else
 	    {
@@ -517,52 +523,96 @@ lw6sys_list_pop_back (lw6sys_list_t ** list)
 	       * value returned would be freed before it is even
 	       * returned to the caller!!!
 	       */
-	      LW6SYS_FREE (end);
+	      LW6SYS_FREE (sys_context, end);
 	    }
 	}
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("calling pop_back on NULL list"));
+      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("calling pop_back on NULL list"));
     }
 
   return data;
 }
 
+/**
+ * lw6sys_lifo_push
+ *
+ * @sys_context: global system context
+ * @list: a pointer to the list (pointer on pointer, read/write value)
+ *
+ * Pops data to a list, in last-in first-out mode (AKA LIFO).
+ * This is equivalent t @lw6sys_list_push_front.
+ *
+ * Return value: none.
+ */
 void
-lw6sys_lifo_push (lw6sys_list_t ** list, void *data)
+lw6sys_lifo_push (lw6sys_context_t * sys_context, lw6sys_list_t ** list, void *data)
 {
-  lw6sys_list_push_front (list, data);
+  lw6sys_list_push_front (sys_context, list, data);
 }
 
+/**
+ * lw6sys_lifo_pop
+ *
+ * @sys_context: global system context
+ * @list: a pointer to the list (pointer on pointer, read/write value)
+ *
+ * Pops the first element of a list, in last-in first-out mode (AKA LIFO).
+ * This is equivalent to @lw6sys_list_pop_front.
+ *
+ * Return value: a pointer on the popped data, whatever you pushed.
+ */
 void *
-lw6sys_lifo_pop (lw6sys_list_t ** list)
+lw6sys_lifo_pop (lw6sys_context_t * sys_context, lw6sys_list_t ** list)
 {
-  return lw6sys_list_pop_front (list);
+  return lw6sys_list_pop_front (sys_context, list);
 }
 
+/**
+ * lw6sys_fifo_push
+ *
+ * @sys_context: global system context
+ * @list: a pointer to the list (pointer on pointer, read/write value)
+ *
+ * Pops data to a list, in first-in first-out mode (AKA FIFO).
+ * This is equivalent t @lw6sys_list_push_front.
+ *
+ * Return value: none.
+ */
 void
-lw6sys_fifo_push (lw6sys_list_t ** list, void *data)
+lw6sys_fifo_push (lw6sys_context_t * sys_context, lw6sys_list_t ** list, void *data)
 {
-  lw6sys_list_push_front (list, data);
+  lw6sys_list_push_front (sys_context, list, data);
 }
 
+/**
+ * lw6sys_fifo_pop
+ *
+ * @sys_context: global system context
+ * @list: a pointer to the list (pointer on pointer, read/write value)
+ *
+ * Pops the first element of a list, in last-in first-out mode (AKA FIFO).
+ * This is equivalent to @lw6sys_list_pop_back.
+ * It can be quite time-consuming on big lists.
+ *
+ * Return value: a pointer on the popped data, whatever you pushed.
+ */
 void *
-lw6sys_fifo_pop (lw6sys_list_t ** list)
+lw6sys_fifo_pop (lw6sys_context_t * sys_context, lw6sys_list_t ** list)
 {
-  return lw6sys_list_pop_back (list);
+  return lw6sys_list_pop_back (sys_context, list);
 }
 
 static void
-list_dup_callback (void *func_data, void *data)
+list_dup_callback (lw6sys_context_t * sys_context, void *func_data, void *data)
 {
-  list_dup_callback_data_t *list_dup_callback_data =
-    (list_dup_callback_data_t *) func_data;
+  list_dup_callback_data_t *list_dup_callback_data = (list_dup_callback_data_t *) func_data;
   void *new_data;
 
   if (list_dup_callback_data->dup_func)
     {
-      new_data = list_dup_callback_data->dup_func (data);
+      new_data = list_dup_callback_data->dup_func (sys_context, data);
     }
   else
     {
@@ -570,12 +620,13 @@ list_dup_callback (void *func_data, void *data)
     }
 
   // push_back is slower but this way we preserve order
-  lw6sys_list_push_back (&(list_dup_callback_data->list), new_data);
+  lw6sys_list_push_back (sys_context, &(list_dup_callback_data->list), new_data);
 }
 
 /**
  * lw6sys_list_dup
  *
+ * @sys_context: global system context
  * @list: the list to duplicate, can be NULL
  * @dup_func: the function which will be called to duplicate data
  *
@@ -589,23 +640,23 @@ list_dup_callback (void *func_data, void *data)
  * Returned value: a newly allocated list.
  */
 lw6sys_list_t *
-lw6sys_list_dup (lw6sys_list_t * list, lw6sys_dup_func_t dup_func)
+lw6sys_list_dup (lw6sys_context_t * sys_context, lw6sys_list_t * list, lw6sys_dup_func_t dup_func)
 {
   list_dup_callback_data_t list_dup_callback_data;
   lw6sys_list_t *ret = NULL;
 
   if (list)
     {
-      list_dup_callback_data.list = lw6sys_list_new (list->free_func);
+      list_dup_callback_data.list = lw6sys_list_new (sys_context, list->free_func);
       list_dup_callback_data.dup_func = dup_func;
 
-      lw6sys_list_map (list, list_dup_callback, &list_dup_callback_data);
+      lw6sys_list_map (sys_context, list, list_dup_callback, &list_dup_callback_data);
 
       ret = list_dup_callback_data.list;
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("calling dup on NULL list"));
+      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("calling dup on NULL list"));
     }
 
   return ret;
