@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -54,43 +54,32 @@
 
 #define _CRITICAL_FILE "sys-log.c"
 #define _CRITICAL_LINE __LINE__
-
-#define _STATIC_LOG_FILENAME_SIZE 65536
-static char _static_log_filename[_STATIC_LOG_FILENAME_SIZE + 1] = { 0 };
-
-static int _timeout_msec = LW6SYS_DIALOG_TIMEOUT_DEFAULT;
-
-/*
- * Console is enabled by default, disabling it is indeed a special
- * case, for instance when there's an interaction with a text-based
- * graphics renderer.
- */
-static int _console_enable_state = 1;
+#define _CRITICAL_FUNC "?"
 
 #define _GTK_NB_IDLE_ITERATIONS 10
 
 static char *
-_get_log_file ()
+_get_log_file (lw6sys_context_t * sys_context)
 {
-  char *log_file;
+  _lw6sys_global_t *global = &(((_lw6sys_context_t *) sys_context)->global);
+  char *log_file = NULL;
 
-  if (_static_log_filename[0] != 0)
+  if (global->log_filename[0] != 0)
     {
-      log_file = _static_log_filename;
+      log_file = global->log_filename;
     }
   else
     {
-      log_file = lw6sys_get_default_log_file ();
+      log_file = lw6sys_get_default_log_file (sys_context);
       if (log_file)
 	{
-	  lw6sys_buf_sprintf (_static_log_filename, _STATIC_LOG_FILENAME_SIZE,
-			      "%s", log_file);
-	  LW6SYS_FREE (log_file);
-	  log_file = _static_log_filename;
+	  lw6sys_buf_sprintf (sys_context, global->log_filename, _LW6SYS_LOG_FILENAME_SIZE, "%s", log_file);
+	  LW6SYS_FREE (sys_context, log_file);
+	  log_file = global->log_filename;
 	}
       else
 	{
-	  lw6sys_log_critical (_("log_file is NULL"));
+	  lw6sys_log_critical (sys_context, _("log_file is NULL"));
 	}
     }
 
@@ -100,6 +89,7 @@ _get_log_file ()
 /**
  * lw6sys_log_errno_str
  *
+ * @sys_context: global system context
  * @errno_int: the error code, typically errno
  *
  * Convenience fonction which returns the "macro" corresponding
@@ -111,7 +101,7 @@ _get_log_file ()
  * Return value: static string, must not be freed
  */
 const char *
-lw6sys_log_errno_str (int errno_int)
+lw6sys_log_errno_str (lw6sys_context_t * sys_context, int errno_int)
 {
   const char *ret = "?";
 
@@ -510,6 +500,7 @@ lw6sys_log_errno_str (int errno_int)
 /**
  * lw6sys_log_set_file:
  *
+ * @sys_context: global system context
  * @filename: the name of the log file.
  *
  * Sets up the log file. Until you call this function, messages
@@ -519,16 +510,18 @@ lw6sys_log_errno_str (int errno_int)
  * Return value: void
  */
 void
-lw6sys_log_set_file (const char *filename)
+lw6sys_log_set_file (lw6sys_context_t * sys_context, const char *filename)
 {
-  memset (_static_log_filename, 0, sizeof (_static_log_filename));
-  memcpy (_static_log_filename, filename,
-	  lw6sys_imin (sizeof (_static_log_filename) - 1, strlen (filename)));
+  _lw6sys_global_t *global = &(((_lw6sys_context_t *) sys_context)->global);
+
+  memset (global->log_filename, 0, sizeof (global->log_filename));
+  memcpy (global->log_filename, filename, lw6sys_imin (sizeof (global->log_filename) - 1, strlen (filename)));
 }
 
 /**
  * lw6sys_log_clear:
  *
+ * @sys_context: global system context
  * @filename: the name of the log file.
  *
  * Clears the log file, this function would typically be called
@@ -538,38 +531,39 @@ lw6sys_log_set_file (const char *filename)
  * Return value: void
  */
 void
-lw6sys_log_clear (const char *filename)
+lw6sys_log_clear (lw6sys_context_t * sys_context, const char *filename)
 {
   char *default_log_file = NULL;
 
   if (filename)
     {
-      lw6sys_log_set_file (filename);
+      lw6sys_log_set_file (sys_context, filename);
     }
   else
     {
-      default_log_file = lw6sys_get_default_log_file ();
+      default_log_file = lw6sys_get_default_log_file (sys_context);
       filename = default_log_file;
     }
 
   if (filename)
     {
-      lw6sys_clear_file (filename);
-      if (!lw6sys_file_exists (filename))
+      lw6sys_clear_file (sys_context, filename);
+      if (!lw6sys_file_exists (sys_context, filename))
 	{
-	  lw6sys_log_critical (_("can't open log file \"%s\""), filename);
+	  lw6sys_log_critical (sys_context, _("can't open log file \"%s\""), filename);
 	}
     }
 
   if (default_log_file)
     {
-      LW6SYS_FREE (default_log_file);
+      LW6SYS_FREE (sys_context, default_log_file);
     }
 }
 
 /**
  * lw6sys_log_set_dialog_timeout
  *
+ * @sys_context: global system context
  * @timeout_sec: number of seconds to wait before alert dialogs disappear
  *
  * By default, alert boxes will stay out forever unless one clicks on them,
@@ -579,13 +573,13 @@ lw6sys_log_clear (const char *filename)
  * Return value: 1 if timeout is supported on platform, 0 if not
  */
 int
-lw6sys_log_set_dialog_timeout (int timeout_sec)
+lw6sys_log_set_dialog_timeout (lw6sys_context_t * sys_context, int timeout_sec)
 {
-  _timeout_msec =
-    LW6SYS_TICKS_PER_SEC * lw6sys_imax (0,
-					lw6sys_imin
-					(LW6SYS_DIALOG_TIMEOUT_MAX,
-					 timeout_sec));
+  _lw6sys_global_t *global = &(((_lw6sys_context_t *) sys_context)->global);
+
+  global->dialog_timeout_msec = LW6SYS_TICKS_PER_SEC * lw6sys_imax (0,
+								    lw6sys_imin (LW6SYS_DIALOG_TIMEOUT_MAX,
+										 timeout_sec));
 
 #ifdef LW6_GTK
   return 1;
@@ -595,20 +589,20 @@ lw6sys_log_set_dialog_timeout (int timeout_sec)
 }
 
 static FILE *
-_open_log_file ()
+_open_log_file (lw6sys_context_t * sys_context)
 {
   FILE *ret = NULL;
   char *name;
 
-  name = _get_log_file ();
+  name = _get_log_file (sys_context);
   ret = fopen (name, "ab");
 
   return ret;
 }
 
 static void
-_log_to_file (FILE * f, int level_id, const char *level_str, const char *file,
-	      int line, const char *fmt, va_list ap)
+_log_to_file (lw6sys_context_t * sys_context, FILE * f, int level_id,
+	      const char *level_str, const char *file, int line, const char *func, const char *fmt, va_list ap)
 {
   time_t t_now;
   struct tm tm_now;
@@ -616,11 +610,23 @@ _log_to_file (FILE * f, int level_id, const char *level_str, const char *file,
   struct timeval timeval_now;
   char *bt = NULL;
   int free_bt = 0;
+  _lw6sys_global_t *global = &(((_lw6sys_context_t *) sys_context)->global);
 
-  bt = lw6sys_backtrace (1, 0);
-  if (bt)
+  switch (global->log_backtrace_mode)
     {
-      free_bt = 1;
+    case LW6SYS_LOG_BACKTRACE_MODE_FUNC:
+      bt = (char *) func;
+      break;
+    case LW6SYS_LOG_BACKTRACE_MODE_FULL:
+      bt = lw6sys_backtrace (sys_context, 1, 0);
+      if (bt)
+	{
+	  free_bt = 1;
+	}
+      break;
+    default:
+      bt = _CRITICAL_FUNC;
+      break;
     }
 
   memset (&t_now, 0, sizeof (time_t));
@@ -631,20 +637,18 @@ _log_to_file (FILE * f, int level_id, const char *level_str, const char *file,
   tm_ret = localtime_r (&t_now, &tm_now);
   if (tm_ret == &tm_now)
     {
-      fprintf (f, "%04d-%02d-%02d %02d:%02d:%02d.%03d\t%s:%d:%s\t%d\t%s\t",
+      fprintf (f, "%04d-%02d-%02d %02d:%02d:%02d.%03d\t%s:%d/%s\t%d\t%s\t",
 	       (int) tm_now.tm_year + 1900, (int) tm_now.tm_mon + 1,
 	       (int) tm_now.tm_mday, (int) tm_now.tm_hour,
 	       (int) tm_now.tm_min, (int) tm_now.tm_sec,
 	       (int) timeval_now.tv_usec / (int) (1000000 /
-						  LW6SYS_TICKS_PER_SEC),
-	       file, line, lw6sys_str_empty_if_null (bt), level_id,
-	       level_str);
+						  LW6SYS_TICKS_PER_SEC), file, line, lw6sys_str_empty_if_null (sys_context, bt), level_id, level_str);
     }
   vfprintf (f, fmt, ap);
 
   if (free_bt)
     {
-      LW6SYS_FREE (bt);
+      LW6SYS_FREE (sys_context, bt);
     }
 
   fprintf (f, "\n");
@@ -652,9 +656,11 @@ _log_to_file (FILE * f, int level_id, const char *level_str, const char *file,
 }
 
 static void
-_log_to_console (FILE * f, const char *level_str, const char *fmt, va_list ap)
+_log_to_console (lw6sys_context_t * sys_context, FILE * f, const char *level_str, const char *fmt, va_list ap)
 {
-  if (_console_enable_state)
+  _lw6sys_global_t *global = &(((_lw6sys_context_t *) sys_context)->global);
+
+  if (global->console_enable_state)
     {
       time_t t_now;
       struct tm tm_now;
@@ -670,8 +676,7 @@ _log_to_console (FILE * f, const char *level_str, const char *fmt, va_list ap)
       if (tm_ret == &tm_now)
 	{
 	  fprintf (f, "%s: (%02d:%02d:%02d) %s",
-		   lw6sys_build_get_package_tarname (), (int) tm_now.tm_hour,
-		   (int) tm_now.tm_min, (int) tm_now.tm_sec, level_str);
+		   lw6sys_build_get_package_tarname (), (int) tm_now.tm_hour, (int) tm_now.tm_min, (int) tm_now.tm_sec, level_str);
 	  vfprintf (f, fmt, ap);
 	  fprintf (f, "\n");
 	  fflush (f);
@@ -680,27 +685,29 @@ _log_to_console (FILE * f, const char *level_str, const char *fmt, va_list ap)
 }
 
 static void
-_log_to_history (const char *level_str, const char *fmt, va_list ap)
+_log_to_history (lw6sys_context_t * sys_context, const char *level_str, const char *fmt, va_list ap)
 {
   char msg[_HISTORY_LENGTH + 1];
   char full_msg[_HISTORY_LENGTH + 1];
 
-  _lw6sys_buf_vsnprintf (msg, _HISTORY_LENGTH, fmt, ap);
-  lw6sys_buf_sprintf (full_msg, _HISTORY_LENGTH, "%s%s", level_str, msg);
-  lw6sys_history_register (full_msg);
+  _lw6sys_buf_vsnprintf (sys_context, msg, _HISTORY_LENGTH, fmt, ap);
+  lw6sys_buf_sprintf (sys_context, full_msg, _HISTORY_LENGTH, "%s%s", level_str, msg);
+  lw6sys_history_register (sys_context, full_msg);
 }
 
 #ifdef LW6_GTK
 static void
-_gtk_dlg_timeout_callback (void *data)
+_gtk_dlg_timeout_callback (lw6sys_context_t * sys_context, void *data)
 {
-  GtkDialog **dlg_timeout_ptr = (GtkDialog **) data;
-  int64_t start_time = lw6sys_get_timestamp ();
-  int64_t end_time = start_time + _timeout_msec;
+  _lw6sys_global_t *global = &(((_lw6sys_context_t *) sys_context)->global);
 
-  while (((*dlg_timeout_ptr) != NULL) && lw6sys_get_timestamp () < end_time)
+  GtkDialog **dlg_timeout_ptr = (GtkDialog **) data;
+  int64_t start_time = lw6sys_get_timestamp (sys_context);
+  int64_t end_time = start_time + global->dialog_timeout_msec;
+
+  while (((*dlg_timeout_ptr) != NULL) && lw6sys_get_timestamp (sys_context) < end_time)
     {
-      lw6sys_idle ();
+      lw6sys_idle (sys_context);
     }
   if (*dlg_timeout_ptr)
     {
@@ -716,47 +723,52 @@ _gtk_dlg_timeout_callback (void *data)
  * does have the _lw6sys_ prefix to avoid name conflicts.
  */
 void
-_lw6sys_msgbox_alert (const char *level_str, const char *file, int line,
-		      const char *fmt, va_list ap)
+_lw6sys_msgbox_alert (lw6sys_context_t * sys_context, const char *level_str, const char *file, int line, const char *func, const char *fmt, va_list ap)
 {
+  _lw6sys_global_t *global = &(((_lw6sys_context_t *) sys_context)->global);
   char message_raw[_MSGBOX_BUF_LENGTH + 1];
   char message_full[_MSGBOX_BUF_LENGTH + 1];
   char *bt = NULL;
   int free_bt = 0;
 
-  _lw6sys_buf_vsnprintf (message_raw, _MSGBOX_BUF_LENGTH, fmt, ap);
-  lw6sys_str_reformat_this (message_raw, _MSGBOX_WIDTH);
-  bt = lw6sys_backtrace (2, 1);	// skip this function & caller
-  if (bt)
+  _lw6sys_buf_vsnprintf (sys_context, message_raw, _MSGBOX_BUF_LENGTH, fmt, ap);
+  lw6sys_str_reformat_this (sys_context, message_raw, _MSGBOX_WIDTH);
+
+  switch (global->log_backtrace_mode)
     {
-      lw6sys_str_truncate_middle (bt, _MSGBOX_BT_LENGTH, _MSGBOX_BT_MIDDLE);
-      lw6sys_str_reformat_this (bt, _MSGBOX_WIDTH);
-      free_bt = 1;
+    case LW6SYS_LOG_BACKTRACE_MODE_FUNC:
+      bt = (char *) func;
+      break;
+    case LW6SYS_LOG_BACKTRACE_MODE_FULL:
+      bt = lw6sys_backtrace (sys_context, 2, 1);	// skip this function & caller
+      if (bt)
+	{
+	  lw6sys_str_truncate_middle (sys_context, bt, _MSGBOX_BT_LENGTH, _MSGBOX_BT_MIDDLE);
+	  lw6sys_str_reformat_this (sys_context, bt, _MSGBOX_WIDTH);
+	  free_bt = 1;
+	}
+      break;
+    default:
+      bt = _CRITICAL_FUNC;
+      break;
     }
-  else
-    {
-      bt = "";
-    }
-  lw6sys_buf_sprintf (message_full, _MSGBOX_BUF_LENGTH,
+
+  lw6sys_buf_sprintf (sys_context, message_full, _MSGBOX_BUF_LENGTH,
 		      "%s (%s:%d)\n\n%s\n\n%s: %s\n\n%s: %s", level_str, file,
-		      line, message_raw, _("Backtrace"), bt, _("Report bugs"),
-		      lw6sys_build_get_bugs_url ());
+		      line, message_raw, _("Backtrace"), lw6sys_str_empty_if_null (sys_context, bt), _("Report bugs"), lw6sys_build_get_bugs_url ());
   if (free_bt)
     {
-      LW6SYS_FREE (bt);
+      LW6SYS_FREE (sys_context, bt);
       bt = NULL;
     }
 #ifdef LW6_MS_WINDOWS
   if (message_full)
     {
-      MessageBox (NULL,
-		  message_full,
-		  lw6sys_build_get_package_name (),
-		  MB_OK | MB_ICONERROR | MB_APPLMODAL);
+      MessageBox (NULL, message_full, lw6sys_build_get_package_name (), MB_OK | MB_ICONERROR | MB_APPLMODAL);
     }
 #else
 #ifdef LW6_MAC_OS_X
-  _lw6sys_macosx_alert (lw6sys_build_get_package_name (), message_full);
+  _lw6sys_macosx_alert (sys_context, lw6sys_build_get_package_name (), message_full);
 #else
 /*
  * Not implemented yet, below sample code, which would require to
@@ -800,22 +812,15 @@ _lw6sys_msgbox_alert (const char *level_str, const char *file, int line,
     }
   if (gtk_init_done)
     {
-      dlg = gtk_message_dialog_new (NULL,
-				    GTK_DIALOG_MODAL,
-				    GTK_MESSAGE_ERROR,
-				    GTK_BUTTONS_NONE, "%s", message_full);
+      dlg = gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_NONE, "%s", message_full);
       if (dlg)
 	{
-	  gtk_window_set_title (GTK_WINDOW (dlg),
-				lw6sys_build_get_package_name ());
-	  gtk_dialog_add_button (GTK_DIALOG (dlg), GTK_STOCK_OK,
-				 GTK_RESPONSE_OK);
+	  gtk_window_set_title (GTK_WINDOW (dlg), lw6sys_build_get_package_name ());
+	  gtk_dialog_add_button (GTK_DIALOG (dlg), GTK_STOCK_OK, GTK_RESPONSE_OK);
 	  dlg_timeout = dlg;
-	  if (_timeout_msec > 0)
+	  if (global->dialog_timeout_msec > 0)
 	    {
-	      timeout_thread =
-		lw6sys_thread_create (_gtk_dlg_timeout_callback, NULL,
-				      (void *) &dlg_timeout);
+	      timeout_thread = lw6sys_thread_create (sys_context, _gtk_dlg_timeout_callback, NULL, (void *) &dlg_timeout);
 	    }
 	  /*
 	   * Here we don't log on error, it's not a really good idea to call
@@ -829,7 +834,7 @@ _lw6sys_msgbox_alert (const char *level_str, const char *file, int line,
 	  dlg_timeout = NULL;
 	  if (timeout_thread)
 	    {
-	      lw6sys_thread_join (timeout_thread);
+	      lw6sys_thread_join (sys_context, timeout_thread);
 	      timeout_thread = NULL;
 	    }
 	  gtk_widget_hide_all (dlg);
@@ -839,7 +844,7 @@ _lw6sys_msgbox_alert (const char *level_str, const char *file, int line,
 	  while (gtk_events_pending ())
 	    {
 	      gtk_main_iteration ();
-	      lw6sys_idle ();
+	      lw6sys_idle (sys_context);
 	    }
 	}
     }
@@ -851,6 +856,7 @@ _lw6sys_msgbox_alert (const char *level_str, const char *file, int line,
 /**
  * lw6sys_log:
  *
+ * @sys_context: global system context
  * @level_id: the log level to use. Possible values are, by order,
  *   LW6SYS_LOG_ERROR_ID (0),
  *   LW6SYS_LOG_WARNING_ID (1),
@@ -862,6 +868,8 @@ _lw6sys_msgbox_alert (const char *level_str, const char *file, int line,
  *   one can use __FILE__
  * @line: the line in the source file where the function is called,
  *   one can use __LINE__
+ * @func: the name of the function where this log line was called,
+ *   on can use __FUNCTION__
  * @fmt: a printf-like format string
  * @...: printf-like arguments, corresponding to @fmt.
  *
@@ -877,15 +885,12 @@ _lw6sys_msgbox_alert (const char *level_str, const char *file, int line,
  * @Return value: void
  */
 void
-lw6sys_log (int level_id, const char *file, int line, const char *fmt, ...)
+lw6sys_log (lw6sys_context_t * sys_context, int level_id, const char *file, int line, const char *func, const char *fmt, ...)
 {
 #ifdef LW6_OPTIMIZE
-  if ((level_id <= LW6SYS_LOG_NOTICE_ID
-       && level_id <= lw6sys_log_get_level ())
-      || level_id == LW6SYS_LOG_TMP_ID || lw6sys_debug_get ())
+  if ((level_id <= LW6SYS_LOG_NOTICE_ID && level_id <= lw6sys_log_get_level (sys_context)) || level_id == LW6SYS_LOG_TMP_ID || lw6sys_debug_get (sys_context))
 #else
-  if (level_id <= lw6sys_log_get_level () || level_id == LW6SYS_LOG_TMP_ID
-      || lw6sys_debug_get ())
+  if (level_id <= lw6sys_log_get_level (sys_context) || level_id == LW6SYS_LOG_TMP_ID || lw6sys_debug_get (sys_context))
 #endif
     {
       char level_str[_LEVEL_LENGTH + 1];
@@ -918,13 +923,11 @@ lw6sys_log (int level_id, const char *file, int line, const char *fmt, ...)
 	case LW6SYS_LOG_ERROR_ID:
 	  if (errno_int)
 	    {
-	      lw6sys_buf_sprintf (level_str, _LEVEL_LENGTH,
-				  _("ERROR! (errno=%d:%s) "), errno_int,
-				  lw6sys_log_errno_str (errno_int));
+	      lw6sys_buf_sprintf (sys_context, level_str, _LEVEL_LENGTH, _("ERROR! (errno=%d:%s) "), errno_int, lw6sys_log_errno_str (sys_context, errno_int));
 	    }
 	  else
 	    {
-	      lw6sys_buf_sprintf (level_str, _LEVEL_LENGTH, _("ERROR! "));
+	      lw6sys_buf_sprintf (sys_context, level_str, _LEVEL_LENGTH, _("ERROR! "));
 	    }
 #ifdef HAVE_SYSLOG_H
 	  syslog_priority = LOG_ERR;
@@ -933,13 +936,12 @@ lw6sys_log (int level_id, const char *file, int line, const char *fmt, ...)
 	case LW6SYS_LOG_WARNING_ID:
 	  if (errno_int)
 	    {
-	      lw6sys_buf_sprintf (level_str, _LEVEL_LENGTH,
-				  _("WARNING! (errno=%d:%s) "), errno_int,
-				  lw6sys_log_errno_str (errno_int));
+	      lw6sys_buf_sprintf (sys_context, level_str, _LEVEL_LENGTH,
+				  _("WARNING! (errno=%d:%s) "), errno_int, lw6sys_log_errno_str (sys_context, errno_int));
 	    }
 	  else
 	    {
-	      lw6sys_buf_sprintf (level_str, _LEVEL_LENGTH, _("WARNING! "));
+	      lw6sys_buf_sprintf (sys_context, level_str, _LEVEL_LENGTH, _("WARNING! "));
 	    }
 #ifdef HAVE_SYSLOG_H
 	  syslog_priority = LOG_WARNING;
@@ -956,13 +958,13 @@ lw6sys_log (int level_id, const char *file, int line, const char *fmt, ...)
 #endif
 	  break;
 	case LW6SYS_LOG_TMP_ID:
-	  lw6sys_buf_sprintf (level_str, _LEVEL_LENGTH, _("[tmp] "));
+	  lw6sys_buf_sprintf (sys_context, level_str, _LEVEL_LENGTH, _("[tmp] "));
 #ifdef HAVE_SYSLOG_H
 	  syslog_priority = LOG_DEBUG;
 #endif
 	  break;
 	default:		// LW6SYS_LOG_DEBUG_ID
-	  lw6sys_buf_sprintf (level_str, _LEVEL_LENGTH, _("[debug] "));
+	  lw6sys_buf_sprintf (sys_context, level_str, _LEVEL_LENGTH, _("[debug] "));
 #ifdef HAVE_SYSLOG_H
 	  syslog_priority = LOG_DEBUG;
 #endif
@@ -972,42 +974,38 @@ lw6sys_log (int level_id, const char *file, int line, const char *fmt, ...)
       if (fmt != NULL)
 	{
 	  // exclude INFO & DEBUG from console in non-debug mode
-	  if (level_id <= LW6SYS_LOG_NOTICE_ID
-	      || level_id == LW6SYS_LOG_TMP_ID || lw6sys_debug_get ())
+	  if (level_id <= LW6SYS_LOG_NOTICE_ID || level_id == LW6SYS_LOG_TMP_ID || lw6sys_debug_get (sys_context))
 	    {
 	      va_copy (ap2, ap);
-	      _log_to_console (stderr, level_str, fmt, ap2);
+	      _log_to_console (sys_context, stderr, level_str, fmt, ap2);
 	      va_end (ap2);
 	    }
-	  if (level_id <= LW6SYS_LOG_WARNING_ID
-	      || level_id == LW6SYS_LOG_TMP_ID)
+	  if (level_id <= LW6SYS_LOG_WARNING_ID || level_id == LW6SYS_LOG_TMP_ID)
 	    {
 	      va_copy (ap2, ap);
-	      _log_to_history (level_str, fmt, ap2);
+	      _log_to_history (sys_context, level_str, fmt, ap2);
 	      va_end (ap2);
 	    }
 #ifdef HAVE_SYSLOG_H
-	  if (level_id <= LW6SYS_LOG_WARNING_ID
-	      || level_id == LW6SYS_LOG_TMP_ID)
+	  if (level_id <= LW6SYS_LOG_WARNING_ID || level_id == LW6SYS_LOG_TMP_ID)
 	    {
 	      va_copy (ap2, ap);
 	      vsyslog (syslog_priority, fmt, ap2);
 	      va_end (ap2);
 	    }
 #endif
-	  f = _open_log_file ();
+	  f = _open_log_file (sys_context);
 	  if (f)
 	    {
 	      va_copy (ap2, ap);
-	      _log_to_file (f, level_id, level_str, file_only, line, fmt,
-			    ap2);
+	      _log_to_file (sys_context, f, level_id, level_str, file_only, line, func, fmt, ap2);
 	      va_end (ap2);
 	      fclose (f);
 	    }
 	  if (level_id <= LW6SYS_LOG_ERROR_ID)
 	    {
 	      va_copy (ap2, ap);
-	      _lw6sys_msgbox_alert (level_str, file_only, line, fmt, ap2);
+	      _lw6sys_msgbox_alert (sys_context, level_str, file_only, line, func, fmt, ap2);
 	      va_end (ap2);
 	    }
 	}
@@ -1025,6 +1023,7 @@ lw6sys_log (int level_id, const char *file, int line, const char *fmt, ...)
 /**
  * lw6sys_log_critical:
  *
+ * @sys_context: global system context
  * @fmt: a printf-like format string
  * @...: printf-like arguments, corresponding to @fmt.
  *
@@ -1038,7 +1037,7 @@ lw6sys_log (int level_id, const char *file, int line, const char *fmt, ...)
  * @Return value: void
  */
 void
-lw6sys_log_critical (const char *fmt, ...)
+lw6sys_log_critical (lw6sys_context_t * sys_context, const char *fmt, ...)
 {
   va_list ap;
   va_list ap2;
@@ -1046,12 +1045,11 @@ lw6sys_log_critical (const char *fmt, ...)
   va_start (ap, fmt);
 
   va_copy (ap2, ap);
-  _log_to_console (stderr, _("CRITICAL! "), fmt, ap2);
+  _log_to_console (sys_context, stderr, _("CRITICAL! "), fmt, ap2);
   va_end (ap2);
 
   va_copy (ap2, ap);
-  _lw6sys_msgbox_alert (_("CRITICAL!"), _CRITICAL_FILE, _CRITICAL_LINE, fmt,
-			ap2);
+  _lw6sys_msgbox_alert (sys_context, _("CRITICAL!"), _CRITICAL_FILE, _CRITICAL_LINE, _CRITICAL_FUNC, fmt, ap2);
   va_end (ap2);
 
   exit (LW6SYS_EXIT_CRITICAL);
@@ -1062,47 +1060,104 @@ lw6sys_log_critical (const char *fmt, ...)
 /**
  * lw6sys_log_get_level
  *
+ * @sys_context: global system context
+ *
+ * Get the current log level. 
+ *
  * @Return value: the log level, integer between 0 & 4. 4 is very verbose
  * (debug), 0 displays errors only.
  */
 int
-lw6sys_log_get_level ()
+lw6sys_log_get_level (lw6sys_context_t * sys_context)
 {
-  return _lw6sys_global.log_level;
+  _lw6sys_global_t *global = &(((_lw6sys_context_t *) sys_context)->global);
+
+  return global->log_level;
 }
 
 /**
  * lw6sys_log_set_level
  *
+ * @sys_context: global system context
  * @level: the log level, integer between 0 & 4. 4 is very verbose (debug),
  * 0 displays errors only.
+ *
+ * Set the current log level.
+ *
+ * @Return valaue: none.
  */
 void
-lw6sys_log_set_level (int level)
+lw6sys_log_set_level (lw6sys_context_t * sys_context, int level)
 {
+  _lw6sys_global_t *global = &(((_lw6sys_context_t *) sys_context)->global);
+
   level = lw6sys_imin (level, LW6SYS_LOG_DEBUG_ID);
   level = lw6sys_imax (level, LW6SYS_LOG_ERROR_ID);
 
-  _lw6sys_global.log_level = level;
+  global->log_level = level;
+}
+
+/**
+ * lw6sys_log_get_backtrace_mode
+ *
+ * @sys_context: global system context
+ *
+ * Gets the current backtrace mode.
+ *
+ * @Return value: the backtrace mode, LW6SYS_LOG_BACKTRACE_MODE_FULL or
+ * LW6SYS_LOG_BACKTRACE_MODE_FUNC.
+ */
+int
+lw6sys_log_get_backtrace_mode (lw6sys_context_t * sys_context)
+{
+  _lw6sys_global_t *global = &(((_lw6sys_context_t *) sys_context)->global);
+
+  return global->log_backtrace_mode;
+}
+
+/**
+ * lw6sys_log_set_backtrace_mode
+ *
+ * Sets the current backtrace mode.
+ *
+ * @sys_context: global system context
+ * @backtrace_mode: the backtrace mode, LW6SYS_LOG_BACKTRACE_MODE_FULL or
+ * LW6SYS_LOG_BACKTRACE_MODE_FUNC.
+ *
+ * Return value : none
+ */
+void
+lw6sys_log_set_backtrace_mode (lw6sys_context_t * sys_context, int backtrace_mode)
+{
+  _lw6sys_global_t *global = &(((_lw6sys_context_t *) sys_context)->global);
+
+  backtrace_mode = backtrace_mode ? LW6SYS_LOG_BACKTRACE_MODE_FULL : LW6SYS_LOG_BACKTRACE_MODE_FUNC;
+
+  global->log_backtrace_mode = backtrace_mode;
 }
 
 /**
  * lw6sys_log_get_console_state
  *
+ * @sys_context: global system context
+ *
  * Get the console output state. This is important, for instance to
  * set the console "back in the state it was" after setting it on or off.
  *
  * Return value: 1 if enabled, 0 if not.
  */
 int
-lw6sys_log_get_console_state ()
+lw6sys_log_get_console_state (lw6sys_context_t * sys_context)
 {
-  return _console_enable_state ? 1 : 0;
+  _lw6sys_global_t *global = &(((_lw6sys_context_t *) sys_context)->global);
+
+  return global->console_enable_state ? 1 : 0;
 }
 
 /**
  * lw6sys_log_set_console_state
  *
+ * @sys_context: global system context
  * @state: 1 to activate console output, 0 to disable it.
  *
  * Enables or disables console output. By console output, we basically
@@ -1113,7 +1168,9 @@ lw6sys_log_get_console_state ()
  * Return value: none.
  */
 void
-lw6sys_log_set_console_state (int state)
+lw6sys_log_set_console_state (lw6sys_context_t * sys_context, int state)
 {
-  _console_enable_state = state ? 1 : 0;
+  _lw6sys_global_t *global = &(((_lw6sys_context_t *) sys_context)->global);
+
+  global->console_enable_state = state ? 1 : 0;
 }
