@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -37,6 +37,7 @@
 /**
  * lw6sys_math_poly_wy1y2s1
  *
+ * @sys_context: global system context
  * @y: the return value (position, may be NULL)
  * @s: the return value (speed, may be NULL)
  * @x: the x parameter, the value to iterate on
@@ -53,8 +54,7 @@
  *
  */
 void
-lw6sys_math_poly_wy1y2s1 (float *y, float *s, float x, float w, float y1,
-			  float y2, float s1)
+lw6sys_math_poly_wy1y2s1 (lw6sys_context_t * sys_context, float *y, float *s, float x, float w, float y1, float y2, float s1)
 {
   float a = 0.0f;
   float b = 0.0f;
@@ -117,8 +117,7 @@ lw6sys_math_poly_wy1y2s1 (float *y, float *s, float x, float w, float y1,
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING,
-		  _x_ ("can't extrapolate with x=%f and w=%f"), x, w);
+      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("can't extrapolate with x=%f and w=%f"), x, w);
       tmp_y = y2;
       tmp_s = 0.0f;
     }
@@ -135,6 +134,7 @@ lw6sys_math_poly_wy1y2s1 (float *y, float *s, float x, float w, float y1,
 /**
  * lw6sys_math_angle_360
  *
+ * @sys_context: global system context
  * @x: x coordinate
  * @y: y coordinate
  *
@@ -145,7 +145,7 @@ lw6sys_math_poly_wy1y2s1 (float *y, float *s, float x, float w, float y1,
  * Return value: the angle, in degrees
  */
 float
-lw6sys_math_angle_360 (int x, int y)
+lw6sys_math_angle_360 (lw6sys_context_t * sys_context, int x, int y)
 {
   float ret = 0.0f;
 
@@ -159,25 +159,22 @@ lw6sys_math_angle_360 (int x, int y)
 	{
 	  if (y >= 0)
 	    {
-	      ret = atanf (((float) y) / ((float) x)) * 180.0f / M_PI;
+	      ret = lw6sys_math_rad2deg (atanf (((float) y) / ((float) x)));
 	    }
 	  else
 	    {
-	      ret =
-		360.0f - atanf (((float) -y) / ((float) x)) * 180.0f / M_PI;
+	      ret = 360.0f - lw6sys_math_rad2deg (atanf (((float) -y) / ((float) x)));
 	    }
 	}
       else
 	{
 	  if (y >= 0)
 	    {
-	      ret =
-		180.0f - atanf (((float) y) / ((float) -x)) * 180.0f / M_PI;
+	      ret = 180.0f - lw6sys_math_rad2deg (atanf (((float) y) / ((float) -x)));
 	    }
 	  else
 	    {
-	      ret =
-		180.0f + atanf (((float) -y) / ((float) -x)) * 180.0f / M_PI;
+	      ret = 180.0f + lw6sys_math_rad2deg (atanf (((float) -y) / ((float) -x)));
 	    }
 	}
     }
@@ -188,6 +185,7 @@ lw6sys_math_angle_360 (int x, int y)
 /**
  * lw6sys_math_heartbeat
  *
+ * @sys_context: global system context
  * @x: the parameter (typically a timestamp)
  * @period: the period (typically something like 1000 milliseconds)
  * @y1: the low value (heart at rest)
@@ -198,7 +196,7 @@ lw6sys_math_angle_360 (int x, int y)
  *
  */
 float
-lw6sys_math_heartbeat (int64_t x, int period, float y1, float y2)
+lw6sys_math_heartbeat (lw6sys_context_t * sys_context, int64_t x, int period, float y1, float y2)
 {
   float ret = y1;
   int t;
@@ -219,28 +217,25 @@ lw6sys_math_heartbeat (int64_t x, int period, float y1, float y2)
 
 	  if (t < high1)
 	    {
-	      lw6sys_math_poly_wy1y2s1 (&ret, NULL, t, high1, y1, y2, 0.0f);
+	      lw6sys_math_poly_wy1y2s1 (sys_context, &ret, NULL, t, high1, y1, y2, 0.0f);
 	    }
 	  else if (t < low1)
 	    {
-	      lw6sys_math_poly_wy1y2s1 (&ret, NULL, t - high1, low1 - high1,
-					y2, y1, 0.0f);
+	      lw6sys_math_poly_wy1y2s1 (sys_context, &ret, NULL, t - high1, low1 - high1, y2, y1, 0.0f);
 	    }
 	  else if (t < high2)
 	    {
-	      lw6sys_math_poly_wy1y2s1 (&ret, NULL, t - low1, high2 - low1,
-					y1, y2, 0.0f);
+	      lw6sys_math_poly_wy1y2s1 (sys_context, &ret, NULL, t - low1, high2 - low1, y1, y2, 0.0f);
 	    }
 	  else if (t < low2)
 	    {
-	      lw6sys_math_poly_wy1y2s1 (&ret, NULL, t - high2, low2 - high2,
-					y2, y1, 0.0f);
+	      lw6sys_math_poly_wy1y2s1 (sys_context, &ret, NULL, t - high2, low2 - high2, y2, y1, 0.0f);
 	    }
 	}
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("can't use period %d"), period);
+      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("can't use period %d"), period);
     }
 
   return ret;
@@ -249,6 +244,7 @@ lw6sys_math_heartbeat (int64_t x, int period, float y1, float y2)
 /**
  * lw6sys_math_blink
  *
+ * @sys_context: global system context
  * @x: the parameter (typically a timestamp)
  * @period: the period (typically something like 1000 milliseconds)
  *
@@ -258,7 +254,7 @@ lw6sys_math_heartbeat (int64_t x, int period, float y1, float y2)
  * Return value: 0 or 1
  */
 int
-lw6sys_math_blink (int64_t x, int period)
+lw6sys_math_blink (lw6sys_context_t * sys_context, int64_t x, int period)
 {
   int ret = 0;
 
@@ -271,7 +267,7 @@ lw6sys_math_blink (int64_t x, int period)
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("can't use period %d"), period);
+      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("can't use period %d"), period);
     }
 
   return ret;
@@ -281,6 +277,7 @@ lw6sys_math_blink (int64_t x, int period)
 /**
  * lw6sys_math_lin2log
  *
+ * @sys_context: global system context
  * @lin_value: value on a linear scale
  * @base: the base to use, 10 for decibel-like scale
  *
@@ -292,7 +289,7 @@ lw6sys_math_blink (int64_t x, int period)
  * Return value: value on a logarithmic scale.
  */
 float
-lw6sys_math_lin2log (int lin_value, int base)
+lw6sys_math_lin2log (lw6sys_context_t * sys_context, int lin_value, int base)
 {
   base = lw6sys_fmax (2.0f, base);
 
@@ -302,6 +299,7 @@ lw6sys_math_lin2log (int lin_value, int base)
 /**
  * lw6sys_math_log2lin
  *
+ * @sys_context: global system context
  * @lin_value: value on a linear scale
  * @base: the base to use, 10 for decibel-like scale
  *
@@ -313,10 +311,39 @@ lw6sys_math_lin2log (int lin_value, int base)
  * Return value: value on a linear scale.
  */
 int
-lw6sys_math_log2lin (float log_value, int base)
+lw6sys_math_log2lin (lw6sys_context_t * sys_context, float log_value, int base)
 {
   base = lw6sys_fmax (2.0f, base);
 
-  return lw6sys_imax (1,
-		      (int) roundf (expf (log_value * logf (base) / base)));
+  return lw6sys_imax (1, (int) roundf (expf (log_value * logf (base) / base)));
+}
+
+/**
+ * lw6sys_math_deg2rad
+ *
+ * @deg: angle in degrees
+ *
+ * Converts an angle from degrees to radians.
+ *
+ * Return value: angle in radians.
+ */
+float
+lw6sys_math_deg2rad (float deg)
+{
+  return deg * M_PI / 180.0f;
+}
+
+/**
+ * lw6sys_math_rad2deg
+ *
+ * @rad: angle in radians
+ *
+ * Converts an angle from radians to degrees.
+ *
+ * Return value: angle in degrees.
+ */
+float
+lw6sys_math_rad2deg (float rad)
+{
+  return rad * 180.0f / M_PI;
 }
