@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -56,6 +56,8 @@
 /**
  * lw6sys_process_is_fully_supported
  *
+ * @sys_context: global system context
+ *
  * Tells wether functions related to fork and pids are likely
  * to work allright or not. Typically, those functions will
  * return false (0) systematically if called on a platform that
@@ -66,7 +68,7 @@
  * Return value: 1 if supported, 0 if not.
  */
 int
-lw6sys_process_is_fully_supported ()
+lw6sys_process_is_fully_supported (lw6sys_context_t * sys_context)
 {
 #ifdef LW6_GNU
   return 1;
@@ -78,6 +80,7 @@ lw6sys_process_is_fully_supported ()
 /**
  * lw6sys_process_fork_and_call
  *
+ * @sys_context: global system context
  * @callback: the function to be called
  * @data: pointer on arbitrary data used by func
  *
@@ -89,7 +92,7 @@ lw6sys_process_is_fully_supported ()
  * Return value: a process ID on success, 0 on failure.
  */
 u_int64_t
-lw6sys_process_fork_and_call (lw6sys_fork_func_t func, void *data)
+lw6sys_process_fork_and_call (lw6sys_context_t * sys_context, lw6sys_fork_func_t func, void *data)
 {
 #ifdef LW6_GNU
   pid_t pid = 0;
@@ -97,19 +100,13 @@ lw6sys_process_fork_and_call (lw6sys_fork_func_t func, void *data)
   pid = fork ();
   if (!pid)
     {
-      lw6sys_log (LW6SYS_LOG_INFO,
-		  _x_ ("process forked, callback begin func=%p data=%p"),
-		  &func, data);
+      lw6sys_log (sys_context, LW6SYS_LOG_INFO, _x_ ("process forked, callback begin func=%p data=%p"), &func, data);
       // run the callback, this is what we're here for
-      func (data);
-      lw6sys_log (LW6SYS_LOG_INFO,
-		  _x_ ("process forked, callback end func=%p data=%p"), &func,
-		  data);
+      func (sys_context, data);
+      lw6sys_log (sys_context, LW6SYS_LOG_INFO, _x_ ("process forked, callback end func=%p data=%p"), &func, data);
 
-      lw6sys_log (LW6SYS_LOG_INFO,
-		  _x_ ("now naively trying to sleep for %d minutes"),
-		  _SLEEP_WHEN_DONE);
-      lw6sys_sleep (_SLEEP_WHEN_DONE);
+      lw6sys_log (sys_context, LW6SYS_LOG_INFO, _x_ ("now naively trying to sleep for %d minutes"), _SLEEP_WHEN_DONE);
+      lw6sys_sleep (sys_context, _SLEEP_WHEN_DONE);
 
       /*
        * Here we exit in "dirty" mode without continuing, freeing
@@ -123,13 +120,11 @@ lw6sys_process_fork_and_call (lw6sys_fork_func_t func, void *data)
     {
       if (pid > 0)
 	{
-	  lw6sys_log (LW6SYS_LOG_INFO,
-		      _x_ ("process forked, child pid=%" LW6SYS_PRINTF_LL
-			   "d"), (long long) pid);
+	  lw6sys_log (sys_context, LW6SYS_LOG_INFO, _x_ ("process forked, child pid=%" LW6SYS_PRINTF_LL "d"), (long long) pid);
 	}
       else
 	{
-	  lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("unable to fork"));
+	  lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("unable to fork"));
 	  pid = 0LL;
 	}
     }
@@ -143,6 +138,7 @@ lw6sys_process_fork_and_call (lw6sys_fork_func_t func, void *data)
 /**
  * lw6sys_process_kill_1_9
  *
+ * @sys_context: global system context
  * @pid: pid to kill
  *
  * Kills a process with the given PID. The kill will first use a signal 1 SIGTERM
@@ -154,13 +150,12 @@ lw6sys_process_fork_and_call (lw6sys_fork_func_t func, void *data)
  * Return value: 1 on success, 0 if failed
  */
 int
-lw6sys_process_kill_1_9 (u_int64_t pid)
+lw6sys_process_kill_1_9 (lw6sys_context_t * sys_context, u_int64_t pid)
 {
 #ifdef LW6_GNU
   int ret = 0;
 
-  lw6sys_log (LW6SYS_LOG_INFO, _x_ ("kill pid=%" LW6SYS_PRINTF_LL "d"),
-	      (long long) pid);
+  lw6sys_log (sys_context, LW6SYS_LOG_INFO, _x_ ("kill pid=%" LW6SYS_PRINTF_LL "d"), (long long) pid);
 
   if (!kill (pid, SIGTERM))
     {
@@ -168,7 +163,7 @@ lw6sys_process_kill_1_9 (u_int64_t pid)
        * Wait a little bit to give a chance to the process to
        * stop cleanly
        */
-      lw6sys_snooze ();
+      lw6sys_snooze (sys_context);
       ret = 1;
     }
 
@@ -180,7 +175,7 @@ lw6sys_process_kill_1_9 (u_int64_t pid)
        * its way to the program, now there's nothing else
        * we can do to stop the child.
        */
-      lw6sys_snooze ();
+      lw6sys_snooze (sys_context);
       ret = 1;
     }
 
@@ -196,9 +191,7 @@ lw6sys_process_kill_1_9 (u_int64_t pid)
    */
   if (!ret)
     {
-      lw6sys_log (LW6SYS_LOG_WARNING,
-		  _x_ ("couldn't kill pid=%" LW6SYS_PRINTF_LL "d"),
-		  (long long) pid);
+      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("couldn't kill pid=%" LW6SYS_PRINTF_LL "d"), (long long) pid);
     }
 
   return ret;
