@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -33,7 +33,7 @@
 #define HEAPPROFILE "HEAPPROFILE"
 
 static void
-_cleanup_first_char (char *env)
+_cleanup_first_char (lw6sys_context_t * sys_context, char *env)
 {
   /*
    * For some reason google-perftools fiddle
@@ -46,48 +46,40 @@ _cleanup_first_char (char *env)
 }
 
 static int
-_cpu_profiler_check (int verbose)
+_cpu_profiler_check (lw6sys_context_t * sys_context, int verbose)
 {
   int ret = 0;
   char *cpuprofile = NULL;
 
-  cpuprofile = lw6sys_getenv (CPUPROFILE);
+  cpuprofile = lw6sys_getenv (sys_context, CPUPROFILE);
   if (cpuprofile)
     {
-      _cleanup_first_char (cpuprofile);
+      _cleanup_first_char (sys_context, cpuprofile);
 #ifdef LW6_PROFILER
       if (verbose)
 	{
-	  lw6sys_log (LW6SYS_LOG_NOTICE,
-		      _x_
-		      ("using Google CPU Profiler with CPUPROFILE=\"%s\""),
-		      cpuprofile);
+	  lw6sys_log (sys_context, LW6SYS_LOG_NOTICE, _x_ ("using Google CPU Profiler with CPUPROFILE=\"%s\""), cpuprofile);
 	}
       ret = 1;
 #else
       if (verbose)
 	{
-	  lw6sys_log (LW6SYS_LOG_WARNING,
-		      _x_
-		      ("CPUPROFILE=\"%s\" but this binaray does not seem to support Google Profiler"),
-		      cpuprofile);
+	  lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("CPUPROFILE=\"%s\" but this binaray does not seem to support Google Profiler"), cpuprofile);
 	}
 #endif
-      LW6SYS_FREE (cpuprofile);
+      LW6SYS_FREE (sys_context, cpuprofile);
     }
   else
     {
 #ifdef LW6_PROFILER
       if (verbose)
 	{
-	  lw6sys_log (LW6SYS_LOG_DEBUG,
-		      _x_ ("Google CPU Profiler supported but turned off"));
+	  lw6sys_log (sys_context, LW6SYS_LOG_DEBUG, _x_ ("Google CPU Profiler supported but turned off"));
 	}
 #else
       if (verbose)
 	{
-	  lw6sys_log (LW6SYS_LOG_DEBUG,
-		      _x_ ("no Google CPU Profiler support"));
+	  lw6sys_log (sys_context, LW6SYS_LOG_DEBUG, _x_ ("no Google CPU Profiler support"));
 	}
 #endif
     }
@@ -96,48 +88,40 @@ _cpu_profiler_check (int verbose)
 }
 
 static int
-_heap_profiler_check (int verbose)
+_heap_profiler_check (lw6sys_context_t * sys_context, int verbose)
 {
   int ret = 0;
   char *heapprofile = NULL;
 
-  heapprofile = lw6sys_getenv (HEAPPROFILE);
+  heapprofile = lw6sys_getenv (sys_context, HEAPPROFILE);
   if (heapprofile)
     {
-      _cleanup_first_char (heapprofile);
+      _cleanup_first_char (sys_context, heapprofile);
 #ifdef LW6_PROFILER
       if (verbose)
 	{
-	  lw6sys_log (LW6SYS_LOG_NOTICE,
-		      _x_
-		      ("using Google HEAP Profiler with HEAPPROFILE=\"%s\""),
-		      heapprofile);
+	  lw6sys_log (sys_context, LW6SYS_LOG_NOTICE, _x_ ("using Google HEAP Profiler with HEAPPROFILE=\"%s\""), heapprofile);
 	}
       ret = 1;
 #else
       if (verbose)
 	{
-	  lw6sys_log (LW6SYS_LOG_WARNING,
-		      _x_
-		      ("HEAPPROFILE=\"%s\" but this binaray does not seem to support Google Profiler"),
-		      heapprofile);
+	  lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("HEAPPROFILE=\"%s\" but this binaray does not seem to support Google Profiler"), heapprofile);
 	}
 #endif
-      LW6SYS_FREE (heapprofile);
+      LW6SYS_FREE (sys_context, heapprofile);
     }
   else
     {
 #ifdef LW6_PROFILER
       if (verbose)
 	{
-	  lw6sys_log (LW6SYS_LOG_DEBUG,
-		      _x_ ("Google HEAP Profiler supported but turned off"));
+	  lw6sys_log (sys_context, LW6SYS_LOG_DEBUG, _x_ ("Google HEAP Profiler supported but turned off"));
 	}
 #else
       if (verbose)
 	{
-	  lw6sys_log (LW6SYS_LOG_DEBUG,
-		      _x_ ("no Google HEAP Profiler support"));
+	  lw6sys_log (sys_context, LW6SYS_LOG_DEBUG, _x_ ("no Google HEAP Profiler support"));
 	}
 #endif
     }
@@ -148,6 +132,7 @@ _heap_profiler_check (int verbose)
 /**
  * lw6sys_check_profiler
  *
+ * @sys_context: global system context
  * @verbose: wether to display informations on the console
  *
  * Checks wether Google Profiler support has been built, and if
@@ -157,12 +142,12 @@ _heap_profiler_check (int verbose)
  * Return value: 1 if google profile enabled and activated, 0 if not
  */
 int
-lw6sys_profiler_check (int verbose)
+lw6sys_profiler_check (lw6sys_context_t * sys_context, int verbose)
 {
   int ret = 1;
 
-  ret = _cpu_profiler_check (verbose) && ret;
-  ret = _heap_profiler_check (verbose) && ret;
+  ret = _cpu_profiler_check (sys_context, verbose) && ret;
+  ret = _heap_profiler_check (sys_context, verbose) && ret;
 
   return ret;
 }
