@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -30,6 +30,7 @@
 /**
  * lw6sys_progress_bind
  *
+ * @sys_context: global system context
  * @progress: the progress struct to initialize
  * @value: the value to point to
  *
@@ -39,7 +40,7 @@
  * Return value: none.
  */
 void
-lw6sys_progress_bind (lw6sys_progress_t * progress, float *value)
+lw6sys_progress_bind (lw6sys_context_t * sys_context, lw6sys_progress_t * progress, float *value)
 {
   if (progress)
     {
@@ -50,6 +51,7 @@ lw6sys_progress_bind (lw6sys_progress_t * progress, float *value)
 /**
  * lw6sys_progress_default
  *
+ * @sys_context: global system context
  * @progress: the progress struct to initialize
  * @value: the value to point to
  *
@@ -60,19 +62,20 @@ lw6sys_progress_bind (lw6sys_progress_t * progress, float *value)
  * Return value: none.
  */
 void
-lw6sys_progress_default (lw6sys_progress_t * progress, float *value)
+lw6sys_progress_default (lw6sys_context_t * sys_context, lw6sys_progress_t * progress, float *value)
 {
   if (progress)
     {
       progress->min = 0.0f;
       progress->max = 1.0f;
-      lw6sys_progress_bind (progress, value);
+      lw6sys_progress_bind (sys_context, progress, value);
     }
 }
 
 /**
  * lw6sys_progress_update
  *
+ * @sys_context: global system context
  * @progress: the progress struct to update
  * @min: the min value
  * @max: the max value
@@ -88,29 +91,21 @@ lw6sys_progress_default (lw6sys_progress_t * progress, float *value)
  * Return value: none.
  */
 void
-lw6sys_progress_update (lw6sys_progress_t * progress, int min, int max,
-			int value)
+lw6sys_progress_update (lw6sys_context_t * sys_context, lw6sys_progress_t * progress, int min, int max, int value)
 {
   if (progress && progress->value && (max > min))
     {
       value = lw6sys_imax (min, value);
       value = lw6sys_imin (max, value);
-      (*(progress->value)) =
-	((((float) value) - ((float) min)) / (((float) max) -
-					      ((float) min))) *
-	(progress->max - progress->min) + progress->min;
+      (*(progress->value)) = ((((float) value) - ((float) min)) / (((float) max) - ((float) min))) * (progress->max - progress->min) + progress->min;
       if ((*(progress->value)) < progress->min)
 	{
-	  lw6sys_log (LW6SYS_LOG_WARNING,
-		      "progress value too low min=%f max=%f value=%f",
-		      progress->min, progress->max, *(progress->value));
+	  lw6sys_log (sys_context, LW6SYS_LOG_WARNING, "progress value too low min=%f max=%f value=%f", progress->min, progress->max, *(progress->value));
 	  (*(progress->value)) = progress->min;
 	}
       if ((*(progress->value)) > progress->max)
 	{
-	  lw6sys_log (LW6SYS_LOG_WARNING,
-		      "progress value too high min=%f max=%f value=%f",
-		      progress->min, progress->max, *(progress->value));
+	  lw6sys_log (sys_context, LW6SYS_LOG_WARNING, "progress value too high min=%f max=%f value=%f", progress->min, progress->max, *(progress->value));
 	  (*(progress->value)) = progress->max;
 	}
     }
@@ -119,9 +114,10 @@ lw6sys_progress_update (lw6sys_progress_t * progress, int min, int max,
 /**
  * lw6sys_progress_split
  *
- * progress1: the first part of the splitted progress
- * progress2: the second part of the splitted progress
- * progress_src: the progress to split
+ * @sys_context: global system context
+ * @progress1: the first part of the splitted progress
+ * @progress2: the second part of the splitted progress
+ * @progress_src: the progress to split
  *
  * Utility function to split a progress struct, that is, if a progress was
  * ranging from a to b, make 2 progress structs, ranging from a to c and
@@ -130,9 +126,7 @@ lw6sys_progress_update (lw6sys_progress_t * progress, int min, int max,
  * Return value: none
  */
 void
-lw6sys_progress_split (lw6sys_progress_t * progress1,
-		       lw6sys_progress_t * progress2,
-		       lw6sys_progress_t * progress_src)
+lw6sys_progress_split (lw6sys_context_t * sys_context, lw6sys_progress_t * progress1, lw6sys_progress_t * progress2, lw6sys_progress_t * progress_src)
 {
   float middle;
 
@@ -168,10 +162,11 @@ lw6sys_progress_split (lw6sys_progress_t * progress1,
 /**
  * lw6sys_progress_split_here
  *
- * progress1: the first part of the splitted progress
- * progress2: the second part of the splitted progress
- * progress_src: the progress to split
- * here: where to split
+ * @sys_context: global system context
+ * @progress1: the first part of the splitted progress
+ * @progress2: the second part of the splitted progress
+ * @progress_src: the progress to split
+ * @here: where to split
  *
  * Utility function to split a progress struct, that is, if a progress was
  * ranging from a to b, make 2 progress structs, ranging from a to c and
@@ -181,9 +176,8 @@ lw6sys_progress_split (lw6sys_progress_t * progress1,
  * Return value: none
  */
 void
-lw6sys_progress_split_here (lw6sys_progress_t * progress1,
-			    lw6sys_progress_t * progress2,
-			    lw6sys_progress_t * progress_src, float here)
+lw6sys_progress_split_here (lw6sys_context_t * sys_context,
+			    lw6sys_progress_t * progress1, lw6sys_progress_t * progress2, lw6sys_progress_t * progress_src, float here)
 {
   float middle;
 
@@ -227,10 +221,11 @@ lw6sys_progress_split_here (lw6sys_progress_t * progress1,
 /**
  * lw6sys_progress_split3
  *
- * progress1: the first part of the splitted progress
- * progress2: the second part of the splitted progress
- * progress3: the third part of the splitted progress
- * progress_src: the progress to split
+ * @sys_context: global system context
+ * @progress1: the first part of the splitted progress
+ * @progress2: the second part of the splitted progress
+ * @progress3: the third part of the splitted progress
+ * @progress_src: the progress to split
  *
  * Utility function to split a progress struct, this one will split it
  * into 3 equal parts.
@@ -238,10 +233,8 @@ lw6sys_progress_split_here (lw6sys_progress_t * progress1,
  * Return value: none
  */
 void
-lw6sys_progress_split3 (lw6sys_progress_t * progress1,
-			lw6sys_progress_t * progress2,
-			lw6sys_progress_t * progress3,
-			lw6sys_progress_t * progress_src)
+lw6sys_progress_split3 (lw6sys_context_t * sys_context,
+			lw6sys_progress_t * progress1, lw6sys_progress_t * progress2, lw6sys_progress_t * progress3, lw6sys_progress_t * progress_src)
 {
   float limit_a, limit_b;
 
@@ -288,11 +281,12 @@ lw6sys_progress_split3 (lw6sys_progress_t * progress1,
 /**
  * lw6sys_progress_split4
  *
- * progress1: the first part of the splitted progress
- * progress2: the second part of the splitted progress
- * progress3: the third part of the splitted progress
- * progress4: the fourth part of the splitted progress
- * progress_src: the progress to split
+ * @sys_context: global system context
+ * @progress1: the first part of the splitted progress
+ * @progress2: the second part of the splitted progress
+ * @progress3: the third part of the splitted progress
+ * @progress4: the fourth part of the splitted progress
+ * @progress_src: the progress to split
  *
  * Utility function to split a progress struct, this one will split it
  * into 4 equal parts.
@@ -300,11 +294,9 @@ lw6sys_progress_split3 (lw6sys_progress_t * progress1,
  * Return value: none
  */
 void
-lw6sys_progress_split4 (lw6sys_progress_t * progress1,
-			lw6sys_progress_t * progress2,
-			lw6sys_progress_t * progress3,
-			lw6sys_progress_t * progress4,
-			lw6sys_progress_t * progress_src)
+lw6sys_progress_split4 (lw6sys_context_t * sys_context,
+			lw6sys_progress_t * progress1,
+			lw6sys_progress_t * progress2, lw6sys_progress_t * progress3, lw6sys_progress_t * progress4, lw6sys_progress_t * progress_src)
 {
   float limit_a, limit_b, limit_c;
 
@@ -362,12 +354,13 @@ lw6sys_progress_split4 (lw6sys_progress_t * progress1,
 /**
  * lw6sys_progress_split5
  *
- * progress1: the first part of the splitted progress
- * progress2: the second part of the splitted progress
- * progress3: the third part of the splitted progress
- * progress4: the fourth part of the splitted progress
- * progress5: the fourth part of the splitted progress
- * progress_src: the progress to split
+ * @sys_context: global system context
+ * @progress1: the first part of the splitted progress
+ * @progress2: the second part of the splitted progress
+ * @progress3: the third part of the splitted progress
+ * @progress4: the fourth part of the splitted progress
+ * @progress5: the fourth part of the splitted progress
+ * @progress_src: the progress to split
  *
  * Utility function to split a progress struct, this one will split it
  * into 5 equal parts.
@@ -375,12 +368,10 @@ lw6sys_progress_split4 (lw6sys_progress_t * progress1,
  * Return value: none
  */
 void
-lw6sys_progress_split5 (lw6sys_progress_t * progress1,
+lw6sys_progress_split5 (lw6sys_context_t * sys_context,
+			lw6sys_progress_t * progress1,
 			lw6sys_progress_t * progress2,
-			lw6sys_progress_t * progress3,
-			lw6sys_progress_t * progress4,
-			lw6sys_progress_t * progress5,
-			lw6sys_progress_t * progress_src)
+			lw6sys_progress_t * progress3, lw6sys_progress_t * progress4, lw6sys_progress_t * progress5, lw6sys_progress_t * progress_src)
 {
   float limit_a, limit_b, limit_c, limit_d;
 
@@ -449,14 +440,15 @@ lw6sys_progress_split5 (lw6sys_progress_t * progress1,
 /**
  * lw6sys_progress_begin
  *
- * progress: the progress to update
+ * @sys_context: global system context
+ * @progress: the progress to update
  *
  * Sets the progress to its min value, NULL values correctly handled.
  *
  * Return value: none
  */
 void
-lw6sys_progress_begin (lw6sys_progress_t * progress)
+lw6sys_progress_begin (lw6sys_context_t * sys_context, lw6sys_progress_t * progress)
 {
   if (progress && progress->value)
     {
@@ -467,7 +459,8 @@ lw6sys_progress_begin (lw6sys_progress_t * progress)
 /**
  * lw6sys_progress_half
  *
- * progress: the progress to update
+ * @sys_context: global system context
+ * @progress: the progress to update
  *
  * Sets the progress to the average between min and max,
  * NULL values correctly handled.
@@ -475,7 +468,7 @@ lw6sys_progress_begin (lw6sys_progress_t * progress)
  * Return value: none
  */
 void
-lw6sys_progress_half (lw6sys_progress_t * progress)
+lw6sys_progress_half (lw6sys_context_t * sys_context, lw6sys_progress_t * progress)
 {
   if (progress && progress->value)
     {
@@ -486,14 +479,15 @@ lw6sys_progress_half (lw6sys_progress_t * progress)
 /**
  * lw6sys_progress_end
  *
- * progress: the progress to update
+ * @sys_context: global system context
+ * @progress: the progress to update
  *
  * Sets the progress to its max value, NULL values correctly handled.
  *
  * Return value: none
  */
 void
-lw6sys_progress_end (lw6sys_progress_t * progress)
+lw6sys_progress_end (lw6sys_context_t * sys_context, lw6sys_progress_t * progress)
 {
   if (progress && progress->value)
     {
