@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -31,6 +31,7 @@
 /**
  * lw6sys_serialize_int64
  *
+ * @sys_context: global system context
  * @data: pointer to the data, must contain at least 8 bytes of writable space
  * @value: the integer to serialize
  *
@@ -39,7 +40,7 @@
  * serializations.
  */
 void
-lw6sys_serialize_int64 (unsigned char *data, int64_t value)
+lw6sys_serialize_int64 (lw6sys_context_t * sys_context, unsigned char *data, int64_t value)
 {
   data[0] = value >> 56;
   data[1] = (value >> 48) & 0xFF;
@@ -54,6 +55,7 @@ lw6sys_serialize_int64 (unsigned char *data, int64_t value)
 /**
  * lw6sys_unserialize_int64
  *
+ * @sys_context: global system context
  * @data: pointer to the data, must contain at least 8 bytes
  * @value: the integer to unserialize
  *
@@ -61,15 +63,14 @@ lw6sys_serialize_int64 (unsigned char *data, int64_t value)
  * for instance, with @lw6sys_serialize_int64.
  */
 int64_t
-lw6sys_unserialize_int64 (unsigned char *data)
+lw6sys_unserialize_int64 (lw6sys_context_t * sys_context, unsigned char *data)
 {
   int64_t ret;
 
   ret =
     (((int64_t) data[0]) << 56) + (((int64_t) data[1]) << 48) +
     (((int64_t) data[2]) << 40) + (((int64_t) data[3]) << 32) +
-    (((int64_t) data[4]) << 24) + (((int64_t) data[5]) << 16) +
-    (((int64_t) data[6]) << 8) + (int64_t) data[7];
+    (((int64_t) data[4]) << 24) + (((int64_t) data[5]) << 16) + (((int64_t) data[6]) << 8) + (int64_t) data[7];
 
   return ret;
 }
@@ -77,6 +78,7 @@ lw6sys_unserialize_int64 (unsigned char *data)
 /**
  * lw6sys_serialize_int32
  *
+ * @sys_context: global system context
  * @data: pointer to the data, must contain at least 4 bytes of writable space
  * @value: the integer to serialize
  *
@@ -85,7 +87,7 @@ lw6sys_unserialize_int64 (unsigned char *data)
  * serializations.
  */
 void
-lw6sys_serialize_int32 (unsigned char *data, int32_t value)
+lw6sys_serialize_int32 (lw6sys_context_t * sys_context, unsigned char *data, int32_t value)
 {
   data[0] = value >> 24;
   data[1] = (value >> 16) & 0xFF;
@@ -96,6 +98,7 @@ lw6sys_serialize_int32 (unsigned char *data, int32_t value)
 /**
  * lw6sys_unserialize_int32
  *
+ * @sys_context: global system context
  * @data: pointer to the data, must contain at least 4 bytes
  * @value: the integer to unserialize
  *
@@ -103,7 +106,7 @@ lw6sys_serialize_int32 (unsigned char *data, int32_t value)
  * for instance, with @lw6sys_serialize_int32.
  */
 int32_t
-lw6sys_unserialize_int32 (unsigned char *data)
+lw6sys_unserialize_int32 (lw6sys_context_t * sys_context, unsigned char *data)
 {
   int32_t ret;
 
@@ -115,6 +118,7 @@ lw6sys_unserialize_int32 (unsigned char *data)
 /**
  * lw6sys_serialize_int16
  *
+ * @sys_context: global system context
  * @data: pointer to the data, must contain at least 2 bytes of writable space
  * @value: the integer to serialize
  *
@@ -123,7 +127,7 @@ lw6sys_unserialize_int32 (unsigned char *data)
  * serializations.
  */
 void
-lw6sys_serialize_int16 (unsigned char *data, int16_t value)
+lw6sys_serialize_int16 (lw6sys_context_t * sys_context, unsigned char *data, int16_t value)
 {
   data[0] = value >> 8;
   data[1] = value & 0xFF;
@@ -132,6 +136,7 @@ lw6sys_serialize_int16 (unsigned char *data, int16_t value)
 /**
  * lw6sys_unserialize_int16
  *
+ * @sys_context: global system context
  * @data: pointer to the data, must contain at least 2 bytes
  * @value: the integer to unserialize
  *
@@ -139,7 +144,7 @@ lw6sys_serialize_int16 (unsigned char *data, int16_t value)
  * for instance, with @lw6sys_serialize_int16.
  */
 int16_t
-lw6sys_unserialize_int16 (unsigned char *data)
+lw6sys_unserialize_int16 (lw6sys_context_t * sys_context, unsigned char *data)
 {
   int16_t ret;
 
