@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -30,6 +30,7 @@
 /**
  * lw6sys_shape_check_min_max_whd
  *
+ * @sys_context: global system context
  * @shape: the dimensions to control
  * @min: the minimum shape allowed
  * @max: the maximum shape allowed
@@ -40,14 +41,11 @@
  * Return value: 1 if OK, 0 if not.
  */
 int
-lw6sys_shape_check_min_max_whd (const lw6sys_whd_t * shape,
-				const lw6sys_whd_t * min,
-				const lw6sys_whd_t * max)
+lw6sys_shape_check_min_max_whd (lw6sys_context_t * sys_context, const lw6sys_whd_t * shape, const lw6sys_whd_t * min, const lw6sys_whd_t * max)
 {
   int ret = 0;
 
-  ret = (shape->w >= min->w && shape->w <= max->w && shape->h >= min->h
-	 && shape->h <= max->h && shape->d >= min->d && shape->d <= max->d);
+  ret = (shape->w >= min->w && shape->w <= max->w && shape->h >= min->h && shape->h <= max->h && shape->d >= min->d && shape->d <= max->d);
 
   return ret;
 }
@@ -55,6 +53,7 @@ lw6sys_shape_check_min_max_whd (const lw6sys_whd_t * shape,
 /**
  * lw6sys_shape_check_pos
  *
+ * @sys_context: global system context
  * @shape: the boundary box
  * @pos: the position
  *
@@ -63,13 +62,11 @@ lw6sys_shape_check_min_max_whd (const lw6sys_whd_t * shape,
  * Return value: 1 if OK, 0 if not.
  */
 int
-lw6sys_shape_check_pos (const lw6sys_whd_t * shape, const lw6sys_xyz_t * pos)
+lw6sys_shape_check_pos (lw6sys_context_t * sys_context, const lw6sys_whd_t * shape, const lw6sys_xyz_t * pos)
 {
   int ret = 0;
 
-  ret = (pos->x >= 0 && pos->x < shape->w && pos->y >= 0
-	 && pos->y < shape->h && pos->z >= 0 && (pos->z == 0
-						 || pos->z < shape->d));
+  ret = (pos->x >= 0 && pos->x < shape->w && pos->y >= 0 && pos->y < shape->h && pos->z >= 0 && (pos->z == 0 || pos->z < shape->d));
 
   return ret;
 }
@@ -77,6 +74,7 @@ lw6sys_shape_check_pos (const lw6sys_whd_t * shape, const lw6sys_xyz_t * pos)
 /**
  * lw6sys_shape_is_same
  *
+ * @sys_context: global system context
  * @shape_a: the first shape to compare
  * @shape_b: the other shape to compare
  *
@@ -85,13 +83,11 @@ lw6sys_shape_check_pos (const lw6sys_whd_t * shape, const lw6sys_xyz_t * pos)
  * Return value: 1 if same, 0 if not.
  */
 int
-lw6sys_shape_is_same (const lw6sys_whd_t * shape_a,
-		      const lw6sys_whd_t * shape_b)
+lw6sys_shape_is_same (lw6sys_context_t * sys_context, const lw6sys_whd_t * shape_a, const lw6sys_whd_t * shape_b)
 {
   int ret = 0;
 
-  ret = (shape_a->w == shape_b->w) && (shape_a->h == shape_b->h)
-    && (shape_a->d == shape_b->d);
+  ret = (shape_a->w == shape_b->w) && (shape_a->h == shape_b->h) && (shape_a->d == shape_b->d);
 
   return ret;
 }
@@ -99,6 +95,7 @@ lw6sys_shape_is_same (const lw6sys_whd_t * shape_a,
 /**
  * lw6sys_shape_is_same_xy
  *
+ * @sys_context: global system context
  * @shape_a: the first shape to compare
  * @shape_b: the other shape to compare
  *
@@ -107,8 +104,7 @@ lw6sys_shape_is_same (const lw6sys_whd_t * shape_a,
  * Return value: 1 if same_xy, 0 if not.
  */
 int
-lw6sys_shape_is_same_xy (const lw6sys_whd_t * shape_a,
-			 const lw6sys_whd_t * shape_b)
+lw6sys_shape_is_same_xy (lw6sys_context_t * sys_context, const lw6sys_whd_t * shape_a, const lw6sys_whd_t * shape_b)
 {
   int ret = 0;
 
@@ -120,12 +116,15 @@ lw6sys_shape_is_same_xy (const lw6sys_whd_t * shape_a,
 /**
  * lw6sys_shape_volume_whd
  *
+ * @sys_context: global system context
+ * @shape: the shape to query
+ *
  * Gives the volume (w * h * d) for a given shape.
  *
  * Return value: the volume.
  */
 int
-lw6sys_shape_volume_whd (const lw6sys_whd_t * shape)
+lw6sys_shape_volume_whd (lw6sys_context_t * sys_context, const lw6sys_whd_t * shape)
 {
   return (shape->w * shape->h * shape->d);
 }
@@ -133,12 +132,15 @@ lw6sys_shape_volume_whd (const lw6sys_whd_t * shape)
 /**
  * lw6sys_shape_surface_wh
  *
+ * @sys_context: global system context
+ * @shape: the shape to query
+ *
  * Gives the surface (w * h) for a given shape.
  *
  * Return value: the surface.
  */
 int
-lw6sys_shape_surface_wh (const lw6sys_whd_t * shape)
+lw6sys_shape_surface_wh (lw6sys_context_t * sys_context, const lw6sys_whd_t * shape)
 {
   return (shape->w * shape->h);
 }
