@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -29,22 +29,29 @@
 
 #include <signal.h>
 
+static lw6sys_context_t *_signal_context = NULL;
+
 /**
  * lw6sys_signal_custom
  *
+ * @sys_context: global system context
  * @trap_errors: set to 1 if you want to trap SIGSEGV and SIGFPE
  *
  * Set up our signal handlers. This will probably be overrided
  * later by other libs such as libSDL, but at least in pure server
  * mode it gives a way to treat SIGTERM the right way.
+ * The callbacks will use the @sys_context passed here, ignoring
+ * whatever thread and/or whatever value for this context was used
+ * when the error was detected. However, one needs at least one
+ * context, for instance to log messages.
  *
  * Return value: none.
  */
 void
-lw6sys_signal_custom (int trap_errors)
+lw6sys_signal_custom (lw6sys_context_t * sys_context, int trap_errors)
 {
-  lw6sys_log (LW6SYS_LOG_INFO,
-	      _x_ ("setting custom SIGTERM, SIGINT, SIGHUP handlers"));
+  lw6sys_log (sys_context, LW6SYS_LOG_INFO, _x_ ("setting custom SIGTERM, SIGINT, SIGHUP handlers"));
+  _signal_context = sys_context;
 #ifdef SIGTERM
   if (signal (SIGTERM, lw6sys_signal_term_handler) == SIG_IGN)
     {
@@ -83,16 +90,17 @@ lw6sys_signal_custom (int trap_errors)
 /**
  * lw6sys_signal_default
  *
+ * @sys_context: global system context
+ *
  * Restore default signal handlers for those modified by @lw6sys_signal_custom.
  *
  * Return value: none.
  */
 void
-lw6sys_signal_default ()
+lw6sys_signal_default (lw6sys_context_t * sys_context)
 {
-  lw6sys_log (LW6SYS_LOG_INFO,
-	      _x_
-	      ("setting default SIGTERM, SIGINT, SIGHUP, SIGSEGV, SIGFPE handlers"));
+  lw6sys_log (sys_context, LW6SYS_LOG_INFO, _x_ ("setting default SIGTERM, SIGINT, SIGHUP, SIGSEGV, SIGFPE handlers"));
+  _signal_context = NULL;
 #ifdef SIGTERM
   if (signal (SIGTERM, SIG_DFL) == SIG_IGN)
     {
@@ -139,8 +147,13 @@ lw6sys_signal_default ()
 void
 lw6sys_signal_term_handler (int signum)
 {
-  lw6sys_log (LW6SYS_LOG_NOTICE, _x_ ("caught SIGTERM"));
-  lw6sys_signal_send_quit ();
+  lw6sys_context_t *sys_context = _signal_context;
+
+  if (sys_context)
+    {
+      lw6sys_log (sys_context, LW6SYS_LOG_NOTICE, _x_ ("caught SIGTERM"));
+      lw6sys_signal_send_quit (sys_context);
+    }
 }
 
 /**
@@ -157,8 +170,13 @@ lw6sys_signal_term_handler (int signum)
 void
 lw6sys_signal_int_handler (int signum)
 {
-  lw6sys_log (LW6SYS_LOG_NOTICE, _x_ ("caught SIGINT"));
-  lw6sys_signal_send_quit ();
+  lw6sys_context_t *sys_context = _signal_context;
+
+  if (sys_context)
+    {
+      lw6sys_log (sys_context, LW6SYS_LOG_NOTICE, _x_ ("caught SIGINT"));
+      lw6sys_signal_send_quit (sys_context);
+    }
 }
 
 /**
@@ -176,17 +194,20 @@ void
 lw6sys_signal_hup_handler (int signum)
 {
   char *uptime = NULL;
+  lw6sys_context_t *sys_context = _signal_context;
 
-  uptime = lw6sys_readable_uptime (lw6sys_get_uptime ());
-  if (uptime)
+  if (sys_context)
     {
-      lw6sys_log (LW6SYS_LOG_NOTICE, _x_ ("caught SIGHUP, uptime=\"%s\""),
-		  uptime);
-      LW6SYS_FREE (uptime);
-    }
-  else
-    {
-      lw6sys_log (LW6SYS_LOG_NOTICE, _x_ ("caught SIGHUP"));
+      uptime = lw6sys_readable_uptime (sys_context, lw6sys_get_uptime (sys_context));
+      if (uptime)
+	{
+	  lw6sys_log (sys_context, LW6SYS_LOG_NOTICE, _x_ ("caught SIGHUP, uptime=\"%s\""), uptime);
+	  LW6SYS_FREE (sys_context, uptime);
+	}
+      else
+	{
+	  lw6sys_log (sys_context, LW6SYS_LOG_NOTICE, _x_ ("caught SIGHUP"));
+	}
     }
 }
 
@@ -203,29 +224,33 @@ void
 lw6sys_signal_segv_handler (int signum)
 {
 #ifdef SIGSEGV
-  /*
-   * OK here we test wether signum is really SIGSEGV,
-   * if this is the case the error is fired for good so
-   * we exit, if not, we keep on going, probably this
-   * is just a test.
-   */
-  if (signum == SIGSEGV)
+  lw6sys_context_t *sys_context = _signal_context;
+
+  if (sys_context)
     {
       /*
-       * Now we restore default, in case our routine
-       * fires the same error once again...
+       * OK here we test wether signum is really SIGSEGV,
+       * if this is the case the error is fired for good so
+       * we exit, if not, we keep on going, probably this
+       * is just a test.
        */
-      if (signal (SIGSEGV, SIG_DFL) == SIG_IGN)
+      if (signum == SIGSEGV)
 	{
-	  signal (SIGSEGV, SIG_IGN);
+	  /*
+	   * Now we restore default, in case our routine
+	   * fires the same error once again...
+	   */
+	  if (signal (SIGSEGV, SIG_DFL) == SIG_IGN)
+	    {
+	      signal (SIGSEGV, SIG_IGN);
+	    }
+	  lw6sys_log (sys_context, LW6SYS_LOG_ERROR, _("Segmentation fault"));
+	  exit (LW6SYS_EXIT_ERROR);
+	}
+      else
+	{
+	  lw6sys_log (sys_context, LW6SYS_LOG_ERROR, _x_ ("Testing segmentation fault handler"));
 	}
-      lw6sys_log (LW6SYS_LOG_ERROR, _("Segmentation fault"));
-      exit (LW6SYS_EXIT_ERROR);
-    }
-  else
-    {
-      lw6sys_log (LW6SYS_LOG_ERROR,
-		  _x_ ("Testing segmentation fault handler"));
     }
 #endif
 }
@@ -243,29 +268,33 @@ void
 lw6sys_signal_fpe_handler (int signum)
 {
 #ifdef SIGFPE
-  /*
-   * OK here we test wether signum is really SIGFPE,
-   * if this is the case the error is fired for good so
-   * we exit, if not, we keep on going, probably this
-   * is just a test.
-   */
-  if (signum == SIGFPE)
+  lw6sys_context_t *sys_context = _signal_context;
+
+  if (sys_context)
     {
       /*
-       * Now we restore default, in case our routine
-       * fires the same error once again...
+       * OK here we test wether signum is really SIGFPE,
+       * if this is the case the error is fired for good so
+       * we exit, if not, we keep on going, probably this
+       * is just a test.
        */
-      if (signal (SIGFPE, SIG_DFL) == SIG_IGN)
+      if (signum == SIGFPE)
 	{
-	  signal (SIGFPE, SIG_IGN);
+	  /*
+	   * Now we restore default, in case our routine
+	   * fires the same error once again...
+	   */
+	  if (signal (SIGFPE, SIG_DFL) == SIG_IGN)
+	    {
+	      signal (SIGFPE, SIG_IGN);
+	    }
+	  lw6sys_log (sys_context, LW6SYS_LOG_ERROR, _("Floating point exception"));
+	  exit (LW6SYS_EXIT_ERROR);
+	}
+      else
+	{
+	  lw6sys_log (sys_context, LW6SYS_LOG_ERROR, _x_ ("Testing floating point exception handler"));
 	}
-      lw6sys_log (LW6SYS_LOG_ERROR, _("Floating point exception"));
-      exit (LW6SYS_EXIT_ERROR);
-    }
-  else
-    {
-      lw6sys_log (LW6SYS_LOG_ERROR,
-		  _x_ ("Testing floating point exception handler"));
     }
 #endif
 }
@@ -273,32 +302,39 @@ lw6sys_signal_fpe_handler (int signum)
 /**
  * lw6sys_signal_send_quit
  *
+ * @sys_context: global system context
+ *
  * Sets the quit flag to 1, so that @lw6sys_signal_poll_quit returns
  * true, that is, tells the polling loop to stop.
  *
  * Return value: none.
  */
 void
-lw6sys_signal_send_quit ()
+lw6sys_signal_send_quit (lw6sys_context_t * sys_context)
 {
-  lw6sys_log (LW6SYS_LOG_INFO, _x_ ("send QUIT"));
-  _lw6sys_global.quit = 1;
+  _lw6sys_global_t *global = &(((_lw6sys_context_t *) sys_context)->global);
+
+  lw6sys_log (sys_context, LW6SYS_LOG_INFO, _x_ ("send QUIT"));
+  global->quit = 1;
 }
 
 /**
  * lw6sys_signal_poll_quit
  *
+ * @sys_context: global system context
+ *
  * Tests wether we need to stop right now.
  *
  * Return value: 1 if we need to stop now, 0 if program can continue.
  */
 int
-lw6sys_signal_poll_quit ()
+lw6sys_signal_poll_quit (lw6sys_context_t * sys_context)
 {
+  _lw6sys_global_t *global = &(((_lw6sys_context_t *) sys_context)->global);
   int ret = 0;
 
-  ret = (_lw6sys_global.quit != 0);
-  lw6sys_log (LW6SYS_LOG_DEBUG, _x_ ("poll quit ret=%d"), ret);
+  ret = (global->quit != 0);
+  lw6sys_log (sys_context, LW6SYS_LOG_DEBUG, _x_ ("poll quit ret=%d"), ret);
 
   return ret;
 }
