@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -55,6 +55,7 @@ typedef struct _join_callback_data_s
 /**
  * lw6sys_str_copy
  *
+ * @sys_context: global system context
  * @src: the string to copy
  *
  * Duplicate a string, creating a new pointer on it, which
@@ -65,13 +66,13 @@ typedef struct _join_callback_data_s
  * Return value: a newly allocated pointer, must be freed.
  */
 char *
-lw6sys_str_copy (const char *src)
+lw6sys_str_copy (lw6sys_context_t * sys_context, const char *src)
 {
   char *copy = NULL;
   int length;
 
   length = strlen (src);
-  copy = LW6SYS_MALLOC (length + 1);
+  copy = LW6SYS_MALLOC (sys_context, length + 1);
   if (copy)
     {
       strncpy (copy, src, length + 1);
@@ -84,6 +85,7 @@ lw6sys_str_copy (const char *src)
 /**
  * lw6sys_str_concat
  *
+ * @sys_context: global system context
  * @str1: the left part to be concatenated
  * @str2: the right part to be concatenated
  *
@@ -94,13 +96,13 @@ lw6sys_str_copy (const char *src)
  * Return value: a newly allocated pointer, must be freed.
  */
 char *
-lw6sys_str_concat (const char *str1, const char *str2)
+lw6sys_str_concat (lw6sys_context_t * sys_context, const char *str1, const char *str2)
 {
   char *concat = NULL;
   int length;
 
   length = strlen (str1) + strlen (str2);
-  concat = LW6SYS_MALLOC (length + 1);
+  concat = LW6SYS_MALLOC (sys_context, length + 1);
   if (concat)
     {
       snprintf (concat, length + 1, "%s%s", str1, str2);
@@ -111,14 +113,14 @@ lw6sys_str_concat (const char *str1, const char *str2)
 }
 
 char *
-_lw6sys_new_vsnprintf (int n, const char *fmt, va_list ap)
+_lw6sys_new_vsnprintf (lw6sys_context_t * sys_context, int n, const char *fmt, va_list ap)
 {
   char *ret = NULL;
   int written;
 
   if (n > 0)
     {
-      ret = (char *) LW6SYS_MALLOC (n);
+      ret = (char *) LW6SYS_MALLOC (sys_context, n);
 
       if (ret)
 	{
@@ -128,7 +130,7 @@ _lw6sys_new_vsnprintf (int n, const char *fmt, va_list ap)
 	      /*
 	       * Problem, either error or string too long.
 	       */
-	      LW6SYS_FREE (ret);
+	      LW6SYS_FREE (sys_context, ret);
 	      ret = NULL;
 	    }
 	  else
@@ -150,6 +152,7 @@ more_mem (int n)
 /**
  * lw6sys_new_sprintf
  *
+ * @sys_context: global system context
  * @fmt: a format string, like the one you would pass to @printf
  * @...: optional arguments, like the ones you would pass to @printf
  *
@@ -165,7 +168,7 @@ more_mem (int n)
  * Return value: a new allocated string, must be freed.
  */
 char *
-lw6sys_new_sprintf (const char *fmt, ...)
+lw6sys_new_sprintf (lw6sys_context_t * sys_context, const char *fmt, ...)
 {
   char *ret = NULL;
   va_list ap;
@@ -181,7 +184,7 @@ lw6sys_new_sprintf (const char *fmt, ...)
 	  va_list ap2;
 
 	  va_copy (ap2, ap);
-	  ret = _lw6sys_new_vsnprintf (n, fmt, ap2);
+	  ret = _lw6sys_new_vsnprintf (sys_context, n, fmt, ap2);
 	  va_end (ap2);
 
 	  /*
@@ -201,7 +204,7 @@ lw6sys_new_sprintf (const char *fmt, ...)
 }
 
 int
-_lw6sys_buf_vsnprintf (char *buf, int len, const char *fmt, va_list ap)
+_lw6sys_buf_vsnprintf (lw6sys_context_t * sys_context, char *buf, int len, const char *fmt, va_list ap)
 {
   int ret = 0;
 
@@ -232,6 +235,7 @@ _lw6sys_buf_vsnprintf (char *buf, int len, const char *fmt, va_list ap)
 /**
  * lw6sys_buf_sprintf
  *
+ * @sys_context: global system context
  * @buf: a buffer of len+1 chars
  * @len: the max length of string
  * @fmt: a format string, like the one you would pass to @printf
@@ -244,7 +248,7 @@ _lw6sys_buf_vsnprintf (char *buf, int len, const char *fmt, va_list ap)
  * Return value: 1 if success, 0 if failed.
  */
 int
-lw6sys_buf_sprintf (char *buf, int len, const char *fmt, ...)
+lw6sys_buf_sprintf (lw6sys_context_t * sys_context, char *buf, int len, const char *fmt, ...)
 {
   int ret = 0;
   va_list ap;
@@ -264,7 +268,7 @@ lw6sys_buf_sprintf (char *buf, int len, const char *fmt, ...)
        * low-level function which do not want to lock
        * anything calling malloc or something.
        */
-      ret = _lw6sys_buf_vsnprintf (buf, len, fmt, ap);
+      ret = _lw6sys_buf_vsnprintf (sys_context, buf, len, fmt, ap);
       va_end (ap);
     }
 
@@ -274,6 +278,7 @@ lw6sys_buf_sprintf (char *buf, int len, const char *fmt, ...)
 /**
  * lw6sys_str_is_blank
  *
+ * @sys_context: global system context
  * @str: the string to test
  *
  * Tests wether a string is blank, that is, if it's composed
@@ -282,7 +287,7 @@ lw6sys_buf_sprintf (char *buf, int len, const char *fmt, ...)
  * Return value: 1 if blank, 0 if not.
  */
 int
-lw6sys_str_is_blank (const char *str)
+lw6sys_str_is_blank (lw6sys_context_t * sys_context, const char *str)
 {
   int ret = 1;
   int pos = 0;
@@ -307,6 +312,7 @@ lw6sys_str_is_blank (const char *str)
 /**
  * lw6sys_str_is_null_or_empty
  *
+ * @sys_context: global system context
  * @str: the string to test
  *
  * Tests wether a string is NULL or empty (string with 0 chars "").
@@ -314,7 +320,7 @@ lw6sys_str_is_blank (const char *str)
  * Return value: 1 if NULL or empty, 0 if contains something.
  */
 int
-lw6sys_str_is_null_or_empty (const char *str)
+lw6sys_str_is_null_or_empty (lw6sys_context_t * sys_context, const char *str)
 {
   return (str == NULL || str[0] == '\0');
 }
@@ -322,6 +328,7 @@ lw6sys_str_is_null_or_empty (const char *str)
 /**
  * lw6sys_str_empty_if_null
  *
+ * @sys_context: global system context
  * @str: the string to test
  *
  * Returns always a non-NULL string, if string is NULL, returns ""
@@ -331,7 +338,7 @@ lw6sys_str_is_null_or_empty (const char *str)
  * Return value: source string or "" if it was NULL
  */
 const char *
-lw6sys_str_empty_if_null (const char *str)
+lw6sys_str_empty_if_null (lw6sys_context_t * sys_context, const char *str)
 {
   return str ? str : LW6SYS_STR_EMPTY;
 }
@@ -339,6 +346,7 @@ lw6sys_str_empty_if_null (const char *str)
 /**
  * lw6sys_str_is_same
  *
+ * @sys_context: global system context
  * @str_a: 1st string to compare, can be NULL
  * @str_b: 2nd string to compare, can be NULL
  *
@@ -350,7 +358,7 @@ lw6sys_str_empty_if_null (const char *str)
  * Return value: 1 if same, 0 if not.
  */
 int
-lw6sys_str_is_same (const char *str_a, const char *str_b)
+lw6sys_str_is_same (lw6sys_context_t * sys_context, const char *str_a, const char *str_b)
 {
   int ret = 1;
 
@@ -369,6 +377,7 @@ lw6sys_str_is_same (const char *str_a, const char *str_b)
 /**
  * lw6sys_str_is_same_no_case
  *
+ * @sys_context: global system context
  * @str_a: 1st string to compare, can be NULL
  * @str_b: 2nd string to compare, can be NULL
  *
@@ -381,7 +390,7 @@ lw6sys_str_is_same (const char *str_a, const char *str_b)
  * Return value: 1 if same, 0 if not.
  */
 int
-lw6sys_str_is_same_no_case (const char *str_a, const char *str_b)
+lw6sys_str_is_same_no_case (lw6sys_context_t * sys_context, const char *str_a, const char *str_b)
 {
   int ret = 1;
 
@@ -400,6 +409,7 @@ lw6sys_str_is_same_no_case (const char *str_a, const char *str_b)
 /**
  * lw6sys_str_starts_with
  *
+ * @sys_context: global system context
  * @str: the string to analyse
  * @beginning: the pattern to search
  *
@@ -408,7 +418,7 @@ lw6sys_str_is_same_no_case (const char *str_a, const char *str_b)
  * Return value: 1 if @str starts with @beginning, 0 if not
  */
 int
-lw6sys_str_starts_with (const char *str, const char *beginning)
+lw6sys_str_starts_with (lw6sys_context_t * sys_context, const char *str, const char *beginning)
 {
   int ret = 0;
 
@@ -420,6 +430,7 @@ lw6sys_str_starts_with (const char *str, const char *beginning)
 /**
  * lw6sys_str_starts_with_no_case
  *
+ * @sys_context: global system context
  * @str: the string to analyse
  * @beginning: the pattern to search
  *
@@ -429,7 +440,7 @@ lw6sys_str_starts_with (const char *str, const char *beginning)
  * Return value: 1 if @str starts with @beginning, 0 if not
  */
 int
-lw6sys_str_starts_with_no_case (const char *str, const char *beginning)
+lw6sys_str_starts_with_no_case (lw6sys_context_t * sys_context, const char *str, const char *beginning)
 {
   int ret = 0;
 
@@ -441,6 +452,7 @@ lw6sys_str_starts_with_no_case (const char *str, const char *beginning)
 /**
  * lw6sys_skip_blanks
  *
+ * @sys_context: global system context
  * @str_ptr: a pointer to a string pointer (read/write parameter).
  *
  * Skips blanks at the beginning of a string. The passed parameter
@@ -449,7 +461,7 @@ lw6sys_str_starts_with_no_case (const char *str, const char *beginning)
  * Return value: 1 if blanks were found, else 0.
  */
 int
-lw6sys_skip_blanks (char **str_ptr)
+lw6sys_skip_blanks (lw6sys_context_t * sys_context, char **str_ptr)
 {
   int ret = 0;
 
@@ -477,7 +489,7 @@ lw6sys_skip_blanks (char **str_ptr)
  * Return value: none.
  */
 void
-lw6sys_str_cleanup (char *str)
+lw6sys_str_cleanup (lw6sys_context_t * sys_context, char *str)
 {
   /*
    * It's important to have pos unsigned here else characters
@@ -499,6 +511,7 @@ lw6sys_str_cleanup (char *str)
 /**
  * lw6sys_str_cleanup_ascii7
  *
+ * @sys_context: global system context
  * @str: a pointer to the string, which will be modified in-place.
  *
  * Used to clean up some strings, for instance if they
@@ -512,7 +525,7 @@ lw6sys_str_cleanup (char *str)
  * Return value: none.
  */
 void
-lw6sys_str_cleanup_ascii7 (char *str)
+lw6sys_str_cleanup_ascii7 (lw6sys_context_t * sys_context, char *str)
 {
   /*
    * It's important to have pos unsigned here else characters
@@ -532,18 +545,16 @@ lw6sys_str_cleanup_ascii7 (char *str)
 }
 
 static void
-reformat_newline (char **formatted_str, char *append, const char *prefix)
+_reformat_newline (lw6sys_context_t * sys_context, char **formatted_str, char *append, const char *prefix)
 {
   char *new_str = NULL;
 
-  lw6sys_str_cleanup (append);
-  lw6sys_skip_blanks (&append);
-  new_str =
-    lw6sys_new_sprintf ("%s%s%s%s", *formatted_str, prefix, append,
-			lw6sys_eol ());
+  lw6sys_str_cleanup (sys_context, append);
+  lw6sys_skip_blanks (sys_context, &append);
+  new_str = lw6sys_new_sprintf (sys_context, "%s%s%s%s", *formatted_str, prefix, append, lw6sys_eol ());
   if (new_str)
     {
-      LW6SYS_FREE (*formatted_str);
+      LW6SYS_FREE (sys_context, *formatted_str);
       (*formatted_str) = new_str;
     }
 }
@@ -551,6 +562,7 @@ reformat_newline (char **formatted_str, char *append, const char *prefix)
 /**
  * lw6sys_str_reformat
  *
+ * @sys_context: global system context
  * @str: a pointer to the string we want to modify
  * @prefix: a prefix to put before each line
  * @nb_colummns: number of columns to use, without prefix.
@@ -564,7 +576,7 @@ reformat_newline (char **formatted_str, char *append, const char *prefix)
  * Return value: a newly allocated string, must be freed.
  */
 char *
-lw6sys_str_reformat (const char *str, const char *prefix, int nb_columns)
+lw6sys_str_reformat (lw6sys_context_t * sys_context, const char *str, const char *prefix, int nb_columns)
 {
   char *ret = NULL;
   char *str_copy = NULL;
@@ -574,10 +586,10 @@ lw6sys_str_reformat (const char *str, const char *prefix, int nb_columns)
   int space_i = 0;
 
   nb_columns = lw6sys_imax (nb_columns, 1);
-  str_copy = lw6sys_str_copy (str);
+  str_copy = lw6sys_str_copy (sys_context, str);
   if (str_copy)
     {
-      ret = lw6sys_str_copy ("");
+      ret = lw6sys_str_copy (sys_context, "");
       line_start = str_copy;
       i = 0;
       pos = str_copy;
@@ -590,7 +602,7 @@ lw6sys_str_reformat (const char *str, const char *prefix, int nb_columns)
 		  pos++;
 		}
 	      pos[0] = '\0';
-	      reformat_newline (&ret, line_start, prefix);
+	      _reformat_newline (sys_context, &ret, line_start, prefix);
 	      line_start = pos + 1;
 	      i = 0;
 	      pos = line_start;
@@ -612,8 +624,7 @@ lw6sys_str_reformat (const char *str, const char *prefix, int nb_columns)
 		  i = 1;
 		  while (line_start[i] && !space_i)
 		    {
-		      if (lw6sys_chr_is_eol (line_start[i])
-			  || lw6sys_chr_is_space (line_start[i]))
+		      if (lw6sys_chr_is_eol (line_start[i]) || lw6sys_chr_is_space (line_start[i]))
 			{
 			  space_i = i;
 			  break;
@@ -628,12 +639,12 @@ lw6sys_str_reformat (const char *str, const char *prefix, int nb_columns)
 	      if (space_i)
 		{
 		  line_start[space_i] = '\0';
-		  reformat_newline (&ret, line_start, prefix);
+		  _reformat_newline (sys_context, &ret, line_start, prefix);
 		  line_start += (space_i + 1);
 		}
 	      else
 		{
-		  lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("reformat problem"));
+		  lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("reformat problem"));
 		  line_start += i;
 		}
 	      i = 0;
@@ -648,10 +659,10 @@ lw6sys_str_reformat (const char *str, const char *prefix, int nb_columns)
 
       if (ret && line_start)
 	{
-	  reformat_newline (&ret, line_start, prefix);
+	  _reformat_newline (sys_context, &ret, line_start, prefix);
 	}
 
-      LW6SYS_FREE (str_copy);
+      LW6SYS_FREE (sys_context, str_copy);
     }
 
   return ret;
@@ -660,6 +671,7 @@ lw6sys_str_reformat (const char *str, const char *prefix, int nb_columns)
 /**
  * lw6sys_str_reformat_this
  *
+ * @sys_context: global system context
  * @str: a pointer to the string we want to modify
  * @nb_colummns: number of columns to use, without prefix.
  *
@@ -672,7 +684,7 @@ lw6sys_str_reformat (const char *str, const char *prefix, int nb_columns)
  * Return value: none
  */
 void
-lw6sys_str_reformat_this (char *str, int nb_columns)
+lw6sys_str_reformat_this (lw6sys_context_t * sys_context, char *str, int nb_columns)
 {
   int i = 0;
   char *pos = NULL;
@@ -700,6 +712,8 @@ lw6sys_str_reformat_this (char *str, int nb_columns)
 /**
  * lw6sys_eol
  *
+ * @sys_context: global system context
+ *
  * Returns the value of EOL, that is, the "end of line" sequence.
  * Will simply return "\n" on UNIX and "\r\n" on Microsoft platforms.
  * Note that while this is convenient to write config and example files,
@@ -710,7 +724,7 @@ lw6sys_str_reformat_this (char *str, int nb_columns)
  * Return value: the EOL string, must not be freed.
  */
 char *
-lw6sys_eol ()
+lw6sys_eol (lw6sys_context_t * sys_context)
 {
   return STR_EOL;
 }
@@ -718,6 +732,7 @@ lw6sys_eol ()
 /**
  * lw6sys_str_split
  *
+ * @sys_context: global system context
  * @str: a string
  * @c: the delimiter to split with
  *
@@ -727,7 +742,7 @@ lw6sys_eol ()
  * Return value: a list containing 0-terminated strings.
  */
 lw6sys_list_t *
-lw6sys_str_split (const char *str, char c)
+lw6sys_str_split (lw6sys_context_t * sys_context, const char *str, char c)
 {
   lw6sys_list_t *ret = NULL;
   char *found = NULL;
@@ -735,30 +750,30 @@ lw6sys_str_split (const char *str, char c)
   char *copy = NULL;
   char *part = NULL;
 
-  copy = lw6sys_str_copy (str);
+  copy = lw6sys_str_copy (sys_context, str);
   if (copy)
     {
-      ret = lw6sys_list_new (lw6sys_free_callback);
+      ret = lw6sys_list_new (sys_context, lw6sys_free_callback);
       if (ret)
 	{
 	  pos = copy;
 	  while ((found = strchr (pos, c)) != NULL)
 	    {
 	      (*found) = '\0';
-	      part = lw6sys_str_copy (pos);
+	      part = lw6sys_str_copy (sys_context, pos);
 	      if (part)
 		{
-		  lw6sys_list_push_back (&ret, part);
+		  lw6sys_list_push_back (sys_context, &ret, part);
 		}
 	      pos = found + 1;
 	    }
-	  part = lw6sys_str_copy (pos);
+	  part = lw6sys_str_copy (sys_context, pos);
 	  if (part)
 	    {
-	      lw6sys_list_push_back (&ret, part);
+	      lw6sys_list_push_back (sys_context, &ret, part);
 	    }
 	}
-      LW6SYS_FREE (copy);
+      LW6SYS_FREE (sys_context, copy);
     }
 
   return ret;
@@ -767,6 +782,7 @@ lw6sys_str_split (const char *str, char c)
 /**
  * lw6sys_str_split_no_0
  *
+ * @sys_context: global system context
  * @str: a string
  * @c: the delimiter to split with
  *
@@ -776,7 +792,7 @@ lw6sys_str_split (const char *str, char c)
  * Return value: a list containing 0-terminated strings.
  */
 lw6sys_list_t *
-lw6sys_str_split_no_0 (const char *str, char c)
+lw6sys_str_split_no_0 (lw6sys_context_t * sys_context, const char *str, char c)
 {
   lw6sys_list_t *ret = NULL;
   char *found = NULL;
@@ -784,44 +800,44 @@ lw6sys_str_split_no_0 (const char *str, char c)
   char *copy = NULL;
   char *part = NULL;
 
-  copy = lw6sys_str_copy (str);
+  copy = lw6sys_str_copy (sys_context, str);
   if (copy)
     {
-      ret = lw6sys_list_new (lw6sys_free_callback);
+      ret = lw6sys_list_new (sys_context, lw6sys_free_callback);
       if (ret)
 	{
 	  pos = copy;
 	  while ((found = strchr (pos, c)) != NULL)
 	    {
 	      (*found) = '\0';
-	      part = lw6sys_str_copy (pos);
+	      part = lw6sys_str_copy (sys_context, pos);
 	      if (part)
 		{
 		  if ((*part) != '\0')
 		    {
-		      lw6sys_list_push_back (&ret, part);
+		      lw6sys_list_push_back (sys_context, &ret, part);
 		    }
 		  else
 		    {
-		      LW6SYS_FREE (part);
+		      LW6SYS_FREE (sys_context, part);
 		    }
 		}
 	      pos = found + 1;
 	    }
-	  part = lw6sys_str_copy (pos);
+	  part = lw6sys_str_copy (sys_context, pos);
 	  if (part)
 	    {
 	      if ((*part) != '\0')
 		{
-		  lw6sys_list_push_back (&ret, part);
+		  lw6sys_list_push_back (sys_context, &ret, part);
 		}
 	      else
 		{
-		  LW6SYS_FREE (part);
+		  LW6SYS_FREE (sys_context, part);
 		}
 	    }
 	}
-      LW6SYS_FREE (copy);
+      LW6SYS_FREE (sys_context, copy);
     }
 
   return ret;
@@ -830,6 +846,7 @@ lw6sys_str_split_no_0 (const char *str, char c)
 /**
  * lw6sys_str_split_config_item
  *
+ * @sys_context: global system context
  * @str: a string
  *
  * Splits a string, ignoring empty '0-length' members, and using
@@ -840,36 +857,34 @@ lw6sys_str_split_no_0 (const char *str, char c)
  * Return value: a list containing 0-terminated strings.
  */
 lw6sys_list_t *
-lw6sys_str_split_config_item (const char *str)
+lw6sys_str_split_config_item (lw6sys_context_t * sys_context, const char *str)
 {
-  return lw6sys_str_split_no_0 (str, ',');
+  return lw6sys_str_split_no_0 (sys_context, str, ',');
 }
 
 static void
-_join_callback (void *func_data, void *data)
+_join_callback (lw6sys_context_t * sys_context, void *func_data, void *data)
 {
-  _join_callback_data_t *join_callback_data =
-    (_join_callback_data_t *) func_data;
+  _join_callback_data_t *join_callback_data = (_join_callback_data_t *) func_data;
   char *str = (char *) data;
   char *tmp = NULL;
 
   if (join_callback_data->ret)
     {
       tmp = join_callback_data->ret;
-      join_callback_data->ret =
-	lw6sys_new_sprintf ("%s%s%s", join_callback_data->ret,
-			    join_callback_data->glue, str);
-      LW6SYS_FREE (tmp);
+      join_callback_data->ret = lw6sys_new_sprintf (sys_context, "%s%s%s", join_callback_data->ret, join_callback_data->glue, str);
+      LW6SYS_FREE (sys_context, tmp);
     }
   else
     {
-      join_callback_data->ret = lw6sys_str_copy (str);
+      join_callback_data->ret = lw6sys_str_copy (sys_context, str);
     }
 }
 
 /**
  * lw6sys_str_join
  *
+ * @sys_context: global system context
  * @list: list of strings to join
  * @glue: string to add in-between
  *
@@ -881,7 +896,7 @@ _join_callback (void *func_data, void *data)
  * Return value: dynamically allocated string
  */
 char *
-lw6sys_str_join (lw6sys_list_t * list, const char *glue)
+lw6sys_str_join (lw6sys_context_t * sys_context, lw6sys_list_t * list, const char *glue)
 {
   char *ret = NULL;
   _join_callback_data_t join_callback_data;
@@ -889,7 +904,7 @@ lw6sys_str_join (lw6sys_list_t * list, const char *glue)
   join_callback_data.ret = ret;
   join_callback_data.glue = glue;
 
-  lw6sys_list_map (list, _join_callback, &join_callback_data);
+  lw6sys_list_map (sys_context, list, _join_callback, &join_callback_data);
 
   ret = join_callback_data.ret;
 
@@ -899,6 +914,7 @@ lw6sys_str_join (lw6sys_list_t * list, const char *glue)
 /**
  * lw6sys_str_toupper
  *
+ * @sys_context: global system context
  * @str: the string to modify
  *
  * Transforms a string to upper case, the pointer must point
@@ -907,7 +923,7 @@ lw6sys_str_join (lw6sys_list_t * list, const char *glue)
  * Return value: none, @str pointed data modified in-place
  */
 void
-lw6sys_str_toupper (char *str)
+lw6sys_str_toupper (lw6sys_context_t * sys_context, char *str)
 {
   char *pos = str;
 
@@ -921,6 +937,7 @@ lw6sys_str_toupper (char *str)
 /**
  * lw6sys_str_tolower
  *
+ * @sys_context: global system context
  * @str: the string to modify
  *
  * Transforms a string to lower case, the pointer must point
@@ -929,7 +946,7 @@ lw6sys_str_toupper (char *str)
  * Return value: none, @str pointed data modified in-place
  */
 void
-lw6sys_str_tolower (char *str)
+lw6sys_str_tolower (lw6sys_context_t * sys_context, char *str)
 {
   char *pos = str;
 
@@ -943,6 +960,7 @@ lw6sys_str_tolower (char *str)
 /**
  * lw6sys_str_truncate
  *
+ * @sys_context: global system context
  * @str: the string to truncate
  * @len: the new length
  *
@@ -952,7 +970,7 @@ lw6sys_str_tolower (char *str)
  * Return value: none, @str pointed data modified in-place
  */
 void
-lw6sys_str_truncate (char *str, int len)
+lw6sys_str_truncate (lw6sys_context_t * sys_context, char *str, int len)
 {
   if (strlen (str) > len)
     {
@@ -963,6 +981,7 @@ lw6sys_str_truncate (char *str, int len)
 /**
  * lw6sys_str_truncate_middle
  *
+ * @sys_context: global system context
  * @str: the string to truncate
  * @len: the new length
  * @middle: the string to add in the middle
@@ -975,7 +994,7 @@ lw6sys_str_truncate (char *str, int len)
  * Return value: none, @str pointed data modified in-place
  */
 void
-lw6sys_str_truncate_middle (char *str, int len, const char *middle)
+lw6sys_str_truncate_middle (lw6sys_context_t * sys_context, char *str, int len, const char *middle)
 {
   int orig_len = strlen (str);
 
@@ -1008,6 +1027,7 @@ lw6sys_str_truncate_middle (char *str, int len, const char *middle)
 /**
  * lw6sys_str_random
  *
+ * @sys_context: global system context
  * @len: the length of the random string to generate.
  *
  * Generates a random string, this is usefull for testing.
@@ -1015,15 +1035,15 @@ lw6sys_str_truncate_middle (char *str, int len, const char *middle)
  * Return value: newly allocated string
  */
 char *
-lw6sys_str_random (int len)
+lw6sys_str_random (lw6sys_context_t * sys_context, int len)
 {
   unsigned char *ret = NULL;
   int i = 0;
 
-  ret = (unsigned char *) LW6SYS_MALLOC (len + 1);
+  ret = (unsigned char *) LW6SYS_MALLOC (sys_context, len + 1);
   for (i = 0; i < len; ++i)
     {
-      ret[i] = lw6sys_random (254) + 1;
+      ret[i] = lw6sys_random (sys_context, 254) + 1;
     }
   ret[len] = 0;
 
@@ -1033,6 +1053,7 @@ lw6sys_str_random (int len)
 /**
  * lw6sys_str_random_words
  *
+ * @sys_context: global system context
  * @len: the length of the random string to generate.
  *
  * Generates a random string, this is usefull for testing.
@@ -1042,16 +1063,16 @@ lw6sys_str_random (int len)
  * Return value: newly allocated string
  */
 char *
-lw6sys_str_random_words (int len)
+lw6sys_str_random_words (lw6sys_context_t * sys_context, int len)
 {
   unsigned char *ret = NULL;
   int i = 0;
   int cat_len = strlen (_STR_RANDOM_WORDS);
 
-  ret = (unsigned char *) LW6SYS_MALLOC (len + 1);
+  ret = (unsigned char *) LW6SYS_MALLOC (sys_context, len + 1);
   for (i = 0; i < len; ++i)
     {
-      ret[i] = _STR_RANDOM_WORDS[lw6sys_random (cat_len)];
+      ret[i] = _STR_RANDOM_WORDS[lw6sys_random (sys_context, cat_len)];
     }
   ret[len] = 0;
 
@@ -1061,6 +1082,7 @@ lw6sys_str_random_words (int len)
 /**
  * lw6sys_str_random_word
  *
+ * @sys_context: global system context
  * @len: the length of the random string to generate.
  *
  * Generates a random string, this is usefull for testing.
@@ -1070,16 +1092,16 @@ lw6sys_str_random_words (int len)
  * Return value: newly allocated string
  */
 char *
-lw6sys_str_random_word (int len)
+lw6sys_str_random_word (lw6sys_context_t * sys_context, int len)
 {
   unsigned char *ret = NULL;
   int i = 0;
   int cat_len = strlen (_STR_RANDOM_WORD);
 
-  ret = (unsigned char *) LW6SYS_MALLOC (len + 1);
+  ret = (unsigned char *) LW6SYS_MALLOC (sys_context, len + 1);
   for (i = 0; i < len; ++i)
     {
-      ret[i] = _STR_RANDOM_WORD[lw6sys_random (cat_len)];
+      ret[i] = _STR_RANDOM_WORD[lw6sys_random (sys_context, cat_len)];
     }
   ret[len] = 0;
 
@@ -1089,14 +1111,13 @@ lw6sys_str_random_word (int len)
 static int
 _chr_is_text (char c)
 {
-  return (c >= 'a' && c <= 'z') || (c >= 'A' && c <= 'Z') || (c >= '0'
-							      && c <= '9')
-    || (strchr (_STR_BIN_TEXT_OTHER, c) != NULL);
+  return (c >= 'a' && c <= 'z') || (c >= 'A' && c <= 'Z') || (c >= '0' && c <= '9') || (strchr (_STR_BIN_TEXT_OTHER, c) != NULL);
 }
 
 /**
  * lw6sys_str_is_bin
  *
+ * @sys_context: global system context
  * @buf: the buffer to test
  * @len: the length of the buffer
  *
@@ -1106,7 +1127,7 @@ _chr_is_text (char c)
  * Return value: 1 if probably binary, 0 if probably text
  */
 int
-lw6sys_str_is_bin (const char *buf, int len)
+lw6sys_str_is_bin (lw6sys_context_t * sys_context, const char *buf, int len)
 {
   int ret = 0;
   int text_chars = 0;
