@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -31,6 +31,7 @@
 /**
  * lw6sys_stream_file_to_str
  *
+ * @sys_context: global system context
  * @f: file to get input from, typically stdin
  *
  * Will read file/stream and return it as a string. This is not
@@ -44,13 +45,13 @@
  * Return value: newly allocated string.
  */
 char *
-lw6sys_stream_file_to_str (FILE * f)
+lw6sys_stream_file_to_str (lw6sys_context_t * sys_context, FILE * f)
 {
   char *ret = NULL;
   int read = 0;
   int size = _MAX_FILE_SIZE;
 
-  ret = (char *) LW6SYS_MALLOC (size + 1);
+  ret = (char *) LW6SYS_MALLOC (sys_context, size + 1);
 
   if (ret)
     {
@@ -64,10 +65,8 @@ lw6sys_stream_file_to_str (FILE * f)
 	}
       else
 	{
-	  lw6sys_log (LW6SYS_LOG_WARNING,
-		      _x_ ("file too long, function \"%s\" can't handle it"),
-		      __FUNCTION__);
-	  LW6SYS_FREE (ret);
+	  lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("file too long, function \"%s\" can't handle it"), __FUNCTION__);
+	  LW6SYS_FREE (sys_context, ret);
 	  ret = NULL;
 	}
       if (ret)
@@ -82,6 +81,7 @@ lw6sys_stream_file_to_str (FILE * f)
 /**
  * lw6sys_stream_str_to_file
  *
+ * @sys_context: global system context
  * @f: file to receive the string
  * @str: the string to output
  *
@@ -91,7 +91,7 @@ lw6sys_stream_file_to_str (FILE * f)
  * Return value: none.
  */
 void
-lw6sys_stream_str_to_file (FILE * f, char *str)
+lw6sys_stream_str_to_file (lw6sys_context_t * sys_context, FILE * f, char *str)
 {
   fprintf (f, "%s", str);
 }
