@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -24,25 +24,34 @@
 #include "config.h"
 #endif // HAVE_CONFIG_H
 
+#include <errno.h>
+
 #include "sys.h"
 #include "sys-internal.h"
 
-static volatile int thread_create_counter = 0;
-static volatile int thread_join_counter = 0;
 static volatile u_int32_t seq_id = 0;
 
-static void
-thread_callback (void *thread_handler)
+/*
+ * Could have been declared as static as it is used
+ * nowhere but in thread-dedicated code, but it's nice
+ * to have this appear in call stacks when backtracing
+ * so we let it be a real symbol, even if it fundamentally
+ * remains private.
+ */
+void
+_lw6sys_thread_callback (void *thread_handler)
 {
-  _lw6sys_thread_handler_t *th;
-  th = (_lw6sys_thread_handler_t *) thread_handler;
-  struct timespec ts;
-
-  ts.tv_sec = _LW6SYS_PTHREAD_COND_TIMEDWAIT_SEC;
-  ts.tv_nsec = _LW6SYS_PTHREAD_COND_TIMEDWAIT_NSEC;
+  _lw6sys_thread_handler_t *th = (_lw6sys_thread_handler_t *) thread_handler;
 
   if (th)
     {
+      lw6sys_context_t *sys_context = th->sys_context;
+      struct timespec ts;
+      int yield_timeslice = 0;
+
+      ts.tv_sec = _LW6SYS_PTHREAD_COND_TIMEDWAIT_SEC;
+      ts.tv_nsec = _LW6SYS_PTHREAD_COND_TIMEDWAIT_NSEC;
+
 #ifndef LW6_MS_WINDOWS
 #ifdef LW6_GPROF
       /*
@@ -53,24 +62,22 @@ thread_callback (void *thread_handler)
        */
       if (setitimer (ITIMER_PROF, &th->itimer, NULL))
 	{
-	  lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("setitimer failed"));
+	  lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("setitimer failed"));
 	}
-#endif
-#endif
+#endif // LW6_GPROF
+#endif // LW6_MS_WINDOWS
 
       if (th->callback_join)
 	{
-	  lw6sys_log (LW6SYS_LOG_INFO, _x_ ("begin thread id=%u"), th->id);
+	  lw6sys_log (sys_context, LW6SYS_LOG_INFO, _x_ ("begin thread id=%u"), th->id);
 	}
       else
 	{
-	  lw6sys_log (LW6SYS_LOG_DEBUG,
-		      _x_ ("begin thread id=%u (fast mode, no join)"),
-		      th->id);
+	  lw6sys_log (sys_context, LW6SYS_LOG_DEBUG, _x_ ("begin thread id=%u (fast mode, no join)"), th->id);
 	}
       if (th->callback_func)
 	{
-	  th->callback_func (th->callback_data);
+	  th->callback_func (sys_context, th->callback_data);
 	}
       /*
        * callback is over, we signal it to the caller, if needed
@@ -84,10 +91,7 @@ thread_callback (void *thread_handler)
       else
 	{
 	  th->flag_callback_done = 1;
-	  lw6sys_log (LW6SYS_LOG_WARNING,
-		      _x_
-		      ("unable to lock internal thread mutex thread id=%u"),
-		      th->id);
+	  lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("unable to lock internal thread mutex thread id=%u"), th->id);
 	}
       /*
        * If callback_join is defined, we wait until the caller
@@ -105,46 +109,39 @@ thread_callback (void *thread_handler)
 	       * Now the caller is supposed to set "can_join"
 	       * to allow this thread to actually finish.
 	       */
-	      lw6sys_log (LW6SYS_LOG_DEBUG,
-			  _x_ ("waiting for can_join to be 1, thread id=%u"),
-			  th->id);
+	      lw6sys_log (sys_context, LW6SYS_LOG_DEBUG, _x_ ("waiting for can_join to be 1, thread id=%u"), th->id);
 	      if (!pthread_mutex_lock (&(th->mutex)))
 		{
-		  pthread_cond_timedwait (&(th->cond_can_join), &(th->mutex),
-					  &ts);
+		  yield_timeslice = (pthread_cond_timedwait (&(th->cond_can_join), &(th->mutex), &ts) == ETIMEDOUT);
 		  pthread_mutex_unlock (&(th->mutex));
+		  if (yield_timeslice)
+		    {
+		      lw6sys_idle (sys_context);
+		    }
 		}
 	      else
 		{
-		  lw6sys_log (LW6SYS_LOG_WARNING,
-			      _x_
-			      ("unable to lock internal thread mutex thread id=%u"),
-			      th->id);
+		  lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("unable to lock internal thread mutex thread id=%u"), th->id);
 		}
 	    }
-	  th->callback_join (th->callback_data);
+	  th->callback_join (sys_context, th->callback_data);
 	}
       if (th->callback_join)
 	{
-	  lw6sys_log (LW6SYS_LOG_INFO, _x_ ("end thread id=%u"), th->id);
+	  lw6sys_log (sys_context, LW6SYS_LOG_INFO, _x_ ("end thread id=%u"), th->id);
 	}
       else
 	{
-	  lw6sys_log (LW6SYS_LOG_DEBUG,
-		      _x_ ("end thread id=%u (fast mode, no join)"), th->id);
+	  lw6sys_log (sys_context, LW6SYS_LOG_DEBUG, _x_ ("end thread id=%u (fast mode, no join)"), th->id);
 	}
       pthread_exit (NULL);
     }
-  else
-    {
-      lw6sys_log (LW6SYS_LOG_WARNING,
-		  _x_ ("can't call thread_callback on NULL thread_handler"));
-    }
 }
 
 /**
  * lw6sys_thread_create
  *
+ * @sys_context: global system context
  * @callback_func: the main callback, the function that will run the thread
  * @callback_join: function which will be called when joining, at the end
  * @callback_data: data which will be passed to the callback
@@ -160,42 +157,38 @@ thread_callback (void *thread_handler)
  * Return value: an opaque pointer on the thread. Can be NULL if failed.
  */
 lw6sys_thread_handler_t *
-lw6sys_thread_create (lw6sys_thread_callback_func_t callback_func,
-		      lw6sys_thread_callback_func_t callback_join,
-		      void *callback_data)
+lw6sys_thread_create (lw6sys_context_t * sys_context,
+		      lw6sys_thread_callback_func_t callback_func, lw6sys_thread_callback_func_t callback_join, void *callback_data)
 {
+  _lw6sys_global_t *global = &(((_lw6sys_context_t *) sys_context)->global);
   _lw6sys_thread_handler_t *thread_handler = NULL;
   int thread_ok = 0;
   int mutex_ok = 0;
   int cond_callback_done_ok = 0;
   int cond_can_join_ok = 0;
 
-  thread_handler =
-    (_lw6sys_thread_handler_t *)
-    LW6SYS_CALLOC (sizeof (_lw6sys_thread_handler_t));
+  thread_handler = (_lw6sys_thread_handler_t *) LW6SYS_CALLOC (sys_context, sizeof (_lw6sys_thread_handler_t));
   if (thread_handler)
     {
       // callback_done & the rest already set to 0, CALLOC is important
-      ++thread_create_counter;
+      ++(global->thread_create_counter);
       thread_handler->id = 0;
       while (!(thread_handler->id))
 	{
 	  thread_handler->id = ++seq_id;
 	}
+      thread_handler->sys_context = sys_context;
       thread_handler->callback_func = callback_func;
       thread_handler->callback_join = callback_join;
       thread_handler->callback_data = callback_data;
 
       if (thread_handler->callback_join)
 	{
-	  lw6sys_log (LW6SYS_LOG_INFO, _x_ ("creating thread id=%u"),
-		      thread_handler->id);
+	  lw6sys_log (sys_context, LW6SYS_LOG_INFO, _x_ ("creating thread id=%u"), thread_handler->id);
 	}
       else
 	{
-	  lw6sys_log (LW6SYS_LOG_DEBUG,
-		      _x_ ("creating thread id=%u (fast mode, no join)"),
-		      thread_handler->id);
+	  lw6sys_log (sys_context, LW6SYS_LOG_DEBUG, _x_ ("creating thread id=%u (fast mode, no join)"), thread_handler->id);
 	}
 
 #ifndef LW6_MS_WINDOWS
@@ -208,7 +201,7 @@ lw6sys_thread_create (lw6sys_thread_callback_func_t callback_func,
        */
       if (getitimer (ITIMER_PROF, &thread_handler->itimer))
 	{
-	  lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("getitimer failed"));
+	  lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("getitimer failed"));
 	}
 #endif
 #endif
@@ -216,16 +209,13 @@ lw6sys_thread_create (lw6sys_thread_callback_func_t callback_func,
       if (!pthread_mutex_init (&(thread_handler->mutex), NULL))
 	{
 	  mutex_ok = 1;
-	  if (!pthread_cond_init
-	      (&(thread_handler->cond_callback_done), NULL))
+	  if (!pthread_cond_init (&(thread_handler->cond_callback_done), NULL))
 	    {
 	      cond_callback_done_ok = 1;
 	      if (!pthread_cond_init (&(thread_handler->cond_can_join), NULL))
 		{
 		  cond_can_join_ok = 1;
-		  if (!pthread_create (&(thread_handler->thread), NULL,
-				       (void *) thread_callback,
-				       (void *) thread_handler))
+		  if (!pthread_create (&(thread_handler->thread), NULL, (void *) _lw6sys_thread_callback, (void *) thread_handler))
 		    {
 		      thread_ok = 1;
 		    }
@@ -235,7 +225,7 @@ lw6sys_thread_create (lw6sys_thread_callback_func_t callback_func,
 
       if (!thread_ok)
 	{
-	  lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("can't start thread"));
+	  lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("can't start thread"));
 	  if (mutex_ok)
 	    {
 	      pthread_mutex_destroy (&(thread_handler->mutex));
@@ -249,14 +239,14 @@ lw6sys_thread_create (lw6sys_thread_callback_func_t callback_func,
 	      pthread_cond_destroy (&(thread_handler->cond_can_join));
 	    }
 	  /*
-	   * Better do a thread_create_counter-- here, this way we
+	   * Better do a global->thread_create_counter-- here, this way we
 	   * can use a "very probably" atomic operation to increase
 	   * it *before* thread creation, ensuring the id is properly
 	   * set. Not perfect, but better and simpler than many other
 	   * "solutions".
 	   */
-	  thread_create_counter--;
-	  LW6SYS_FREE (thread_handler);
+	  --(global->thread_create_counter);
+	  LW6SYS_FREE (sys_context, thread_handler);
 	  thread_handler = NULL;
 	}
     }
@@ -267,6 +257,7 @@ lw6sys_thread_create (lw6sys_thread_callback_func_t callback_func,
 /**
  * lw6sys_thread_is_callback_done
  *
+ * @sys_context: global system context
  * @thread_handler: thread to work on
  *
  * Tells wether the callback is done, that is to say, wether the
@@ -275,7 +266,7 @@ lw6sys_thread_create (lw6sys_thread_callback_func_t callback_func,
  * Return value: 1 if done, else 0.
  */
 int
-lw6sys_thread_is_callback_done (lw6sys_thread_handler_t * thread_handler)
+lw6sys_thread_is_callback_done (lw6sys_context_t * sys_context, lw6sys_thread_handler_t * thread_handler)
 {
   int ret = 0;
 
@@ -288,8 +279,7 @@ lw6sys_thread_is_callback_done (lw6sys_thread_handler_t * thread_handler)
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING,
-		  _x_ ("can't call is_callback_done on NULL thread_handler"));
+      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("can't call is_callback_done on NULL thread_handler"));
     }
 
   return ret;
@@ -298,6 +288,7 @@ lw6sys_thread_is_callback_done (lw6sys_thread_handler_t * thread_handler)
 /**
  * lw6sys_thread_wait_callback_done
  *
+ * @sys_context: global system context
  * @thread_handler: thread to work on
  *
  * Waits until the callback of the thread is done, this does not
@@ -308,7 +299,7 @@ lw6sys_thread_is_callback_done (lw6sys_thread_handler_t * thread_handler)
  * Return value: 1 if done, 0 on error
  */
 int
-lw6sys_thread_wait_callback_done (lw6sys_thread_handler_t * thread_handler)
+lw6sys_thread_wait_callback_done (lw6sys_context_t * sys_context, lw6sys_thread_handler_t * thread_handler)
 {
   int ret = 0;
   struct timespec ts;
@@ -325,16 +316,12 @@ lw6sys_thread_wait_callback_done (lw6sys_thread_handler_t * thread_handler)
 	{
 	  if (!pthread_mutex_lock (&(th->mutex)))
 	    {
-	      pthread_cond_timedwait (&(th->cond_callback_done), &(th->mutex),
-				      &ts);
+	      pthread_cond_timedwait (&(th->cond_callback_done), &(th->mutex), &ts);
 	      pthread_mutex_unlock (&(th->mutex));
 	    }
 	  else
 	    {
-	      lw6sys_log (LW6SYS_LOG_WARNING,
-			  _x_
-			  ("unable to lock internal thread mutex thread id=%u"),
-			  th->id);
+	      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("unable to lock internal thread mutex thread id=%u"), th->id);
 	    }
 	}
 
@@ -342,9 +329,7 @@ lw6sys_thread_wait_callback_done (lw6sys_thread_handler_t * thread_handler)
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING,
-		  _x_
-		  ("can't call wait_callback_done on NULL thread_handler"));
+      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("can't call wait_callback_done on NULL thread_handler"));
     }
 
   return ret;
@@ -353,6 +338,7 @@ lw6sys_thread_wait_callback_done (lw6sys_thread_handler_t * thread_handler)
 /**
  * lw6sys_thread_get_id
  *
+ * @sys_context: global system context
  * @thread_handler: thread to query
  *
  * Returns the id of the thread, this is an internal value,
@@ -361,7 +347,7 @@ lw6sys_thread_wait_callback_done (lw6sys_thread_handler_t * thread_handler)
  * Return value: the id, should be >0.
  */
 int
-lw6sys_thread_get_id (lw6sys_thread_handler_t * thread_handler)
+lw6sys_thread_get_id (lw6sys_context_t * sys_context, lw6sys_thread_handler_t * thread_handler)
 {
   int ret = 0;
 
@@ -374,8 +360,7 @@ lw6sys_thread_get_id (lw6sys_thread_handler_t * thread_handler)
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING,
-		  _x_ ("can't call get_id on NULL thread_handler"));
+      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("can't call get_id on NULL thread_handler"));
     }
 
   return ret;
@@ -384,6 +369,7 @@ lw6sys_thread_get_id (lw6sys_thread_handler_t * thread_handler)
 /**
  * lw6sys_thread_get_data
  *
+ * @sys_context: global system context
  * @thread_handler: thread to query
  *
  * Returns the data associated to the thread, that is, the pointer
@@ -392,7 +378,7 @@ lw6sys_thread_get_id (lw6sys_thread_handler_t * thread_handler)
  * Return value: a pointer.
  */
 void *
-lw6sys_thread_get_data (lw6sys_thread_handler_t * thread_handler)
+lw6sys_thread_get_data (lw6sys_context_t * sys_context, lw6sys_thread_handler_t * thread_handler)
 {
   void *ret = NULL;
 
@@ -405,8 +391,7 @@ lw6sys_thread_get_data (lw6sys_thread_handler_t * thread_handler)
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING,
-		  _x_ ("can't call get_data on NULL thread_handler"));
+      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("can't call get_data on NULL thread_handler"));
     }
 
   return ret;
@@ -415,6 +400,7 @@ lw6sys_thread_get_data (lw6sys_thread_handler_t * thread_handler)
 /**
  * lw6sys_thread_join
  *
+ * @sys_context: global system context
  * @thread_handler: thread to end
  *
  * Joins the thread, that's to say wait until the thread is over,
@@ -425,8 +411,10 @@ lw6sys_thread_get_data (lw6sys_thread_handler_t * thread_handler)
  * Return value: none.
  */
 void
-lw6sys_thread_join (lw6sys_thread_handler_t * thread_handler)
+lw6sys_thread_join (lw6sys_context_t * sys_context, lw6sys_thread_handler_t * thread_handler)
 {
+  _lw6sys_global_t *global = &(((_lw6sys_context_t *) sys_context)->global);
+
   if (thread_handler)
     {
       _lw6sys_thread_handler_t *th;
@@ -434,13 +422,11 @@ lw6sys_thread_join (lw6sys_thread_handler_t * thread_handler)
 
       if (th->callback_join)
 	{
-	  lw6sys_log (LW6SYS_LOG_INFO, _x_ ("joining thread id=%u"), th->id);
+	  lw6sys_log (sys_context, LW6SYS_LOG_INFO, _x_ ("joining thread id=%u"), th->id);
 	}
       else
 	{
-	  lw6sys_log (LW6SYS_LOG_DEBUG,
-		      _x_ ("joining thread id=%u (fast mode, no join)"),
-		      th->id);
+	  lw6sys_log (sys_context, LW6SYS_LOG_DEBUG, _x_ ("joining thread id=%u (fast mode, no join)"), th->id);
 	}
 
       if (!pthread_mutex_lock (&(th->mutex)))
@@ -452,10 +438,7 @@ lw6sys_thread_join (lw6sys_thread_handler_t * thread_handler)
       else
 	{
 	  th->flag_can_join = 1;
-	  lw6sys_log (LW6SYS_LOG_WARNING,
-		      _x_
-		      ("unable to lock internal thread mutex thread id=%u"),
-		      th->id);
+	  lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("unable to lock internal thread mutex thread id=%u"), th->id);
 	}
 
       if (!pthread_join (th->thread, NULL))
@@ -469,56 +452,61 @@ lw6sys_thread_join (lw6sys_thread_handler_t * thread_handler)
 	    }
 	  else
 	    {
-	      lw6sys_log (LW6SYS_LOG_WARNING,
-			  _x_
-			  ("unable to lock internal thread mutex thread id=%u"),
-			  th->id);
+	      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("unable to lock internal thread mutex thread id=%u"), th->id);
 	    }
-	  LW6SYS_FREE (th);
-	  thread_join_counter++;
+	  LW6SYS_FREE (sys_context, th);
+	  ++(global->thread_join_counter);
 	}
       else
 	{
-	  lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("can't join thread id=%u"),
-		      th->id);
+	  lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("can't join thread id=%u"), th->id);
 	}
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING,
-		  _x_ ("can't call join on NULL thread_handler"));
+      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("can't call join on NULL thread_handler"));
     }
 }
 
 /**
  * lw6sys_get_thread_create_count
  *
+ * @sys_context: global system context
+ *
  * Utility function used to check how many threads where created and joined.
  *
  * Return value: how many threads were created.
  */
 int
-lw6sys_get_thread_create_count ()
+lw6sys_get_thread_create_count (lw6sys_context_t * sys_context)
 {
-  return thread_create_counter;
+  _lw6sys_global_t *global = &(((_lw6sys_context_t *) sys_context)->global);
+
+  return global->thread_create_counter;
 }
 
 /**
  * lw6sys_get_thread_join_count
  *
+ * @sys_context: global system context
+ *
  * Utility function used to check how many threads where created and joined.
  *
  * Return value: how many threads were joined.
  */
 int
-lw6sys_get_thread_join_count ()
+lw6sys_get_thread_join_count (lw6sys_context_t * sys_context)
 {
-  return thread_join_counter;
+  _lw6sys_global_t *global = &(((_lw6sys_context_t *) sys_context)->global);
+
+  return global->thread_join_counter;
 }
 
 /**
  * lw6sys_check_thread_count
  *
+ * @sys_context: global system context
+ *
  * Utility function used to check how many threads where created and joined.
  * This one will compare the results of @lw6sys_get_thread_create_count
  * and @lw6sys_get_thread_join_count.
@@ -526,17 +514,18 @@ lw6sys_get_thread_join_count ()
  * Return value: 1 if both are equals, 0 if not (error...).
  */
 int
-lw6sys_check_thread_count ()
+lw6sys_check_thread_count (lw6sys_context_t * sys_context)
 {
+  _lw6sys_global_t *global = &(((_lw6sys_context_t *) sys_context)->global);
   int ret = 1;
 
-  if (thread_create_counter != thread_join_counter)
+  if (global->thread_create_counter != global->thread_join_counter)
     {
       ret = 0;
-      lw6sys_log (LW6SYS_LOG_WARNING,
+      lw6sys_log (sys_context, LW6SYS_LOG_WARNING,
 		  _x_
 		  ("possible thread problem, %d threads have been started, but only %d threads have been joined"),
-		  thread_create_counter, thread_join_counter);
+		  global->thread_create_counter, global->thread_join_counter);
     }
 
   return ret;
