@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -33,7 +33,6 @@
 #include <unistd.h>
 #endif // HAVE_UNISTD_H
 
-
 #include "sys.h"
 #include "sys-internal.h"
 
@@ -46,6 +45,8 @@ static int64_t timestamp_0 = 0;
 /**
  * lw6sys_get_timestamp
  *
+ * @sys_context: global system context
+ *
  * Returns a 64-bit timestamp, for general purpose. The unit is milliseconds,
  * should return the number of milliseconds since EPOCH. Don't use this
  * for accurate date handling, but rather to technical stamp events.
@@ -53,11 +54,11 @@ static int64_t timestamp_0 = 0;
  * Return value: the timestamp.
  */
 int64_t
-lw6sys_get_timestamp ()
+lw6sys_get_timestamp (lw6sys_context_t * sys_context)
 {
   int64_t ret = 0L;
 
-  ret = lw6sys_get_uptime () + timestamp_0;
+  ret = lw6sys_get_uptime (sys_context) + timestamp_0;
 
   return ret;
 }
@@ -65,13 +66,15 @@ lw6sys_get_timestamp ()
 /**
  * lw6sys_get_uptime
  *
+ * @sys_context: global system context
+ *
  * Returns the number of milliseconds since program was started. Milliseconds
  * are often referred to as 'ticks'.
  *
  * Return value: the number of milliseconds (64-bit)
  */
 int64_t
-lw6sys_get_uptime ()
+lw6sys_get_uptime (lw6sys_context_t * sys_context)
 {
   int64_t ret = 0;
   static int64_t last_ret = 0;
@@ -88,10 +91,7 @@ lw6sys_get_uptime ()
 
   memset (&now, 0, sizeof (struct timeval));
   gettimeofday (&now, NULL);
-  ret =
-    ((int64_t) (now.tv_sec)) * LW6SYS_TICKS_PER_SEC +
-    ((int64_t) (now.tv_usec)) / (1000000 / LW6SYS_TICKS_PER_SEC) -
-    timestamp_0;
+  ret = ((int64_t) (now.tv_sec)) * LW6SYS_TICKS_PER_SEC + ((int64_t) (now.tv_usec)) / (1000000 / LW6SYS_TICKS_PER_SEC) - timestamp_0;
 
   if (ret < last_ret)
     {
@@ -112,6 +112,8 @@ lw6sys_get_uptime ()
 /**
  * lw6sys_get_cycle
  *
+ * @sys_context: global system context
+ *
  * Returns a 32-bit timestamp, which is likely to "loop" and have twice
  * the same value during a single program execution. The idea here is
  * just to provide a 32-bit value, not too big, for animation purposes.
@@ -127,18 +129,19 @@ lw6sys_get_uptime ()
  * Return value: the cycle value, a 20-bit integer.
  */
 int32_t
-lw6sys_get_cycle ()
+lw6sys_get_cycle (lw6sys_context_t * sys_context)
 {
   int64_t ret = 0L;
 
-  ret = lw6sys_get_uptime () & _TIMER_CYCLE_MASK;
+  ret = lw6sys_get_uptime (sys_context) & _TIMER_CYCLE_MASK;
 
   return ret;
 }
 
 /**
- * lw6sys_timer_updqte
+ * lw6sys_timer_update
  *
+ * @sys_context: global system context
  * @timestamp: the timestamp in msec since EPOCH (output), can be NULL
  * @uptime: the uptime in msec since startup (output), can be NULL
  * @cycle: a 20-bit value for animation purpose.
@@ -148,11 +151,11 @@ lw6sys_get_cycle ()
  * Return value: none (parameters modified).
  */
 void
-lw6sys_timer_update (int64_t * timestamp, int64_t * uptime, int32_t * cycle)
+lw6sys_timer_update (lw6sys_context_t * sys_context, int64_t * timestamp, int64_t * uptime, int32_t * cycle)
 {
   int64_t tmp = 0;
 
-  tmp = lw6sys_get_uptime ();
+  tmp = lw6sys_get_uptime (sys_context);
 
   if (uptime)
     {
@@ -171,6 +174,7 @@ lw6sys_timer_update (int64_t * timestamp, int64_t * uptime, int32_t * cycle)
 /**
  * lw6sys_sleep
  *
+ * @sys_context: global system context
  * @seconds: the number of seconds to wait, fractions allowed
  *
  * Will sleep for the given amount of seconds. Same as @lw6sys_delay
@@ -178,14 +182,15 @@ lw6sys_timer_update (int64_t * timestamp, int64_t * uptime, int32_t * cycle)
  * of ticks.
  */
 void
-lw6sys_sleep (float seconds)
+lw6sys_sleep (lw6sys_context_t * sys_context, float seconds)
 {
-  lw6sys_delay ((int) (seconds * ((float) LW6SYS_TICKS_PER_SEC)));
+  lw6sys_delay (sys_context, (int) (seconds * ((float) LW6SYS_TICKS_PER_SEC)));
 }
 
 /**
  * lw6sys_delay
  *
+ * @sys_context: global system context
  * @msec: the number of milliseconds (ticks) to wait
  *
  * Will sleep for the given amount of seconds. Provides accurate timing
@@ -198,7 +203,7 @@ lw6sys_sleep (float seconds)
  * 100% of the CPU for nothing.
  */
 void
-lw6sys_delay (int msec)
+lw6sys_delay (lw6sys_context_t * sys_context, int msec)
 {
   if (msec > 0)
     {
@@ -228,6 +233,8 @@ lw6sys_delay (int msec)
 /**
  * lw6sys_idle
  *
+ * @sys_context: global system context
+ *
  * Will sleep for a minimal amount of time, just giving the OS a chance
  * to let other threads/processes execute themselves. This can make
  * a big difference in polling loops between a process that eats 100% CPU
@@ -235,44 +242,48 @@ lw6sys_delay (int msec)
  * of ticks.
  */
 void
-lw6sys_idle ()
+lw6sys_idle (lw6sys_context_t * sys_context)
 {
-  lw6sys_delay (LW6SYS_SLEEP_DELAY);
+  lw6sys_delay (sys_context, LW6SYS_SLEEP_DELAY);
 }
 
 /**
  * lw6sys_snooze
  *
+ * @sys_context: global system context
+ *
  * Will sleep for some time, like @lw6sys_idle, except it's a "longer"
  * time, use this when you don't really care about reactivity but are
  * more concerned about saving CPU, not running uselessly the same
  * polling code.
  */
 void
-lw6sys_snooze ()
+lw6sys_snooze (lw6sys_context_t * sys_context)
 {
-  lw6sys_delay (LW6SYS_SNOOZE_DELAY);
+  lw6sys_delay (sys_context, LW6SYS_SNOOZE_DELAY);
 }
 
 /**
  * lw6sys_time_init
  *
+ * @sys_context: global system context
+ *
  * Global initializations required to handle time properly.
  */
 void
-lw6sys_time_init ()
+lw6sys_time_init (lw6sys_context_t * sys_context)
 {
   struct timeval now;
 
   memset (&now, 0, sizeof (struct timeval));
   gettimeofday (&now, NULL);
-  timestamp_0 =
-    ((int64_t) (now.tv_sec)) * 1000L + ((int64_t) (now.tv_usec)) / 1000L;
+  timestamp_0 = ((int64_t) (now.tv_sec)) * 1000L + ((int64_t) (now.tv_usec)) / 1000L;
 }
 
 /**
  * lw6sys_date_rfc1123
  *
+ * @sys_context: global system context
  * @seconds_from_now: an offset to add to current time
  *
  * Gives the date according to RFC1123, this is typically
@@ -281,7 +292,7 @@ lw6sys_time_init ()
  * Return value: newly allocated string.
  */
 char *
-lw6sys_date_rfc1123 (int seconds_from_now)
+lw6sys_date_rfc1123 (lw6sys_context_t * sys_context, int seconds_from_now)
 {
   char *ret = NULL;
   time_t now;
@@ -293,7 +304,7 @@ lw6sys_date_rfc1123 (int seconds_from_now)
   struct tm *tm_ptr;
   int strflen;
 
-  ret = (char *) LW6SYS_CALLOC (_RFC1123_SIZE + 1);	// 32 should even be enough
+  ret = (char *) LW6SYS_CALLOC (sys_context, _RFC1123_SIZE + 1);	// 32 should even be enough
 
   locale = setlocale (LC_TIME, NULL);
   if (locale)
@@ -303,12 +314,12 @@ lw6sys_date_rfc1123 (int seconds_from_now)
        * otherwise the content pointed by *locale
        * might change dynamically when calling setlocale
        */
-      old_locale = lw6sys_str_copy (locale);
+      old_locale = lw6sys_str_copy (sys_context, locale);
 
       setlocale (LC_TIME, "POSIX");
 
-      old_tz = lw6sys_getenv ("TZ");
-      lw6sys_setenv ("TZ", "GMT");
+      old_tz = lw6sys_getenv (sys_context, "TZ");
+      lw6sys_setenv (sys_context, "TZ", "GMT");
       tzset ();
 
       time (&now);
@@ -325,23 +336,21 @@ lw6sys_date_rfc1123 (int seconds_from_now)
       tm_ptr = &tm;
 #endif // LW6_MS_WINDOWS
       // http://www.gta.igs.net/~hwt/rfcdate.html
-      strflen =
-	strftime (ret, _RFC1123_SIZE, "%a, %d %b %Y %H:%M:%S +0000", tm_ptr);
+      strflen = strftime (ret, _RFC1123_SIZE, "%a, %d %b %Y %H:%M:%S +0000", tm_ptr);
       if (strflen >= _RFC1123_SIZE)
 	{
-	  lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("buffer exceeded %d>=%d"),
-		      strflen, _RFC1123_SIZE);
+	  lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("buffer exceeded %d>=%d"), strflen, _RFC1123_SIZE);
 	}
       // called with old_tz=NULL, will unset
-      lw6sys_setenv ("TZ", old_tz);
+      lw6sys_setenv (sys_context, "TZ", old_tz);
       if (old_locale)
 	{
 	  setlocale (LC_TIME, old_locale);
-	  LW6SYS_FREE (old_locale);
+	  LW6SYS_FREE (sys_context, old_locale);
 	}
       if (old_tz)
 	{
-	  LW6SYS_FREE (old_tz);
+	  LW6SYS_FREE (sys_context, old_tz);
 	}
     }
 
@@ -351,13 +360,15 @@ lw6sys_date_rfc1123 (int seconds_from_now)
 /**
  * lw6sys_date_clf
  *
+ * @sys_context: global system context
+ *
  * Gives the date in a format which is compatible with Apache CLF
  * Common Log Format.
  *
  * Return value: newly allocated string.
  */
 char *
-lw6sys_date_clf ()
+lw6sys_date_clf (lw6sys_context_t * sys_context)
 {
   char *ret = NULL;
   time_t now;
@@ -367,7 +378,7 @@ lw6sys_date_clf ()
   struct tm *tm_ptr;
   int strflen;
 
-  ret = (char *) LW6SYS_CALLOC (_CLF_SIZE + 1);
+  ret = (char *) LW6SYS_CALLOC (sys_context, _CLF_SIZE + 1);
 
   locale = setlocale (LC_TIME, NULL);
   if (locale)
@@ -377,7 +388,7 @@ lw6sys_date_clf ()
        * otherwise the content pointed by *locale
        * might change dynamically when calling setlocale
        */
-      old_locale = lw6sys_str_copy (locale);
+      old_locale = lw6sys_str_copy (sys_context, locale);
 
       setlocale (LC_TIME, "C");
 
@@ -397,13 +408,12 @@ lw6sys_date_clf ()
       strflen = strftime (ret, _CLF_SIZE, "%d/%b/%Y:%H:%M:%S %z", tm_ptr);
       if (strflen >= _CLF_SIZE)
 	{
-	  lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("buffer exceeded %d>=%d"),
-		      strflen, _CLF_SIZE);
+	  lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("buffer exceeded %d>=%d"), strflen, _CLF_SIZE);
 	}
       if (old_locale)
 	{
 	  setlocale (LC_TIME, old_locale);
-	  LW6SYS_FREE (old_locale);
+	  LW6SYS_FREE (sys_context, old_locale);
 	}
     }
 
@@ -413,6 +423,7 @@ lw6sys_date_clf ()
 /**
  * lw6sys_readable_uptimew
  *
+ * @sys_context: global system context
  * @timestamp_delta: the duration to show, in msec
  *
  * Returns a readable form of an uptime, typically 1d 12:34:06
@@ -422,7 +433,7 @@ lw6sys_date_clf ()
  * Return value: newly allocated string
  */
 char *
-lw6sys_readable_uptime (int64_t timestamp_delta)
+lw6sys_readable_uptime (lw6sys_context_t * sys_context, int64_t timestamp_delta)
 {
   char *ret = NULL;
   int delta;
@@ -438,13 +449,11 @@ lw6sys_readable_uptime (int64_t timestamp_delta)
   days = (delta / (3600 * 24));
   if (days > 0)
     {
-      ret =
-	lw6sys_new_sprintf ("%dd %d:%02d:%02d", days, hours, minutes,
-			    seconds);
+      ret = lw6sys_new_sprintf (sys_context, "%dd %d:%02d:%02d", days, hours, minutes, seconds);
     }
   else
     {
-      ret = lw6sys_new_sprintf ("%d:%02d:%02d", hours, minutes, seconds);
+      ret = lw6sys_new_sprintf (sys_context, "%d:%02d:%02d", hours, minutes, seconds);
     }
 
   return ret;
