@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -29,58 +29,56 @@
 #include "tsk.h"
 #include "tsk-internal.h"
 
-#define LOADER_LOCK loader_lock (__FILE__,__LINE__,__FUNCTION__,loader_data)
-#define LOADER_UNLOCK loader_unlock (__FILE__,__LINE__,__FUNCTION__,loader_data)
+#define _LOADER_LOCK(SYS_CONTEXT) _loader_lock ((SYS_CONTEXT),__FILE__,__LINE__,__FUNCTION__,loader_data)
+#define _LOADER_UNLOCK(SYS_CONTEXT) _loader_unlock ((SYS_CONTEXT),__FILE__,__LINE__,__FUNCTION__,loader_data)
 
 static void
-loader_lock (char *file, int line, const char *func,
-	     _lw6tsk_loader_data_t * loader_data)
+_loader_lock (lw6sys_context_t * sys_context, char *file, int line, const char *func, _lw6tsk_loader_data_t * loader_data)
 {
   /*
    * Could put some log command here to debug
    */
-  lw6sys_mutex_lock (loader_data->mutex);
+  LW6SYS_MUTEX_LOCK (sys_context, loader_data->mutex);
   /*
    * Could put some log command here to debug
    */
 }
 
 static void
-loader_unlock (char *file, int line, const char *func,
-	       _lw6tsk_loader_data_t * loader_data)
+_loader_unlock (lw6sys_context_t * sys_context, char *file, int line, const char *func, _lw6tsk_loader_data_t * loader_data)
 {
   /*
    * Could put some log command here to debug
    */
-  lw6sys_mutex_unlock (loader_data->mutex);
+  LW6SYS_MUTEX_UNLOCK (sys_context, loader_data->mutex);
 }
 
 static void
-stage1_clear_request (_lw6tsk_loader_stage1_t * stage1)
+_stage1_clear_request (lw6sys_context_t * sys_context, _lw6tsk_loader_stage1_t * stage1)
 {
   if (stage1->map_path)
     {
-      LW6SYS_FREE (stage1->map_path);
+      LW6SYS_FREE (sys_context, stage1->map_path);
       stage1->map_path = NULL;
     }
   if (stage1->relative_path)
     {
-      LW6SYS_FREE (stage1->relative_path);
+      LW6SYS_FREE (sys_context, stage1->relative_path);
       stage1->relative_path = NULL;
     }
   if (stage1->default_param)
     {
-      lw6sys_assoc_free (stage1->default_param);
+      lw6sys_assoc_free (sys_context, stage1->default_param);
       stage1->default_param = NULL;
     }
   if (stage1->forced_param)
     {
-      lw6sys_assoc_free (stage1->forced_param);
+      lw6sys_assoc_free (sys_context, stage1->forced_param);
       stage1->forced_param = NULL;
     }
   if (stage1->seed)
     {
-      LW6SYS_FREE (stage1->seed);
+      LW6SYS_FREE (sys_context, stage1->seed);
       stage1->seed = NULL;
     }
   stage1->display_w = 0;
@@ -88,70 +86,70 @@ stage1_clear_request (_lw6tsk_loader_stage1_t * stage1)
 }
 
 static void
-stage1_clear_response (_lw6tsk_loader_stage1_t * stage1)
+_stage1_clear_response (lw6sys_context_t * sys_context, _lw6tsk_loader_stage1_t * stage1)
 {
   if (stage1->level)
     {
-      lw6map_free (stage1->level);
+      lw6map_free (sys_context, stage1->level);
       stage1->level = NULL;
     }
 }
 
 static void
-stage1_clear (_lw6tsk_loader_stage1_t * stage1)
+_stage1_clear (lw6sys_context_t * sys_context, _lw6tsk_loader_stage1_t * stage1)
 {
-  stage1_clear_request (stage1);
-  stage1_clear_response (stage1);
+  _stage1_clear_request (sys_context, stage1);
+  _stage1_clear_response (sys_context, stage1);
   memset (stage1, 0, sizeof (_lw6tsk_loader_stage1_t));
 }
 
 static void
-stage2_clear_request (_lw6tsk_loader_stage2_t * stage2)
+_stage2_clear_request (lw6sys_context_t * sys_context, _lw6tsk_loader_stage2_t * stage2)
 {
   if (stage2->src)
     {
-      lw6map_free (stage2->src);
+      lw6map_free (sys_context, stage2->src);
       stage2->src = NULL;
     }
 }
 
 static void
-stage2_clear_response (_lw6tsk_loader_stage2_t * stage2)
+_stage2_clear_response (lw6sys_context_t * sys_context, _lw6tsk_loader_stage2_t * stage2)
 {
   if (stage2->game_state)
     {
-      lw6ker_game_state_free (stage2->game_state);
+      lw6ker_game_state_free (sys_context, stage2->game_state);
       stage2->game_state = NULL;
     }
   if (stage2->game_struct)
     {
-      lw6ker_game_struct_free (stage2->game_struct);
+      lw6ker_game_struct_free (sys_context, stage2->game_struct);
       stage2->game_struct = NULL;
     }
   if (stage2->level)
     {
-      lw6map_free (stage2->level);
+      lw6map_free (sys_context, stage2->level);
       stage2->level = NULL;
     }
 }
 
 static void
-stage2_clear (_lw6tsk_loader_stage2_t * stage2)
+_stage2_clear (lw6sys_context_t * sys_context, _lw6tsk_loader_stage2_t * stage2)
 {
-  stage2_clear_request (stage2);
-  stage2_clear_response (stage2);
+  _stage2_clear_request (sys_context, stage2);
+  _stage2_clear_response (sys_context, stage2);
   memset (stage2, 0, sizeof (_lw6tsk_loader_stage2_t));
 }
 
 static void
-clear (_lw6tsk_loader_data_t * loader_data)
+_clear (lw6sys_context_t * sys_context, _lw6tsk_loader_data_t * loader_data)
 {
-  stage2_clear (&(loader_data->stage2));
-  stage1_clear (&(loader_data->stage1));
+  _stage2_clear (sys_context, &(loader_data->stage2));
+  _stage1_clear (sys_context, &(loader_data->stage1));
 }
 
 static void
-stage1 (_lw6tsk_loader_data_t * loader_data)
+_stage1 (lw6sys_context_t * sys_context, _lw6tsk_loader_data_t * loader_data)
 {
   int request_number = 0;
   char *map_path = NULL;
@@ -177,7 +175,7 @@ stage1 (_lw6tsk_loader_data_t * loader_data)
       progress.value = &dummy;
     }
 
-  LOADER_LOCK;
+  _LOADER_LOCK (sys_context);
   request_number = loader_data->request_number;
 
   /*
@@ -185,26 +183,20 @@ stage1 (_lw6tsk_loader_data_t * loader_data)
    */
   if (loader_data->stage1.map_path && loader_data->stage1.relative_path)
     {
-      lw6sys_log (LW6SYS_LOG_INFO,
-		  _x_
-		  ("async load stage1 using ldr, request_number %d, level \"%s\""),
-		  request_number, loader_data->stage1.relative_path);
+      lw6sys_log (sys_context, LW6SYS_LOG_INFO,
+		  _x_ ("async load stage1 using ldr, request_number %d, level \"%s\""), request_number, loader_data->stage1.relative_path);
 
       (*(progress.value)) = _LW6TSK_LOADER_PROGRESS_STAGE1_BEGIN;
-      map_path = lw6sys_str_copy (loader_data->stage1.map_path);
-      relative_path = lw6sys_str_copy (loader_data->stage1.relative_path);
-      default_param =
-	lw6sys_assoc_dup (loader_data->stage1.default_param,
-			  (lw6sys_dup_func_t) lw6sys_str_copy);
-      forced_param =
-	lw6sys_assoc_dup (loader_data->stage1.forced_param,
-			  (lw6sys_dup_func_t) lw6sys_str_copy);
+      map_path = lw6sys_str_copy (sys_context, loader_data->stage1.map_path);
+      relative_path = lw6sys_str_copy (sys_context, loader_data->stage1.relative_path);
+      default_param = lw6sys_assoc_dup (sys_context, loader_data->stage1.default_param, (lw6sys_dup_func_t) lw6sys_str_copy);
+      forced_param = lw6sys_assoc_dup (sys_context, loader_data->stage1.forced_param, (lw6sys_dup_func_t) lw6sys_str_copy);
       display_w = loader_data->stage1.display_w;
       display_h = loader_data->stage1.display_h;
       bench_value = loader_data->stage1.bench_value;
       magic_number = loader_data->stage1.magic_number;
 
-      stage1_clear_request (&(loader_data->stage1));
+      _stage1_clear_request (sys_context, &(loader_data->stage1));
     }
 
   /*
@@ -212,34 +204,30 @@ stage1 (_lw6tsk_loader_data_t * loader_data)
    */
   if (loader_data->stage1.seed)
     {
-      lw6sys_log (LW6SYS_LOG_INFO,
-		  _x_
-		  ("async load stage1 using gen, request_number %d, seed \"%s\""),
-		  request_number, loader_data->stage1.seed);
+      lw6sys_log (sys_context, LW6SYS_LOG_INFO, _x_ ("async load stage1 using gen, request_number %d, seed \"%s\""), request_number, loader_data->stage1.seed);
 
       (*(progress.value)) = _LW6TSK_LOADER_PROGRESS_STAGE1_BEGIN;
-      seed = lw6gen_seed_normalize (loader_data->stage1.seed);
+      seed = lw6gen_seed_normalize (sys_context, loader_data->stage1.seed);
       display_w = loader_data->stage1.display_w;
       display_h = loader_data->stage1.display_h;
       bench_value = loader_data->stage1.bench_value;
       magic_number = loader_data->stage1.magic_number;
 
-      stage1_clear_request (&(loader_data->stage1));
+      _stage1_clear_request (sys_context, &(loader_data->stage1));
     }
-  LOADER_UNLOCK;
+  _LOADER_UNLOCK (sys_context);
 
   if (map_path && relative_path)
     {
       progress.min = _LW6TSK_LOADER_PROGRESS_STAGE1_BEGIN_MAP;
       progress.max = _LW6TSK_LOADER_PROGRESS_STAGE1_END_MAP;
-      lw6sys_progress_begin (&progress);
+      lw6sys_progress_begin (sys_context, &progress);
       level =
-	lw6ldr_read_relative (map_path, relative_path, default_param,
-			      forced_param, display_w, display_h, bench_value,
-			      magic_number, loader_data->user_dir, &progress);
+	lw6ldr_read_relative (sys_context, map_path, relative_path, default_param,
+			      forced_param, display_w, display_h, bench_value, magic_number, loader_data->user_dir, &progress);
       if (level)
 	{
-	  lw6sys_progress_end (&progress);
+	  lw6sys_progress_end (sys_context, &progress);
 	}
     }
 
@@ -247,39 +235,38 @@ stage1 (_lw6tsk_loader_data_t * loader_data)
     {
       progress.min = _LW6TSK_LOADER_PROGRESS_STAGE1_BEGIN_MAP;
       progress.max = _LW6TSK_LOADER_PROGRESS_STAGE1_END_MAP;
-      lw6sys_progress_begin (&progress);
-      lw6ldr_resampler_use_for_gen (&map_w, &map_h, display_w, display_h,
-				    bench_value, magic_number);
-      level = lw6gen_create_from_seed (seed, map_w, map_h);
+      lw6sys_progress_begin (sys_context, &progress);
+      lw6ldr_resampler_use_for_gen (sys_context, &map_w, &map_h, display_w, display_h, bench_value, magic_number);
+      level = lw6gen_create_from_seed (sys_context, seed, map_w, map_h);
       if (level)
 	{
-	  lw6sys_progress_end (&progress);
+	  lw6sys_progress_end (sys_context, &progress);
 	}
     }
 
   if (map_path)
     {
-      LW6SYS_FREE (map_path);
+      LW6SYS_FREE (sys_context, map_path);
       map_path = NULL;
     }
   if (relative_path)
     {
-      LW6SYS_FREE (relative_path);
+      LW6SYS_FREE (sys_context, relative_path);
       relative_path = NULL;
     }
   if (default_param)
     {
-      lw6sys_assoc_free (default_param);
+      lw6sys_assoc_free (sys_context, default_param);
       default_param = NULL;
     }
   if (forced_param)
     {
-      lw6sys_assoc_free (forced_param);
+      lw6sys_assoc_free (sys_context, forced_param);
       forced_param = NULL;
     }
   if (seed)
     {
-      LW6SYS_FREE (seed);
+      LW6SYS_FREE (sys_context, seed);
       seed = NULL;
     }
 
@@ -287,50 +274,43 @@ stage1 (_lw6tsk_loader_data_t * loader_data)
     {
       char *repr = NULL;
 
-      repr = lw6map_repr (level);
+      repr = lw6map_repr (sys_context, level);
       if (repr)
 	{
 	  progress.min = _LW6TSK_LOADER_PROGRESS_STAGE1_BEGIN_DUP;
 	  progress.max = _LW6TSK_LOADER_PROGRESS_STAGE1_END_DUP;
-	  lw6sys_progress_begin (&progress);
-	  src2 = lw6map_dup (level, &progress);
-	  LOADER_LOCK;
+	  lw6sys_progress_begin (sys_context, &progress);
+	  src2 = lw6map_dup (sys_context, level, &progress);
+	  _LOADER_LOCK (sys_context);
 	  if (request_number == loader_data->request_number)
 	    {
-	      lw6sys_progress_end (&progress);
-	      stage1_clear_response (&(loader_data->stage1));
+	      lw6sys_progress_end (sys_context, &progress);
+	      _stage1_clear_response (sys_context, &(loader_data->stage1));
 	      loader_data->stage1.level = level;
-	      lw6sys_log (LW6SYS_LOG_INFO,
-			  _x_
-			  ("async load stage1 done, request_number %d, level \"%s\""),
-			  request_number, repr);
-	      stage2_clear_request (&(loader_data->stage2));
+	      lw6sys_log (sys_context, LW6SYS_LOG_INFO, _x_ ("async load stage1 done, request_number %d, level \"%s\""), request_number, repr);
+	      _stage2_clear_request (sys_context, &(loader_data->stage2));
 	      loader_data->stage2.src = src2;
 	      ok = 1;
 	    }
 	  else if (request_number < loader_data->request_number)
 	    {
-	      lw6sys_log (LW6SYS_LOG_INFO,
-			  _x_
-			  ("async load stage1 abort, request number %d < %d, level \"%s\""),
-			  request_number, loader_data->request_number, repr);
+	      lw6sys_log (sys_context, LW6SYS_LOG_INFO,
+			  _x_ ("async load stage1 abort, request number %d < %d, level \"%s\""), request_number, loader_data->request_number, repr);
 	      if (src2)
 		{
-		  lw6map_free (src2);
+		  lw6map_free (sys_context, src2);
 		  src2 = NULL;
 		}
-	      lw6map_free (level);
+	      lw6map_free (sys_context, level);
 	      level = NULL;
 	    }
 	  else
 	    {
-	      lw6sys_log (LW6SYS_LOG_WARNING,
-			  _x_
-			  ("async load stage1, inconsistent request number %d > %d, level \"%s\""),
-			  request_number, loader_data->request_number, repr);
+	      lw6sys_log (sys_context, LW6SYS_LOG_WARNING,
+			  _x_ ("async load stage1, inconsistent request number %d > %d, level \"%s\""), request_number, loader_data->request_number, repr);
 	    }
-	  LOADER_UNLOCK;
-	  LW6SYS_FREE (repr);
+	  _LOADER_UNLOCK (sys_context);
+	  LW6SYS_FREE (sys_context, repr);
 	  repr = NULL;
 	}
     }
@@ -341,7 +321,7 @@ stage1 (_lw6tsk_loader_data_t * loader_data)
 }
 
 static void
-stage2 (_lw6tsk_loader_data_t * loader_data)
+_stage2 (lw6sys_context_t * sys_context, _lw6tsk_loader_data_t * loader_data)
 {
   int request_number = 0;
   lw6map_level_t *level = NULL;
@@ -357,39 +337,37 @@ stage2 (_lw6tsk_loader_data_t * loader_data)
       progress.value = &dummy;
     }
 
-  LOADER_LOCK;
+  _LOADER_LOCK (sys_context);
   request_number = loader_data->request_number;
 
   if (loader_data->stage2.src)
     {
-      lw6sys_log (LW6SYS_LOG_INFO,
-		  _x_ ("async load stage2, request_number %d"),
-		  request_number);
+      lw6sys_log (sys_context, LW6SYS_LOG_INFO, _x_ ("async load stage2, request_number %d"), request_number);
       (*(progress.value)) = _LW6TSK_LOADER_PROGRESS_STAGE2_BEGIN;
 
       progress.min = _LW6TSK_LOADER_PROGRESS_STAGE2_BEGIN_MAP;
       progress.max = _LW6TSK_LOADER_PROGRESS_STAGE2_END_MAP;
-      lw6sys_progress_begin (&progress);
-      level = lw6map_dup (loader_data->stage2.src, &progress);
-      lw6sys_progress_end (&progress);
+      lw6sys_progress_begin (sys_context, &progress);
+      level = lw6map_dup (sys_context, loader_data->stage2.src, &progress);
+      lw6sys_progress_end (sys_context, &progress);
 
-      stage2_clear_request (&(loader_data->stage2));
+      _stage2_clear_request (sys_context, &(loader_data->stage2));
     }
-  LOADER_UNLOCK;
+  _LOADER_UNLOCK (sys_context);
 
   if (level)
     {
       progress.min = _LW6TSK_LOADER_PROGRESS_STAGE2_BEGIN_STRUCT;
       progress.max = _LW6TSK_LOADER_PROGRESS_STAGE2_END_STRUCT;
-      lw6sys_progress_begin (&progress);
-      game_struct = lw6ker_game_struct_new (level, &progress);
+      lw6sys_progress_begin (sys_context, &progress);
+      game_struct = lw6ker_game_struct_new (sys_context, level, &progress);
       if (game_struct)
 	{
-	  lw6sys_progress_end (&progress);
+	  lw6sys_progress_end (sys_context, &progress);
 	}
       else
 	{
-	  lw6map_free (level);
+	  lw6map_free (sys_context, level);
 	  level = NULL;
 	}
     }
@@ -397,17 +375,17 @@ stage2 (_lw6tsk_loader_data_t * loader_data)
     {
       progress.min = _LW6TSK_LOADER_PROGRESS_STAGE2_BEGIN_STATE;
       progress.max = _LW6TSK_LOADER_PROGRESS_STAGE2_END_STATE;
-      lw6sys_progress_begin (&progress);
-      game_state = lw6ker_game_state_new (game_struct, &progress);
+      lw6sys_progress_begin (sys_context, &progress);
+      game_state = lw6ker_game_state_new (sys_context, game_struct, &progress);
       if (game_state)
 	{
-	  lw6sys_progress_end (&progress);
+	  lw6sys_progress_end (sys_context, &progress);
 	}
       else
 	{
-	  lw6ker_game_struct_free (game_struct);
+	  lw6ker_game_struct_free (sys_context, game_struct);
 	  game_struct = NULL;
-	  lw6map_free (level);
+	  lw6map_free (sys_context, level);
 	  level = NULL;
 	}
     }
@@ -416,45 +394,39 @@ stage2 (_lw6tsk_loader_data_t * loader_data)
     {
       char *repr = NULL;
 
-      repr = lw6ker_game_state_repr (game_state);
+      repr = lw6ker_game_state_repr (sys_context, game_state);
       if (repr)
 	{
-	  LOADER_LOCK;
+	  _LOADER_LOCK (sys_context);
 	  if (request_number == loader_data->request_number)
 	    {
-	      stage1_clear_response (&(loader_data->stage1));
-	      stage2_clear_response (&(loader_data->stage2));
+	      _stage1_clear_response (sys_context, &(loader_data->stage1));
+	      _stage2_clear_response (sys_context, &(loader_data->stage2));
 	      loader_data->stage2.level = level;
 	      loader_data->stage2.game_struct = game_struct;
 	      loader_data->stage2.game_state = game_state;
-	      lw6sys_log (LW6SYS_LOG_INFO,
-			  _x_
-			  ("async load stage2 done, request_number %d, game_state \"%s\""),
-			  request_number, repr);
+	      lw6sys_log (sys_context, LW6SYS_LOG_INFO, _x_ ("async load stage2 done, request_number %d, game_state \"%s\""), request_number, repr);
 	      ok = 1;
 	    }
 	  else if (request_number < loader_data->request_number)
 	    {
-	      lw6sys_log (LW6SYS_LOG_INFO,
-			  _x_
-			  ("async load stage2 abort, request number %d < %d, game_state \"%s\""),
-			  request_number, loader_data->request_number, repr);
-	      lw6ker_game_state_free (game_state);
+	      lw6sys_log (sys_context, LW6SYS_LOG_INFO,
+			  _x_ ("async load stage2 abort, request number %d < %d, game_state \"%s\""), request_number, loader_data->request_number, repr);
+	      lw6ker_game_state_free (sys_context, game_state);
 	      game_state = NULL;
-	      lw6ker_game_struct_free (game_struct);
+	      lw6ker_game_struct_free (sys_context, game_struct);
 	      game_struct = NULL;
-	      lw6map_free (level);
+	      lw6map_free (sys_context, level);
 	      level = NULL;
 	    }
 	  else
 	    {
-	      lw6sys_log (LW6SYS_LOG_WARNING,
+	      lw6sys_log (sys_context, LW6SYS_LOG_WARNING,
 			  _x_
-			  ("async load stage2, inconsistent request number %d > %d, game_state \"%s\""),
-			  request_number, loader_data->request_number, repr);
+			  ("async load stage2, inconsistent request number %d > %d, game_state \"%s\""), request_number, loader_data->request_number, repr);
 	    }
-	  LOADER_UNLOCK;
-	  LW6SYS_FREE (repr);
+	  _LOADER_UNLOCK (sys_context);
+	  LW6SYS_FREE (sys_context, repr);
 	  repr = NULL;
 	}
     }
@@ -465,18 +437,19 @@ stage2 (_lw6tsk_loader_data_t * loader_data)
 }
 
 void
-_lw6tsk_loader_poll (_lw6tsk_loader_data_t * loader_data)
+_lw6tsk_loader_poll (lw6sys_context_t * sys_context, _lw6tsk_loader_data_t * loader_data)
 {
   loader_data->stage = 1;
-  stage1 (loader_data);
+  _stage1 (sys_context, loader_data);
   loader_data->stage = 2;
-  stage2 (loader_data);
+  _stage2 (sys_context, loader_data);
   loader_data->stage = 0;
 }
 
 /**
  * lw6tsk_loader_push_ldr
  *
+ * @sys_context: global system context
  * @loader: loader object
  * @map_path: map-path config entry
  * @relative_path: relative map path
@@ -494,38 +467,35 @@ _lw6tsk_loader_poll (_lw6tsk_loader_data_t * loader_data)
  * Return value: none.
  */
 void
-lw6tsk_loader_push_ldr (lw6tsk_loader_t * loader, const char *map_path,
+lw6tsk_loader_push_ldr (lw6sys_context_t * sys_context, lw6tsk_loader_t * loader, const char *map_path,
 			const char *relative_path,
-			lw6sys_assoc_t * default_param,
-			lw6sys_assoc_t * forced_param, int display_w,
-			int display_h, int bench_value, int magic_number)
+			lw6sys_assoc_t * default_param, lw6sys_assoc_t * forced_param, int display_w, int display_h, int bench_value, int magic_number)
 {
   _lw6tsk_loader_data_t *loader_data;
 
   loader_data = (_lw6tsk_loader_data_t *) loader->data;
 
-  LOADER_LOCK;
+  _LOADER_LOCK (sys_context);
 
   loader_data->request_number++;
-  clear (loader_data);
-  loader_data->stage1.map_path = lw6sys_str_copy (map_path);
-  loader_data->stage1.relative_path = lw6sys_str_copy (relative_path);
-  loader_data->stage1.default_param =
-    lw6sys_assoc_dup (default_param, (lw6sys_dup_func_t) lw6sys_str_copy);
-  loader_data->stage1.forced_param =
-    lw6sys_assoc_dup (forced_param, (lw6sys_dup_func_t) lw6sys_str_copy);
+  _clear (sys_context, loader_data);
+  loader_data->stage1.map_path = lw6sys_str_copy (sys_context, map_path);
+  loader_data->stage1.relative_path = lw6sys_str_copy (sys_context, relative_path);
+  loader_data->stage1.default_param = lw6sys_assoc_dup (sys_context, default_param, (lw6sys_dup_func_t) lw6sys_str_copy);
+  loader_data->stage1.forced_param = lw6sys_assoc_dup (sys_context, forced_param, (lw6sys_dup_func_t) lw6sys_str_copy);
   loader_data->stage1.seed = NULL;
   loader_data->stage1.display_w = display_w;
   loader_data->stage1.display_h = display_h;
   loader_data->stage1.bench_value = bench_value;
   loader_data->stage1.magic_number = magic_number;
 
-  LOADER_UNLOCK;
+  _LOADER_UNLOCK (sys_context);
 }
 
 /**
  * lw6tsk_loader_push_gen
  *
+ * @sys_context: global system context
  * @loader: loader object
  * @seed: seed string used to create the map
  * @display_w: display width
@@ -540,34 +510,34 @@ lw6tsk_loader_push_ldr (lw6tsk_loader_t * loader, const char *map_path,
  * Return value: none.
  */
 void
-lw6tsk_loader_push_gen (lw6tsk_loader_t * loader, const char *seed,
-			int display_w, int display_h, int bench_value,
+lw6tsk_loader_push_gen (lw6sys_context_t * sys_context, lw6tsk_loader_t * loader, const char *seed, int display_w, int display_h, int bench_value,
 			int magic_number)
 {
   _lw6tsk_loader_data_t *loader_data;
 
   loader_data = (_lw6tsk_loader_data_t *) loader->data;
 
-  LOADER_LOCK;
+  _LOADER_LOCK (sys_context);
 
   loader_data->request_number++;
-  clear (loader_data);
+  _clear (sys_context, loader_data);
   loader_data->stage1.map_path = NULL;
   loader_data->stage1.relative_path = NULL;
   loader_data->stage1.default_param = NULL;
   loader_data->stage1.forced_param = NULL;
-  loader_data->stage1.seed = lw6gen_seed_normalize (seed);
+  loader_data->stage1.seed = lw6gen_seed_normalize (sys_context, seed);
   loader_data->stage1.display_w = display_w;
   loader_data->stage1.display_h = display_h;
   loader_data->stage1.bench_value = bench_value;
   loader_data->stage1.magic_number = magic_number;
 
-  LOADER_UNLOCK;
+  _LOADER_UNLOCK (sys_context);
 }
 
 /**
  * lw6tsk_loader_pop
  *
+ * @sys_context: global system context
  * @level: loaded level (out param)
  * @game_struct: loaded struct (out param)
  * @game_state: loaded state (out param)
@@ -583,9 +553,7 @@ lw6tsk_loader_push_gen (lw6tsk_loader_t * loader, const char *seed,
  * Return value: 1 if some data, 0 if none.
  */
 int
-lw6tsk_loader_pop (lw6map_level_t ** level,
-		   lw6ker_game_struct_t ** game_struct,
-		   lw6ker_game_state_t ** game_state,
+lw6tsk_loader_pop (lw6sys_context_t * sys_context, lw6map_level_t ** level, lw6ker_game_struct_t ** game_struct, lw6ker_game_state_t ** game_state,
 		   int *bench_value, lw6tsk_loader_t * loader)
 {
   int ret = 0;
@@ -593,7 +561,7 @@ lw6tsk_loader_pop (lw6map_level_t ** level,
 
   loader_data = (_lw6tsk_loader_data_t *) loader->data;
 
-  LOADER_LOCK;
+  _LOADER_LOCK (sys_context);
 
   if (level)
     {
@@ -623,8 +591,7 @@ lw6tsk_loader_pop (lw6map_level_t ** level,
     }
   if (level && game_struct && game_state)
     {
-      if (loader_data->stage2.level && loader_data->stage2.game_struct
-	  && loader_data->stage2.game_state && (!(*level)))
+      if (loader_data->stage2.level && loader_data->stage2.game_struct && loader_data->stage2.game_state && (!(*level)))
 	{
 	  (*level) = loader_data->stage2.level;
 	  (*game_struct) = loader_data->stage2.game_struct;
@@ -640,7 +607,7 @@ lw6tsk_loader_pop (lw6map_level_t ** level,
 	}
     }
 
-  LOADER_UNLOCK;
+  _LOADER_UNLOCK (sys_context);
 
   return ret;
 }
@@ -656,26 +623,26 @@ lw6tsk_loader_pop (lw6map_level_t ** level,
 static volatile u_int32_t seq_id = 0;
 
 static void
-loader_data_free (_lw6tsk_loader_data_t * loader_data)
+_loader_data_free (lw6sys_context_t * sys_context, _lw6tsk_loader_data_t * loader_data)
 {
   if (loader_data->mutex)
     {
-      LOADER_LOCK;
+      _LOADER_LOCK (sys_context);
 
-      clear (loader_data);
+      _clear (sys_context, loader_data);
 
-      LOADER_UNLOCK;
-      lw6sys_mutex_destroy (loader_data->mutex);
+      _LOADER_UNLOCK (sys_context);
+      LW6SYS_MUTEX_DESTROY (sys_context, loader_data->mutex);
     }
   if (loader_data->user_dir)
     {
-      LW6SYS_FREE (loader_data->user_dir);
+      LW6SYS_FREE (sys_context, loader_data->user_dir);
     }
-  LW6SYS_FREE (loader_data);
+  LW6SYS_FREE (sys_context, loader_data);
 }
 
 static void
-loader_callback (void *data)
+_loader_callback (lw6sys_context_t * sys_context, void *data)
 {
   _lw6tsk_loader_data_t *loader_data;
 
@@ -683,24 +650,25 @@ loader_callback (void *data)
 
   while (!loader_data->stop)
     {
-      _lw6tsk_loader_poll (loader_data);
-      lw6sys_sleep (loader_data->sleep);
+      _lw6tsk_loader_poll (sys_context, loader_data);
+      lw6sys_sleep (sys_context, loader_data->sleep);
     }
 }
 
 static void
-loader_join (void *data)
+_loader_join (lw6sys_context_t * sys_context, void *data)
 {
   _lw6tsk_loader_data_t *loader_data;
 
   loader_data = (_lw6tsk_loader_data_t *) data;
 
-  loader_data_free (loader_data);
+  _loader_data_free (sys_context, loader_data);
 }
 
 /**
  * lw6tsk_loader_new
  *
+ * @sys_context: global system context
  * @sleep: how many seconds to wait between every poll
  * @user_dir: user directory
  * @progress: progress indicator to use
@@ -713,12 +681,12 @@ loader_join (void *data)
  * Return value: a pointer to the loader, NULL if failed.
  */
 lw6tsk_loader_t *
-lw6tsk_loader_new (float sleep, char *user_dir, volatile float *progress)
+lw6tsk_loader_new (lw6sys_context_t * sys_context, float sleep, char *user_dir, volatile float *progress)
 {
   lw6tsk_loader_t *loader = NULL;
   _lw6tsk_loader_data_t *loader_data = NULL;
 
-  loader = (lw6tsk_loader_t *) LW6SYS_CALLOC (sizeof (lw6tsk_loader_t));
+  loader = (lw6tsk_loader_t *) LW6SYS_CALLOC (sys_context, sizeof (lw6tsk_loader_t));
   if (loader)
     {
       loader->id = 0;
@@ -726,53 +694,44 @@ lw6tsk_loader_new (float sleep, char *user_dir, volatile float *progress)
 	{
 	  loader->id = ++seq_id;
 	}
-      loader_data =
-	(_lw6tsk_loader_data_t *)
-	LW6SYS_CALLOC (sizeof (_lw6tsk_loader_data_t));
+      loader_data = (_lw6tsk_loader_data_t *) LW6SYS_CALLOC (sys_context, sizeof (_lw6tsk_loader_data_t));
       loader->data = loader_data;
       if (loader->data)
 	{
 	  loader_data->sleep = sleep;
-	  loader_data->user_dir = lw6sys_str_copy (user_dir);
+	  loader_data->user_dir = lw6sys_str_copy (sys_context, user_dir);
 	  loader_data->progress = progress;
-	  loader_data->mutex = lw6sys_mutex_create ();
+	  loader_data->mutex = LW6SYS_MUTEX_CREATE (sys_context);
 	  if (loader_data->mutex)
 	    {
-	      loader->thread =
-		lw6sys_thread_create (loader_callback, loader_join,
-				      loader->data);
+	      loader->thread = lw6sys_thread_create (sys_context, _loader_callback, _loader_join, loader->data);
 	    }
 	  else
 	    {
-	      lw6sys_log (LW6SYS_LOG_WARNING,
-			  _x_ ("unable to create mutex for loader"));
+	      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("unable to create mutex for loader"));
 	    }
 	}
       else
 	{
-	  lw6sys_log (LW6SYS_LOG_WARNING,
-		      _x_ ("unable to allocate memory for loader data"));
+	  lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("unable to allocate memory for loader data"));
 	}
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING,
-		  _x_ ("unable to allocate memory for loader"));
+      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("unable to allocate memory for loader"));
     }
 
-  if (loader
-      && (!loader->thread || !loader->data
-	  || (loader_data && !loader_data->user_dir)))
+  if (loader && (!loader->thread || !loader->data || (loader_data && !loader_data->user_dir)))
     {
       if (loader->thread)
 	{
-	  lw6sys_thread_join (loader->thread);
+	  lw6sys_thread_join (sys_context, loader->thread);
 	}
       if (loader_data)
 	{
-	  loader_data_free (loader_data);
+	  _loader_data_free (sys_context, loader_data);
 	}
-      LW6SYS_FREE (loader);
+      LW6SYS_FREE (sys_context, loader);
       loader = NULL;
     }
 
@@ -782,6 +741,7 @@ lw6tsk_loader_new (float sleep, char *user_dir, volatile float *progress)
 /**
  * lw6tsk_loader_free
  *
+ * @sys_context: global system context
  * @loader: the loader to free.
  *
  * Deletes a loader. Will automatically stop the child thread,
@@ -790,20 +750,21 @@ lw6tsk_loader_new (float sleep, char *user_dir, volatile float *progress)
  * Return value: none.
  */
 void
-lw6tsk_loader_free (lw6tsk_loader_t * loader)
+lw6tsk_loader_free (lw6sys_context_t * sys_context, lw6tsk_loader_t * loader)
 {
   _lw6tsk_loader_data_t *loader_data;
 
   loader_data = (_lw6tsk_loader_data_t *) loader->data;
   loader_data->stop = 1;
-  lw6sys_thread_join (loader->thread);
+  lw6sys_thread_join (sys_context, loader->thread);
   // no need to free loader_data, done by join
-  LW6SYS_FREE (loader);
+  LW6SYS_FREE (sys_context, loader);
 }
 
 /**
  * lw6tsk_loader_repr
  *
+ * @sys_context: global system context
  * @loader: the loader to represent.
  *
  * Creates a string which briefly describes the loader.
@@ -811,7 +772,7 @@ lw6tsk_loader_free (lw6tsk_loader_t * loader)
  * Return value: a dynamically allocated pointer, must be freed.
  */
 char *
-lw6tsk_loader_repr (const lw6tsk_loader_t * loader)
+lw6tsk_loader_repr (lw6sys_context_t * sys_context, const lw6tsk_loader_t * loader)
 {
   char *ret = NULL;
   _lw6tsk_loader_data_t *loader_data;
@@ -825,15 +786,12 @@ lw6tsk_loader_repr (const lw6tsk_loader_t * loader)
 	  progress = *(loader_data->progress);
 	}
       ret =
-	lw6sys_new_sprintf (_x_
-			    ("%u request_number=%d stage=%d progress=%0.2f"),
-			    loader->id, loader_data->request_number,
-			    loader_data->stage, progress);
+	lw6sys_new_sprintf (sys_context, _x_ ("%u request_number=%d stage=%d progress=%0.2f"), loader->id, loader_data->request_number, loader_data->stage,
+			    progress);
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING,
-		  _x_ ("can't generate string id for NULL loader"));
+      lw6sys_log (sys_context, LW6SYS_LOG_WARNING, _x_ ("can't generate string id for NULL loader"));
     }
 
   return ret;
@@ -842,6 +800,7 @@ lw6tsk_loader_repr (const lw6tsk_loader_t * loader)
 /**
  * lw6tsk_loader_get_stage
  *
+ * @sys_context: global system context
  * @loader: the loader to query.
  *
  * Returns the current stage of the loader.
@@ -850,7 +809,7 @@ lw6tsk_loader_repr (const lw6tsk_loader_t * loader)
  *               dynamic stuff such as game_state.
  */
 int
-lw6tsk_loader_get_stage (lw6tsk_loader_t * loader)
+lw6tsk_loader_get_stage (lw6sys_context_t * sys_context, lw6tsk_loader_t * loader)
 {
   int ret = 0;
   _lw6tsk_loader_data_t *loader_data;
