@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -49,29 +49,22 @@ typedef struct lw6tsk_loader_s
 lw6tsk_loader_t;
 
 /* tsk-loader.c */
-extern void lw6tsk_loader_push_ldr (lw6tsk_loader_t * loader,
+extern void lw6tsk_loader_push_ldr (lw6sys_context_t * sys_context, lw6tsk_loader_t * loader,
 				    const char *map_path,
 				    const char *relative_path,
 				    lw6sys_assoc_t * default_param,
-				    lw6sys_assoc_t * forced_param,
-				    int display_w, int display_h,
-				    int bench_value, int magic_number);
-extern void lw6tsk_loader_push_gen (lw6tsk_loader_t * loader,
-				    const char *seed, int display_w,
-				    int display_h, int bench_value,
+				    lw6sys_assoc_t * forced_param, int display_w, int display_h, int bench_value, int magic_number);
+extern void lw6tsk_loader_push_gen (lw6sys_context_t * sys_context, lw6tsk_loader_t * loader, const char *seed, int display_w, int display_h, int bench_value,
 				    int magic_number);
-extern int lw6tsk_loader_pop (lw6map_level_t ** level,
-			      lw6ker_game_struct_t ** game_struct,
-			      lw6ker_game_state_t ** game_state,
+extern int lw6tsk_loader_pop (lw6sys_context_t * sys_context, lw6map_level_t ** level, lw6ker_game_struct_t ** game_struct, lw6ker_game_state_t ** game_state,
 			      int *bench_value, lw6tsk_loader_t * loader);
-extern lw6tsk_loader_t *lw6tsk_loader_new (float sleep, char *user_dir,
-					   volatile float *progress);
-extern void lw6tsk_loader_free (lw6tsk_loader_t * loader);
-extern char *lw6tsk_loader_repr (const lw6tsk_loader_t * loader);
-extern int lw6tsk_loader_get_stage (lw6tsk_loader_t * loader);
+extern lw6tsk_loader_t *lw6tsk_loader_new (lw6sys_context_t * sys_context, float sleep, char *user_dir, volatile float *progress);
+extern void lw6tsk_loader_free (lw6sys_context_t * sys_context, lw6tsk_loader_t * loader);
+extern char *lw6tsk_loader_repr (lw6sys_context_t * sys_context, const lw6tsk_loader_t * loader);
+extern int lw6tsk_loader_get_stage (lw6sys_context_t * sys_context, lw6tsk_loader_t * loader);
 
 /* tsk-test.c */
-extern int lw6tsk_test_register (int mode);
-extern int lw6tsk_test_run (int mode);
+extern int lw6tsk_test_register (lw6sys_context_t * sys_context, int mode);
+extern int lw6tsk_test_run (lw6sys_context_t * sys_context, int mode);
 
 #endif
