@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -32,8 +32,7 @@ typedef struct _lw6vox_renderer_s
 } _lw6vox_renderer_t;
 
 /* vox-renderer.c */
-extern _lw6vox_renderer_t *_lw6vox_renderer_new (lw6ker_game_state_t *
-						 game_state);
-extern void _lw6vox_renderer_free (_lw6vox_renderer_t * renderer);
+extern _lw6vox_renderer_t *_lw6vox_renderer_new (lw6sys_context_t * sys_context, lw6ker_game_state_t * game_state);
+extern void _lw6vox_renderer_free (lw6sys_context_t * sys_context, _lw6vox_renderer_t * renderer);
 
 #endif
